@@ -22,8 +22,8 @@
 ("activation" "aktivering")
 ("acute" "naar rechts")
 ("add package" "gebruik pakket")
-("add switch after" "voeg 'switch hierna' in")
-("add switch before" "voeg 'switch hiervoor' in")
+("add switch after" "voeg 'schakelaar hierna' in")
+("add switch before" "voeg 'schakelaar hiervoor' in")
 ("address" "adres")
 ("address block" "adres blok")
 ("advanced" "geavanceerd")
@@ -56,11 +56,13 @@
 ("alignment" "plaatsing")
 ("all" "alles")
 ("allow" "sta toe")
+("allow for macro definitions in preamble" "sta macro definities in preambule toe")
 ("allowed extension" "toegestane verlenging")
 ("allowed reduction" "toegestane reduktie")
 ("alpha release" "alpha versie")
 ("alt key" "alt toets")
 ("alternative specification" "alternatieve specificatie")
+("always" "altijd")
 ("american" "amerikaans")
 ("and" "en")
 ("angular" "hoekig")
@@ -70,11 +72,14 @@
 ("apply macro once" "gebruik macro eenmalig")
 ("april" "april")
 ("arab" "arabisch")
+("arc cosine" "boogcosinus")
+("arc sine" "boogsinus")
+("arc tangent" "boogtangens")
 ("arch series" "arch reeks")
 ("archaic" "archaisch")
 ("architecture" "opzet")
 ("argument" "argument")
-("arithmetic" "arithmetisch")
+("arithmetic" "arithmetiek")
 ("armenian" "armeens")
 ("arrow" "pijl")
 ("arrows" "pijlen")
@@ -110,6 +115,7 @@
 ("bar" "streep")
 ("bard" "bardisch")
 ("base level" "basisniveau")
+("baseline" "richtlijn")
 ("bashkirian" "bashkirisch")
 ("basic" "basis")
 ("basic communication using pipes" "elementaire kommunicatie over pijpen")
@@ -135,6 +141,9 @@
 ("blackboard bold" "schoolbord vet")
 ("blackboard math" "schoolbord wiskunde")
 ("blackletter" "zwarte letter")
+("blank column" "lege kolom")
+("blank row" "lege rij")
+("block content" "blokinhoud")
 ("blue" "blauw")
 ("body" "lichaam")
 ("bold" "vet")
@@ -163,10 +172,12 @@
 ("bulgarian" "bulgaars")
 ("bullet" "rondje")
 ("bullets" "rondjes")
+("busy" "bezig")
 ("by" "door")
 ("by typing" "ook verkrijgen via de toetsenkombinatie")
 ("bytes free" "bytes vrij")
 ("bytes used" "bytes gebruikt")
+("calculus" "differentiaalrekening")
 ("calligraphic" "kaligrafisch")
 ("cancel" "annuleer")
 ("caps-lock key" "caps-lock toets")
@@ -174,10 +185,11 @@
 ("cell" "cel")
 ("cell background color" "achtergrondkleur cel")
 ("cell border" "rand cel")
-("cell height" "hoogte cel")
+("cell height" "hoogte van de cel")
 ("cell operation mode" "celmode")
-("cell width" "breedte cel")
-("center" "in het midden")
+("cell width" "breedte van de cel")
+("cells" "cellen")
+("center" "midden")
 ("center text" "centreer tekst")
 ("centered" "gecentreerd")
 ("centered block" "gencetreerd blok")
@@ -185,6 +197,7 @@
 ("change border of cell" "verander celrand")
 ("change cell operation mode" "verander celmode")
 ("change log" "opgave van veranderingen")
+("change the border of the table" "verander de rand van de tabel")
 ("changes" "veranderingen")
 ("chapter" "hoofdstuk")
 ("check" "check")
@@ -195,7 +208,7 @@
 ("cite" "citeer")
 ("class" "klasse")
 ("clear" "wis")
-("clear selection" "wis selectie")
+("clear selection" "wis selektie")
 ("clipped" "afgeknot")
 ("clipped and magnified" "afgeknot en uitvergroot")
 ("clipped and resized" "afgeknot en uitgerekt")
@@ -204,6 +217,7 @@
 ("close" "sluit af")
 ("close TeXmacs" "sluit TeXmacs")
 ("close buffer" "sluit buffer")
+("close document" "sluit dokument")
 ("close session" "sluit sessie")
 ("close window" "sluit venster")
 ("closing" "afsluiting")
@@ -212,6 +226,9 @@
 ("color" "kleur")
 ("column" "kolom")
 ("column contains glued items" "kolom bevat aan elkaar gelijmde delen")
+("column to the left" "kolom naar links")
+("column to the right" "kolom naar rechts")
+("columns" "kolommen")
 ("common formats" "algemene formaten")
 ("compact" "kompakt")
 ("compactification" "kompaktheid")
@@ -232,18 +249,23 @@
 ("content tag" "inhoudweergave")
 ("context dependent icons" "context afhankelijke iconen")
 ("continuation of" "vervolg van")
+("contract logarithms" "logarithmes inkrimpen")
 ("contribute" "doe mee")
-("control the evaluation of expressions" "kontroleer de uitvoering van expressies")
+("control the evaluation of expressions" "kontroleer de evaluatie van expressies")
 ("convention" "conventie")
+("converters" "uitwisselaars")
 ("converters to other data formats" "uitwisselaars met andere formaten")
+("cosine" "cosinus")
 ("copy" "kopier")
 ("copy text" "kopier tekst")
 ("copy to" "kopier naar")
 ("copying" "copiren")
 ("corollary" "gevolg")
 ("correct text" "korrigeer tekst")
+("create a new document" "begin met een nieuw dokument")
 ("create web site" "website creren")
 ("cursors" "cursor")
+("curve" "kromme")
 ("custom tab" "gepersonnaliseerde tabulering")
 ("customizing TeXmacs" "personaliseer TeXmacs")
 ("customizing the TeXmacs styles" "personaliseer de TeXmacs stijlen")
@@ -266,7 +288,10 @@
 ("date" "datum")
 ("deactivate" "deaktiveer")
 ("deactivate table" "deaktiveer tabel")
+("dead" "dood")
 ("december" "december")
+("decimal comma" "decimale komma")
+("decimal dot" "decimale punt")
 ("decorate atoms" "versier atomen")
 ("default" "vooringesteld")
 ("default padding" "gebruik standaard ruimte")
@@ -279,9 +304,12 @@
 ("destination" "bestemming")
 ("detach" "ontkoppel")
 ("detailed" "gedetailleerd")
+("detailed menus" "gedetailleerde menus")
+("details in menus" "details in de menus")
 ("determinant" "determinant")
 ("devangari" "devangarisch")
 ("developers guide" "gids voor ontwikkelaars")
+("differentiate" "afgeleide")
 ("directory" "dossier")
 ("disable" "uit")
 ("disable first indentation" "begin inspringen uit")
@@ -311,12 +339,15 @@
 ("down" "omlaag")
 ("download" "haal van web")
 ("dpi" "punten per duim")
+("draw image" "teken plaatje")
+("draw over selection" "teken over selektie")
 ("duplicate" "dubbel")
 ("dutch" "nederlands")
 ("dynamic libraries" "dynamische bibliotheken")
 ("edit" "bewerken")
 ("edit source tree" "bewerk de boomstruktuur")
 ("editing tools" "bewerkingsgereedschap")
+("eigenvalues" "eigenwaarden")
 ("email" "email")
 ("emphasize" "benadruk")
 ("emphasize text" "benadruk tekst")
@@ -330,9 +361,12 @@
 ("enable last indentation" "eind inspringen aan")
 ("enable last indentation after" "eind inspringen aan hierna")
 ("enable last indentation before" "eind inspringen aan hiervoor")
+("encoding" "codering")
 ("end" "einde")
 ("english" "engels")
 ("enter a title" "geef een titel op")
+("enter data" "gegevens invoeren")
+("entire table" "hele tabel")
 ("enumerate" "nummeren")
 ("enumerate|Alpha" "Letters")
 ("enumerate|Roman" "Romeins")
@@ -348,8 +382,10 @@
 ("error" "fout")
 ("esperanto" "esperanto")
 ("etruscan" "etruskisch")
-("evaluate" "voer uit")
+("evaluate" "evalueer")
 ("evaluate scheme expression" "scheme expressie uitvoeren")
+("evaluation switch" "evaluatie schakelaar")
+("evaluation tag" "evaluatie veld")
 ("even page footer" "even pagina voet")
 ("even page header" "even pagina kop")
 ("even page margin" "even pagina rand")
@@ -369,13 +405,21 @@
 ("executive" "executief")
 ("exercise" "oefening")
 ("expand" "ontwikkel")
+("expand logarithms" "logarithmes uitbreiden")
+("expand trigonometric functions" "trigonometrische funkties uitbreiden")
+("expand unrecognized macros" "onbekende macros uitbreiden")
+("expand user-defined macros" "gebruikersmacros uitbreiden")
 ("explained" "met uitleg")
+("exponential" "exponentiele funktie")
 ("export" "exporteer")
 ("export as" "exporteer als")
+("export bibliographies as links" "bibliografin als verwijzingen exporteren")
+("export formulas as images" "formules exporteren als plaatjes")
 ("extend or normal" "'extend' of 'normal'")
 ("extern " "extern")
 ("extra" "extra")
 ("extract format" "haal formaat eruit")
+("factor" "ontbind")
 ("family" "familie")
 ("february" "februari")
 ("figure" "figuur")
@@ -432,6 +476,7 @@
 ("future changes" "toekomstige veranderingen")
 ("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs komt zonder enige vorm van juridische garantie")
 ("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs valt onder de ``GNU general public license''")
+("gcd" "ggd")
 ("general architecture of TeXmacs" "algemene opbouw van TeXmacs")
 ("general negation" "algemene ontkenning")
 ("general note" "algemene noot")
@@ -476,6 +521,7 @@
 ("home" "thuis")
 ("homepage" "thuispagina")
 ("horizontal" "horizontaal")
+("horizontal alignment" "horizontale plaatsing")
 ("horizontal cell alignment" "horizontale plaatsing in cel")
 ("horizontal ink separation" "horizontale inkt afstand")
 ("horizontal part" "horizontaal deel")
@@ -493,11 +539,13 @@
 ("hyphenation" "regelafbraak")
 ("icelandic" "ijslands")
 ("if" "als")
+("if hyphenated" "als afgebroken")
 ("image" "plaatje")
 ("image links" "verbonden plaatjes")
 ("implementation" "implementatie")
 ("import" "importeer")
 ("improving the current implementation" "de huidige implementatie verbeteren")
+("in popup windows" "in apparte vensters")
 ("inactive" "niet aktief")
 ("include" "opnemen")
 ("include a document" "een document opnemen")
@@ -636,7 +684,9 @@
 ("insert thick horizontal space" "voeg dikke horizontale spatie in")
 ("insert title" "voeg titel in")
 ("insert value" "voeg waarde in")
+("integrate" "integreer")
 ("interactive command" "interaktief kommando")
+("interactive questions" "interaktieve vragen")
 ("interfacing" "nieuwe interfaces")
 ("interfacing TeXmacs with other systems" "TeXmacs aan andere systemen koppelen")
 ("interjection" "tussenwerpsel")
@@ -645,7 +695,9 @@
 ("internationalization" "internationalisering")
 ("interparagraph space" "afstand tussen paragrafen")
 ("interrupt execution" "onderbreek executie")
+("interrupted" "onderbroken")
 ("introduction" "inleiding")
+("invert" "inverse")
 ("invisible" "onzichtbaar")
 ("invisible citation" "onzichtbare citatie")
 ("irish" "iers")
@@ -663,11 +715,12 @@
 ("june" "juni")
 ("justified" "uitgelijnd")
 ("justify text" "lijn tekst uit")
+("keep evaluated expressions" "gevalueerde expressies aanhouden")
 ("key" "toets")
 ("keyboard" "toetsenbord")
 ("keyboard equivalent" "via toetsenbord")
 ("keyboard modifiers" "toetsenbordwijzigingen")
-("keyboard shorthand" "toetsenbordafkorting")
+("keyboard shortcut" "toetsenbordafkorting")
 ("keymaps" "toetsenbord")
 ("keyword" "sleutelwoord")
 ("keywords" "sleutelwoorden")
@@ -686,6 +739,7 @@
 ("latex command" "latex kommando")
 ("latin" "latijns")
 ("layout" "indeling")
+("lcm" "kgv")
 ("left" "links")
 ("left arrow" "pijl naar links")
 ("left border" "linker rand")
@@ -715,6 +769,7 @@
 ("line" "lijn")
 ("line break" "breek lijn af")
 ("line stretch" "regel uitrekbaarheid")
+("linear algebra" "lineaire algebra")
 ("link" "verband")
 ("link image" "verbind plaatje")
 ("list" "lijst")
@@ -736,6 +791,8 @@
 ("load tex file" "laad tex bestand")
 ("load verbatim file" "laad verbatim bestand")
 ("loaded" "geladen")
+("logarithm" "logarithme")
+("logarithms" "logarithmes")
 ("long" "lang")
 ("look and feel" "gebruikersinterface")
 ("look up" "zoek op")
@@ -786,10 +843,15 @@
 ("mathematical input" "wiskundige invoer")
 ("mathematical typesetting" "wiskundige pagina-opmaak")
 ("mathematics" "wiskunde")
+("matrices" "matrices")
 ("matrix" "matrix")
 ("maximal" "maximaal")
+("maximal cell height" "maximale hoogte van de cel")
+("maximal cell width" "maximale breedte van de cel")
 ("maximal number of columns" "maximaal aantal kolommen")
 ("maximal number of rows" "maximaal aantal rijen")
+("maximal table height" "maximale hoogte van de tabel")
+("maximal table width" "maximale breedte van de tabel")
 ("maximum mode" "maximum mode")
 ("may" "mei")
 ("medium" "gewoon")
@@ -800,8 +862,12 @@
 ("meta key" "meta toets")
 ("middle" "midden")
 ("minimal" "minimaal")
+("minimal cell height" "minimale hoogte van de cel")
+("minimal cell width" "minimale breedte van de cel")
 ("minimal number of columns" "minimaal aantal kolommen")
 ("minimal number of rows" "minimaal aantal rijen")
+("minimal table height" "minimale hoogte van de tabel")
+("minimal table width" "minimale breedte van de tabel")
 ("minimum mode" "minimum mode")
 ("minus" "strepen")
 ("miscellaneous" "divers")
@@ -816,7 +882,7 @@
 ("modify table border" "rand tabel veranderen")
 ("modify table padding" "ruimte om tabel veranderen")
 ("mongolian" "mongools")
-("more information about GNU TeXmacs can be found in the help" "meer informatie over GNU TeXmacs kunt U vinden in het help")
+("more information about GNU TeXmacs can be found in the Help" "meer informatie over GNU TeXmacs kunt U vinden in het Help")
 ("mosaic" "mozaek")
 ("move down" "ga naar beneden")
 ("move object" "verplaats object")
@@ -829,9 +895,11 @@
 ("n-th root" "n-de machts wortel")
 ("name" "naam")
 ("negation" "ontkenning")
+("never" "nooit")
 ("new" "nieuw")
 ("new buffer" "nieuwe buffer")
 ("new column" "nieuwe kolom")
+("new document" "nieuw dokument")
 ("new double page" "nieuwe dubbele pagina")
 ("new double page before" "nieuwe dubbele pagina hiervoor")
 ("new item" "nieuw element")
@@ -896,6 +964,7 @@
 ("on columns" "per kolom")
 ("on entire table" "per hele tabel")
 ("on rows" "per rij")
+("on the footer" "op de statusbalk")
 ("one spelling error has been corrected" "n spelfout is gekorrigeerd")
 ("online documentation" "on-line documentatie")
 ("online help" "hulp van het web")
@@ -904,10 +973,11 @@
 ("open a new buffer" "open een nieuwe buffer")
 ("open new window" "nieuw venster openen")
 ("opening" "aanvang")
-("operation on named selection" "operatie op aan te geven selectie")
-("operation on primary selection" "operatie op hoofdselectie")
-("operation on secondary selection" "operatie op tweede selectie")
-("operation on ternary selection" "operatie op derde selectie")
+("operation mode" "operatiemode")
+("operation on named selection" "operatie op aan te geven selektie")
+("operation on primary selection" "operatie op hoofdselektie")
+("operation on secondary selection" "operatie op tweede selektie")
+("operation on ternary selection" "operatie op derde selektie")
 ("optical" "optisch")
 ("option" "optie")
 ("options" "opties")
@@ -946,6 +1016,8 @@
 ("paragraph" "paragraaf")
 ("paragraph mode" "paragraaf soort")
 ("paragraph width" "paragraaf breedte")
+("parametric curve" "geparametriseerde kromme")
+("parametric surface" "geparametriseerd oppervlak")
 ("part" "deel")
 ("past changes" "gemaakte veranderingen")
 ("paste" "plak")
@@ -970,6 +1042,7 @@
 ("plans for the future" "plannen voor de toekomst")
 ("please" "graag")
 ("please wait" "een ogenblik a.u.b.")
+("plot" "grafiek")
 ("plus" "plus")
 ("polish" "pools")
 ("porting TeXmacs to other platforms" "TeXmacs overzetten naar andere systemen")
@@ -1025,13 +1098,16 @@
 ("proportional typewriter" "proportionele schrijfmachine")
 ("proposition" "propositie")
 ("query replace" "tekst op gecontroleerde wijze vervangen")
+("question" "vraag")
 ("quit" "verlaat")
 ("quotation" "citaat")
 ("quote" "citeren")
 ("range" "deel")
+("rank" "rang")
 ("really close it" "echt sluiten")
 ("really huge" "echt enorm")
 ("really quit" "wilt u echt ophouden")
+("really tiny" "werkelijk miniem")
 ("recover autosave file" "herstel veiligheidsbestand")
 ("red" "rood")
 ("redo" "opnieuw")
@@ -1041,6 +1117,7 @@
 ("reduce margins" "randen verkleinen")
 ("reduce right margin by" "verklein rechter rand met")
 ("reduce top margin by" "verklein boven rand met")
+("reduce trigonometric functions" "trigonometrische funkties inkorten")
 ("reduction even page margin" "verkleining even pagina rand")
 ("reduction odd page margin" "verkleining oneven pagina rand")
 ("reduction page bottom margin" "verkleining pagina beneden rand")
@@ -1055,18 +1132,20 @@
 ("release" "versie")
 ("reload" "herlaad")
 ("remark" "opmerking")
+("remove" "verwijder")
 ("remove all output fields" "verwijder alle uitvoervelden")
 ("remove fields" "velden verwijderen")
 ("remove input field" "verwijder invoerveld")
 ("remove input field above" "verwijder invoerveld hierboven")
 ("remove number" "nummer verwijderen")
 ("remove package" "schrap pakket")
-("remove this switch" "switch verwijderen")
+("remove this switch" "schakelaar verwijderen")
 ("renumber this page" "hernummer deze pagina")
 ("repeat" "herhaal")
 ("repeat object" "herhaal object")
 ("replace" "vervang")
 ("replace by" "vervang door")
+("replace unrecognized styles" "vervang onbekende stijlen")
 ("replaced" "ik heb")
 ("replaced one occurrence" "ik heb n treffer vervangen")
 ("reset" "herzet")
@@ -1097,7 +1176,10 @@
 ("rotate backward" "terug draaien")
 ("rotate forward" "vooruit draaien")
 ("row" "rij")
+("row above" "rij naar boven")
+("row below" "rij naar beneden")
 ("row contains glued items" "rij bevat aan elkaar gelijmde delen")
+("rows" "rijen")
 ("runic" "runen")
 ("running author" "lopende auteur")
 ("running title" "lopende titel")
@@ -1143,8 +1225,8 @@
 ("select a foreground color" "selekteer een voorgrondkleur")
 ("select a language" "selekteer een taal")
 ("selected region" "geselecteerde streek")
-("selection" "selectie")
-("selections" "selecties")
+("selection" "selektie")
+("selections" "selekties")
 ("seminar" "voordracht")
 ("sending commands to TeXmacs" "kommandos naar TeXmacs zenden")
 ("separation between lines" "aftand tussen regels")
@@ -1189,8 +1271,14 @@
 ("show on screen" "zien op het scherm")
 ("shrinking factor" "krimpfaktor")
 ("signature" "handtekening")
+("simplify" "versimpel")
+("simplification" "versimpelen")
+("simplified evaluation of formulas" "versimpeld evalueren van formules")
+("simplified menus" "versimpelde menus")
+("sine" "sinus")
 ("size" "grootte")
 ("size limits" "limieten aan grootte")
+("size tag" "grootte")
 ("slanted" "scheef")
 ("sloppy" "slobberig")
 ("slovene" "sloveens")
@@ -1208,8 +1296,11 @@
 ("spanish" "spaans")
 ("special" "speciaal")
 ("special cell properties" "speciale celeigenschappen")
+("special functions" "speciale funkties")
+("special properties" "speciale eigenschappen")
 ("special table properties" "speciale tabeleigenschappen")
 ("specific" "specifiek")
+("specify the size of the table" "grootte van de tabel bepalen")
 ("spell" "spel")
 ("spell checking complete" "klaar met het doornemen van spelfouten")
 ("spelling error" "spelfout")
@@ -1243,31 +1334,36 @@
 ("subsection" "deelsectie")
 ("subsub" "onder onder")
 ("subsubsection" "deeldeelsectie")
+("subtable" "deeltabel")
 ("subtitle" "ondertitel")
 ("summary" "samenvatting")
 ("summary of the principal TeXmacs tags" "de voornaamste TeXmacs tags")
 ("superpose" "opeenstapelen")
 ("superposed" "opeengestapeld")
 ("superscript" "exponent")
+("surface" "oppervlak")
 ("swedish" "zweeds")
 ("swiss" "zwitsers")
-("switch" "switch")
-("switch to first" "switch naar eerste")
+("switch" "schakelaar")
+("switch to first" "schakel naar eerste")
 ("switch to formula style" "gebruik formule stijl")
-("switch to last" "switch naar laatste")
-("switch to next" "switch naar volgende")
-("switch to previous" "switch naar vorige")
-("switching and folding" "switchen en vouwen")
+("switch to last" "schakel naar laatste")
+("switch to next" "schakel naar volgende")
+("switch to previous" "schakel naar vorige")
+("switching and folding" "schakelen en vouwen")
 ("symbol" "symbool")
 ("system command" "systeem kommando")
 ("system environment variables" "primitieve omgevingsvariabelen")
 ("tab" "tabulering")
 ("table" "tabel")
 ("table command" "tabel kommando")
+("table height" "hoogte van tabel")
 ("table of contents" "inhoudsopgave")
+("table width" "breedte van tabel")
 ("tables" "tabellen")
 ("tabular" "tabuleer")
 ("tabular material" "tabellen")
+("tangent" "tangens")
 ("teXmacs as an interface" "TeXmacs als koppelprogramma")
 ("teXmacs fonts" "TeXmacs lettertypes")
 ("teXmacs notice" "dank aan TeXmacs")
@@ -1298,11 +1394,14 @@
 ("theorem" "stelling")
 ("there are unsaved files" "niet alle bestanden zijn bewaard")
 ("this buffer has not been saved" "deze buffer is niet bewaard")
+("this column" "deze kolom")
 ("this document has been produced using" "dit dokument is tot stand gekomen met behulp van")
 ("this line" "deze regel")
 ("this page" "deze pagina")
 ("this page footer" "voet voor deze pagina")
 ("this page header" "kop voor deze pagina")
+("this row" "deze rij")
+("thumbnails" "serie van plaatjes")
 ("tilda" "slangetje")
 ("tilde" "slangetje")
 ("times" "maal")
@@ -1322,7 +1421,11 @@
 ("top table border" "bovenrand tabel")
 ("top table padding" "ruimte bovenkant tabel")
 ("translate" "vertaak")
+("transpose" "transposeer")
 ("tree" "boom")
+("triangularize" "trianguleer")
+("trigonometric" "trigonometrisch")
+("trigonometry" "trigonometrie")
 ("tuple" "tupel")
 ("turkish" "turks")
 ("tutorial" "leerboek")
@@ -1349,6 +1452,7 @@
 ("update image links" "aktualiseer verbonden plaatjes")
 ("upper border" "bovenrand")
 ("upright" "rechtop")
+("use MathML" "gebruik MathML")
 ("use TeXmacs" "gebruik TeXmacs")
 ("use a black color" "gebruik zwarte kleur")
 ("use a blue color" "gebruik blauwe kleur")
@@ -1368,6 +1472,7 @@
 ("use blackboard bold font" "gebruik schoolbord letters")
 ("use bold font series" "gebruik vette letters")
 ("use calligraphical font" "gebruik kalligrafische letters")
+("use catcode definitions in preamble" "gebruik catcodes in preambule")
 ("use footnote font size" "gebruik erg kleine letters")
 ("use fraktur font" "gebruik Gotische letters")
 ("use huge font size" "gebruik enorm grote letters")
@@ -1406,6 +1511,7 @@
 ("verse" "vers")
 ("vertical" "vertikaal")
 ("vertical after" "vertikaal achteraan")
+("vertical alignment" "vertikale plaatsing")
 ("vertical before" "vertikaal vooraan")
 ("vertical cell alignment" "vertikale plaatsing in cel")
 ("vertical part" "vertikaal deel")
@@ -1439,6 +1545,7 @@
 ("window width" "venster breedte")
 ("windows key" "windows toets")
 ("with" "met")
+("wrap lines" "regels afbreken")
 ("write a macro" "schrijf een macro")
 ("write a name" "schrijf een naam")
 ("write bold mathematics" "schrijf vette wiskunde")
