@@ -56,11 +56,14 @@
 ("alignment" "alignement")
 ("all" "le tout")
 ("allow" "permettre")
+("allow for macro definitions in preamble" "permettre des dfinitions de macros
+dans le prambule")
 ("allowed extension" "extension permise")
 ("allowed reduction" "rduction permise")
 ("alpha release" "version alpha")
 ("alt key" "touche alt")
 ("alternative specification" "spcification alternative")
+("always" "toujours")
 ("american" "amricain")
 ("and" "et")
 ("angular" "angulaire")
@@ -70,6 +73,9 @@
 ("apply macro once" "appliquer macro une fois")
 ("april" "avril")
 ("arab" "arabe")
+("arc cosine" "arc cosinus")
+("arc sine" "arc sinus")
+("arc tangent" "arc tangente")
 ("arch series" "srie arch")
 ("archaic" "archaque")
 ("architecture" "architecture")
@@ -110,6 +116,7 @@
 ("bar" "barre")
 ("bard" "bard")
 ("base level" "niveau infrieur")
+("baseline" "ligne de base")
 ("bashkirian" "bashkirien")
 ("basic" "base")
 ("basic communication using pipes" "communication de base par tubes")
@@ -135,6 +142,9 @@
 ("blackboard bold" "tableau noir gras")
 ("blackboard math" "tableau noir math")
 ("blackletter" "lettre noir")
+("blank column" "colonne vide")
+("blank row" "ligne vide")
+("block content" "contenu de bloc")
 ("blue" "bleu")
 ("body" "corps")
 ("bold" "gras")
@@ -163,10 +173,12 @@
 ("bulgarian" "bulgare")
 ("bullet" "puce")
 ("bullets" "puces")
+("busy" "en cours")
 ("by" "par")
 ("by typing" "en tapant")
 ("bytes free" "octets de libre")
 ("bytes used" "octets utiliss")
+("calculus" "calcul diffrentiel")
 ("calligraphic" "calligraphique")
 ("cancel" "annuler")
 ("caps-lock key" "touche majuscules")
@@ -178,6 +190,7 @@
 ("cell height" "hauteur de la cellule")
 ("cell operation mode" "mode d'opration sur les cellules")
 ("cell width" "largeur de la cellule")
+("cells" "cellules")
 ("center" "centr")
 ("center text" "centrer le texte")
 ("centered" "centr")
@@ -186,6 +199,7 @@
 ("change border of cell" "changer bordure de la cellule")
 ("change cell operation mode" "changer mode d'opration")
 ("change log" "tous les changements")
+("change the border of the table" "changer la bordure du tableau")
 ("changes" "changements")
 ("chapter" "chapitre")
 ("check" "tchche")
@@ -205,6 +219,7 @@
 ("close" "fermer")
 ("close TeXmacs" "fermer TeXmacs")
 ("close buffer" "fermer tampon")
+("close document" "fermer document")
 ("close session" "fermer la session")
 ("close window" "fermer fentre")
 ("closing" "fermeture")
@@ -213,6 +228,9 @@
 ("color" "couleur")
 ("column" "colonne")
 ("column contains glued items" "la colonne contient des parties colles")
+("column to the left" "colonne vers la gauche")
+("column to the right" "colonne vers la droite")
+("columns" "colonnes")
 ("common formats" "formats courants")
 ("compact" "compact")
 ("compactification" "compactification")
@@ -233,18 +251,23 @@
 ("content tag" "balise")
 ("context dependent icons" "icnes dpendantes du contexte")
 ("continuation of" "continuation de")
+("contract logarithms" "contracter les logarithmes")
 ("contribute" "contribuer")
 ("control the evaluation of expressions" "contrler l'valuation des expressions")
 ("convention" "convention")
+("converters" "convertisseurs")
 ("converters to other data formats" "convertisseurs pour d'autres formats")
+("cosine" "cosinus")
 ("copy" "copier")
 ("copy text" "copier du texte")
 ("copy to" "copier vers")
 ("copying" "copier")
 ("corollary" "corollaire")
 ("correct text" "corrige texte")
+("create a new document" "crer un nouveau document")
 ("create web site" "cration d'un site web")
 ("cursors" "curseurs")
+("curve" "courbe")
 ("custom tab" "tabulation personnalis")
 ("customizing TeXmacs" "personnalisation")
 ("customizing the TeXmacs styles" "personnaliser les styles TeXmacs")
@@ -267,7 +290,10 @@
 ("date" "date")
 ("deactivate" "desactiver")
 ("deactivate table" "desactiver tableau")
+("dead" "mort")
 ("december" "dcembre")
+("decimal comma" "virgule dcimal")
+("decimal dot" "point dcimal")
 ("decorate atoms" "dcorations atomiques")
 ("default" "valeur par dfaut")
 ("default padding" "espacement par dfaut")
@@ -280,9 +306,12 @@
 ("destination" "destination")
 ("detach" "dtacher")
 ("detailed" "dtaill")
+("detailed menus" "menus dtaills")
+("details in menus" "dtails dans les menus")
 ("determinant" "dterminant")
 ("devangari" "dvangari")
 ("developers guide" "guide du dveloppeur")
+("differentiate" "driver")
 ("directory" "rpertoire")
 ("disable" "dsactiver")
 ("disable first indentation" "dsactiver premire indentation")
@@ -312,12 +341,18 @@
 ("down" "en bas")
 ("download" "tlcharger")
 ("dpi" "points par pouce")
+("draw image" "dessiner image")
+("draw over selection" "dessiner sur slection")
 ("duplicate" "en double")
 ("dutch" "nerlandais")
 ("dynamic libraries" "librairies dynamiques")
 ("edit" "diter")
 ("edit source tree" "diter l'arbre source")
 ("editing tools" "outils d'dition")
+("edition" "edition")
+("editor" "diteur")
+("editors" "diteurs")
+("eigenvalues" "valeurs propres")
 ("email" "email")
 ("emphasize" "mis en relief")
 ("emphasize text" "mettre en relief du texte")
@@ -332,9 +367,12 @@
 ("enable last indentation after" "activer dernire indentation aprs")
 ("enable last indentation before" "activer dernire indentation avant")
 ("encl" "inclus")
+("encoding" "encodage")
 ("end" "fin")
 ("english" "anglais")
 ("enter a title" "entrer un titre")
+("enter data" "entrer des donnes")
+("entire table" "tableau entier")
 ("enumerate" "numration")
 ("enumerate|Alpha" "Lettres")
 ("enumerate|Roman" "Romain")
@@ -352,6 +390,8 @@
 ("etruscan" "trusque")
 ("evaluate" "valuer")
 ("evaluate scheme expression" "valuer expression scheme")
+("evaluation switch" "commutateur d'valuation")
+("evaluation tag" "balise d'valuation")
 ("even page footer" "en bas pour pages paires")
 ("even page header" "en-tte pour pages paires")
 ("even page margin" "marge pour pages paires")
@@ -371,14 +411,22 @@
 ("executive" "excutif")
 ("exercise" "exercice")
 ("expand" "dvelopper")
+("expand logarithms" "dvelopper les logarithmes")
+("expand trigonometric functions" "dvelopper les fonctions trigonomtriques")
+("expand unrecognized macros" "dvelopper les macros non reconnus")
+("expand user-defined macros" "dvelopper les macros des utilisateurs")
 ("explained" "dtaill")
+("exponential" "exponentielle")
 ("export" "exporter")
 ("export as" "exporter en tant que")
+("export bibliographies as links" "exporter les bibliographies comme des liens")
+("export formulas as images" "exporter les formules comme des images")
 ("extend or normal" "'extend' ou 'normal'")
 ("extern " "externe")
 ("extra" "extra")
 ("extract format" "extraire format")
 ("extras" "extra")
+("factor" "factoriser")
 ("family" "famille")
 ("february" "fvrier")
 ("figure" "figure")
@@ -435,6 +483,7 @@
 ("future changes" "changements  venir")
 ("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs n'offre aucune garantie juridique")
 ("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs tombe sous la ``GNU general public license''")
+("gcd" "pgcd")
 ("general architecture of TeXmacs" "architecture gnrale de TeXmacs")
 ("general negation" "ngation gnrale")
 ("general note" "note gnrale")
@@ -479,6 +528,7 @@
 ("home" "racine")
 ("homepage" "page d'acceuil")
 ("horizontal" "horizontal")
+("horizontal alignment" "alignement horizontal")
 ("horizontal cell alignment" "alignement horizontal de la cellule")
 ("horizontal ink separation" "sparation d'encre horizontale")
 ("horizontal part" "partie horizontale")
@@ -496,11 +546,14 @@
 ("hyphenation" "csure")
 ("icelandic" "islandais")
 ("if" "si")
+("if hyphenated" "en mode csure")
 ("image" "image")
 ("image links" "images lis")
 ("implementation" "implantation")
 ("import" "importer")
 ("improving the current implementation" "amlioration de l'implantation prsente")
+("in" "dans")
+("in popup windows" "dans des fentres  part")
 ("inactive" "inactif")
 ("include" "inclure")
 ("include a document" "inclure un document")
@@ -640,7 +693,9 @@
 ("insert thick horizontal space" "insrer une espace horizontale paisse")
 ("insert title" "insrer titre")
 ("insert value" "insrer valeur")
+("integrate" "intgrer")
 ("interactive command" "commande interactive")
+("interactive questions" "questions interactives")
 ("interfacing" "interfaage")
 ("interfacing TeXmacs with other systems" "interfaage de TeXmacs avec d'autres systmes")
 ("interjection" "interjection")
@@ -649,7 +704,9 @@
 ("internationalization" "internationalisation")
 ("interparagraph space" "espace d'interparagraphe")
 ("interrupt execution" "interrompre l'xcution")
+("interrupted" "interrompu")
 ("introduction" "introduction")
+("invert" "inverser")
 ("invisible" "invisible")
 ("invisible citation" "citation invisible")
 ("irish" "irlandais")
@@ -667,11 +724,12 @@
 ("june" "juin")
 ("justified" "justifi")
 ("justify text" "justifier le texte")
+("keep evaluated expressions" "garder les expressions values")
 ("key" "touche")
 ("keyboard" "clavier")
 ("keyboard equivalent" "raccourci clavier")
 ("keyboard modifiers" "modificateurs de clavier")
-("keyboard shorthand" "raccourci clavier")
+("keyboard shortcut" "raccourci clavier")
 ("keymaps" "claviers")
 ("keyword" "mot-clef")
 ("keywords" "mots-clefs")
@@ -690,6 +748,7 @@
 ("latex command" "commande latex")
 ("latin" "latin")
 ("layout" "mise en page")
+("lcm" "ppcm")
 ("left" " gauche")
 ("left arrow" "flche vers la gauche")
 ("left border" "limite  gauche")
@@ -717,6 +776,7 @@
 ("line" "droite")
 ("line break" "saut de ligne")
 ("line stretch" "tirabilit de lignes")
+("linear algebra" "algbre linaire")
 ("link" "lien")
 ("link image" "lier image")
 ("list" "liste")
@@ -738,6 +798,8 @@
 ("load tex file" "charger fichier tex")
 ("load verbatim file" "charger fichier verbatim")
 ("loaded" "charg")
+("logarithm" "logarithme")
+("logarithms" "logarithmes")
 ("long" "long")
 ("look and feel" "aspect de l'interface")
 ("look up" "rechercher")
@@ -775,6 +837,7 @@
 ("margins" "marges")
 ("margins as on paper" "marges comme sur le papier")
 ("master" "matre")
+("master's thesis" "mmoire de master")
 ("master file" "fichier matre")
 ("math" "maths")
 ("math font" "police mathmatique")
@@ -788,10 +851,15 @@
 ("mathematical input" "entres sous forme mathmatique")
 ("mathematical typesetting" "mise en page mathmatique")
 ("mathematics" "mathmatiques")
+("matrices" "matrices")
 ("matrix" "matrice")
 ("maximal" "maximal")
+("maximal cell height" "hauteur maximale de la cellule")
+("maximal cell width" "largeur maximale de la cellule")
 ("maximal number of columns" "nombre minimal de colonnes")
 ("maximal number of rows" "nombre maximal de lignes")
+("maximal table height" "hauteur maximale du tableau")
+("maximal table width" "largeur maximale du tableau")
 ("maximum mode" "mode maximum")
 ("may" "mai")
 ("medium" "moyen")
@@ -802,8 +870,12 @@
 ("meta key" "touche meta")
 ("middle" "au milieu")
 ("minimal" "minimal")
+("minimal cell height" "hauteur minimale de la cellule")
+("minimal cell width" "largeur minimale de la cellule")
 ("minimal number of columns" "nombre minimal de colonnes")
 ("minimal number of rows" "nombre minimal de lignes")
+("minimal table height" "hauteur minimale du tableau")
+("minimal table width" "largeur minimale du tableau")
 ("minimum mode" "mode minimum")
 ("minus" "moins")
 ("miscellaneous" "divers")
@@ -818,7 +890,7 @@
 ("modify table border" "bordure du tableau")
 ("modify table padding" "espacement autour du tableau")
 ("mongolian" "mongol")
-("more information about GNU TeXmacs can be found in the help" "pour plus de renseignements sur GNU TeXmacs, veuillez consulter le menu aide")
+("more information about GNU TeXmacs can be found in the Help" "pour plus de renseignements sur GNU TeXmacs, veuillez consulter le menu Aide")
 ("mosaic" "mosaque")
 ("move down" "aller vers le bas")
 ("move object" "dplacer objet")
@@ -831,9 +903,11 @@
 ("n-th root" "racine n-ime")
 ("name" "nom")
 ("negation" "ngation")
+("never" "jamais")
 ("new" "nouveau")
 ("new buffer" "nouveau tampon")
 ("new column" "nouvelle colonne")
+("new document" "nouveau document")
 ("new double page" "nouvelle page double")
 ("new double page before" "nouvelle page double avant")
 ("new item" "nouvel lment")
@@ -888,6 +962,7 @@
 ("odd page right margin" "marge  droite pour pages impaires")
 ("odd page shift" "dcalage pour les pages impaires")
 ("odd page text" "texte pour les pages impaires")
+("of" "de")
 ("off" "dsactiver")
 ("ok" "ok")
 ("old english" "vieil anglais")
@@ -898,6 +973,7 @@
 ("on columns" "par colonnes")
 ("on entire table" "par tableau entier")
 ("on rows" "par lignes")
+("on the footer" "sur la barre d'tat")
 ("one spelling error has been corrected" "une faute d'orthographe a t corrige")
 ("online documentation" "documentation en ligne")
 ("online help" "aide en ligne")
@@ -906,6 +982,7 @@
 ("open a new buffer" "ouvrir un nouveau tampon")
 ("open new window" "ouvrir nouvelle fentre")
 ("opening" "ouverture")
+("operation mode" "mode d'opration")
 ("operation on named selection" "opration sur slection  spcifier")
 ("operation on primary selection" "opration sur slection primaire")
 ("operation on secondary selection" "opration sur slection secondaire")
@@ -928,6 +1005,7 @@
 ("overline" "surlign")
 ("padding" "espacement")
 ("page" "page")
+("pages" "pages")
 ("page bottom margin" "marge de page en bas")
 ("page break" "saut de page")
 ("page break before" "saut de page avant")
@@ -948,6 +1026,8 @@
 ("paragraph" "paragraphe")
 ("paragraph mode" "type de paragraphe")
 ("paragraph width" "largeur du paragraphe")
+("parametric curve" "courbe paramtrise")
+("parametric surface" "surface paramtrise")
 ("part" "partie")
 ("past changes" "changements effectus")
 ("paste" "coller")
@@ -962,6 +1042,7 @@
 ("person" "personne")
 ("personal dictionary has been modified" "votre dictionnaire personnel a t modifi")
 ("phantasy" "fantaisie")
+("phd thesis" "thse de doctorat")
 ("philosophy" "philosophie")
 ("phoenician" "phnicien")
 ("phonetic" "phontique")
@@ -972,6 +1053,7 @@
 ("plans for the future" "projets pour l'avenir")
 ("please" "de grce")
 ("please wait" "patientez un instant s.v.p.")
+("plot" "graphique")
 ("plugin" "greffon")
 ("plugins" "greffons")
 ("plus" "plus")
@@ -1029,13 +1111,16 @@
 ("proportional typewriter" "proportionnel machine  crire")
 ("proposition" "proposition")
 ("query replace" "remplacement contrl")
+("question" "question")
 ("quit" "quitter")
 ("quotation" "citation")
 ("quote" "citer")
 ("range" "partie")
+("rank" "rang")
 ("really close it" "vraiment fermer")
 ("really huge" "vraiment norme")
 ("really quit" "voulez-vous vraiment quitter")
+("really tiny" "vraiment minuscule")
 ("recover autosave file" "recuprer fichier de sauvegarde automatique")
 ("red" "rouge")
 ("redo" "rpter")
@@ -1045,6 +1130,7 @@
 ("reduce margins" "rduire les marges")
 ("reduce right margin by" "rduire marge  droite de")
 ("reduce top margin by" "rduire marge en haut de")
+("reduce trigonometric functions" "rduire les fonctions trigonomtriques")
 ("reduction bottom margin" "rduction marge en bas")
 ("reduction even page margin" "rduction marge de page impaire")
 ("reduction odd page margin" "rduction marge de page paire")
@@ -1063,6 +1149,7 @@ styles standards de TeXmacs")
 ("release" "version")
 ("reload" "recharger")
 ("remark" "remarque")
+("remove" "enlever")
 ("remove all output fields" "enlever tous les champs de sortie")
 ("remove fields" "enlever des champs")
 ("remove input field" "enlever champ d'entre")
@@ -1074,6 +1161,7 @@ styles standards de TeXmacs")
 ("repeat object" "rpter objet")
 ("replace" "remplacer")
 ("replace by" "remplacer par")
+("replace unrecognized styles" "remplacer des styles non reconnus")
 ("replaced" "j'ai remplac")
 ("replaced one occurrence" "j'ai remplac une occurrence")
 ("reset" "remettre")
@@ -1104,7 +1192,10 @@ styles standards de TeXmacs")
 ("rotate backward" "tourner en arrire")
 ("rotate forward" "tourner en avant")
 ("row" "ligne")
+("row above" "ligne au dessus")
+("row below" "ligne en dessous")
 ("row contains glued items" "la ligne contient des parties colles")
+("rows" "lignes")
 ("runic" "runes")
 ("running author" "auteur courant")
 ("running title" "titre courant")
@@ -1196,8 +1287,14 @@ styles standards de TeXmacs")
 ("show on screen" "montrer sur l'cran")
 ("shrinking factor" "facteur de rduction")
 ("signature" "signature")
+("simplify" "simplifier")
+("simplification" "simplification")
+("simplified evaluation of formulas" "valuation simplifie de formules")
+("simplified menus" "menus simplifis")
+("sine" "sinus")
 ("size" "taille")
 ("size limits" "limitations de taille")
+("size tag" "balise de taille")
 ("slanted" "oblique")
 ("sloppy" "relch")
 ("slovene" "slovne")
@@ -1215,8 +1312,11 @@ styles standards de TeXmacs")
 ("spanish" "espagnol")
 ("special" "spcial")
 ("special cell properties" "proprits spciales de la cellule")
+("special functions" "fonctions spciales")
+("special properties" "proprits spciales")
 ("special table properties" "proprits spciales du tableau")
 ("specific" "spcifique")
+("specify the size of the table" "spcifier la taille du tableau")
 ("spell" "orthographe")
 ("spell checking complete" "le correcteur d'orthographe a termin")
 ("spelling error" "faute d'orthographe")
@@ -1250,12 +1350,14 @@ styles standards de TeXmacs")
 ("subsection" "sous-section")
 ("subsub" "sous-sous")
 ("subsubsection" "sous-sous-section")
+("subtable" "sous-tableau")
 ("subtitle" "sous-titre")
 ("summary" "rsum")
 ("summary of the principal TeXmacs tags" "les principaux marqueurs de contenu")
 ("superpose" "superposer")
 ("superposed" "superpos")
 ("superscript" "exposant")
+("surface" "surface")
 ("swedish" "sudois")
 ("swiss" "suisse")
 ("switch" "commutateur")
@@ -1271,10 +1373,14 @@ styles standards de TeXmacs")
 ("tab" "tabulation")
 ("table" "tableau")
 ("table command" "commande de tableau")
+("table height" "hauteur du tableau")
 ("table of contents" "table des matires")
+("table width" "largeur du tableau")
 ("tables" "tableaux")
 ("tabular" "tabuler")
 ("tabular material" "tableaux")
+("tangent" "tangente")
+("technical report" "rapport technique")
 ("teXmacs as an interface" "teXmacs en tant qu'interface")
 ("teXmacs fonts" "les polices TeXmacs")
 ("teXmacs notice" "avis sur TeXmacs")
@@ -1305,11 +1411,14 @@ styles standards de TeXmacs")
 ("theorem" "thorme")
 ("there are unsaved files" "tous les fichiers n'ont pas t sauvegards")
 ("this buffer has not been saved" "ce document n'a pas t sauvegard")
+("this column" "cette colonne")
 ("this document has been produced using" "ce document a t conu avec")
 ("this line" "cette ligne")
 ("this page" "cette page")
 ("this page footer" "en bas de cette page")
 ("this page header" "en-tte pour cette page")
+("this row" "cette ligne")
+("thumbnails" "onglets d'images")
 ("tilda" "tilde")
 ("tilde" "tilde")
 ("times" "fois")
@@ -1329,7 +1438,11 @@ styles standards de TeXmacs")
 ("top table border" "bordure en haut du tableau")
 ("top table padding" "espacement en haut du tableau")
 ("translate" "traduire")
+("transpose" "transposer")
 ("tree" "arbre")
+("triangularize" "trianguler")
+("trigonometric" "trigonomtrique")
+("trigonometry" "trigonomtrie")
 ("tuple" "tuplet")
 ("turkish" "turque")
 ("tutorial" "tutoriel")
@@ -1347,7 +1460,7 @@ styles standards de TeXmacs")
 ("ugaritic" "ougaritique")
 ("ukrainian" "ukrainien")
 ("underbrace" "accolade en dessous")
-("underline" "soulign")
+("underline" "souslign")
 ("undo" "annuler")
 ("undo last changes" "annuler les derniers changements")
 ("up" "en haut")
@@ -1356,6 +1469,7 @@ styles standards de TeXmacs")
 ("update image links" "mise  jour des images lis")
 ("upper border" "limite en haut")
 ("upright" "droit")
+("use MathML" "utiliser MathML")
 ("use TeXmacs" "utilisez TeXmacs")
 ("use a black color" "utiliser une couleur noire")
 ("use a blue color" "utiliser une couleur bleue")
@@ -1376,6 +1490,7 @@ styles standards de TeXmacs")
 ("use bold font series" "utiliser une police grasse")
 ("use calligraphic font" "utiliser la police calligraphique")
 ("use calligraphical font" "utiliser une police calligraphique")
+("use catcode definitions in preamble" "utiliser des catcodes dans la prambule")
 ("use footnote font size" "utiliser une trs petite police")
 ("use fraktur font" "utiliser la police Gothique")
 ("use huge font size" "utiliser une police norme")
@@ -1414,6 +1529,7 @@ styles standards de TeXmacs")
 ("verse" "vers")
 ("vertical" "vertical")
 ("vertical after" "vertical aprs")
+("vertical alignment" "alignement vertical")
 ("vertical before" "vertical avant")
 ("vertical cell alignment" "alignement vertical de la cellule")
 ("vertical part" "partie verticale")
@@ -1427,6 +1543,7 @@ styles standards de TeXmacs")
 ("vietnamese" "vietnamien")
 ("view" "vue")
 ("visible" "visible")
+("volume" "volume")
 ("warning" "avertissement")
 ("web" "toile")
 ("welcome" "bienvenue")
@@ -1447,6 +1564,7 @@ styles standards de TeXmacs")
 ("window width" "largeur de fentre")
 ("windows key" "touche windows")
 ("with" "avec")
+("wrap lines" "couper les lignes")
 ("write a macro" "crire un macro")
 ("write a name" "crire un nom")
 ("write bold mathematics" "crire des mathmatiques en gras")
