@@ -660,7 +660,7 @@
 ("keyboard" "Tastatur")
 ("keyboard equivalent" "Tastenkombination")
 ("keyboard modifiers" "Tastatur-Modifikator")
-("keyboard shorthand" "Tastenkombination")
+("keyboard shortcut" "Tastenkombination")
 ("keymaps" "Tastatur Mappings")
 ("keyword" "Stichwort")
 ("keywords" "Stichworte")
@@ -806,7 +806,7 @@
 ("modify table border" "Tabellenumrandung ndern")
 ("modify table padding" "Tabellenpadding ndern")
 ("mongolian" "mongolisch")
-("more information about GNU TeXmacs can be found in the help" "weitere Informationen ber GNU TeXmacs finden Sie unter Hilfe")
+("more information about GNU TeXmacs can be found in the Help" "weitere Informationen ber GNU TeXmacs finden Sie unter Hilfe")
 ("mosaic" "Mosaik")
 ("move down" "nach unten bewegen")
 ("move object" "Objekt verschieben")
@@ -1013,6 +1013,7 @@
 ("quasi" "Substitution")
 ("quasiquote" "Substitution ohne Evaluierung")
 ("query replace" "ersetzen mit Rckfragen")
+("question" "Frage")
 ("quit" "verlassen")
 ("quotation" "Zitat")
 ("quote" "zitieren")
