@@ -1,4 +1,4 @@
-<TeXmacs|1.0.5.3>
+<TeXmacs|1.0.7.2>
 
 <style|source>
 
@@ -13,11 +13,10 @@
     <src-copyright|2001--2004|Joris van der Hoeven>
 
     <\src-license>
-      This <TeXmacs> style package falls under the <hlink|GNU general public
-      license|$TEXMACS_PATH/LICENSE> and comes WITHOUT ANY WARRANTY
-      WHATSOEVER. If you do not have a copy of the license, then write to the
-      Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-      02111-1307, USA.
+      This software falls under the <hlink|GNU general public license,
+      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
+      WARRANTY WHATSOEVER. You should have received a copy of the license
+      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
     </src-license>
   </src-title>>
 
@@ -57,14 +56,22 @@
     </src-comment>
   </active*>
 
-  <assign|explain|<\macro|what|body>
+  <assign|explain-header|<\macro|what>
     <\with|par-first|0fn|par-par-sep|0fn>
       <surround|<vspace*|0.5fn>|<no-page-break>|<arg|what>>
     </with>
+  </macro>>
 
+  <assign|explain-body|<\macro|body>
     <surround||<right-flush><vspace|0.5fn><no-indent*>|<with|par-left|<plus|<value|par-left>|1.5fn>|<arg|body>>>
   </macro>>
 
+  <assign|explain|<\macro|what|body>
+    <explain-header|<arg|what>>
+
+    <explain-body|<arg|body>>
+  </macro>>
+
   <assign|explain-macro-sub|<macro|x|pos|<if|<equal|<arg|pos>|0>|<indexed|<src-macro|<arg|x>>>|<src-arg|<arg|x>>>>>
 
   <assign|explain-macro|<xmacro|args|<map-args|explain-macro-sub|inline-tag|args>>>
@@ -78,33 +85,6 @@
 
   <assign|var-val|<macro|var|val|<src-var|<arg|var>><active*|<with|mode|math|\<assign\>>><with|font-family|tt|<arg|val>>>>
 
-  <\active*>
-    <\src-comment>
-      Documentation of scheme macros.
-    </src-comment>
-  </active*>
-
-  <assign|scm|<macro|x|<with|mode|prog|<arg|x>>>>
-
-  <assign|scm-fun|<macro|x|<with|color|dark blue|<scm|<arg|x>>>>>
-
-  <assign|scm-macro|<macro|x|<with|color|dark magenta|<scm|<arg|x>>>>>
-
-  <assign|scm-arg|<macro|x|<scm|<with|prog-font-shape|italic|<arg|x>>>>>
-
-  <assign|scm-args|<macro|x|<scm|<with|prog-font-shape|italic|<arg|x>><rsup|*>>>>
-
-  <assign|scm-opt-arg|<macro|x|<with|color|dark
-  grey|[<style-with|<scm-arg|<arg|x>>>]>>>
-
-  <assign|explain-scm-sub|<macro|x| <arg|x>>>
-
-  <assign|explain-scm-fun|<xmacro|x|<style-with|src-compact|none|<scm|(<scm-fun|<arg|x|0>><map-args|explain-scm-sub|concat|x|1>)>>>>
-
-  <assign|explain-scm-macro|<xmacro|x|<style-with|src-compact|none|<scm|(<scm-macro|<arg|x|0>><map-args|explain-scm-sub|concat|x|1>)>>>>
-
-  <drd-props|explain-scm-macro|arity|<tuple|repeat|1|1>|accessible|all>
-
   <\active*>
     <\src-comment>
       Links inside the documentation and special types of links. We are not
@@ -115,9 +95,7 @@
 
   <assign|simple-link|<macro|x|<hlink|<with|font-family|tt|<arg|x>>|<arg|x>>>>
 
-  <assign|hyper-link|<macro|x|y|<hlink|<arg|x>|<arg|y>>>>
-
-  <assign|hyper-link|<macro|x|y|<quasiquote|<style-with|src-compact|none|<datoms|<macro|x|<hlink|<arg|x>|<unquote|<arg|y>>>>|<with|color|blue|<arg|x>>>>>>>
+  <assign|hyper-link*|<macro|x|y|<hlink|<arg|x>|<arg|y>>>>
 
   <assign|concept-link|<macro|x|<with|color|magenta|<arg|x>>>>
 
@@ -131,14 +109,10 @@
 
   <\active*>
     <\src-comment>
-      Fragments of code.
+      Framed fragmentd.
     </src-comment>
   </active*>
 
-  <assign|scheme|<name|Scheme>>
-
-  <assign|cpp|<name|C++>>
-
   <assign|framed-table|<macro|x|<with|color|dark
   grey|<tformat|<twith|table-width|1par>|<cwith|1|-1|1|-1|cell-hyphen|t>|<cwith|1|-1|1|-1|cell-bsep|1spc>|<cwith|1|-1|1|-1|cell-tsep|1spc>|<cwith|1|-1|1|-1|cell-background|pastel
   blue>|<cwith|1|-1|1|-1|cell-lborder|0.5ln>|<cwith|1|-1|1|-1|cell-rborder|0.5ln>|<cwith|1|-1|1|-1|cell-bborder|0.5ln>|<cwith|1|-1|1|-1|cell-tborder|0.5ln>|<arg|x>>>>>
@@ -153,29 +127,88 @@
     </cell>>>>>
   </macro>>
 
-  <assign|scheme-fragment|<\macro|x>
-    <quote-env|<framed-fragment|<with|par-par-sep|0fn|<scm|<arg|x>>>>>
-  </macro>>
+  <assign|todo|<macro|x|<block|<tformat|<cwith|1|1|1|1|cell-background|pastel
+  red>|<cwith|1|1|1|1|cell-lborder|0.5ln>|<cwith|1|1|1|1|cell-rborder|0.5ln>|<cwith|1|1|1|1|cell-bborder|0.5ln>|<cwith|1|1|1|1|cell-tborder|0.5ln>|<table|<row|<cell|To
+  do: <arg|x>>>>>>>>
 
-  <assign|shell-fragment|<\macro|x>
-    <quote-env|<framed-fragment|<with|par-par-sep|0fn|<verbatim|<arg|x>>>>>
-  </macro>>
-
-  <assign|cpp-fragment|<\macro|x>
-    <quote-env|<framed-fragment|<with|par-par-sep|0fn|<verbatim|<arg|x>>>>>
-  </macro>>
+  <\active*>
+    <\src-comment>
+      Fragments of <TeXmacs> code.
+    </src-comment>
+  </active*>
 
   <assign|tm-fragment|<\macro|x>
     <quotation|<framed-fragment|<arg|x>>>
   </macro>>
 
-  <assign|scheme-code|<macro|x|<verbatim|<arg|x>>>>
+  <\active*>
+    <\src-comment>
+      Fragments of scheme code.
+    </src-comment>
+  </active*>
 
-  <assign|cpp-code|<macro|x|<verbatim|<arg|x>>>>
+  <assign|scheme|<macro|<name|Scheme>>>
 
-  <assign|todo|<macro|x|<block|<tformat|<cwith|1|1|1|1|cell-background|pastel
-  red>|<cwith|1|1|1|1|cell-lborder|0.5ln>|<cwith|1|1|1|1|cell-rborder|0.5ln>|<cwith|1|1|1|1|cell-bborder|0.5ln>|<cwith|1|1|1|1|cell-tborder|0.5ln>|<table|<row|<cell|To
-  do: <arg|x>>>>>>>>
+  <assign|scm|<macro|x|<with|mode|prog|prog-language|scheme|<arg|x>>>>
+
+  <assign|scm-verb|<macro|x|<with|prog-language|verbatim|<arg|x>>>>
+
+  <assign|scm-arg|<macro|x|<with|prog-font-shape|italic|<scm|<scm-verb|<arg|x>>>>>>
+
+  <assign|scm-args|<macro|x|<with|prog-font-shape|italic|<scm|<scm-verb|<arg|x>>>><rsup|*>>>
+
+  <assign|scm-opt-arg|<macro|x|<with|color|dark
+  grey|[<style-with|<scm-arg|<arg|x>>>]>>>
+
+  <assign|scm-fragment|<\macro|x>
+    <quote-env|<framed-fragment|<with|par-par-sep|0fn|<scm|<arg|x>>>>>
+  </macro>>
+
+  <\active*>
+    <\src-comment>
+      Fragments of shell code.
+    </src-comment>
+  </active*>
+
+  <assign|shell|<macro|x|<with|mode|prog|prog-language|shell|<arg|x>>>>
+
+  <assign|shell-fragment|<\macro|x>
+    <quote-env|<framed-fragment|<with|par-par-sep|0fn|<shell|<arg|x>>>>>
+  </macro>>
+
+  <\active*>
+    <\src-comment>
+      Fragments of C++ code.
+    </src-comment>
+  </active*>
+
+  <assign|c++|<macro|<name|C++>>>
+
+  <assign|cpp|<macro|x|<with|mode|prog|prog-language|cpp|<arg|x>>>>
+
+  <assign|cpp-fragment|<\macro|x>
+    <quote-env|<framed-fragment|<with|par-par-sep|0fn|<cpp|<arg|x>>>>>
+  </macro>>
+
+  <\active*>
+    <\src-comment>
+      Fragments of mathemagix code.
+    </src-comment>
+  </active*>
+
+  <assign|mmxlib|<macro|<with|font-shape|small-caps|Mmxlib>>>
+
+  <assign|mathemagix|<macro|<with|font-shape|small-caps|Mathemagix>>>
+
+  <assign|mmx|<macro|x|<with|mode|prog|prog-language|mathemagix|<arg|x>>>>
+
+  <assign|mmx-fragment|<\macro|x>
+    <quote-env|<framed-fragment|<with|par-par-sep|0fn|<mmx|<arg|x>>>>>
+  </macro>>
+
+  <assign|mmx-fragment*|<\macro|x>
+    <framed-fragment|<with|par-par-sep|0fn|<mmx|<arg|x>>>>
+  </macro>>
 
   <\active*>
     <\src-comment>
@@ -192,7 +225,7 @@
     </src-comment>
   </active*>
 
-  <assign|icon|<macro|name|<postscript|<find-file|$TEXMACS_DOC_PATH/images/pixmaps|$TEXMACS_HOME_PATH/doc/images/pixmaps|$TEXMACS_PATH/doc/images/pixmaps|http://www.gnu.org/software/texmacs-doc/images/pixmaps|<arg|name>>|/2|/2||||>>>
+  <assign|icon|<macro|name|<postscript|<find-file|$TEXMACS_PATH/misc/pixmaps|$TEXMACS_DOC_PATH/images/pixmaps|$TEXMACS_HOME_PATH/doc/images/pixmaps|$TEXMACS_PATH/doc/images/pixmaps|http://www.gnu.org/software/texmacs-doc/images/pixmaps|<arg|name>>|/2|/2||||>>>
 
   <assign|screenshot|<macro|name|<postscript|<find-file|$TEXMACS_DOC_PATH/images/screenshots|$TEXMACS_HOME_PATH/doc/images/screenshots|$TEXMACS_PATH/doc/images/screenshots|http://www.gnu.org/software/texmacs-doc/images/screenshots|<arg|name>>|/2|/2||||>>>
 
