@@ -1,6 +1,6 @@
-<TeXmacs|1.0.5.10>
+<TeXmacs|1.0.7.7>
 
-<style|source>
+<style|<tuple|source|std>>
 
 <\body>
   <active*|<\src-title>
@@ -13,11 +13,10 @@
     <src-copyright|1998--2004|Joris van der Hoeven>
 
     <\src-license>
-      This <TeXmacs> style package falls under the <hlink|GNU general public
-      license|$TEXMACS_PATH/LICENSE> and comes WITHOUT ANY WARRANTY
-      WHATSOEVER. If you don't have this file, then write to the Free
-      Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-      02111-1307, USA.
+      This software falls under the <hlink|GNU general public license,
+      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
+      WARRANTY WHATSOEVER. You should have received a copy of the license
+      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
     </src-license>
   </src-title>>
 
@@ -60,7 +59,7 @@
   <assign|compact-strong-dash-item|<macro|x|<compact-item|<item-strong|<arg|x>>
   <emdash> >>>
 
-  <assign|long-compact-strong-dot-item|<macro|x|<item-long|<move|<item-strong|<arg|x>.>|-1.5fn|0fn>>>>
+  <assign|long-compact-strong-dot-item|<macro|x|<item-long|<no-indent><move|<item-strong|<arg|x>.>|-1.5fn|0fn>>>>
 
   <\active*>
     <\src-comment>
@@ -71,17 +70,19 @@
 
   <new-counter|item>
 
-  <assign|last-item|<active*|<with|mode|math|||\<cdot\>||<with|math-font-series|bold|<group|\<ast\>>>>>>
+  <assign|last-item|<active*|<with|mode|math|||\<cdot\>||<with|math-font-series|bold|<rigid|\<ast\>>>>>>
 
   <assign|current-item|<value|aligned-space-item>>
 
-  <assign|transform-item|<macro|x|<active*|<with|mode|math|||\<cdot\>||<with|math-font-series|bold|<group|\<ast\>>>>>>>
+  <assign|transform-item|<macro|x|<active*|<with|mode|math|||\<cdot\>||<with|math-font-series|bold|<rigid|\<ast\>>>>>>>
 
   <assign|the-item|<macro|<transform-item|<value|<counter-item>>>>>
 
-  <assign|item*|<macro|x|<assign|last-item|<arg|x>><current-item|<arg|x>>>>
+  <assign|render-item|<macro|x|<assign|last-item|<arg|x>><current-item|<arg|x>>>>
 
-  <assign|item|<macro|<next-item><item*|<the-item>>>>
+  <assign|item*|<macro|x|<set-binding|<arg|x>><render-item|<arg|x>>>>
+
+  <assign|item|<macro|<next-item><render-item|<the-item>>>>
 
   <\active*>
     <\src-comment>
@@ -123,9 +124,9 @@
 
   <new-list|itemize-1|<value|aligned-space-item>|<macro|x|<active*|<with|mode|math|\<bullet\>>>>>
 
-  <new-list|itemize-2|<value|aligned-space-item>|<macro|x|<active*|<with|mode|math|<group|\<circ\>>>>>>
+  <new-list|itemize-2|<value|aligned-space-item>|<macro|x|<active*|<with|mode|math|<rigid|\<circ\>>>>>>
 
-  <new-list|itemize-3|<value|aligned-space-item>|<macro|x|<active*|<with|mode|math|<group|->>>>>
+  <new-list|itemize-3|<value|aligned-space-item>|<macro|x|<active*|<with|mode|math|<rigid|->>>>>
 
   <assign|itemize|<\macro|body>
     <\with|itemize-level|<plus|<mod|<value|itemize-level>|3>|1>>
@@ -171,11 +172,11 @@
     </src-comment>
   </active*>
 
-  <new-list|itemize-minus|<value|aligned-space-item>|<macro|x|<active*|<with|mode|math|<group|->>>>>
+  <new-list|itemize-minus|<value|aligned-space-item>|<macro|x|<active*|<with|mode|math|<rigid|->>>>>
 
   <new-list|itemize-dot|<value|aligned-space-item>|<macro|x|<active*|<with|mode|math|\<bullet\>>>>>
 
-  <new-list|itemize-arrow|<value|aligned-space-item>|<macro|x|<active*|<with|mode|math|<group|\<rightarrow\>>>>>>
+  <new-list|itemize-arrow|<value|aligned-space-item>|<macro|x|<active*|<with|mode|math|<rigid|\<rightarrow\>>>>>>
 
   <new-list|enumerate-numeric|<value|aligned-dot-item>|<value|identity>>
 
@@ -187,15 +188,15 @@
 
   <new-list|enumerate-Alpha|<value|aligned-bracket-item>|<macro|x|<number|<arg|x>|Alpha>>>
 
-  <new-list|description-compact|<value|compact-strong-dot-item>|<macro|x|<active*|<with|mode|math|<with|math-font-series|bold|<group|\<ast\>>>>>>>
+  <new-list|description-compact|<value|compact-strong-dot-item>|<macro|x|<active*|<with|mode|math|<with|math-font-series|bold|<rigid|\<ast\>>>>>>>
 
-  <new-list|description-aligned|<value|aligned-strong-dot-item>|<macro|x|<active*|<with|mode|math|<with|math-font-series|bold|<group|\<ast\>>>>>>>
+  <new-list|description-aligned|<value|aligned-strong-dot-item>|<macro|x|<active*|<with|mode|math|<with|math-font-series|bold|<rigid|\<ast\>>>>>>>
 
-  <new-list|description-dash|<value|compact-strong-dash-item>|<macro|x|<active*|<with|mode|math|<with|math-font-series|bold|<group|\<ast\>>>>>>>
+  <new-list|description-dash|<value|compact-strong-dash-item>|<macro|x|<active*|<with|mode|math|<with|math-font-series|bold|<rigid|\<ast\>>>>>>>
 
-  <new-list|description-long|<value|long-compact-strong-dot-item>|<macro|x|<active*|<with|mode|math|<with|math-font-series|bold|<group|\<ast\>>>>>>>
+  <new-list|description-long|<value|long-compact-strong-dot-item>|<macro|x|<active*|<with|mode|math|<with|math-font-series|bold|<rigid|\<ast\>>>>>>>
 
-  <new-list|description|<value|compact-strong-dot-item>|<macro|x|<active*|<with|mode|math|<with|math-font-series|bold|<group|\<ast\>>>>>>>
+  <new-list|description|<value|compact-strong-dot-item>|<macro|x|<active*|<with|mode|math|<with|math-font-series|bold|<rigid|\<ast\>>>>>>>
 
   \;
 </body>
