@@ -1,4 +1,4 @@
-<TeXmacs|1.0.5.11>
+<TeXmacs|1.0.7.7>
 
 <style|<tuple|source|std>>
 
@@ -13,11 +13,10 @@
     <src-copyright|1998--2004|Joris van der Hoeven>
 
     <\src-license>
-      This <TeXmacs> style package falls under the <hlink|GNU general public
-      license|$TEXMACS_PATH/LICENSE> and comes WITHOUT ANY WARRANTY
-      WHATSOEVER. If you do not have a copy of the license, then write to the
-      Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-      02111-1307, USA.
+      This software falls under the <hlink|GNU general public license,
+      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
+      WARRANTY WHATSOEVER. You should have received a copy of the license
+      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
     </src-license>
   </src-title>>
 
@@ -33,7 +32,7 @@
 
   <assign|TeXmacs-version-release|<macro|type|<extern|texmacs-version-release*|<quote-arg|type>>>>
 
-  <assign|made-by-TeXmacs|<macro|<float|footnote||<with|font-size|0.84|par-mode|justify|par-left|0cm|par-right|0cm|<active*|<move|<postscript|local:$TEXMACS_PATH/misc/images/tm_gnu3.ps||1fn||||>|0fn|-0.2fn>><space|2spc><localize|This
+  <assign|made-by-TeXmacs|<macro|<float|footnote||<with|font-size|0.84|par-mode|justify|par-left|0cm|par-right|0cm|<active*|<move|<image|local:$TEXMACS_PATH/misc/images/tm_gnu3.ps||1fn||||>|0fn|-0.2fn>><space|2spc><localize|This
   document has been produced using> GNU <TeXmacs> (<localize|see>
   <with|font-family|tt|http://www.texmacs.org>).<right-flush>>>>>
 
@@ -41,8 +40,12 @@
 
   <assign|LaTeX|<macro|<active*|L<rsup|<space|-0.8spc><move|A|0fn|-0.1fn>><space|-0.2spc>T<rsub|<space|-0.4spc><move|<resize|<with|math-level|0|E>||||0.5fn|>|0fn|-0.1fn>><space|-0.4spc>X>>>
 
+  <assign|BibTeX|<macro|<active*|<with|font-shape|small-caps|Bib>T<rsub|<space|-0.4spc><move|<resize|<with|math-level|0|E>||||0.5fn|>|0fn|-0.1fn>><space|-0.4spc>X>>>
+
   <assign|hrule|<macro|<no-indent><tabular|<tformat|<cwith|1|-1|1|-1|cell-tborder|1ln>|<twith|table-width|1par>|<cwith|1|-1|1|-1|cell-vmode|exact>|<cwith|1|-1|1|-1|cell-height|1ln>|<cwith|1|-1|1|-1|cell-lsep|0fn>|<cwith|1|-1|1|-1|cell-rsep|0fn>|<cwith|1|-1|1|-1|cell-bsep|0fn>|<cwith|1|-1|1|-1|cell-tsep|0fn>|<cwith|1|-1|1|-1|cell-vcorrect|n>|<table|<row|<cell|<space|1fn|0ln|1ln>>>>>>>>
 
+  <assign|pre-edit|<macro|x|<with|ornament-color|#ffffc0|ornament-sunny-color|#fff0e0|ornament-shadow-color|#ffc080|ornament-border|1px|ornament-hpadding|2px|ornament-vpadding|2px|<smash|<ornament|<with|color|#4040c0|<arg|x>>>>>>>
+
   <\active*>
     <\src-comment>
       Size tags (very-small: scriptsize, smaller: footnotesize, larger:
@@ -84,6 +87,10 @@
 
   <assign|really-huge|<macro|x|<with|font-size|2|<arg|x>>>>
 
+  <assign|font-zoom|<macro|factor|x|<with|font-size|<times|<value|font-size>|<arg|factor>>|<arg|x>>>>
+
+  <assign|font-unzoom|<macro|factor|x|<with|font-size|<over|<value|font-size>|<arg|factor>>|<arg|x>>>>
+
   <\active*>
     <\src-comment>
       Below follow some frequently used content tags.
@@ -100,10 +107,12 @@
 
   <assign|samp|<macro|x|<with|font-family|ss|<arg|x>>>>
 
-  <assign|abbr|<macro|x|<group|<arg|x>>>>
+  <assign|abbr|<macro|x|<rigid|<arg|x>>>>
 
   <assign|math|<macro|x|<with|mode|math|<arg|x>>>>
 
+  <assign|text|<macro|x|<with|mode|text|<arg|x>>>>
+
   <assign|op|<macro|x|<with|math-condensed|true|<arg|x>>>>
 
   <assign|cite*|<macro|x|<with|font-shape|italic|<arg|x>>>>
@@ -120,6 +129,58 @@
 
   <assign|person|<macro|x|<with|font-shape|small-caps|<arg|x>>>>
 
+  <\active*>
+    <\src-comment>
+      Common language tags.
+    </src-comment>
+  </active*>
+
+  <assign|british|<macro|x|<with|language|british|<arg|x>>>>
+
+  <assign|bulgarian|<macro|x|<with|language|bulgarian|<arg|x>>>>
+
+  <assign|chinese|<macro|x|<with|language|chinese|<arg|x>>>>
+
+  <assign|czech|<macro|x|<with|language|czech|<arg|x>>>>
+
+  <assign|danish|<macro|x|<with|language|danish|<arg|x>>>>
+
+  <assign|dutch|<macro|x|<with|language|dutch|<arg|x>>>>
+
+  <assign|english|<macro|x|<with|language|english|<arg|x>>>>
+
+  <assign|finnish|<macro|x|<with|language|finnish|<arg|x>>>>
+
+  <assign|french|<macro|x|<with|language|french|<arg|x>>>>
+
+  <assign|german|<macro|x|<with|language|german|<arg|x>>>>
+
+  <assign|hungarian|<macro|x|<with|language|hungarian|<arg|x>>>>
+
+  <assign|italian|<macro|x|<with|language|italian|<arg|x>>>>
+
+  <assign|japanese|<macro|x|<with|language|japanese|<arg|x>>>>
+
+  <assign|korean|<macro|x|<with|language|korean|<arg|x>>>>
+
+  <assign|polish|<macro|x|<with|language|polish|<arg|x>>>>
+
+  <assign|portuguese|<macro|x|<with|language|portuguese|<arg|x>>>>
+
+  <assign|romanian|<macro|x|<with|language|romanian|<arg|x>>>>
+
+  <assign|russian|<macro|x|<with|language|russian|<arg|x>>>>
+
+  <assign|slovene|<macro|x|<with|language|slovene|<arg|x>>>>
+
+  <assign|spanish|<macro|x|<with|language|spanish|<arg|x>>>>
+
+  <assign|swedish|<macro|x|<with|language|swedish|<arg|x>>>>
+
+  <assign|taiwanese|<macro|x|<with|language|taiwanese|<arg|x>>>>
+
+  <assign|ukrainian|<macro|x|<with|language|ukrainian|<arg|x>>>>
+
   <\active*>
     <\src-comment>
       Below follow some frequently used content environments.
@@ -171,7 +232,7 @@
 
   <assign|block|<macro|x|<tformat|<cwith|1|-1|1|-1|cell-rborder|1ln>|<cwith|1|-1|1|-1|cell-bborder|1ln>|<cwith|1|1|1|-1|cell-tborder|1ln>|<cwith|1|-1|1|1|cell-lborder|1ln>|<arg|x>>>>
 
-  <assign|block*|<macro|x|<tformat|<cwith|1|-1|1|-1|cell-rborder|1ln>|<cwith|1|-1|1|-1|cell-bborder|1ln>|<cwith|1|1|0|0|cell-tborder|1ln>|<cwith|1|-1|1|1|cell-lborder|1ln>|<cwith|1|-1|1|-1|cell-halign|c>|<arg|x>>>>
+  <assign|block*|<macro|x|<tformat|<cwith|1|-1|1|-1|cell-rborder|1ln>|<cwith|1|-1|1|-1|cell-bborder|1ln>|<cwith|1|1|1|-1|cell-tborder|1ln>|<cwith|1|-1|1|1|cell-lborder|1ln>|<cwith|1|-1|1|-1|cell-halign|c>|<arg|x>>>>
 
   <\active*>
     <\src-comment>
@@ -181,8 +242,16 @@
 
   <assign|hresize|<macro|x|left|right|<resize|<arg|x>|<arg|left>||<arg|right>|>>>
 
+  <assign|hextend|<macro|x|right|<resize|<arg|x>|||<maximum|1r|<arg|right>>|>>>
+
   <assign|vresize|<macro|x|bottom|top|<resize|<arg|x>||<arg|bottom>||<arg|top>>>>
 
+  <assign|bcorrect|<macro|x|<resize|<arg|x>||<minimum|1b|1fnbot>||>>>
+
+  <assign|tcorrect|<macro|x|<resize|<arg|x>||||<maximum|1t|1fntop>>>>
+
+  <assign|vcorrect|<macro|x|<resize|<arg|x>||<minimum|1b|1fnbot>||<maximum|1t|1fntop>>>>
+
   <assign|smash|<macro|x|<vresize|<arg|x>|0ex|1ex>>>
 
   <assign|smash-top|<macro|x|<vresize|<arg|x>||1ex>>>
@@ -199,11 +268,17 @@
 
   <assign|overline|<macro|x|<eval|<quasiquote|<style-with|src-compact|none|<datoms|<macro|x|<with|color|<unquote|<value|color>>|<wide|<arg|x>|\<wide-bar\>>>>|<arg|x>>>>>>>
 
-  <drd-props|overline|arity|1|accessible|all>
+  <drd-props|overline|with-like|yes|arity|1|accessible|all>
 
   <assign|underline|<macro|x|<eval|<quasiquote|<style-with|src-compact|none|<datoms|<macro|x|<with|color|<unquote|<value|color>>|<wide*|<arg|x>|\<wide-bar\>>>>|<arg|x>>>>>>>
 
-  <drd-props|underline|arity|1|accessible|all>
+  <drd-props|underline|with-like|yes|arity|1|accessible|all>
+
+  \;
+
+  <assign|href|<macro|x|<hlink|<with|font-family|tt|<arg|x>>|<arg|x>>>>
+
+  <assign|square|<macro|x|<times|<arg|x>|<arg|x>>>>
 
   \;
 </body>
