@@ -5,10 +5,9 @@
 ;; DESCRIPTION : Test suite for tmhtml.scm
 ;; COPYRIGHT   : (C) 2002  David Allouche
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -363,14 +362,14 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define (regtest-tmhtml-picture)
-  (define (make-result l) (tmhtml-root `(postscript ,@l "" "" "" "")))
+  (define (make-result l) (tmhtml-root `(image ,@l "" "" "" "")))
   (define (make-expected l) (if (null? l) '() (apply make-expected-sub l)))
   (define (make-expected-sub f w h)
     `((h:img (@ (src ,f)
 		,@(if w `((width ,w)) '())
 		,@(if h `((height ,h)) '())))))
   (regression-test-group
-   "tmhtml, pictures" "postscript"
+   "tmhtml, pictures" "image"
    make-result make-expected
    (test "simple link" '("foo.png" "" "") '("foo.png" #f #f))
    (test "inclusion" '((tuple (raw-data "...") "png") "" "") '())
