@@ -5,10 +5,9 @@
 ;; DESCRIPTION : conversion of TeXmacs trees into Html trees
 ;; COPYRIGHT   : (C) 2002  Joris van der Hoeven, David Allouche
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -31,7 +30,7 @@
 (define tmhtml-css? #t)
 (define tmhtml-mathml? #f)
 (define tmhtml-images? #f)
-(define tmhtml-serial 0)
+(define tmhtml-image-serial 0)
 (define tmhtml-image-cache (make-ahash-table))
 (define tmhtml-image-root-url (string->url "image"))
 (define tmhtml-image-root-string "image")
@@ -49,10 +48,12 @@
 	 (n (+ (string-length suffix) 1)))
     (if (in? suffix '("html" "xhtml"))
 	(begin
+	  (set! tmhtml-image-serial 0)
 	  (set! tmhtml-image-root-url (url-unglue current-save-target n))
 	  (set! tmhtml-image-root-string
 		(url->string (url-tail tmhtml-image-root-url))))
 	(begin
+	  (set! tmhtml-image-serial 0)
 	  (set! tmhtml-image-root-url (string->url "image"))
 	  (set! tmhtml-image-root-string "image")))))
 
@@ -98,7 +99,7 @@
       (list (cork->html s))))
 
 (define (tmhtml-text s)
-  (if (ahash-ref tmhtml-env :math)
+  (if (or (ahash-ref tmhtml-env :math) (ahash-ref tmhtml-env :preformatted))
       (tmhtml-string s)
       (tmhtml-string (make-ligatures s))))
 
@@ -117,10 +118,12 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define (tmhtml-find-title doc)
-  (cond ((func? doc 'tmdoc-title 1) (cadr doc))
+  (cond ((npair? doc) #f)
+	((func? doc 'doc-title 1) (cadr doc))
+	((func? doc 'tmdoc-title 1) (cadr doc))
 	((func? doc 'tmdoc-title* 2) (cadr doc))
 	((func? doc 'tmdoc-title** 3) (caddr doc))
-	((npair? doc) #f)
+	((func? doc 'hidden-title 1) (cadr doc))
 	(else (with title (tmhtml-find-title (car doc))
 		(if title title
 		    (tmhtml-find-title (cdr doc)))))))
@@ -161,8 +164,9 @@
 	 (body (tmhtml doc)))
     (set! title (cond ((not title) "No title")
 		      ((or (in? "tmdoc" styles) (in? "tmweb" styles))
-		       `(concat ,title " (FSF GNU project)"))
-		      (else title)))
+		       `(concat ,(tmhtml-force-string title)
+				" (FSF GNU project)"))
+		      (else (tmhtml-force-string title))))
     (if (or (in? "tmdoc" styles) (in? "tmweb" styles) (in? "mmxdoc" styles))
 	(with ss (if (in? "mmxdoc" styles)
 		     "http://www.texmacs.org/css/mmxdoc.css"
@@ -213,6 +217,51 @@
       (tmhtml (list (car x) (list 'document (cadr x))))
       (tmhtml x)))
 
+(define (tmhtml-compute-max-vspace l after?)
+  (and (nnull? l)
+    (with s1 (tmhtml-compute-vspace (car l) after?)
+      (with s2 (tmhtml-compute-max-vspace (cdr l) after?)
+	(cond ((not s1) s2)
+	      ((not s2) s1)
+	      (else
+		(with l1 (string->tmlength s1)
+		  (with l2 (string->tmlength s2)
+		    (if (== (tmlength-unit l1) (tmlength-unit l2))
+			(if (>= (tmlength-value l1) (tmlength-value l2)) s1 s2)
+			l1 ;; FIXME: do something more subtle here
+			)))))))))
+
+(define (tmhtml-compute-vspace x after?)
+  (cond ((and (not after?) (func? x 'vspace* 1)) (tmhtml-force-string (cadr x)))
+	((and after? (func? x 'vspace 1)) (tmhtml-force-string (cadr x)))
+	;;((and (not after?) (func? x 'document)) (tmhtml-compute-vspace (cadr x) #f))
+	;;((and after? (func? x 'document)) (tmhtml-compute-vspace (cAr x) #t))
+	((func? x 'concat) (tmhtml-compute-max-vspace (cdr x) after?))
+	((func? x 'with) (tmhtml-compute-vspace (cAr x) after?))
+	;;((func? x 'surround) (tmhtml-compute-max-vspace (cDdr x) after?))
+	;;((func? x 'surround) (tmhtml-compute-max-vspace (cdr x) after?))
+	(else #f)))
+
+(define (tmhtml-document-p x)
+  (let* ((body (tmhtml-document-elem x))
+	 (l1 (tmhtml-compute-vspace x #f))
+	 (l2 (tmhtml-compute-vspace x #t))
+	 (h1 (and l1 (tmlength->htmllength l1 #t)))
+	 (h2 (and l2 (tmlength->htmllength l2 #t)))
+	 (s1 (and h1 (string-append "margin-top: " h1)))
+	 (s2 (and h2 (string-append "margin-bottom: " h2)))
+	 (s (cond ((and s1 s2) (string-append s1 "; " s2))
+		  (s1 s2)
+		  (s2 s1)
+		  (else #f))))
+    ;;(display* "paragraph= " x "\n")
+    ;;(display* "style    = " s "\n")
+    (if s `(h:p (@ (style ,s)) ,@body) `(h:p ,@body))))
+
+(define (xtmhtml-document-p x)
+  (with body (tmhtml-document-elem x)
+    `(h:p ,@body)))
+
 (define (tmhtml-document l)
   (cond ((null? l) '())
 	((ahash-ref tmhtml-env :preformatted)
@@ -221,8 +270,7 @@
 	   ((cut list-intersperse <> '("\n"))
 	    (map tmhtml l)))))
 	(else
-	 (tmhtml-post-paragraphs
-	  (map (lambda (x) (cons 'h:p (tmhtml-document-elem x))) l)))))
+	  (tmhtml-post-paragraphs (map tmhtml-document-p l)))))
 
 (define (tmhtml-paragraph l)
   (let rec ((l l))
@@ -458,8 +506,7 @@
 (define (tmhtml-hspace l)
   (with len (tmlength->htmllength (if (list-1? l) (car l) (cadr l)) #t)
     (if (not len) '()
-	`((spacer (@ (type "block")
-		     (style ,(string-append "width: " len))))))))
+	`((span (@ (style ,(string-append "margin-left: " len))))))))
 
 (define (tmhtml-vspace l)
   '())
@@ -608,6 +655,13 @@
 (define (make-exact x)
   (number->string (inexact->exact x)))
 
+(define (number->htmlstring x)
+  (number->string (if (exact? x)
+		      (if (integer? x) x (exact->inexact x))
+		      (if (and (integer? (inexact->exact x))
+			       (= x (exact->inexact (inexact->exact x))))
+			  (inexact->exact x) x))))
+
 (define (tmlength->htmllength len css?)
   (and-let* ((len-str (tmhtml-force-string len))
 	     (tmlen (string->tmlength len-str))
@@ -616,19 +670,19 @@
 	     (unit (symbol->string (tmlength-unit tmlen)))
 	     (incm (ahash-ref tmhtml-length-table unit))
 	     (cmpx (/ 1 (ahash-ref tmhtml-length-table "px"))))
-    (cond ((== unit "px") (make-exact val))
+    (cond ((== unit "px") (number->htmlstring val))
 	  ((in? unit '("par" "pag"))
-	   (string-append (make-exact (* 100 val)) "%"))
+	   (string-append (number->htmlstring (* 100 val)) "%"))
 	  ((and css? (== unit "tmpt"))
-	   (string-append (make-exact (* cmpx val incm)) "px"))
+	   (string-append (number->htmlstring (* cmpx val incm)) "px"))
 	  ((and css? (== unit "fn"))
-	   (string-append (number->string val) "em"))
+	   (string-append (number->htmlstring val) "em"))
 	  ((and css? (== unit "spc"))
-	   (string-append (number->string (/ val 2)) "em"))
+	   (string-append (number->htmlstring (/ val 2)) "em"))
 	  ((and css? (== unit "ln"))
-	   (string-append (number->string val) "px"))
+	   (string-append (number->htmlstring val) "px"))
 	  (css? len)
-	  (else (make-exact (* cmpx val incm))))))
+	  (else (number->htmlstring (* cmpx val incm))))))
 
 (define (tmlength->px len)
   (and-let* ((tmlen (string->tmlength len))
@@ -645,18 +699,19 @@
 
 (define (tmhtml-with-mode val arg)
   (ahash-with tmhtml-env :math (== val "math")
-    (tmhtml arg)))
+    (tmhtml (if (== val "prog") `(verbatim ,arg) arg))))
 
 (define (tmhtml-with-color val arg)
   `((h:font (@ (color ,(tmcolor->htmlcolor val))) ,@(tmhtml arg))))
 
 (define (tmhtml-with-font-size val arg)
-  (let* ((x (* (string->number val) 100))
-	 (s (cond ((< x 1) "-4") ((< x 55) "-4") ((< x 65) "-3")
-		  ((< x 75) "-2") ((< x 95) "-1") ((< x 115) "0")
-		  ((< x 135) "+1") ((< x 155) "+2") ((< x 185) "+3")
-		  ((< x 225) "+4") ((< x 500) "+5") (else "+5"))))
-    (if s `((h:font (@ (size ,s)) ,@(tmhtml arg))) (tmhtml arg))))
+  (ahash-with tmhtml-env :mag val
+    (let* ((x (* (string->number val) 100))
+	   (s (cond ((< x 1) "-4") ((< x 55) "-4") ((< x 65) "-3")
+		    ((< x 75) "-2") ((< x 95) "-1") ((< x 115) "0")
+		    ((< x 135) "+1") ((< x 155) "+2") ((< x 185) "+3")
+		    ((< x 225) "+4") ((< x 500) "+5") (else "+5"))))
+      (if s `((h:font (@ (size ,s)) ,@(tmhtml arg))) (tmhtml arg)))))
 
 (define (tmhtml-with-block style arg)
   (with r (tmhtml (blockify arg))
@@ -667,7 +722,7 @@
   (with x (tmlength->px val)
     (if (not x) (tmhtml arg)
 	(with d (- x (ahash-ref tmhtml-env :left-margin))
-	  (with s (string-append "margin-left: " (make-exact d) "px")
+	  (with s (string-append "margin-left: " (number->htmlstring d) "px")
 	    (ahash-with tmhtml-env :left-margin x
 	      (tmhtml-with-block s arg)))))))
 
@@ -675,7 +730,7 @@
   (with x (tmlength->px val)
     (if (not x) (tmhtml arg)
 	(with d (- x (ahash-ref tmhtml-env :right-margin))
-	  (with s (string-append "margin-right: " (make-exact d) "px")
+	  (with s (string-append "margin-right: " (number->htmlstring d) "px")
 	    (ahash-with tmhtml-env :right-margin x
 	      (tmhtml-with-block s arg)))))))
 
@@ -687,7 +742,7 @@
 
 (define (tmhtml-with-par-par-sep val arg)
   (with x (tmlength->px val)
-    (if (== (inexact->exact x) 0)
+    (if (and x (== (inexact->exact x) 0))
 	`((h:div (@ (class "compact-block")) ,@(tmhtml arg)))
 	(tmhtml arg))))
 
@@ -699,12 +754,14 @@
 	(else (tmhtml arg))))
 
 (define (tmhtml-force-string x)
-  (cond ((func? x 'quote 1) (tmhtml-force-string (cadr x)))
+  (cond ((string? x) x)
+	((func? x 'quote 1) (tmhtml-force-string (cadr x)))
 	((func? x 'tmlen 1)
 	 (string-append (tmhtml-force-string (cadr x)) "tmpt"))
 	((func? x 'tmlen 3)
 	 (string-append (tmhtml-force-string (caddr x)) "tmpt"))
-	(else (force-string x))))
+	;;(else (force-string x))))
+	(else (texmacs->verbatim (tm->tree x)))))
 
 (define (tmhtml-with l)
   (cond ((null? l) '())
@@ -789,6 +846,8 @@
 	  ((string-ends? s ".tm")
 	   (string-append (string-drop-right s 3)
 			  (if tmhtml-mathml? ".xhtml" ".html")))
+	  ((string-ends? s ".texmacs")
+	   (string-append (string-drop-right s 8) ".tm"))
 	  (else s))))
 
 (define (tmhtml-hyperlink l)
@@ -802,7 +861,7 @@
 	`((h:a (@ (href ,(tmhtml-suffix to))) ,@body)))))
 
 (define (tmhtml-specific l)
-  (cond ((== (car l) "html") (tmhtml (cadr l)))
+  (cond ((== (car l) "html") (list (tmstring->string (force-string (cadr l)))))
 	((== (car l) "image") (tmhtml-png (cadr l)))
 	(else '())))
 
@@ -874,7 +933,7 @@
   (with part (tmhtml-width-part attrl)
     (if (== part 0) attrl
 	(with l (list-filter attrl (lambda (x) (!= (car x) "cell-width")))
-	  (with w (number->string (/ part sum))
+	  (with w (number->htmlstring (/ part sum))
 	    (cons (list "cell-width" (string-append w "par")) l))))))
 
 (define (tmhtml-make-cells l cellf)
@@ -921,7 +980,7 @@
 (define (tmhtml-make-table t tablef colf rowf cellf)
   (let* ((attrs (map* tmhtml-make-table-attr tablef))
 	 (em (- (* (tmtable-rows t) 0.55)))
-	 (va (string-append "vertical-align: " (number->string em) "em")))
+	 (va (string-append "vertical-align: " (number->htmlstring em) "em")))
     (if (not (list-find attrs (cut == <> "width: 100%")))
 	(set! attrs (cons* "display: inline" va attrs)))
     `(h:table ,@(html-css-attrs attrs)
@@ -940,30 +999,44 @@
 ;;; Pictures
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(define (tmhtml-collect-labels x)
+  (cond ((nlist? x) '())
+	((and (func? x 'label 1) (string? (cadr x))) `((id ,(cadr x))))
+	(else (append-map tmhtml-collect-labels (cdr x)))))
+
 (define (tmhtml-png-names)
-  (set! tmhtml-serial (+ tmhtml-serial 1))
-  (let* ((postfix (string-append "-" (number->string tmhtml-serial) ".png"))
+  (set! tmhtml-image-serial (+ tmhtml-image-serial 1))
+  (let* ((postfix (string-append
+		   "-" (number->string tmhtml-image-serial) ".png"))
 	 (name-url (url-glue tmhtml-image-root-url postfix))
 	 (name-string (string-append tmhtml-image-root-string postfix)))
     (values name-url name-string)))
 
-(define (tmhtml-png x)
-  (with cached (ahash-ref tmhtml-image-cache x)
-    (if (not cached)
-	(receive (name-url name-string) (tmhtml-png-names)
-	  (let* ((extents (print-snippet name-url x))
-		 (pixels (inexact->exact (/ (second extents) 2100)))
-		 (valign (number->string pixels))
-		 (style (string-append "vertical-align: " valign "px")))
-	    ;;(display* x " -> " extents "\n")
-	    (set! cached `((h:img (@ (src ,name-string) (style ,style)))))
-	    (ahash-set! tmhtml-image-cache x cached)))
-	cached)))
+(define (tmhtml-png y)
+  (let* ((mag (ahash-ref tmhtml-env :mag))
+	 (x (if (or (nstring? mag) (== mag "1")) y
+		`(with "font-size" ,mag ,y)))
+	 (l1 (tmhtml-collect-labels y))
+	 (l2 (if (null? l1) l1 (list (car l1)))))
+    (with cached (ahash-ref tmhtml-image-cache x)
+      (if (not cached)
+	  (receive (name-url name-string) (tmhtml-png-names)
+	    ;;(display* x " -> " name-url ", " name-string "\n")
+	    (let* ((extents (print-snippet name-url x))
+		   ;;(pixels (inexact->exact (/ (second extents) 2100)))
+		   (pixels (inexact->exact (/ (second extents) 2000)))
+		   (valign (number->htmlstring pixels))
+		   (style (string-append "vertical-align: " valign "px")))
+	      ;;(display* x " -> " extents "\n")
+	      (set! cached
+		    `((h:img (@ (src ,name-string) (style ,style) ,@l2))))
+	      (ahash-set! tmhtml-image-cache x cached)))
+	  cached))))
 
 (define (tmhtml-graphics l)
   (tmhtml-png (cons 'graphics l)))
 
-(define (tmhtml-postscript-name name)
+(define (tmhtml-image-name name)
   (with u (url-relative current-save-target (string->url name))
     (if (and (or (string-ends? name ".ps") (string-ends? name ".eps"))
 	     (url-exists? u))
@@ -972,12 +1045,12 @@
 	  name-string)
 	name)))
 
-(define (tmhtml-postscript l)
+(define (tmhtml-image l)
   ;; FIXME: Should also test that width and height are not magnifications.
   ;; Currently, magnifications make tmlength->htmllength return #f.
   (if (nstring? (first l))
-      (tmhtml-png (cons 'postscript l))
-      (let* ((s (tmhtml-postscript-name (cork->html (first l))))
+      (tmhtml-png (cons 'image l))
+      (let* ((s (tmhtml-image-name (cork->html (first l))))
 	     (w (tmlength->htmllength (second l) #f))
 	     (h (tmlength->htmllength (third l) #f)))
 	`((h:img (@ (src ,s)
@@ -1178,11 +1251,12 @@
       '()))
 
 (tm-define (tmhtml-root x)
-  (ahash-with tmhtml-env :math #f
-    (ahash-with tmhtml-env :preformatted #f
-      (ahash-with tmhtml-env :left-margin 0
-        (ahash-with tmhtml-env :right-margin 0
-          (tmhtml x))))))
+  (ahash-with tmhtml-env :mag "1"
+    (ahash-with tmhtml-env :math #f
+      (ahash-with tmhtml-env :preformatted #f
+	(ahash-with tmhtml-env :left-margin 0
+	  (ahash-with tmhtml-env :right-margin 0
+	    (tmhtml x)))))))
 
 (define (tmhtml x)
   ;; Main conversion function.
@@ -1207,8 +1281,9 @@
   (para tmhtml-paragraph)
   (surround tmhtml-surround)
   (concat tmhtml-concat)
+  (rigid tmhtml-id)
   (format tmhtml-noop)
-  (hspace tmhtml-vspace)
+  (hspace tmhtml-hspace)
   (vspace* tmhtml-vspace)
   (vspace tmhtml-vspace)
   (space tmhtml-hspace)
@@ -1242,7 +1317,7 @@
   (new-dpage* tmhtml-noop)
   (new-dpage tmhtml-noop)
 
-  (group tmhtml-id)
+  ((:or around around* big-around) tmhtml-concat)
   (left tmhtml-id)
   (mid tmhtml-id)
   (right tmhtml-id)
@@ -1304,7 +1379,7 @@
   ((:or switch fold exclusive progressive superposed) tmhtml-noop)
   (graphics tmhtml-graphics)
   ((:or point line arc bezier) tmhtml-noop)
-  (postscript tmhtml-postscript)
+  (image tmhtml-image)
 
   (!file tmhtml-file))
 
@@ -1350,6 +1425,7 @@
   (TeX ,(lambda x '("TeX")))
   (LaTeX ,(lambda x '("LaTeX")))
   ;; additional tags
+  (hidden-title ,tmhtml-noop)
   (doc-title-block ,tmhtml-doc-title-block)
   (equation* ,tmhtml-equation*)
   (equation-lab ,tmhtml-equation-lab)
