@@ -6,10 +6,9 @@
 ;;               which is understood by TeXmacs
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -30,7 +29,7 @@
   - / [ ] ! * | i j ss SS oe OE ae AE
   AA DH L NG O S TH aa dh dj l ng o th pounds
   quad qquad par smallskip medskip bigskip
-  noindent newline linebreak nolinebreak
+  noindent newline linebreak nobreak nolinebreak
   pagebreak nopagebreak newpage newdoublepage clearpage cleardoublepage
   newblock bgroup egroup protect cr date hfill appendix nolimits dots
   maketitle tableofcontents TeX LaTeX
@@ -38,9 +37,10 @@
 
   ;; temporarily
   hline
-
   ;; rewritten
-  notin vert Vert addots)
+  notin vert Vert addots
+  ;; wikipedia
+  infin rang)
 
 (drd-group latex-command-1%
   usepackage part part* chapter chapter*
@@ -54,21 +54,25 @@
   label ref pageref index hspace hspace* vspace vspace*
   mbox hbox text not
   ,(string->symbol "'") ,(string->symbol "`") ,(string->symbol "\"")
-  ^ over ~ = u v H t c d b k r thispagestyle ensuremath
+  ^ over atop ~ = u v H t c d b k r thispagestyle ensuremath
   mathord mathbin mathopen mathpunct mathop mathrel mathclose mathalpha
   arabic displaylines cases underbrace overbrace
-  includegraphics url penalty
   title author thanks
   phantom hphantom vphantom smash
+  newcounter stepcounter refstepcounter value
   citet citep citet* citep* citealt citealp citealt* citealp*
-  citetext citeauthor citeauthor* citeyear)
+  citetext citeauthor citeauthor* citeyear
+  includegraphics epsfig url penalty
+  enlargethispage)
 
 (drd-group latex-command-1% ;; . needs a special treatment
   ,(string->symbol "."))
 
 (drd-group latex-command-2%
-  binom choose sideset stackrel citeauthoryear setcounter equal
-  href)
+  binom choose cfrac tfrac
+  sideset stackrel citeauthoryear
+  equal href
+  setcounter addtocounter setlength addtolength)
 
 (drd-group latex-command-3%
   ifthenelse)
@@ -94,7 +98,7 @@
   documentclass documentstyle sqrt bibitem cite)
 
 (drd-group latex-command-2*%
-  def newcommand renewcommand frac)
+  def newcommand renewcommand newtheorem frac)
 
 (drd-group latex-command-3*%
   newenvironment renewenvironment)
@@ -115,7 +119,8 @@
 
 (drd-group latex-environment-0%
   begin-document begin-abstract begin-verbatim
-  begin-matrix begin-pmatrix begin-center begin-picture)
+  begin-matrix begin-pmatrix begin-bmatrix begin-vmatrix
+  begin-center begin-picture)
 
 (drd-group latex-environment-0*%
   begin-figure begin-table)
@@ -294,6 +299,8 @@
   ("hyperref" 140))
 
 (drd-table latex-needs%
+  (!verbatim "alltt")
+
   (geometry "geometry")
   (epsfig "epsfig")
   (includegraphics "graphicx")
