@@ -7,10 +7,9 @@
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -30,6 +29,9 @@
   (longrightarrowlim "\\mathop{\\longrightarrow}\\limits")
   (longleftrightarrowlim "\\mathop{\\longleftrightarrow}\\limits")
   (longmapstolim "\\mathop{\\longmapsto}\\limits")
+  (leftsquigarrowlim "\\mathop{\\leftsquigarrow}\\limits")
+  (rightsquigarrowlim "\\mathop{\\rightsquigarrow}\\limits")
+  (leftrightsquigarrowlim "\\mathop{\\leftrightsquigarrow}\\limits")
   (equallim "\\mathop{=}\\limits")
   (longequallim "\\mathop{\\longequal}\\limits")
   (Leftarrowlim "\\mathop{\\leftarrow}\\limits")
@@ -41,10 +43,10 @@
    
   ;; asymptotic relations by Joris
   (nasymp "\\not\\asymp")
-  (asympasymp "\\asymp\\!\\!\\!-")
-  (nasympasymp "\\not\\asymp\\!\\!\\!-")
-  (simsim "\\approx\\!\\!\\!-")
-  (nsimsim "\\not\\approx\\!\\!\\!-")
+  (asympasymp "{\\asymp\\!\\!\\!\\!\\!\\!-}")
+  (nasympasymp "{\\not\\asymp\\!\\!\\!\\!\\!\\!-}")
+  (simsim "{\\approx\\!\\!\\!\\!\\!\\!-}")
+  (nsimsim "{\\not\\approx\\!\\!\\!\\!\\!\\!-}")
   (npreccurlyeq "\\not\\preccurlyeq")
   (precprec "\\prec\\!\\!\\!\\prec")
   (precpreceq "\\preceq\\!\\!\\!\\preceq")
@@ -63,6 +65,7 @@
   (btimes "{\\mbox{\\rotatebox[origin=c]{90}{$\\ltimes$}}}")
   (Backepsilon "{\\mbox{\\rotatebox[origin=c]{180}{E}}}")
   (Mho "{\\mbox{\\rotatebox[origin=c]{180}{$\\Omega$}}}")
+  (mapmulti "{\\mbox{\\rotatebox[origin=c]{180}{$\\multimap$}}}")
   (mathcatalan "C")
   (mathd "\\mathrm{d}")
   (mathe "\\mathrm{e}")
@@ -84,11 +87,19 @@
   (Zeta "\\mathrm{Z}")
 
   ;; other extra symbols
+  (Exists "\\exists")
   (bigintwl "\\int")
   (bigointwl "\\oint")
-  (bignone "")
   (asterisk "*")
-  (nonesep "")
+  (point ".")
+  (cdummy "\\cdot")
+  (comma "{,}")
+  (bignone "")
+  (nobracket "")
+  (nospace "")
+  (nocomma "")
+  (noplus "")
+  (nosymbol "")
   (nin "\\not\\in")
   (nni "\\not\\ni")
   (notni "\\not\\ni")
@@ -249,7 +260,7 @@
   ("elsequation*" ((!begin "eqnarray*") (!append --- "&&")))
   ("theglossary"
    ((!begin "list" "" (!append "\\setlength{\\labelwidth}{6.5em}"
-			       "\\setlength{\\leftindent}{7em}"
+			       "\\setlength{\\leftmargin}{7em}"
 			       "\\small")) ---)))
 
 (drd-table latex-texmacs-env-arity%
@@ -357,12 +368,17 @@
     "    \\end{center}\n"
     "  \\end{minipage}}\n")))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Plain style theorems
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
 (define-macro (latex-texmacs-thmenv prim name before after)
   (with env-sym (string->symbol (string-append "begin-" prim))
     `(begin
        (drd-table latex-texmacs-env-preamble%
 	 (,prim (!append ,@before (newtheorem ,prim (!translate ,name))
-			 ,@after "\n")))
+			 ,@after "\n")
+		no-amsthm-package%))
        ;;;
        (drd-group latex-texmacs-tag% ,env-sym)
        (drd-group latex-environment-0% ,env-sym))))
@@ -394,6 +410,42 @@
 (latex-texmacs-exercise "exercise" "Exercise")
 (latex-texmacs-exercise "problem" "Problem")
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; AMS style theorems
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define-macro (ams-texmacs-theorem abbr full)
+  `(begin
+     (drd-table latex-texmacs-env-preamble%
+       (,abbr (!append "\\theoremstyle{plain}\n"
+		       (newtheorem ,abbr (!translate ,full))
+		       "\n")
+	      amsthm-package%))))
+
+(define-macro (ams-texmacs-remark abbr full)
+  `(begin
+     (drd-table latex-texmacs-env-preamble%
+       (,abbr (!append "\\theoremstyle{remark}\n"
+		       (newtheorem ,abbr (!translate ,full))
+		       "\n")
+	      amsthm-package%))))
+
+(ams-texmacs-theorem "theorem" "Theorem")
+(ams-texmacs-theorem "proposition" "Proposition")
+(ams-texmacs-theorem "lemma" "Lemma")
+(ams-texmacs-theorem "corollary" "Corollary")
+(ams-texmacs-theorem "axiom" "Axiom")
+(ams-texmacs-theorem "definition" "Definition")
+(ams-texmacs-theorem "notation" "Notation")
+(ams-texmacs-theorem "conjecture" "Conjecture")
+(ams-texmacs-remark "remark" "Remark")
+(ams-texmacs-remark "note" "Note")
+(ams-texmacs-remark "example" "Example")
+(ams-texmacs-remark "convention" "Convention")
+(ams-texmacs-remark "warning" "Warning")
+(ams-texmacs-remark "exercise" "Exercise")
+(ams-texmacs-remark "problem" "Problem")
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Style-dependent extra macros
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -466,73 +518,167 @@
 ;; Catcode tables
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(drd-table iso-latin-catcodes%
-  ("" "\\`a")
-  ("" "\\`A")
-  ("" "\\'a")
-  ("" "\\'A")
-  ("" "\\\"a")
-  ("" "\\\"A")
-  ("" "\\^a")
-  ("" "\\^A")
-  ("" "{\\aa}")
-  ("" "{\\AA}")
-  ("" "\\~A")
-  ("" "\\~a")
-  ("" "{\\AE}")
-  ("" "{\\ae}")
-  ("" "\\c{c}")
-  ("" "\\c{C}")
-  ("" "{\\dh}")
-  ("" "{\\DH}")
-  ("" "\\`e")
-  ("" "\\`E")
-  ("" "\\'e")
-  ("" "\\'E")
-  ("" "\\\"e")
-  ("" "\\\"E")
-  ("" "\\^e")
-  ("" "\\^E")
-  ("" "\\`{\\i}")
-  ("" "\\`I")
-  ("" "\\'{\\i}")
-  ("" "\\'I")
-  ("" "\\\"{\\i}")
-  ("" "\\\"I")
-  ("" "\\^{\\i}")
-  ("" "\\^I")
-  ("" "\\~N")
-  ("" "\\~n")
-  ("" "\\`o")
-  ("" "\\`O")
-  ("" "\\'o")
-  ("" "\\'O")
-  ("" "\\\"o")
-  ("" "\\\"O")
-  ("" "\\^o")
-  ("" "\\^O")
-  ("" "\\~O")
-  ("" "\\~o")
-  ("" "{\\O}")
-  ("" "{\\o}")
-  ("" "{\\ss}")
-  ("" "{\\th}")
-  ("" "{\\TH}")
-  ("" "\\`u")
-  ("" "\\`U")
-  ("" "\\'u")
-  ("" "\\'U")
-  ("" "\\\"u")
-  ("" "\\\"U")
-  ("" "\\^u")
-  ("" "\\^U")
-  ("" "\\'y")
-  ("" "\\'Y")
-  ("" "\\\"y")
-  ("" "\\\"Y")
-  ("" "!`")
-  ("" "?`")
-  ("" "?`"))
+(drd-table corkT1-to-latex-catcodes%
+  ("\x00" "\\`{ }")
+  ("\x01" "\\'{ }")
+  ("\x02" "\\^{ }")
+  ("\x03" "\\~{ }")
+  ("\x04" "\\\"{ }")
+  ("\x05" "\\H{ }")
+  ("\x06" "\\r{ }")
+  ("\x07" "\\v{ }")
+  ("\x08" "\\u{ }")
+  ("\x09" "\\b{ }")
+;  ("\x0A" "\\.{ }") ; newline may still be present in strings!!!
+  ("\x0B" "\\c{ }")
+  ("\x0C" "\\k{ }")
+  ("\x0D" ",")
+  ("\x0E" "{\\guilsinglleft}")
+  ("\x0F" "{\\guilsinglright}")
+  ("\x10" "``")
+  ("\x11" "''")
+  ("\x12" ",,")
+  ("\x13" "<<")
+  ("\x14" ">>")
+  ("\x15" "--")
+  ("\x16" "---")
+  ("\x17" "{}")
+  ("\x18" "{}")
+  ("\x19" "\\i")
+  ("\x1A" "\\j")
+  ("\x1B" "ff")
+  ("\x1C" "fi")
+  ("\x1D" "fl")
+  ("\x1E" "ffi")
+  ("\x1F" "ffl")
+  ("\x80" "\\u{A}")
+  ("\x81" "\\k{A}")
+  ("\x82" "\\'C")
+  ("\x83" "\\v{C}")
+  ("\x84" "\\v{D}")
+  ("\x85" "\\v{E}")
+  ("\x86" "\\k{E}")
+  ("\x87" "\\u{G}")
+  ("\x88" "\\'L")
+  ("\x89" "\\v{L}")
+  ("\x8A" "\\L")
+  ("\x8B" "\\'N")
+  ("\x8C" "\\v{N}")
+  ("\x8D" "{\\NG}")
+  ("\x8E" "\\H{O}")
+  ("\x8F" "\\'R")
+  ("\x90" "\\v{R}")
+  ("\x91" "\\'S")
+  ("\x92" "\\v{S}")
+  ("\x93" "\\c{S}")
+  ("\x94" "\\v{T}")
+  ("\x95" "\\c{T}")
+  ("\x96" "\\H{U}")
+  ("\x97" "\\r{U}")
+  ("\x98" "\\\"Y")
+  ("\x99" "\\'Z")
+  ("\x9A" "\\v{Z}")
+  ("\x9B" "\\.Z")
+  ("\x9C" "IJ")
+  ("\x9D" "\\.I")
+  ("\x9E" "{\\dj}")
+  ("\x9F" "{\\S}")
+  ("\xA0" "\\u{a}")
+  ("\xA1" "\\k{a}")
+  ("\xA2" "\\'c")
+  ("\xA3" "\\v{c}")
+  ("\xA4" "\\v{d}")
+  ("\xA5" "\\v{e}")
+  ("\xA6" "\\k{e}")
+  ("\xA7" "\\u{g}")
+  ("\xA8" "\\'l")
+  ("\xA9" "\\v{l}")
+  ("\xAA" "{\\l}")
+  ("\xAB" "\\'n")
+  ("\xAC" "\\v{n}")
+  ("\xAD" "{\\ng}")
+  ("\xAE" "\\H{o}")
+  ("\xAF" "\\'r")
+  ("\xB0" "\\v{r}")
+  ("\xB1" "\\'s")
+  ("\xB2" "\\v{s}")
+  ("\xB3" "\\c{s}")
+  ("\xB4" "\\v{t}")
+  ("\xB5" "\\c{t}")
+  ("\xB6" "\\H{u}")
+  ("\xB7" "\\r{u}")
+  ("\xB8" "\\\"y")
+  ("\xB9" "\\'z")
+  ("\xBA" "\\v{z}")
+  ("\xBB" "\\.z")
+  ("\xBC" "ij")
+  ("\xBD" "!`")
+  ("\xBE" "?`")
+  ("\xBF" "{\\pounds}")
+  ("\xC0" "\\`A")
+  ("\xC1" "\\'A")
+  ("\xC2" "\\^A")
+  ("\xC3" "\\~A")
+  ("\xC4" "\\\"A")
+  ("\xC5" "{\\AA}")
+  ("\xC6" "{\\AE}")
+  ("\xC7" "\\c{C}")
+  ("\xC8" "\\`E")
+  ("\xC9" "\\'E")
+  ("\xCA" "\\^E")
+  ("\xCB" "\\\"E")
+  ("\xCC" "\\`I")
+  ("\xCD" "\\'I")
+  ("\xCE" "\\^I")
+  ("\xCF" "\\\"I")
+  ("\xD0" "{\\DH}")
+  ("\xD1" "\\~N")
+  ("\xD2" "\\`O")
+  ("\xD3" "\\'O")
+  ("\xD4" "\\^O")
+  ("\xD5" "\\~O")
+  ("\xD6" "\\\"O")
+  ("\xD7" "{\\OE}")
+  ("\xD8" "{\\O}")
+  ("\xD9" "\\`U")
+  ("\xDA" "\\'U")
+  ("\xDB" "\\^U")
+  ("\xDC" "\\\"U")
+  ("\xDD" "\\'Y")
+  ("\xDE" "{\\TH}")
+  ("\xDF" "{\\SS}")
+  ("\xE0" "\\`a")
+  ("\xE1" "\\'a")
+  ("\xE2" "\\^a")
+  ("\xE3" "\\~a")
+  ("\xE4" "\\\"a")
+  ("\xE5" "{\\aa}")
+  ("\xE6" "{\\ae}")
+  ("\xE7" "\\c{c}")
+  ("\xE8" "\\`e")
+  ("\xE9" "\\'e")
+  ("\xEA" "\\^e")
+  ("\xEB" "\\\"e")
+  ("\xEC" "\\`{\\i}")
+  ("\xED" "\\'{\\i}")
+  ("\xEE" "\\^{\\i}")
+  ("\xEF" "\\\"{\\i}")
+  ("\xF0" "{\\dh}")
+  ("\xF1" "\\~n")
+  ("\xF2" "\\`o")
+  ("\xF3" "\\'o")
+  ("\xF4" "\\^o")
+  ("\xF5" "\\~o")
+  ("\xF6" "\\\"o")
+  ("\xF7" "{\\oe}")
+  ("\xF8" "{\\o}")
+  ("\xF9" "\\`u")
+  ("\xFA" "\\'u")
+  ("\xFB" "\\^u")
+  ("\xFC" "\\\"u")
+  ("\xFD" "\\'y")
+  ("\xFE" "{\\th}")
+  ("\xFF" "{\\ss}"))
 
 (drd-table cyrillic-catcodes%
   ("" "\\CYRA")
