@@ -5,10 +5,9 @@
 ;; DESCRIPTION : conversion of TeXmacs trees into TeX/LaTeX trees
 ;; COPYRIGHT   : (C) 2002  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -21,12 +20,14 @@
 	(convert latex texout)
 	(convert latex latex-tools)))
 
+(use-modules (ice-9 format))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Global variables
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(define tmtex-style "generic")
-(define tmtex-packages '())
+(define-public tmtex-style "generic")
+(define-public tmtex-packages '())
 (define tmtex-env (make-ahash-table))
 (define tmtex-serial 0)
 (define tmtex-auto-produce 0)
@@ -47,13 +48,12 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (texmacs-modes
-  (elsevier-style% (in? tmtex-style '("elsart")))
+  (elsevier-style% (in? tmtex-style '("elsart" "jsc")))
+  (jsc-style% (in? tmtex-style '("jsc")) elsevier-style%)
   (natbib-package% (in? "cite-author-year" tmtex-packages)))
 
-(define (tmtex-set-style style body)
-  (set! tmtex-style (car style))
-  (set! tmtex-packages (cdr style))
-  (if (elsevier-style?) (init-elsevier body)))
+(tm-define (tmtex-style-init body)
+  (noop))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Language
@@ -270,7 +270,6 @@
 		       ;;(cv (string-convert qs "Cork" "cp936")) ; Chinese?
 		       ;;(cv (string-convert qs "Cork" "cp950")) ; Taiwanese ?
 		       (cv (string-convert qs "Cork" "UTF-8")))
-		  (set! cv (string-append cv ex))
 		  (list '!widechar (string->symbol cv))))))
 	(else (let ((ss (list (string->symbol s))))
 		(cond ((not (drd-in? (car ss) latex-symbol%))
@@ -316,8 +315,6 @@
 	      ((== c #\22) (tmtex-text-sub ",," l))
 	      ((== c #\25) (tmtex-text-sub "--" l))
 	      ((== c #\26) (tmtex-text-sub "---" l))
-	      ((== c #\337) (tmtex-text-sub "SS" l))
-	      ((== c #\377) (tmtex-text-sub "" l))
 	      (else (cons c (tmtex-text-list (cdr l))))))))
 
 (define (tmtex-math-operator l)
@@ -428,13 +425,22 @@
 	((== (car l) 'hide-preamble) "")
 	(else (cons (car l) (map tmtex-filter-body (cdr l))))))
 
+(define (tmtex-apply-init body init)
+  ;;(display* "init= " init "\n")
+  (cond ((== (assoc-ref init "language") "verbatim")
+	 (with init* (assoc-remove! init "language")
+	   (tmtex-apply-init `(verbatim ,body) init*)))
+	(else body)))
+
 (define (tmtex-file l)
   (let* ((doc (car l))
 	 (styles (cadr l))
 	 (lang (caddr l))
 	 (init (cadddr l))
+	 (init-bis (map (lambda (x) (cons (cadr x) (caddr x))) (cdr init)))
 	 (doc-preamble (tmtex-filter-preamble doc))
-	 (doc-body (tmtex-filter-body doc)))
+	 (doc-body-pre (tmtex-filter-body doc))
+	 (doc-body (tmtex-apply-init doc-body-pre init-bis)))
     (if (== (get-preference "texmacs->latex:expand-user-macros") "on")
 	(set! doc-preamble '()))
     (if (null? styles) (tmtex doc)
@@ -507,7 +513,7 @@
       (tex-concat (tmtex-math-concat-spaces (tmtex-list l)))
       (tex-concat (tmtex-list (tmtex-rewrite-no-break l)))))
 
-(define (tmtex-group l)
+(define (tmtex-rigid l)
   (tmtex-function '!group l))
 
 (define (tmtex-no-first-indentation l) (tex-apply 'noindent))
@@ -587,6 +593,15 @@
 ;; Mathematics
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(define (tmtex-around l)
+  (tmtex-concat (cdr (downgrade-brackets (cons 'around l)))))
+
+(define (tmtex-around* l)
+  (tmtex-concat (cdr (downgrade-brackets (cons 'around* l)))))
+
+(define (tmtex-big-around l)
+  (tmtex-concat (cdr (downgrade-brackets (cons 'big-around l)))))
+
 (define (tmtex-large-decode s)
   (cond ((nstring? s) ".")
         ((in? s '("(" ")" "[" "]" "|" "/" ".")) s)
@@ -595,7 +610,14 @@
 	(else (string-append "\\" s))))
 
 (define (tmtex-left l)
-  (list (string->symbol (string-append "left" (tmtex-large-decode (car l))))))
+  (let* ((s (tmtex-large-decode (car l)))
+	 (n (if (> (length l) 1) (string->number (cadr l)) 0))
+	 (b (cond ((= n 1) "bigl")
+		  ((= n 2) "Bigl")
+		  ((= n 3) "biggl")
+		  ((= n 4) "Biggl")
+		  (else "left"))))
+    (list (string->symbol (string-append b s)))))
 
 (define (tmtex-mid l)
   (let ((s (tmtex-large-decode (car l))))
@@ -604,7 +626,14 @@
 	s)))
 
 (define (tmtex-right l)
-  (list (string->symbol (string-append "right" (tmtex-large-decode (car l))))))
+  (let* ((s (tmtex-large-decode (car l)))
+	 (n (if (> (length l) 1) (string->number (cadr l)) 0))
+	 (b (cond ((= n 1) "bigr")
+		  ((= n 2) "Bigr")
+		  ((= n 3) "biggr")
+		  ((= n 4) "Biggr")
+		  (else "right"))))
+    (list (string->symbol (string-append b s)))))
 
 (define (tmtex-big-decode s)
   (cond ((nstring? s) "bignone")
@@ -881,7 +910,13 @@
 	      ((== "par-first" var) (tmtex-make-parmod "0pt" "0pt" val arg))
 	      ((== "par-par-sep" var) (tmtex-make-parsep val arg))
 	      ((== var "color")
-	      	(list '!group (tex-concat (list (list 'color val) " " arg))))
+	        (if (and (= (string-length val) 7) (char=? (string-ref val 0) #\#))
+		  (let* ((r (quotient (* (string->number (substring val 1 3) 16) 1000) 255))
+			 (g (quotient (* (string->number (substring val 3 5) 16) 1000) 255))
+			 (b (quotient (* (string->number (substring val 5 7) 16) 1000) 255))
+			 (rgb (format #f "~,,-3f,~,,-3f,~,,-3f" r g b)))
+		    (list '!group (tex-concat (list (list 'color (list '!option "rgb") rgb) " " arg))))
+		  (list '!group (tex-concat (list (list 'color val) " " arg)))))
 	      (else arg)))))
 
 (define (tmtex-with l)
@@ -1007,7 +1042,7 @@
 	    (convert-to-file u fm "postscript-file" name-url)
 	    (list 'includegraphics name-string))))))
 
-(define (tmtex-postscript l)
+(define (tmtex-image l)
   (let* ((fig (tmtex-as-eps (force-string (car l))))
 	 (hor (if (== (cadr l) "") "!" (tmtex-decode-length (cadr l))))
 	 (ver (if (== (caddr l) "") "!" (tmtex-decode-length (caddr l)))))
@@ -1235,28 +1270,36 @@
 (define (tmtex-nbsp s l)
   '(!nbsp))
 
+(define (tmtex-nbhyph s l)
+  '(!nbhyph))
+
 (define (tmtex-session s l)
-  (tmtex (car l)))
+  (tmtex (cAr l)))
 
 (define (tmtex-input s l)
   (let ((prompt (car l)) (x (cadr l)))
     (tex-concat
-     (list `(!group (!concat (color "red") (ttfamily ,(tmtex prompt))))
+     (list '(noindent)
+	   `(!group (!concat (color "red") (ttfamily ,(tmtex prompt))))
 	   (cond ((func? x 'math 1)
 		  (tmtex-env-set "mode" "math")
 		  (let ((r (tmtex (cadr x))))
 		    (tmtex-env-reset "mode")
 		    `(!math (!group (!concat (color "blue") ,r)))))
 		 (else `(!group (!concat (color "blue")
-					 (!verb ,(tmtex-tt x))))))))))
+					 (!verb ,(tmtex-tt x))))))
+	   '(smallskip)))))
 
 (define (tmtex-output s l)
-  (list '!group (list 'ttfamily (tmtex (car l)))))
+  (tex-concat
+   (list '(noindent)
+	 (list '!group (list 'ttfamily (tmtex (car l))))
+	 '(medskip))))
 
 (define (tmtex-hlink s l)
   (list 'href (tmtex (cadr l)) (tmtex (car l))))
 
-(define (tmtex-slink s l)
+(define (tmtex-href s l)
   (tmtex-function 'url l))
 
 (define (tmtex-action s l)
@@ -1410,7 +1453,7 @@
   (para tmtex-para)
   (surround tmtex-surround)
   (concat tmtex-concat)
-  (group tmtex-group)
+  (rigid tmtex-rigid)
   (hidden tmtex-noop)
   (hspace tmtex-hspace)
   (vspace* tmtex-noop)
@@ -1441,6 +1484,9 @@
   (new-dpage* tmtex-noop)
   (new-dpage tmtex-noop)
 
+  (around tmtex-around)
+  (around* tmtex-around*)
+  (big-around tmtex-big-around)
   (left tmtex-left)
   (mid tmtex-mid)
   (right tmtex-right)
@@ -1515,7 +1561,7 @@
   (superpose tmtex-noop)
   ((:or gr-group gr-linear-transform
 	text-at cline arc carc spline spine* cspline fill) tmtex-noop)
-  (postscript tmtex-postscript)
+  (image tmtex-image)
   ((:or box-info frame-direct frame-inverse) tmtex-noop)
 
   ((:or format line-sep split delay hold release
@@ -1583,12 +1629,13 @@
   (item* (,tmtex-item-arg 1))
   (render-proof (,tmtex-render-proof 2))
   (nbsp (,tmtex-nbsp 0))
-  (session (,tmtex-session 1))
+  (nbhyph (,tmtex-nbhyph 0))
+  (session (,tmtex-session -1))
   (input (,tmtex-input 2))
   (output (,tmtex-output 1))
   (hlink (,tmtex-hlink 2))
-  (action (,tmtex-action 2))
-  (slink (,tmtex-slink 1))
+  (action (,tmtex-action -1))
+  (href (,tmtex-href 1))
   (choose (,tmtex-choose 2))
   ((:or strong em tt name samp abbr dfn kbd var acronym person)
    (,tmtex-modifier 1))
@@ -1667,18 +1714,15 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define (tmtex-get-style sty)
-  (cond ((string? sty) (set! sty (list sty)))
+  (cond ((not sty) (set! sty (list "generic")))
+	((string? sty) (set! sty (list sty)))
 	((func? sty 'tuple) (set! sty (cdr sty)))
 	((null? sty) (set! sty '("letter"))))
   (if (== (car sty) "generic") (set! sty (cons "letter" (cdr sty))))
   sty)
 
-(define (find? x what)
-  (cond ((== x what) #t)
-	((nlist? x) #f)
-	(else (list-or (map (cut find? <> what) x)))))
-
 (tm-define (texmacs->latex x opts)
+  ;;(display* "texmacs->latex [" opts "], " x "\n")
   (if (tmfile? x)
       (let* ((body (tmfile-extract x 'body))
 	     (style (tmtex-get-style (tmfile-extract x 'style)))
@@ -1687,11 +1731,17 @@
 	     (init (tmfile-extract x 'initial))
 	     (doc (list '!file body style lan init (get-texmacs-path))))
 	(latex-set-style main-style)
+	(latex-set-packages '())
 	(latex-set-language lan)
-	(tmtex-set-style style body)
+	(set! tmtex-style (car style))
+	(set! tmtex-packages (cdr style))
+	(when (elsevier-style?)
+	  (import-from (convert latex tmtex-elsevier)))
+	(tmtex-style-init body)
 	(tmtex-set-language lan)
 	(with result (texmacs->latex doc opts)
-	  (tmtex-set-style '("generic") "")
+	  (set! tmtex-style "generic")
+	  (set! tmtex-packages '())
 	  (tmtex-set-language "english")
 	  result))
       (let* ((x2 (tmtm-eqnumber->nonumber x))
