@@ -5,17 +5,17 @@
 ;; DESCRIPTION : conversion of TeXmacs trees into MathML trees
 ;; COPYRIGHT   : (C) 2004  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (texmacs-module (convert mathml tmmath)
   (:use (convert tools tmconcat)
 	(convert tools tmtable)
-	(convert mathml mathml-drd)))
+	(convert mathml mathml-drd)
+	(convert rewrite tmtm-brackets)))
 
 (define tmmath-env (make-ahash-table))
 
@@ -58,9 +58,18 @@
 ;; Mathematics
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(define (tmmath-group l)
+(define (tmmath-rigid l)
   `(m:mrow ,(tmmath (car l))))
 
+(define (tmmath-around l)
+  (tmmath-concat (cdr (downgrade-brackets (cons 'around l)))))
+
+(define (tmmath-around* l)
+  (tmmath-concat (cdr (downgrade-brackets (cons 'around* l)))))
+
+(define (tmmath-big-around l)
+  (tmmath-concat (cdr (downgrade-brackets (cons 'big-around l)))))
+
 (define (tmmath-large x)
   (with y (drd-ref tm->mathml-large% x)
     (if y y (cork->utf8 x))))
@@ -277,7 +286,10 @@
   ;; Mathematics
   (concat tmmath-concat)
   (concat! tmmath-concat!)
-  (group tmmath-group)
+  (rigid tmmath-rigid)
+  (around tmmath-around)
+  (around* tmmath-around*)
+  (big-around tmmath-big-around)
   (left tmmath-left)
   (mid tmmath-mid)
   (right tmmath-right)
