@@ -5,10 +5,9 @@
 ;; DESCRIPTION : data relation definitions for dynamic tags
 ;; COPYRIGHT   : (C) 2005  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -34,6 +33,7 @@
 (define-fold folded unfolded)
 (define-fold folded-plain unfolded-plain)
 (define-fold folded-std unfolded-std)
+(define-fold folded-explain unfolded-explain)
 (define-fold folded-env unfolded-env)
 (define-fold folded-grouped unfolded-grouped)
 
@@ -82,3 +82,11 @@
 
 (define-group expanded-tag
   expanded slides)
+
+;; ornaments
+
+(define-group ornament-tag
+  granite manila-paper metal pine rough-paper ridged-paper)
+
+(define-group variant-tag (ornament-tag))
+(define-group similar-tag (ornament-tag))
