@@ -454,7 +454,7 @@
 	 (cond ((== mode :var-last)
 		(switch-set-range t 1 :last #f)
 		(switch-set t 0 #t)
-		(tree-insert-unary t 0 '(traversed)))
+		(tree-insert-node t 0 '(traversed)))
 	       ((== mode :first)
 		(switch-set-range t 1 :last #f)
 		(switch-set t 0 #t))
@@ -501,7 +501,6 @@
   (dynamic-operate (tree-ref t 0) :var-expand))
 
 (tm-define (dynamic-make-slides)
-  (init-remove-package "presentation")
   (init-add-package "slides")
   (init-default "page-medium" "page-type" "page-width" "page-height"
 		"page-width-margin" "page-height-margin"
