@@ -5,10 +5,9 @@
 ;; DESCRIPTION : menus for setting global document properties
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -29,6 +28,60 @@
   ---
   ("Other style" (interactive init-style)))
 
+(menu-bind document-view-menu
+  ("Edit source tree" (toggle-preamble))
+  (-> "Informative flags"
+      ("Default" (init-default "info-flag"))
+      ---
+      ("None" (init-env "info-flag" "none"))
+      ("Short" (init-env "info-flag" "short"))
+      ("Detailed" (init-env "info-flag" "detailed"))
+      ("Also on paper" (init-env "info-flag" "paper")))
+  (-> "Page layout"
+      ("Default" (init-default "page-screen-margin" "page-show-hf"
+			       "page-screen-left" "page-screen-right"
+			       "page-screen-top" "page-screen-bot"))
+      ---
+      ("Show header and footer" (toggle-visible-header-and-footer))
+      ("Margins as on paper" (toggle-page-screen-margin))
+      ---
+      (when (test-env? "page-screen-margin" "true")
+	("Left margin" (init-interactive-env "page-screen-left"))
+	("Right margin" (init-interactive-env "page-screen-right"))
+	("Top margin" (init-interactive-env "page-screen-top"))
+	("Bottom margin" (init-interactive-env "page-screen-bot"))))
+  ---
+  (group "Source tags")
+  (-> "Style"
+      ("Default" (init-default "src-style"))
+      ---
+      ("Angular" (init-env "src-style" "angular"))
+      ("Scheme" (init-env "src-style" "scheme"))
+      ("Functional" (init-env "src-style" "functional"))
+      ("Latex" (init-env "src-style" "latex")))
+  (-> "Special"
+      ("Default" (init-default "src-special"))
+      ---
+      ("None" (init-env "src-special" "raw"))
+      ("Formatting" (init-env "src-special" "format"))
+      ("Normal" (init-env "src-special" "normal"))
+      ("Maximal" (init-env "src-special" "maximal")))
+  (-> "Compactification"
+      ("Default" (init-default "src-compact"))
+      ---
+      ("Minimal" (init-env "src-compact" "none"))
+      ("Only inline tags" (init-env "src-compact" "inline"))
+      ("Normal" (init-env "src-compact" "normal"))
+      ("Inline arguments" (init-env "src-compact" "inline args"))
+      ("Maximal" (init-env "src-compact" "all")))
+  (-> "Closing style"
+      ("Default" (init-default "src-close"))
+      ---
+      ("Repeat" (init-env "src-close" "repeat"))
+      ("Stretched" (init-env "src-close" "long"))
+      ("Compact" (init-env "src-close" "compact"))
+      ("Minimal" (init-env "src-close" "minimal"))))
+
 (menu-bind global-language-menu
   ("British"
    (begin
@@ -38,9 +91,14 @@
    (begin
      (init-language "bulgarian")
      (set-output-language "bulgarian")))
+  (when (supports-chinese?)
+    ("Chinese"
+     (begin
+       (init-language "chinese")
+       (set-output-language "chinese"))))
   ("Czech"
    (begin
-     (init-language "czech")
+     (init-language <"czech")
      (set-output-language "czech")))
   ("Danish"
    (begin
@@ -74,6 +132,16 @@
    (begin
      (init-language "italian")
      (set-output-language "italian")))
+  (when (supports-japanese?)
+    ("Japanese"
+     (begin
+       (init-language "japanese")
+       (set-output-language "japanese"))))
+  (when (supports-korean?)
+    ("Korean"
+     (begin
+       (init-language "korean")
+       (set-output-language "korean"))))
   ("Polish"
    (begin
      (init-language "polish")
@@ -102,6 +170,11 @@
    (begin
      (init-language "swedish")
      (set-output-language "swedish")))
+  (when (supports-chinese?)
+    ("Taiwanese"
+     (begin
+       (init-language "taiwanese")
+       (set-output-language "taiwanese"))))
   ("Ukrainian"
    (begin
      (init-language "ukrainian")
@@ -113,78 +186,27 @@
 
 (menu-bind document-menu
   (-> "Style" (link document-style-menu))
-  (-> "Add package"
-      (link add-package-menu)
-      ---
-      ("Other" (interactive init-add-package)))
-  (-> "Remove package"
-      (link remove-package-menu)
-      ---
-      ("Other" (interactive init-remove-package)))
-  (if (!= (get-init-tree "sectional-short-style") (tree 'macro "false"))
-      (-> "Part" (link document-part-menu)))
-  (-> "View"
-      ("Edit source tree" (toggle-preamble))
-      (-> "Informative flags"
-	  ("Default" (init-default "info-flag"))
+  (if (detailed-menus?)
+      (-> "Add package"
+	  (link add-package-menu)
 	  ---
-	  ("None" (init-env "info-flag" "none"))
-	  ("Short" (init-env "info-flag" "short"))
-	  ("Detailed" (init-env "info-flag" "detailed"))
-	  ("Also on paper" (init-env "info-flag" "paper")))
-      (-> "Page layout"
-	  ("Default" (init-default "page-screen-margin" "page-show-hf"
-				   "page-screen-left" "page-screen-right"
-				   "page-screen-top" "page-screen-bot"))
+	  ("Other" (interactive init-add-package)))
+      (-> "Remove package"
+	  (link remove-package-menu)
 	  ---
-	  ("Show header and footer" (toggle-visible-header-and-footer))
-	  ("Margins as on paper" (toggle-page-screen-margin))
-	  ---
-	  (when (test-env? "page-screen-margin" "true")
-		("Left margin" (init-interactive-env "page-screen-left"))
-		("Right margin" (init-interactive-env "page-screen-right"))
-		("Top margin" (init-interactive-env "page-screen-top"))
-		("Bottom margin" (init-interactive-env "page-screen-bot"))))
-      ---
-      (group "Source tags")
-      (-> "Style"
-	  ("Default" (init-default "src-style"))
-	  ---
-	  ("Angular" (init-env "src-style" "angular"))
-	  ("Scheme" (init-env "src-style" "scheme"))
-	  ("Functional" (init-env "src-style" "functional"))
-	  ("Latex" (init-env "src-style" "latex")))
-      (-> "Special"
-	  ("Default" (init-default "src-special"))
-	  ---
-	  ("None" (init-env "src-special" "raw"))
-	  ("Formatting" (init-env "src-special" "format"))
-	  ("Normal" (init-env "src-special" "normal"))
-	  ("Maximal" (init-env "src-special" "maximal")))
-      (-> "Compactification"
-	  ("Default" (init-default "src-compact"))
-	  ---
-	  ("Minimal" (init-env "src-compact" "none"))
-	  ("Only inline tags" (init-env "src-compact" "inline"))
-	  ("Normal" (init-env "src-compact" "normal"))
-	  ("Inline arguments" (init-env "src-compact" "inline args"))
-	  ("Maximal" (init-env "src-compact" "all")))
-      (-> "Closing style"
-	  ("Default" (init-default "src-close"))
-	  ---
-	  ("Repeat" (init-env "src-close" "repeat"))
-	  ("Stretched" (init-env "src-close" "long"))
-	  ("Compact" (init-env "src-close" "compact"))
-	  ("Minimal" (init-env "src-close" "minimal"))))
+	  ("Other" (interactive init-remove-package)))
+      (if (!= (get-init-tree "sectional-short-style") (tree 'macro "false"))
+	  (-> "Part" (link document-part-menu)))
+      (-> "View" (link document-view-menu)))
   ---
   (-> "Font"
       (-> "Text font"
 	  ("Default" (init-default "font"))
 	  ---
-	  ("Roman" (init-env "font" "roman"))
-	  ("Pandora" (init-env "font" "pandora"))
 	  ("Concrete" (init-env "font" "concrete"))
 	  ("Cyrillic" (init-env "font" "cyrillic"))
+	  ("Pandora" (init-env "font" "pandora"))
+	  ("Roman" (init-env "font" "roman"))
 	  ---
 	  ("Bookman" (init-env "font" "bookman"))
 	  ("Courier" (init-env "font" "courier"))
@@ -192,24 +214,93 @@
 	  ("Palatino" (init-env "font" "palatino"))
 	  ("Times" (init-env "font" "times"))
 	  ---
+	  (if (font-exists-in-tt? "DejaVuSerif")
+	      ("Dejavu" (init-env "font" "dejavu")))
+	  ("Lucida" (init-env "font" "x-lucida"))
 	  (if (> (get-font-type) 0)
 	      (if (font-exists-in-tt? "luxirr")
 		  ("Luxi" (init-env "font" "luxi"))))
-	  ("Lucida" (init-env "font" "x-lucida"))
-	  ("Utopia" (init-env "font" "x-utopia")))
+	  (if (font-exists-in-tt? "STIXGeneral")
+	      ("Stix" (init-env "font" "stix")))
+	  ("Utopia" (init-env "font" "x-utopia"))
+	  (if (or (supports-chinese?)
+		  (supports-japanese?)
+		  (supports-korean?))
+	      ---
+	      (if (font-exists-in-tt? "Batang")
+		  ("Batang" (init-env "font" "batang")))
+	      (if (font-exists-in-tt? "fireflysung")
+		  ("Fireflysung" (init-env "font" "fireflysung")))
+	      (if (font-exists-in-tt? "AppleGothic")
+		  ("Gothic" (init-env "font" "apple-gothic")))
+	      (if (font-exists-in-tt? "Gulim")
+		  ("Gulim" (init-env "font" "gulim")))
+	      (if (font-exists-in-tt? "华文细黑")
+		  ("HeiTi" (init-env "font" "heiti")))
+	      (if (font-exists-in-tt? "ヒラギノ明朝 ProN W6")
+		  ("Hiragino Kaku" (init-env "font" "kaku")))
+	      (if (font-exists-in-tt? "ipam")
+		  ("Ipa" (init-env "font" "ipa")))
+	      (if (font-exists-in-tt? "kochi-mincho")
+		  ("Kochi" (init-env "font" "kochi")))
+	      (if (font-exists-in-tt? "儷黑 Pro")
+		  ("LiHei" (init-env "font" "lihei")))
+	      (if (font-exists-in-tt? "wqy-microhei")
+		  ("MicroHei" (init-env "font" "wqy-microhei")))
+	      (if (font-exists-in-tt? "mingliu")
+		  ("MingLiU" (init-env "font" "mingliu")))
+	      (if (font-exists-in-tt? "PMingLiU")
+		  ("MingLiU" (init-env "font" "pmingliu")))	      
+	      (if (font-exists-in-tt? "MS Gothic")
+		  ("MS Gothic" (init-env "font" "ms-gothic")))
+	      (if (font-exists-in-tt? "MS Mincho")
+		  ("MS Mincho" (init-env "font" "ms-mincho")))
+	      (if (font-exists-in-tt? "simfang")
+		  ("SimFang" (init-env "font" "simfang")))
+	      (if (font-exists-in-tt? "simhei")
+		  ("SimHei" (init-env "font" "simhei")))
+	      (if (font-exists-in-tt? "simkai")
+		  ("SimKai" (init-env "font" "simkai")))
+	      (if (font-exists-in-tt? "simli")
+		  ("SimLi" (init-env "font" "simli")))
+	      (if (font-exists-in-tt? "simsun")
+		  ("SimSun" (init-env "font" "simsun")))
+	      (if (and (font-exists-in-tt? "SimSun")
+		       (not (font-exists-in-tt? "simsun")))
+		  ("SimSun" (init-env "font" "apple-simsun")))
+	      (if (font-exists-in-tt? "simyou")
+		  ("SimYou" (init-env "font" "simyou")))
+	      (if (font-exists-in-tt? "ukai")
+		  ("UKai" (init-env "font" "ukai")))
+	      (if (font-exists-in-tt? "unbatang")
+		  ("Unbatang" (init-env "font" "unbatang")))
+	      (if (font-exists-in-tt? "uming")
+		  ("UMing" (init-env "font" "uming")))
+	      (if (font-exists-in-tt? "wqy-zenhei")
+		  ("ZenHei" (init-env "font" "wqy-zenhei")))))
       (-> "Mathematical font"
 	  ("Default" (init-default "math-font"))
 	  ---
-	  ("Roman" (init-env "math-font" "roman"))
+	  ("Adobe" (init-env "math-font" "adobe"))
+	  (if (font-exists-in-tt? "Apple Symbols")
+	      ("Apple symbols" (init-env "math-font" "math-apple")))
+	  (if (font-exists-in-tt? "Asana-Math")
+	      ("Asana" (init-env "math-font" "math-asana")))
 	  ("Concrete" (init-env "math-font" "concrete"))
+	  (if (font-exists-in-tt? "DejaVuSerif")
+	      ("Dejavu" (init-env "math-font" "math-dejavu")))
 	  ("Euler new roman" (init-env "math-font" "ENR"))
-	  ("Adobe" (init-env "math-font" "adobe")))
+	  (if (font-exists-in-tt? "LucidaGrande")
+	      ("Lucida" (init-env "math-font" "math-lucida")))
+	  ("Roman" (init-env "math-font" "roman"))
+	  (if (font-exists-in-tt? "STIXGeneral")
+	      ("Stix" (init-env "math-font" "math-stix"))))
       (-> "Program font"
 	  ("Default" (init-default "prog-font"))
 	  ---
-	  ("Roman" (init-env "prog-font" "roman"))
-	  ("Pandora" (init-env "prog-font" "pandora"))
 	  ("Concrete" (init-env "prog-font" "concrete"))
+	  ("Pandora" (init-env "prog-font" "pandora"))
+	  ("Roman" (init-env "prog-font" "roman"))
 	  ("Times" (init-env "prog-font" "times")))
       ---
       (-> "Size"
@@ -222,7 +313,7 @@
 	  ("12" (init-env "font-base-size" "12"))
 	  ("14" (init-env "font-base-size" "14"))
 	  ---
-	  ("Other" (init-interactive-env "font-size")))
+	  ("Other" (init-interactive-env "font-base-size")))
       (-> "Dpi"
 	  ("Default" (init-default "dpi"))
 	  ---
@@ -234,7 +325,7 @@
 	  ("800" (init-env "dpi" "800"))
 	  ("1200" (init-env "dpi" "1200"))
 	  ---
-	  ("Other" (init-interactive-dpi "dpi"))))
+	  ("Other" (init-interactive-env "dpi"))))
   (-> "Magnification"
       ("Default" (init-default "magnification"))
       ---
@@ -283,28 +374,37 @@
 	  ("Broken white" (init-env "bg-color" "broken white"))
 	  ---
 	  ("Other" (init-interactive-env "bg-color"))))
-  (-> "Language"
-      ("Default" (init-default "language"))
-      ---
-      ("British" (init-language "british"))
-      ("Bulgarian" (init-language "bulgarian"))
-      ("Czech" (init-language "czech"))
-      ("Danish" (init-language "danish"))
-      ("Dutch" (init-language "dutch"))
-      ("English" (init-language "english"))
-      ("Finnish" (init-language "finnish"))
-      ("French" (init-language "french"))
-      ("German" (init-language "german"))
-      ("Hungarian" (init-language "hungarian"))
-      ("Italian" (init-language "italian"))
-      ("Polish" (init-language "polish"))
-      ("Portuguese" (init-language "portuguese"))
-      ("Romanian" (init-language "romanian"))
-      ("Russian" (init-language "russian"))
-      ("Slovene" (init-language "slovene"))
-      ("Spanish" (init-language "spanish"))
-      ("Swedish" (init-language "swedish"))
-      ("Ukrainian" (init-language "ukrainian")))
+  (if (detailed-menus?)
+      (-> "Language"
+	  ("Default" (init-default "language"))
+	  ---
+	  ("British" (init-language "british"))
+	  ("Bulgarian" (init-language "bulgarian"))
+	  (when (supports-chinese?)
+	    ("Chinese" (init-language "chinese")))
+	  ("Czech" (init-language "czech"))
+	  ("Danish" (init-language "danish"))
+	  ("Dutch" (init-language "dutch"))
+	  ("English" (init-language "english"))
+	  ("Finnish" (init-language "finnish"))
+	  ("French" (init-language "french"))
+	  ("German" (init-language "german"))
+	  ("Hungarian" (init-language "hungarian"))
+	  ("Italian" (init-language "italian"))
+	  (when (supports-japanese?)
+	    ("Japanese" (init-language "japanese")))
+	  (when (supports-korean?)
+	    ("Korean" (init-language "korean")))
+	  ("Polish" (init-language "polish"))
+	  ("Portuguese" (init-language "portuguese"))
+	  ("Romanian" (init-language "romanian"))
+	  ("Russian" (init-language "russian"))
+	  ("Slovene" (init-language "slovene"))
+	  ("Spanish" (init-language "spanish"))
+	  ("Swedish" (init-language "swedish"))
+	  (when (supports-chinese?)
+	    ("Taiwanese" (init-language "taiwanese")))
+	  ("Ukrainian" (init-language "ukrainian"))))
   (-> "Scripts"
       ("Default" (init-default "prog-scripts"))
       ---
@@ -447,27 +547,28 @@
 		("Paragraph width" (init-interactive-env "par-width"))
 		("Odd page shift" (init-interactive-env "page-odd-shift"))
 		("Even page shift" (init-interactive-env "page-even-shift"))))
-      ---
-      (group "Breaking")
-      (-> "Algorithm"
-	  ("Default" (init-default "page-breaking"))
+      (if (detailed-menus?)
 	  ---
-	  ("Sloppy" (init-env "page-breaking" "sloppy"))
-	  ("Medium" (init-env "page-breaking" "medium"))
-	  ("Professional" (init-env "page-breaking" "optimal")))
-      (-> "Limits"
-	  ("Allowed reduction" (init-interactive-env "page-shrink"))
-	  ("Allowed extension" (init-interactive-env "page-extend")))
-      (-> "Flexibility"
-	  ("Default" (init-default "page-flexibility"))
-	  ---
-	  ("0" (init-env "page-flexibility" "0.0"))
-	  ("1/4" (init-env "page-flexibility" "0.25"))
-	  ("1/2" (init-env "page-flexibility" "0.5"))
-	  ("3/4" (init-env "page-flexibility" "0.75"))
-	  ("1" (init-env "page-flexibility" "1.0"))
-	  ---
-	  ("Other" (init-interactive-env "page-flexibility"))))
+	  (group "Breaking")
+	  (-> "Algorithm"
+	      ("Default" (init-default "page-breaking"))
+	      ---
+	      ("Sloppy" (init-env "page-breaking" "sloppy"))
+	      ("Medium" (init-env "page-breaking" "medium"))
+	      ("Professional" (init-env "page-breaking" "optimal")))
+	  (-> "Limits"
+	      ("Allowed reduction" (init-interactive-env "page-shrink"))
+	      ("Allowed extension" (init-interactive-env "page-extend")))
+	  (-> "Flexibility"
+	      ("Default" (init-default "page-flexibility"))
+	      ---
+	      ("0" (init-env "page-flexibility" "0.0"))
+	      ("1/4" (init-env "page-flexibility" "0.25"))
+	      ("1/2" (init-env "page-flexibility" "0.5"))
+	      ("3/4" (init-env "page-flexibility" "0.75"))
+	      ("1" (init-env "page-flexibility" "1.0"))
+	      ---
+	      ("Other" (init-interactive-env "page-flexibility")))))
   ---
   (-> "Update"
       ("All" (generate-all-aux) (update-buffer))
