@@ -7,10 +7,9 @@
 ;; COPYRIGHT   : (C) 2001  Joris van der Hoeven
 ;;               (C) 2004-2007  Joris van der Hoeven and Henri Lesourd
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -412,7 +411,8 @@
 
 (tm-define (graphics-interactive-set-grid-nsubds visual?)
   (:interactive #t)
-  (interactive (lambda (x) (graphics-set-grid-aspect 'detailed x visual?))
+  (interactive
+    (lambda (x) (graphics-set-grid-aspect 'detailed (string->number x) visual?))
     "Number of subunit steps"))
 
 ;; Setting visual grid aspect properties (colors)
