@@ -5,10 +5,9 @@
 ;; DESCRIPTION : This is the standard TeXmacs initialization file
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -31,7 +30,9 @@
 ;; (set! primitive-load new-primitive-load)
 
 ;(display "Booting TeXmacs kernel functionality\n")
-(load (url-concretize "$TEXMACS_PATH/progs/kernel/boot/boot.scm"))
+(if (os-mingw?)
+    (load "kernel/boot/boot.scm")
+    (load (url-concretize "$TEXMACS_PATH/progs/kernel/boot/boot.scm")))
 (inherit-modules (kernel boot compat) (kernel boot abbrevs)
 		 (kernel boot debug) (kernel boot srfi)
 		 (kernel boot ahash-table) (kernel boot prologue))
@@ -44,25 +45,28 @@
 		 (kernel texmacs tm-preferences) (kernel texmacs tm-modes)
 		 (kernel texmacs tm-plugins) (kernel texmacs tm-secure)
 		 (kernel texmacs tm-convert) (kernel texmacs tm-dialogue)
-		 (kernel texmacs tm-file-system))
+		 (kernel texmacs tm-language)  (kernel texmacs tm-file-system))
 (inherit-modules (kernel gui menu-define) (kernel gui menu-widget)
-		 (kernel gui kbd-define) (kernel gui gui-widget)
-		 (kernel gui gui-factory) (kernel gui gui-form))
+		 (kernel gui kbd-define) (kernel gui kbd-handlers)
+		 (kernel gui gui-widget) (kernel gui gui-factory)
+		 (kernel gui gui-form))
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 
 ;(display "Booting utilities\n")
 (lazy-define (utils cas cas-out) cas->stree)
+(use-modules (utils misc markup-funcs))
+;(display* "time: " (- (texmacs-time) boot-start) "\n")
+
+;(display "Booting BibTeX style modules\n")
+(use-modules (bibtex bib-utils))
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 
 ;(display "Booting main TeXmacs functionality\n")
 (use-modules (texmacs texmacs tm-server) (texmacs texmacs tm-view)
 	     (texmacs texmacs tm-files) (texmacs texmacs tm-print))
 (use-modules (texmacs keyboard config-kbd))
-(lazy-keyboard (texmacs keyboard wildcards-kbd) always?)
-(if (like-emacs?) (lazy-keyboard (texmacs keyboard emacs-kbd) always?))
-(if (like-windows?) (lazy-keyboard (texmacs keyboard windows-kbd) always?))
+(lazy-keyboard (texmacs keyboard prefix-kbd) always?)
 (lazy-keyboard (texmacs keyboard latex-kbd) always?)
-(lazy-keyboard (texmacs keyboard texmacs-kbd) always?)
 (lazy-menu (texmacs menus file-menu) file-menu go-menu
 	   new-file-menu load-menu save-menu print-menu close-menu)
 (lazy-menu (texmacs menus edit-menu) edit-menu)
@@ -97,6 +101,10 @@
 (lazy-menu (math math-menu) math-menu math-icons insert-math-menu)
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 
+;(display "Booting programming modes\n")
+(lazy-keyboard (prog scheme-edit) in-prog-scheme?)
+;(display* "time: " (- (texmacs-time) boot-start) "\n")
+
 ;(display "Booting source mode\n")
 (lazy-keyboard (source source-kbd) always?)
 (lazy-menu (source source-menu) source-menu source-icons
@@ -118,11 +126,17 @@
 	     graphics-dragging graphics-end-drag)
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 
+;(display "Booting formal languages\n")
+(lazy-language (language minimal) minimal)
+(lazy-language (language std-math) std-math)
+;(display* "time: " (- (texmacs-time) boot-start) "\n")
+
 ;(display "Booting dynamic features\n")
 (lazy-keyboard (dynamic fold-kbd) always?)
 (lazy-keyboard (dynamic scripts-kbd) always?)
 (lazy-menu (dynamic format-prog-menu) prog-format-menu prog-format-icons)
 (lazy-menu (dynamic fold-menu) insert-fold-menu)
+(lazy-define (dynamic session-edit) scheme-eval)
 (lazy-menu (dynamic session-menu) insert-session-menu
 	   session-menu session-icons session-help-icons help-icons)
 (lazy-menu (dynamic scripts-menu) scripts-eval-menu
@@ -145,6 +159,7 @@
 (lazy-format (convert tmml init-tmml) tmml)
 (lazy-format (convert latex init-latex) latex)
 (lazy-format (convert html init-html) html)
+(lazy-format (convert bibtex init-bibtex) bibtex)
 (lazy-format (convert images init-images)
 	     postscript pdf xfig xmgrace svg xpm jpeg ppm gif png pnm)
 (lazy-define (convert rewrite init-rewrite) texmacs->verbatim)
@@ -176,6 +191,15 @@
 	     get-link-locations register-link-locations)
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 
+;(display "Booting versioning facilities\n")
+(lazy-menu (version version-menu) version-menu)
+(lazy-keyboard (version version-kbd) with-versioning-tool?)
+;(display* "time: " (- (texmacs-time) boot-start) "\n")
+
+;(display "Booting debugging facilities\n")
+(lazy-menu (texmacs menus debug-menu) debug-menu)
+;(display* "time: " (- (texmacs-time) boot-start) "\n")
+
 ;(display "Booting plugins\n")
 (for-each lazy-plugin-initialize (plugin-list))
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
