@@ -5,10 +5,9 @@
 ;; DESCRIPTION : Definition of menus
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -24,9 +23,11 @@
 ;; (shortcut :string?) and multiple actions in menu entries.
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(define-grammar
+(define-regexp-grammar
   (:menu-label (:or
     :string?
+    (concat :*)
+    (verbatim :%1)
     (text :tuple? :string?)
     (icon :string?)
     (balloon :menu-label :string?)))
@@ -74,6 +75,10 @@
 
 (define-public (menu-label-add-dots l)
   (cond ((match? l ':string?) (string-append l "..."))
+	((match? l '(concat :*))
+	 `(,@(cDr l) ,(menu-label-add-dots (cAr l))))
+	((match? l '(verbatim :*))
+	 `(,@(cDr l) ,(menu-label-add-dots (cAr l))))
 	((match? l '(text :tuple? :string?))
 	 `(text ,(cadr l) ,(string-append (caddr l) "...")))
 	((match? l '(icon :string?)) l)
@@ -130,7 +135,10 @@
 
 (define-table menu-pre-table
   (group (:string?) ,(lambda (p) p))
-  (symbol (:string? :*) ,(lambda (p) p))
+  (symbol (:string? :*)
+    ,(lambda (p)
+       (if (<= (length p) 2) p
+	   `(symbol ,(cadr p) ,(make-promise (caddr p))))))
   (link (:%1) ,(lambda (p) p))
   (horizontal (:*)
     ,(lambda (p) `(horizontal ,@(menu-pre-list (cdr p)))))
