@@ -76,6 +76,24 @@
 				((== what "off") "on")
 				(else what)))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Look and feel
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define-public (look-and-feel)
+  (with s (get-preference "look and feel")
+    (if (== s "default") (default-look-and-feel) s)))
+
+(define (test-look-and-feel t)
+  ;;(display* "Check look and feel " t "\n")
+  (cond ((list? t) (list-or (map test-look-and-feel t)))
+	((symbol? t) (test-look-and-feel (symbol->string t)))
+	(else
+	  (with s (look-and-feel)
+	    (or (== t s) (and (== t "std") (!= s "emacs")))))))
+
+(set! has-look-and-feel? test-look-and-feel)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Applying preferences
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -118,3 +136,4 @@
   (fill-dictionary preferences-table saved-preferences))
 
 (retrieve-preferences)
+(notify-preferences-loaded)
