@@ -5,10 +5,9 @@
 ;; DESCRIPTION : menus for altering text properties in math mode
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -31,11 +30,21 @@
 
 (menu-bind math-font-menu
   (-> "Name"
-      ("Roman" (make-with "math-font" "roman"))
+      (if (font-exists-in-tt? "Apple Symbols")
+	  ("Apple symbols" (make-with "math-font" "math-apple")))
+      (if (font-exists-in-tt? "Asana-Math")
+	  ("Asana" (make-with "math-font" "math-asana")))
       (if (url-exists-in-tex? "ccr10.mf")
 	  ("Concrete" (make-with "math-font" "concrete")))
+      (if (font-exists-in-tt? "DejaVuSerif")
+	  ("Dejavu" (make-with "math-font" "math-dejavu"))) 
+      (if (font-exists-in-tt? "LucidaGrande")
+	  ("Lucida" (make-with "math-font" "math-lucida")))
       (if (url-exists-in-tex? "eurm10.mf")
 	  ("New Roman" (make-with "math-font" "ENR")))
+      ("Roman" (make-with "math-font" "roman"))
+      (if (font-exists-in-tt? "STIXGeneral")
+	  ("Stix" (make-with "math-font" "math-stix")))
       ---
       (if (url-exists-in-tex? "rpsyr.tfm")
 	  ("Adobe" (make-with "math-font" "adobe")))
