@@ -5,19 +5,18 @@
 ;; DESCRIPTION : keyboard shortcuts for mathematics
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (texmacs-module (math math-kbd)
-  (:use
-    (utils edit auto-close)
-    (generic format-edit)
-    (math math-edit))
-    (table table-edit))
+  (:use (generic generic-kbd)
+	(utils edit auto-close)
+	(generic format-edit)
+	(math math-edit)
+	(table table-edit)))
 
 (kbd-map
   (:mode in-math?)
@@ -42,7 +41,7 @@
   ("math:under accent:check" (make-wide-under "<check>"))
   ;; end
 
-  ("$" (go-end-with "mode" "math"))
+  ("$" (math-make-math))
   ("math $" (make-with "mode" "text"))
   ("`" (make-lprime "`"))
   ("'" (make-rprime "'"))
@@ -55,6 +54,7 @@
   ("math:left _" (make-script #f #f))
   ("math:left ^" (make-script #t #f))
   ("math f" (make-fraction))
+  ("math f var" (make 'frac*))
   ("math s" (make-sqrt))
   ("math S" (make-var-sqrt))
   ("math n" (make-neg))
@@ -136,23 +136,16 @@
   ("onehalf" (insert '(frac "1" "2")))
   ("threequarters" (insert '(frac "3" "4")))
 
-  ("(" (make-bracket-open "(" ")"))
-  (")" (make-bracket-close ")" "("))
-  ("[" (make-bracket-open "[" "]"))
-  ("]" (make-bracket-close "]" "["))
-  ("{" (make-bracket-open "{" "}"))
-  ("}" (make-bracket-close "}" "{"))
-  ("| ," (make-bracket-open "<lfloor>" "<rfloor>"))
-  (", |" (make-bracket-close "<rfloor>" "<lfloor>"))
-  ("| '" (make-bracket-open "<lceil>" "<rceil>"))
-  ("' |" (make-bracket-close "<rceil>" "<lceil>"))
-  ("| accent:acute" (make-bracket-open "<lceil>" "<rceil>"))
-  ("accent:acute |" (make-bracket-close "<rceil>" "<lceil>"))
-
   ("space" " ")
-  ("S-space" " ")
-  ("space var" "<nonesep>")
+  ("space var" "<space>")
+  ("space var var" "<nospace>")
+  ("space var var var" (noop) (make-space "1em"))
   (", var" "<comma>")
+  (", var var" "<nocomma>")
+  ("." ".")
+  (". var" "<point>")
+  (". var var" "<cdummy>")
+  (". var var var" "<nosymbol>")
 
   ("math:symbol a" "<amalg>")
   ("math:symbol d" "<partial>")
@@ -172,72 +165,166 @@
   ("math:symbol v var var var" "<curlyveedownarrow>")
   ("math:symbol x" "<times>")
 
-  ("math:symbol S" (make-big-operator "sum"))
-  ("math:symbol P" (make-big-operator "prod"))
-  ("math:symbol I" (make-big-operator "int"))
-  ("math:symbol:limits I" (make-big-operator "intlim"))
-  ("math:symbol O" (make-big-operator "oint"))
-  ("math:symbol:limits O" (make-big-operator "ointlim"))
-  ("math:symbol A" (make-big-operator "amalg"))
-  ("math:symbol N" (make-big-operator "cap"))
-  ("math:symbol W" (make-big-operator "wedge"))
-  ("math:symbol U" (make-big-operator "cup"))
-  ("math:symbol V" (make-big-operator "vee"))
-  ("math:symbol:circled ." (make-big-operator "odot"))
-  ("math:symbol:circled +" (make-big-operator "oplus"))
-  ("math:symbol:circled x" (make-big-operator "otimes"))
-  ("math:symbol ." (make-big-operator "."))
+  ("math:symbol S" (math-big-operator "sum"))
+  ("math:symbol P" (math-big-operator "prod"))
+  ("math:symbol I" (math-big-operator "int"))
+  ("math:symbol I !" (math-big-operator "intlim"))
+  ("math:symbol:limits I" (math-big-operator "intlim"))
+  ("math:symbol O" (math-big-operator "oint"))
+  ("math:symbol O !" (math-big-operator "ointlim"))
+  ("math:symbol:limits O" (math-big-operator "ointlim"))
+  ("math:symbol A" (math-big-operator "amalg"))
+  ("math:symbol N" (math-big-operator "cap"))
+  ("math:symbol N var" (math-big-operator "sqcap"))
+  ("math:symbol W" (math-big-operator "wedge"))
+  ("math:symbol W var" (math-big-operator "curlywedge"))
+  ("math:symbol U" (math-big-operator "cup"))
+  ("math:symbol U var" (math-big-operator "sqcup"))
+  ("math:symbol V" (math-big-operator "vee"))
+  ("math:symbol V var" (math-big-operator "curlyvee"))
+  ("math:symbol:circled ." (math-big-operator "odot"))
+  ("math:symbol:circled +" (math-big-operator "oplus"))
+  ("math:symbol:circled x" (math-big-operator "otimes"))
+  ("math:symbol ." (math-big-operator "."))
 
-  ("math:large (" (make-bracket-open "(" ")" #t))
-  ("math:large )" (make-bracket-close ")" "(" #t))
-  ("math:large [" (make-bracket-open "[" "]" #t))
-  ("math:large ]" (make-bracket-close "]" "[" #t))
-  ("math:large {" (make-bracket-open "{" "}" #t))
-  ("math:large }" (make-bracket-close "}" "{" #t))
-  ("math:large <" (make-bracket-open "langle" "rangle" #t))
-  ("math:large >" (make-bracket-close "rangle" "langle" #t))
-  ("math:large /" (make-separator "/" #t))
-  ("math:large \\" (make-separator "\\" #t))
-  ("math:large |" (make-separator "|" #t))
+  ("symbol \\" "\\")
+  ("symbol \\ var" "<setminus>")
+  ("symbol \\ var var" "<smallsetminus>")
+  ("symbol |" "|")
+  ("symbol | /" "<nmid>")
+  ("symbol | var" "<divides>")
+  ("symbol | var /" "<ndivides>")
+  ("symbol | var var" "<shortmid>")
+  ("symbol | var var /" "<nshortmid>")
+  ("symbol | |" "<||>")
+  ("symbol | | /" "<nparallel>")
+  ("symbol | | var" "<shortparallel>")
+  ("symbol | | var /" "<nshortparallel>")
 
-  ("math:left (" (make-bracket-open "(" ")" #t))
-  ("math:left )" (make-bracket-open ")" "(" #t))
-  ("math:left [" (make-bracket-open "[" "]" #t))
-  ("math:left ]" (make-bracket-open "]" "[" #t))
-  ("math:left {" (make-bracket-open "{" "}" #t))
-  ("math:left }" (make-bracket-open "}" "{" #t))
-  ("math:left <" (make-bracket-open "langle" "rangle" #t))
-  ("math:left >" (make-bracket-open "rangle" "langle" #t))
-  ("math:left /" (make-bracket-open "/" "\\" #t))
-  ("math:left \\" (make-bracket-open "\\" "/" #t))
-  ("math:left |" (make-bracket-open "|" "|" #t))
-  ("math:left ." (make-bracket-open "." "." #t))
+  ("(" (math-bracket-open "(" ")" #f))
+  ("( var" (math-bracket-open "<nobracket>" "<nobracket>" #f))
+  (")" (math-bracket-close ")" "(" #f))
+  ("[" (math-bracket-open "[" "]" #f))
+  ("[ var" (math-bracket-open "[" "[" #f))
+  ("[ var var" (math-bracket-open "]" "]" #f))
+  ("[ var var var" (math-bracket-open "]" "[" #f))
+  ("]" (math-bracket-close "]" "[" #f))
+  ("[ [" (twice (math-bracket-open "[" "]" #f)))
+  ("] ]" (twice (math-bracket-close "]" "[" #f)))
+  ("[ [ var" (math-bracket-open "<llbracket>" "<rrbracket>" #f))
+  ("] ] var" (math-bracket-close "<rrbracket>" "<llbracket>" #f))
+  ("{" (math-bracket-open "{" "}" #f))
+  ("{ var" (math-bracket-open "<langle>" "<rangle>" #f))
+  ("{ var var" (math-bracket-open "<llangle>" "<rrangle>" #f))
+  ("{ {" (twice (math-bracket-open "{" "}" #f)))
+  ("{ { var" (math-bracket-open "<llangle>" "<rrangle>" #f))
+  ("}" (math-bracket-close "}" "{" #f))
+  ("|" (math-bracket-open "|" "|" #f))
+  ("| |" (math-bracket-open "<||>" "<||>" #f))
+  ("| | |" (math-bracket-open "<interleave>" "<interleave>" #f))
+  ("| ," (math-bracket-open "<lfloor>" "<rfloor>" #f))
+  ("| , var" (math-bracket-open "<lfloor>" "<rceil>" #f))
+  (", |" (math-bracket-close "<rfloor>" "<lfloor>" #f))
+  ("| '" (math-bracket-open "<lceil>" "<rceil>" #f))
+  ("| ' var" (math-bracket-open "<lceil>" "<rfloor>" #f))
+  ("' |" (math-bracket-close "<rceil>" "<lceil>" #f))
+  ("| accent:acute" (math-bracket-open "<lceil>" "<rceil>" #f))
+  ("| accent:acute var" (math-bracket-open "<lceil>" "<rfloor>" #f))
+  ("accent:acute |" (math-bracket-close "<rceil>" "<lceil>" #f))
 
-  ("math:middle (" (make-separator "(" #t))
-  ("math:middle )" (make-separator ")" #t))
-  ("math:middle [" (make-separator "[" #t))
-  ("math:middle ]" (make-separator "]" #t))
-  ("math:middle {" (make-separator "{" #t))
-  ("math:middle }" (make-separator "}" #t))
-  ("math:middle <" (make-separator "langle" #t))
-  ("math:middle >" (make-separator "rangle" #t))
-  ("math:middle /" (make-separator "/" #t))
-  ("math:middle \\" (make-separator "\\" #t))
-  ("math:middle |" (make-separator "|" #t))
-  ("math:middle ." (make-separator "." #t))
+  ("math:left (" (math-bracket-open "(" ")" #t))
+  ("math:left )" (math-bracket-open ")" "(" #t))
+  ("math:left [" (math-bracket-open "[" "]" #t))
+  ("math:left ]" (math-bracket-open "]" "[" #t))
+  ("math:left {" (math-bracket-open "{" "}" #t))
+  ("math:left }" (math-bracket-open "}" "{" #t))
+  ("math:left <" (math-bracket-open "langle" "rangle" #t))
+  ("math:left >" (math-bracket-open "rangle" "langle" #t))
+  ("math:left |" (math-bracket-open "|" "|" #t))
+  ("math:left | |" (math-bracket-open "||" "||" #t))
+  ("math:left /" (math-bracket-open "/" "\\" #t))
+  ("math:left \\" (math-bracket-open "\\" "/" #t))
+  ("math:left | ," (math-bracket-open "lfloor" "rfloor" #t))
+  ("math:left | , var" (math-bracket-open "lfloor" "rceil" #t))
+  ("math:left , |" (math-bracket-open "rfloor" "lfloor" #t))
+  ("math:left | '" (math-bracket-open "lceil" "rceil" #t))
+  ("math:left | '" (math-bracket-open "lceil" "rfloor" #t))
+  ("math:left ' | var" (math-bracket-open "rceil" "lceil" #t))
+  ("math:left | accent:acute" (math-bracket-open "lceil" "rceil" #t))
+  ("math:left | accent:acute var" (math-bracket-open "lceil" "rfloor" #t))
+  ("math:left accent:acute |" (math-bracket-open "rceil" "lceil" #t))
+  ("math:left ." (math-bracket-open "." "." #t))
 
-  ("math:right (" (make-bracket-close "(" ")" #t))
-  ("math:right )" (make-bracket-close ")" "(" #t))
-  ("math:right [" (make-bracket-close "[" "]" #t))
-  ("math:right ]" (make-bracket-close "]" "[" #t))
-  ("math:right {" (make-bracket-close "{" "}" #t))
-  ("math:right }" (make-bracket-close "}" "{" #t))
-  ("math:right <" (make-bracket-close "langle" "rangle" #t))
-  ("math:right >" (make-bracket-close "rangle" "langle" #t))
-  ("math:right /" (make-bracket-close "/" "\\" #t))
-  ("math:right \\" (make-bracket-close "\\" "/" #t))
-  ("math:right |" (make-bracket-close "|" "|" #t))
-  ("math:right ." (make-bracket-close "." "." #t))
+  ("math:middle (" (math-separator "(" #t))
+  ("math:middle )" (math-separator ")" #t))
+  ("math:middle [" (math-separator "[" #t))
+  ("math:middle ]" (math-separator "]" #t))
+  ("math:middle {" (math-separator "{" #t))
+  ("math:middle }" (math-separator "}" #t))
+  ("math:middle <" (math-separator "langle" #t))
+  ("math:middle >" (math-separator "rangle" #t))
+  ("math:middle |" (math-separator "|" #t))
+  ("math:middle | |" (math-separator "||" #t))
+  ("math:middle /" (math-separator "/" #t))
+  ("math:middle \\" (math-separator "\\" #t))
+  ("math:left | ," (math-separator "lfloor" #t))
+  ("math:left , |" (math-separator "rfloor" #t))
+  ("math:left | '" (math-separator "lceil" #t))
+  ("math:left ' |" (math-separator "rceil" #t))
+  ("math:left | accent:acute" (math-separator "lceil" #t))
+  ("math:left accent:acute |" (math-separator "rceil" #t))
+  ("math:middle ." (math-separator "." #t))
+
+  ("math:right (" (math-bracket-close "(" ")" #t))
+  ("math:right )" (math-bracket-close ")" "(" #t))
+  ("math:right [" (math-bracket-close "[" "]" #t))
+  ("math:right ]" (math-bracket-close "]" "[" #t))
+  ("math:right {" (math-bracket-close "{" "}" #t))
+  ("math:right }" (math-bracket-close "}" "{" #t))
+  ("math:right <" (math-bracket-close "langle" "rangle" #t))
+  ("math:right >" (math-bracket-close "rangle" "langle" #t))
+  ("math:right |" (math-bracket-close "|" "|" #t))
+  ("math:right | |" (math-bracket-close "||" "||" #t))
+  ("math:right /" (math-bracket-close "/" "\\" #t))
+  ("math:right \\" (math-bracket-close "\\" "/" #t))
+  ("math:right | ," (math-bracket-close "lfloor" "rfloor" #t))
+  ("math:right , |" (math-bracket-close "rfloor" "lfloor" #t))
+  ("math:right | '" (math-bracket-close "lceil" "rceil" #t))
+  ("math:right ' |" (math-bracket-close "rceil" "lceil" #t))
+  ("math:right | accent:acute" (math-bracket-close "lceil" "rceil" #t))
+  ("math:right accent:acute |" (math-bracket-close "rceil" "lceil" #t))
+  ("math:right ." (math-bracket-close "." "." #t))
+
+  ("math:large (" (math-bracket-open "(" ")" #t))
+  ("math:large ( var" (math-bracket-open "." "." #t))
+  ("math:large )" (math-bracket-close ")" "(" #t))
+  ("math:large [" (math-bracket-open "[" "]" #t))
+  ("math:large [ var" (math-bracket-open "[" "[" #t))
+  ("math:large [ var var" (math-bracket-open "]" "]" #t))
+  ("math:large [ var var var" (math-bracket-open "]" "[" #t))
+  ("math:large ]" (math-bracket-close "]" "[" #t))
+  ("math:large [ [" (twice (math-bracket-open "[" "]" #t)))
+  ("math:large ] ]" (twice (math-bracket-close "]" "[" #t)))
+  ("math:large [ [ var" (math-bracket-open "llbracket" "rrbracket" #t))
+  ("math:large ] ] var" (math-bracket-close "llbracket" "rrbracket" #t))
+  ("math:large {" (math-bracket-open "{" "}" #t))
+  ("math:large }" (math-bracket-close "}" "{" #t))
+  ("math:large <" (math-bracket-open "langle" "rangle" #t))
+  ("math:large >" (math-bracket-close "rangle" "langle" #t))
+  ("math:large |" (math-bracket-open "|" "|" #t))
+  ("math:large | var" (math-separator "|" #t))
+  ("math:large | |" (math-bracket-open "||" "||" #t))
+  ("math:large | | var" (math-separator "||" #t))
+  ("math:large /" (math-bracket-open "/" "\\"#t))
+  ("math:large / var" (math-separator "/" #t))
+  ("math:large \\" (math-bracket-open "\\" "/" #t))
+  ("math:large \\ var" (math-separator "\\" #t))
+  ("math:large | ," (math-bracket-open "lfloor" "rfloor" #t))
+  ("math:large , |" (math-bracket-close "rfloor" "lfloor" #t))
+  ("math:large | '" (math-bracket-open "lceil" "rceil" #t))
+  ("math:large ' |" (math-bracket-close "rceil" "lceil" #t))
+  ("math:large | accent:acute" (math-bracket-open "lceil" "rceil" #t))
+  ("math:large accent:acute |" (math-bracket-close "rceil" "lceil" #t))
 
   ("<" "<less>")
   (">" "<gtr>")
@@ -306,11 +393,10 @@
   (". > var" "<dotsucc>")
   ("< var = ." "<preceqdot>")
   (". > var =" "<dotsucceq>")
-  ("< < var var" "<llangle>")
-  ("> > var var" "<rrangle>")
 
   ("< >" "<lessgtr>")
   ("> <" "<gtrless>")
+  ("> < var" "<join>")
   ("< ~" "<lesssim>")
   ("< ~ ~" "<lessapprox>")
   ("< var ~" "<precsim>")
@@ -392,6 +478,10 @@
   ("< = = var var" "<Longdownarrow>")
   ("< = = >" "<Longleftrightarrow>")
   ("< = = > var" "<Longupdownarrow>")
+  ("- /" "<rightharpoondown>")
+  ("- / var" "<rightharpoonup>")
+  ("/ -" "<leftharpoonup>")
+  ("/ - var" "<leftharpoondown>")
   ("| - >" "<mapsto>")
   ("| - > var" "<hookrightarrow>")
   ("| - > var var" "<mapsdown>")
@@ -463,6 +553,9 @@
   ("< - - !" "<longleftarrowlim>")
   ("< - - > !" "<longleftrightarrowlim>")
   ("| - - > !" "<longmapstolim>")
+  ("~ > !" "<rightsquigarrowlim>")
+  ("< ~ !" "<leftsquigarrowlim>")
+  ("< ~ > !" "<leftrightsquigarrowlim>")
   ("= !" "<equallim>")
   ("= = !" "<longequallim>")
   ("= > !" "<Rightarrowlim>")
@@ -476,9 +569,11 @@
   ("@ /" "<varnothing>")
   ("@ +" "<oplus>")
   ("@ -" "<ominus>")
+  ("@ - var" "<mapmulti>")
   ("@ x" "<otimes>")
   ("@ :" "<oover>")
-  ("@ ." "<odot>")
+  ("@ *" "<oast>")
+  ("@ x" "<otimes>")
   ("@ R" "<circledR>")
   ("@ S" "<circledS>")
   ("@ / var" "<oslash>")
@@ -524,53 +619,62 @@
   ("~ - /" "<nsimeq>")
   ("~ = /" "<ncong>")
     
-  ("|" "|")
-  ("| |" "<||>")
-  ("| | |" "<interleave>")
-  ("| | var" "<shortparallel>")
-  ("| -" "<vdash>")
+  ("| - var" "<vdash>")
+  ("| - var -" "<vdash>")
   ("| - -" "<longvdash>")
-  ("| | -" "<Vdash>")
+  ("| | - var" "<Vdash>")
+  ("| | - var -" "<longVdash>")
   ("| | - -" "<longVdash>")
-  ("| | | -" "<Vvdash>")
+  ("| | | - var" "<Vvdash>")
+  ("| | | - var -" "<longVvdash>")
   ("| | | - -" "<longVvdash>")
-  ("- |" "<dashv>")
+  ("- | var" "<dashv>")
   ("- - |" "<longdashv>")
-  ("| =" "<vDash>")
+  ("| = var" "<vDash>")
+  ("| = var =" "<longvDash>")
   ("| = =" "<longvDash>")
-  ;; ("| | =" "<VDash>")
+  ;; ("| | = var" "<VDash>")
+  ;; ("| | = var =" "<longVDash>")
   ;; ("| | = =" "<longVDash>")
-  ("| /" "<nmid>")
-  ("| | /" "<nparallel>")
-  ("| | var /" "<nshortparallel>")
+  ("| - var /" "<nvdash>")
   ("| - /" "<nvdash>")
+  ("| | - var /" "<nVdash>")
   ("| | - /" "<nVdash>")
+  ;; ("- | var /" "<ndashv>")
   ;; ("- | /" "<ndashv>")
+  ;; ("- | var | /" "<ndashV>")
+  ;; ("- | | var /" "<ndashV>")
   ;; ("- | | /" "<ndashV>")
+  ("| = var /" "<nvDash>")
   ("| = /" "<nvDash>")
+  ;; ("| | = var /" "<nVDash>")
   ;; ("| | = /" "<nVDash>")
+  ;; ("= | var /" "<nDashv>")
   ;; ("= | /" "<nDashv>")
+  ;; ("= | var | /" "<nDashV>")
+  ;; ("= | | var /" "<nDashV>")
   ;; ("= | | /" "<nDashV>")
 
-  ("< |" "<vartriangleleft>")
-  ("< | var" "<blacktriangleleft>")
-  ("< | /" "<ntriangleleft>")
-  ("< | =" "<trianglelefteqslant>")
-  ("< | = /" "<ntrianglelefteqslant>")
-  ("< | = var" "<trianglelefteq>")
-  ("< | = var /" "<ntrianglelefteq>")
-  ("| >" "<vartriangleright>")
-  ("| > var" "<blacktriangleright>")
-  ("| > /" "<ntriangleright>")
-  ("| > =" "<trianglerighteqslant>")
-  ("| > = /" "<ntrianglerighteqslant>")
-  ("| > = var" "<trianglerighteq>")
-  ("| > = var /" "<ntrianglerighteq>")
+  ("< | var" "<vartriangleleft>")
+  ("< | var var" "<blacktriangleleft>")
+  ("< | var /" "<ntriangleleft>")
+  ("< | var =" "<trianglelefteqslant>")
+  ("< | var = /" "<ntrianglelefteqslant>")
+  ("< | var = var" "<trianglelefteq>")
+  ("< | var = var /" "<ntrianglelefteq>")
+  ("| > var" "<vartriangleright>")
+  ("| > var var" "<blacktriangleright>")
+  ("| > var /" "<ntriangleright>")
+  ("| > var =" "<trianglerighteqslant>")
+  ("| > var = /" "<ntrianglerighteqslant>")
+  ("| > var = var" "<trianglerighteq>")
+  ("| > var = var /" "<ntrianglerighteq>")
     
   ("+ var" "<upl>")
-  ("+ var var" "<kreuz>")
-  ("+ var var var" "<dag>")
-  ("+ var var var var" "<ddag>")
+  ("+ var var" "<noplus>")
+  ("+ var var var" "<kreuz>")
+  ("+ var var var var" "<dag>")
+  ("+ var var var var var" "<ddag>")
   ("- var" "<um>")
   ("+ -" "<pm>")
   ("+ - var" "<upm>")
@@ -587,12 +691,14 @@
   (". . var var var" "<vdots>")
   (". . var var var var" "<ddots>")
   (". . var var var var var" "<udots>")
+  (": :" "<colons>")
+  (": >" "<transtype>")
   (": =" "<assign>")
   ("+ =" "<plusassign>")
   ("- =" "<minusassign>")
   ("/ var" "<div>")
-  ("* var" "<ast>")
-  ("* var var" "<times>")
+  ("* var" "<times>")
+  ("* var var" "<ast>")
   ("* var var var" "<cdot>")
   ("| * var" "<ltimes>")
   ("| * var |" "<join>")
@@ -643,29 +749,37 @@
   ("< var var var var = /" "<nsqsubseteq>")
   ("> var var var var = /" "<nsqsupseteq>")
 
-  ("< var var var var var" "<langle>")
-  ("> var var var var var" "<rangle>")
-  ("< var var var var var var" "<leftslice>")
-  ("> var var var var var var" "<rightslice>")
+  ("< var var var var var" (math-bracket-open "<langle>" "<rangle>" #f))
+  ("> var var var var var" (math-bracket-close "<rangle>" "<langle>" #f))
+  ("< < var var" (math-bracket-open "<llangle>" "<rrangle>" #f))
+  ("> > var var" (math-bracket-close "<rrangle>" "<llangle>" #f))
 
-  ("symbol \\ var" "<setminus>")
-  ("symbol \\ var var" "<smallsetminus>")
   ("# var" "<sharp>")
   ("# var var" "<natural>")
   ("# var var var" "<flat>")
   ("& var" "<wedge>")
   ("& var var" "<cap>")
   ("& var var var" "<sqcap>")
-  ("| var" "<vee>")
+  ("| var " "<vee>")
   ("| var var" "<cup>")
   ("| var var +" "<uplus>")
   ("| var var var" "<sqcup>")
-  ("| var var var var" "<shortmid>")
-  ("| var var var var /" "<nshortmid>")
+  ("| var var var var" "|")
+  ("| var var var var /" "<nmid>")
+  ("| var var var var var" "<divides>")
+  ("| var var var var var /" "<ndivides>")
+  ("| var var var var var var" "<shortmid>")
+  ("| var var var var var var /" "<nshortmid>")
+  ("| | var" "<||>")
+  ("| | var /" "<nparallel>")
+  ("| | var var" "<shortparallel>")
+  ("| | var var /" "<nshortparallel>")
+  ("| | | var" "<interleave>")
 
   ("math:greek a" "<alpha>")
   ("math:greek b" "<beta>")
   ("math:greek g" "<gamma>")
+  ("math:greek g var" "<matheuler>")
   ("math:greek d" "<delta>")
   ("math:greek e" "<varepsilon>")
   ("math:greek e var" "<epsilon>")
@@ -730,6 +844,20 @@
   ("math:greek W var" "<Mho>")
   ("math:greek V" "<Phi>")
 
+  ("math:greek \\" "\\")
+  ("math:greek \\ var" "<setminus>")
+  ("math:greek \\ var var" "<smallsetminus>")
+  ("math:greek |" "|")
+  ("math:greek | /" "<nmid>")
+  ("math:greek | var" "<divides>")
+  ("math:greek | var /" "<ndivides>")
+  ("math:greek | var var" "<shortmid>")
+  ("math:greek | var var /" "<nshortmid>")
+  ("math:greek | |" "<||>")
+  ("math:greek | | /" "<nparallel>")
+  ("math:greek | | var" "<shortparallel>")
+  ("math:greek | | var /" "<nshortparallel>")
+
   ("math:bold 0" "<b-0>")
   ("math:bold 1" "<b-1>")
   ("math:bold 2" "<b-2>")
@@ -971,6 +1099,16 @@
   ("math:frak Y" "<frak-Y>")
   ("math:frak Z" "<frak-Z>")
 
+  ("math:bbb 0" "<bbb-0>")
+  ("math:bbb 1" "<bbb-1>")
+  ("math:bbb 2" "<bbb-2>")
+  ("math:bbb 3" "<bbb-3>")
+  ("math:bbb 4" "<bbb-4>")
+  ("math:bbb 5" "<bbb-5>")
+  ("math:bbb 6" "<bbb-6>")
+  ("math:bbb 7" "<bbb-7>")
+  ("math:bbb 8" "<bbb-8>")
+  ("math:bbb 9" "<bbb-9>")
   ("math:bbb a" "<bbb-a>")
   ("math:bbb b" "<bbb-b>")
   ("math:bbb c" "<bbb-c>")
@@ -1022,7 +1160,37 @@
   ("math:bbb W" "<bbb-W>")
   ("math:bbb X" "<bbb-X>")
   ("math:bbb Y" "<bbb-Y>")
-  ("math:bbb Z" "<bbb-Z>"))
+  ("math:bbb Z" "<bbb-Z>")
+
+  ("A A" "<bbb-A>")
+  ("B B" "<bbb-B>")
+  ("C C" "<bbb-C>")
+  ("D D" "<bbb-D>")
+  ("E E" "<bbb-E>")
+  ("F F" "<bbb-F>")
+  ("G G" "<bbb-G>")
+  ("H H" "<bbb-H>")
+  ("I I" "<bbb-I>")
+  ("J J" "<bbb-J>")
+  ("K K" "<bbb-K>")
+  ("L L" "<bbb-L>")
+  ("M M" "<bbb-M>")
+  ("N N" "<bbb-N>")
+  ("O O" "<bbb-O>")
+  ("P P" "<bbb-P>")
+  ("Q Q" "<bbb-Q>")
+  ("R R" "<bbb-R>")
+  ("S S" "<bbb-S>")
+  ("T T" "<bbb-T>")
+  ("U U" "<bbb-U>")
+  ("V V" "<bbb-V>")
+  ("W W" "<bbb-W>")
+  ("X X" "<bbb-X>")
+  ("Y Y" "<bbb-Y>")
+  ("Z Z" "<bbb-Z>")
+
+  ("R E" "<Re>")
+  ("I M" "<Im>"))
 
 (kbd-map
   (:mode in-math-not-hybrid?)
@@ -1041,6 +1209,7 @@
   ("v var var" "<varphi>")
   ("f var" "<varphi>")
   ("g var" "<gamma>")
+  ("g var var" "<matheuler>")
   ("h var" "<eta>")
   ("h var var" "<hbar>")
   ("i var" "<iota>")
@@ -1076,17 +1245,19 @@
 
   ("A var" "<Alpha>")
   ("A var var" "<forall>")
-  ("A var var avr" "<aleph>")
+  ("A var var var" "<aleph>")
   ("B var" "<Beta>")
   ("B var var" "<bot>")
   ("B var var var" "<beth>")
   ("C var" "<Sigma>")
+  ("C var var" "<mathcatalan>")
   ("D var" "<Delta>")
   ("D var var" "<mathD>")
   ("D var var var" "<daleth>")
   ("E var" "<Epsilon>")
   ("E var var" "<exists>")
-  ("E var var var" "<Backepsilon>")
+  ("E var var var" "<Exists>")
+  ("E var var var var" "<Backepsilon>")
   ("F var" "<Phi>")
   ("G var" "<Gamma>")
   ("G var var" "<gimel>")
@@ -1107,6 +1278,7 @@
   ("T var var" "<top>")
   ("U var" "<Upsilon>")
   ("V var" "<Phi>")
+  ("V var var" "<nabla>")
   ("W var" "<Omega>")
   ("W var var" "<Mho>")
   ("X var" "<Xi>")
