@@ -5,10 +5,9 @@
 ;; DESCRIPTION : menus for mathematical mode and mathematical symbols
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -27,8 +26,8 @@
   (if (style-has? "env-math-dtd")
       (when (in-text?)
 	    ---
-	    ("Equation" (begin (make 'equation*) (temp-proof-fix)))
-	    ("Equations" (begin (make 'eqnarray*) (temp-proof-fix))))))
+	    ("Equation" (make-equation*))
+	    ("Equations" (make-eqnarray*)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; The Mathematics menu
@@ -144,95 +143,97 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (menu-bind left-delimiter-menu
-  (symbol "<left-(-2>" (left "(") "A-(")
-  (symbol "<left-)-2>" (left ")") "A-l )")
-  (symbol "<left-[-2>" (left "[") "A-[")
-  (symbol "<left-]-2>" (left "]") "A-l ]")
-  (symbol "<left-{-2>" (left "{") "A-{")
-  (symbol "<left-}-2>" (left "}") "A-l }")
-  (symbol "<left-langle-2>" (left "langle") "A-<")
-  (symbol "<left-rangle-2>" (left "rangle") "A-l >")
-  (symbol "<left-lfloor-2>" (left "lfloor"))
-  (symbol "<left-rfloor-2>" (left "rfloor"))
-  (symbol "<left-lceil-2>" (left "lceil"))
-  (symbol "<left-rceil-2>" (left "rceil"))
-  (symbol "<left-llbracket-2>" (left "llbracket"))
-  (symbol "<left-rrbracket-2>" (left "rrbracket"))
-  (symbol "<left-|-4>" (left "|") "A-l |")
-  (symbol "<left-||-4>" (left "||"))
-  (symbol "<left-/-2>" (left "/") "A-l /")
-  (symbol "<left-\\-2>" (left "\\") "A-l b")
-  (symbol "<left-.-2>" (left ".") "A-l ."))
+  (symbol "<left-(-2>" (math-bracket-open "(" ")" #t))
+  (symbol "<left-)-2>" (math-bracket-open ")" "(" #t))
+  (symbol "<left-[-2>" (math-bracket-open "[" "]" #t))
+  (symbol "<left-]-2>" (math-bracket-open "]" "[" #t))
+  (symbol "<left-{-2>" (math-bracket-open "{" "}" #t))
+  (symbol "<left-}-2>" (math-bracket-open "}" "{" #t))
+  (symbol "<left-langle-2>" (math-bracket-open "langle" "rangle" #t))
+  (symbol "<left-rangle-2>" (math-bracket-open "rangle" "langle" #t))
+  (symbol "<left-lfloor-2>" (math-bracket-open "lfloor" "rfloor" #t))
+  (symbol "<left-rfloor-2>" (math-bracket-open "rfloor" "lfloor" #t))
+  (symbol "<left-lceil-2>" (math-bracket-open "lceil" "rceil" #t))
+  (symbol "<left-rceil-2>" (math-bracket-open "rceil" "lceil" #t))
+  (symbol "<left-llbracket-2>" (math-bracket-open "llbracket" "rrbracket" #t))
+  (symbol "<left-rrbracket-2>" (math-bracket-open "rrbracket" "llbracket" #t))
+  (symbol "<left-|-4>" (math-bracket-open "|" "|" #t))
+  (symbol "<left-||-4>" (math-bracket-open "||" "||" #t))
+  (symbol "<left-/-2>" (math-bracket-open "/" "\\" #t))
+  (symbol "<left-\\-2>" (math-bracket-open "\\" "/" #t))
+  (symbol "<left-.-2>" (math-bracket-open "." "." #t)))
 
 (menu-bind middle-delimiter-menu
-  (symbol "<mid-(-2>" (mid "(") "A-m (")
-  (symbol "<mid-)-2>" (mid ")") "A-m )")
-  (symbol "<mid-[-2>" (mid "[") "A-m [")
-  (symbol "<mid-]-2>" (mid "]") "A-m ]")
-  (symbol "<mid-{-2>" (mid "{") "A-m {")
-  (symbol "<mid-}-2>" (mid "}") "A-m }")
-  (symbol "<mid-langle-2>" (mid "langle") "A-m <")
-  (symbol "<mid-rangle-2>" (mid "rangle") "A-m >")
-  (symbol "<mid-lfloor-2>" (mid "lfloor"))
-  (symbol "<mid-rfloor-2>" (mid "rfloor"))
-  (symbol "<mid-lceil-2>" (mid "lceil"))
-  (symbol "<mid-rceil-2>" (mid "rceil"))
-  (symbol "<mid-llbracket-2>" (mid "llbracket"))
-  (symbol "<mid-rrbracket-2>" (mid "rrbracket"))
-  (symbol "<mid-|-4>" (mid "|") "A-|")
-  (symbol "<mid-||-4>" (mid "||"))
-  (symbol "<mid-/-2>" (mid "/") "A-/")
-  (symbol "<mid-\\-2>" (mid "\\") "A-b"))
+  (symbol "<mid-(-2>" (math-separator "(" #t))
+  (symbol "<mid-)-2>" (math-separator ")" #t))
+  (symbol "<mid-[-2>" (math-separator "[" #t))
+  (symbol "<mid-]-2>" (math-separator "]" #t))
+  (symbol "<mid-{-2>" (math-separator "{" #t))
+  (symbol "<mid-}-2>" (math-separator "}" #t))
+  (symbol "<mid-langle-2>" (math-separator "langle" #t))
+  (symbol "<mid-rangle-2>" (math-separator "rangle" #t))
+  (symbol "<mid-lfloor-2>" (math-separator "lfloor" #t))
+  (symbol "<mid-rfloor-2>" (math-separator "rfloor" #t))
+  (symbol "<mid-lceil-2>" (math-separator "lceil" #t))
+  (symbol "<mid-rceil-2>" (math-separator "rceil" #t))
+  (symbol "<mid-llbracket-2>" (math-separator "llbracket" #t))
+  (symbol "<mid-rrbracket-2>" (math-separator "rrbracket" #t))
+  (symbol "<mid-|-4>" (math-separator "|" #t))
+  (symbol "<mid-||-4>" (math-separator "||" #t))
+  (symbol "<mid-/-2>" (math-separator "/" #t))
+  (symbol "<mid-\\-2>" (math-separator "\\" #t)))
 
 (menu-bind right-delimiter-menu
-  (symbol "<right-(-2>" (right "(") "A-r (")
-  (symbol "<right-)-2>" (right ")") "A-)")
-  (symbol "<right-[-2>" (right "[") "A-r [")
-  (symbol "<right-]-2>" (right "]") "A-]")
-  (symbol "<right-{-2>" (right "{") "A-r {")
-  (symbol "<right-}-2>" (right "}") "A-}")
-  (symbol "<right-langle-2>" (right "langle") "A-r <")
-  (symbol "<right-rangle-2>" (right "rangle") "A->")
-  (symbol "<right-lfloor-2>" (right "lfloor"))
-  (symbol "<right-rfloor-2>" (right "rfloor"))
-  (symbol "<right-lceil-2>" (right "lceil"))
-  (symbol "<right-rceil-2>" (right "rceil"))
-  (symbol "<right-llbracket-2>" (right "llbracket"))
-  (symbol "<right-rrbracket-2>" (right "rrbracket"))
-  (symbol "<right-|-4>" (right "|") "A-r |")
-  (symbol "<right-||-4>" (right "||"))
-  (symbol "<right-/-2>" (right "/") "A-r /")
-  (symbol "<right-\\-2>" (right "\\") "A-r b")
-  (symbol "<right-.-2>" (right ".") "A-r ."))
+  (symbol "<right-(-2>" (math-bracket-close "(" ")" #t))
+  (symbol "<right-)-2>" (math-bracket-close ")" "(" #t))
+  (symbol "<right-[-2>" (math-bracket-close "[" "]" #t))
+  (symbol "<right-]-2>" (math-bracket-close "]" "[" #t))
+  (symbol "<right-{-2>" (math-bracket-close "{" "}" #t))
+  (symbol "<right-}-2>" (math-bracket-close "}" "{" #t))
+  (symbol "<right-langle-2>" (math-bracket-close "langle" "rangle" #t))
+  (symbol "<right-rangle-2>" (math-bracket-close "rangle" "langle" #t))
+  (symbol "<right-lfloor-2>" (math-bracket-close "lfloor" "rfloor" #t))
+  (symbol "<right-rfloor-2>" (math-bracket-close "rfloor" "lfloor" #t))
+  (symbol "<right-lceil-2>" (math-bracket-close "lceil" "rceil" #t))
+  (symbol "<right-rceil-2>" (math-bracket-close "rceil" "lceil" #t))
+  (symbol "<right-llbracket-2>"
+	  (math-bracket-close "llbracket" "rrbracket" #t))
+  (symbol "<right-rrbracket-2>"
+	  (math-bracket-close "rrbracket" "llbracket" #t))
+  (symbol "<right-|-4>" (math-bracket-close "|" "|" #t))
+  (symbol "<right-||-4>" (math-bracket-close "||" "||" #t))
+  (symbol "<right-/-2>" (math-bracket-close "/" "\\" #t))
+  (symbol "<right-\\-2>" (math-bracket-close "\\" "/" #t))
+  (symbol "<right-.-2>" (math-bracket-close "." "." #t)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Big operators
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (menu-bind big-operator-menu
-  (symbol "<big-sum-2>" (big "sum") "S-F5 S")
-  (symbol "<big-prod-2>" (big "prod") "S-F5 P")
-  (symbol "<big-int-2>" (big "int") "S-F5 I")
-  (symbol "<big-oint-2>" (big "oint") "S-F5 O")
-  (symbol "<big-amalg-2>" (big "amalg") "S-F5 A")
-  (symbol "<big-cap-2>" (big "cap") "S-F5 N")
-  (symbol "<big-cup-2>" (big "cup") "S-F5 U")
-  (symbol "<big-wedge-2>" (big "wedge") "S-F5 W")
-  (symbol "<big-vee-2>" (big "vee") "S-F5 V")
-  (symbol "<big-odot-2>" (big "odot") "S-F5 @ .")
-  (symbol "<big-oplus-2>" (big "oplus") "S-F5 @ +")
-  (symbol "<big-otimes-2>" (big "otimes") "S-F5 @ x")
-  (symbol "<big-sqcap-2>" (big "sqcap"))
-  (symbol "<big-sqcup-2>" (big "sqcup"))
-  (symbol "<big-curlywedge-2>" (big "curlywedge"))
-  (symbol "<big-curlyvee-2>" (big "curlyvee"))
-  (symbol "<big-triangleup-2>" (big "triangleup"))
-  (symbol "<big-triangledown-2>" (big "triangledown"))
-  (symbol "<big-box-2>" (big "box"))
-  (symbol "<big-pluscup-2>" (big "pluscup"))
-  (symbol "<big-parallel-2>" (big "parallel"))
-  (symbol "<big-interleave-2>" (big "interleave"))
-  (symbol "<big-.-2>" (big ".") "S-F5 ."))
+  (symbol "<big-sum-2>" (math-big-operator "sum"))
+  (symbol "<big-prod-2>" (math-big-operator "prod"))
+  (symbol "<big-int-2>" (math-big-operator "int"))
+  (symbol "<big-oint-2>" (math-big-operator "oint"))
+  (symbol "<big-amalg-2>" (math-big-operator "amalg"))
+  (symbol "<big-cap-2>" (math-big-operator "cap"))
+  (symbol "<big-cup-2>" (math-big-operator "cup"))
+  (symbol "<big-wedge-2>" (math-big-operator "wedge"))
+  (symbol "<big-vee-2>" (math-big-operator "vee"))
+  (symbol "<big-odot-2>" (math-big-operator "odot"))
+  (symbol "<big-oplus-2>" (math-big-operator "oplus"))
+  (symbol "<big-otimes-2>" (math-big-operator "otimes"))
+  (symbol "<big-sqcap-2>" (math-big-operator "sqcap"))
+  (symbol "<big-sqcup-2>" (math-big-operator "sqcup"))
+  (symbol "<big-curlywedge-2>" (math-big-operator "curlywedge"))
+  (symbol "<big-curlyvee-2>" (math-big-operator "curlyvee"))
+  (symbol "<big-triangleup-2>" (math-big-operator "triangleup"))
+  (symbol "<big-triangledown-2>" (math-big-operator "triangledown"))
+  (symbol "<big-box-2>" (math-big-operator "box"))
+  (symbol "<big-pluscup-2>" (math-big-operator "pluscup"))
+  (symbol "<big-parallel-2>" (math-big-operator "parallel"))
+  (symbol "<big-interleave-2>" (math-big-operator "interleave"))
+  (symbol "<big-.-2>" (math-big-operator ".")))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Binary operations
@@ -883,15 +884,15 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (menu-bind math-icons
-  ((balloon (icon "tm_fraction.xpm") "Insert a fraction#(A-f)")
+  ((balloon (icon "tm_fraction.xpm") "Insert a fraction")
    (make-fraction))
-  ((balloon (icon "tm_sqrt.xpm") "Insert a square root#(A-s)")
+  ((balloon (icon "tm_sqrt.xpm") "Insert a square root")
    (make-sqrt))
-  ((balloon (icon "tm_root.xpm") "Insert an n-th root#(A-S)")
+  ((balloon (icon "tm_root.xpm") "Insert an n-th root")
    (make-var-sqrt))
-  ((balloon (icon "tm_sub.xpm") "Make a subscript#(_)")
+  ((balloon (icon "tm_sub.xpm") "Make a subscript")
    (make-script #f #t))
-  ((balloon (icon "tm_sup.xpm") "Make a superscript#(^)")
+  ((balloon (icon "tm_sup.xpm") "Make a superscript")
    (make-script #t #t))
   (=> (balloon (icon "tm_hat.xpm") "Insert an accent")
       ((icon "tm_hat.xpm") "A-^" (make-wide "^"))
