@@ -5,18 +5,17 @@
 ;; DESCRIPTION : setup key combinations for frequently used commands
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (texmacs-module (texmacs keyboard latex-kbd)
-  (:use
-    (utils edit auto-close)
-    (generic format-edit)
-    (text std-text-edit)))
+  (:use (utils edit auto-close)
+	(generic format-edit)
+	(generic generic-edit)
+	(text std-text-edit)))
 
 (kbd-symbols
   "alpha" "beta" "gamma" "delta" "epsilon"
@@ -139,12 +138,9 @@
   ("qquad" "Insert a qquad space" (make-space "2em"))
   ("\\" "Go to the next line" (make 'next-line))
 
-  ("[" "Insert equation"
-   (begin (make 'equation*) (temp-proof-fix)))
-  ("equation" "Insert numbered equation"
-   (begin (make 'equation) (temp-proof-fix)))
-  ("eqnarray*" "Insert equation array"
-   (begin (make 'eqnarray*) (temp-proof-fix)))
+  ("[" "Insert equation" (make-equation*))
+  ("equation" "Insert numbered equation" (make-equation))
+  ("eqnarray*" "Insert equation array" (make-eqnarray*))
 
   ("cC" "Make " (emulate-keyboard "cedilla C"))
   ("cc" "Make " (emulate-keyboard "cedilla c"))
@@ -242,68 +238,68 @@
   ("widehat" "Make hat" (make-wide "^"))
   ("widetilde" "Make tilde" (make-wide "~"))
 
-  ("sum" "Insert big summation" (make-big-operator "sum"))
-  ("prod" "Insert big product" (make-big-operator "prod"))
-  ("coprod" "Insert big coproduct" (make-big-operator "amalg"))
-  ("int" "Insert big integral" (make-big-operator "int"))
-  ("oint" "Insert big contour integral" (make-big-operator "oint"))
-  ("bigcap" "Insert big intersection" (make-big-operator "cap"))
-  ("bigcup" "Insert big union" (make-big-operator "cup"))
-  ("bigsqcup" "Insert big square union" (make-big-operator "sqcup"))
-  ("bigvee" "Insert big logical or" (make-big-operator "vee"))
-  ("bigwedge" "Insert big logical and" (make-big-operator "wedge"))
-  ("bigodot" "Insert big dotted point" (make-big-operator "odot"))
-  ("bigotimes" "Insert big tensor product" (make-big-operator "otimes"))
-  ("bigoplus" "Insert big direct sum" (make-big-operator "oplus"))
-  ("biguplus" "Insert big union sum" (make-big-operator "uplus"))
+  ("sum" "Insert big summation" (math-big-operator "sum"))
+  ("prod" "Insert big product" (math-big-operator "prod"))
+  ("coprod" "Insert big coproduct" (math-big-operator "amalg"))
+  ("int" "Insert big integral" (math-big-operator "int"))
+  ("oint" "Insert big contour integral" (math-big-operator "oint"))
+  ("bigcap" "Insert big intersection" (math-big-operator "cap"))
+  ("bigcup" "Insert big union" (math-big-operator "cup"))
+  ("bigsqcup" "Insert big square union" (math-big-operator "sqcup"))
+  ("bigvee" "Insert big logical or" (math-big-operator "vee"))
+  ("bigwedge" "Insert big logical and" (math-big-operator "wedge"))
+  ("bigodot" "Insert big dotted point" (math-big-operator "odot"))
+  ("bigotimes" "Insert big tensor product" (math-big-operator "otimes"))
+  ("bigoplus" "Insert big direct sum" (math-big-operator "oplus"))
+  ("biguplus" "Insert big union sum" (math-big-operator "uplus"))
 
-  ("left(" "Insert large (" (make-bracket-open "(" ")" #t))
-  ("left)" "Insert large left )" (make-bracket-open ")" "(" #t))
-  ("left[" "Insert large [" (make-bracket-open "[" "]" #t))
-  ("left]" "Insert large left ]" (make-bracket-open "]" "[" #t))
-  ("left{" "Insert large {" (make-bracket-open "{" "}" #t))
-  ("left}" "Insert large left }" (make-bracket-open "}" "{" #t))
+  ("left(" "Insert large (" (math-bracket-open "(" ")" #t))
+  ("left)" "Insert large left )" (math-bracket-open ")" "(" #t))
+  ("left[" "Insert large [" (math-bracket-open "[" "]" #t))
+  ("left]" "Insert large left ]" (math-bracket-open "]" "[" #t))
+  ("left{" "Insert large {" (math-bracket-open "{" "}" #t))
+  ("left}" "Insert large left }" (math-bracket-open "}" "{" #t))
   ("leftlfloor" "Insert large <lfloor>"
-   (make-bracket-open "lfloor" "rfloor" #t))
+   (math-bracket-open "lfloor" "rfloor" #t))
   ("leftrfloor" "Insert large left <rfloor>"
-   (make-bracket-open "rfloor" "lfloor" #t))
+   (math-bracket-open "rfloor" "lfloor" #t))
   ("leftlceil" "Insert large <lceil>"
-   (make-bracket-open "lceil" "rceil" #t))
+   (math-bracket-open "lceil" "rceil" #t))
   ("leftrceil" "Insert large left <rceil>"
-   (make-bracket-open "rceil" "lceil" #t))
+   (math-bracket-open "rceil" "lceil" #t))
   ("leftlangle" "Insert large <langle>"
-   (make-bracket-open "langle" "rangle" #t))
+   (math-bracket-open "langle" "rangle" #t))
   ("leftrangle" "Insert large left <rangle>"
-   (make-bracket-open "rangle" "langle" #t))
-  ("left|" "Insert large left <mid>" (make-bracket-open "|" "|" #t))
-  ("left||" "Insert large left <parallel>" (make-bracket-open "||" "||" #t))
-  ("left/" "Insert large left /" (make-bracket-open "/" "\\" #t))
-  ("leftbackslash" "Insert large left \\" (make-bracket-open "\\" "/" #t))
-  ("left." "Insert large left ." (make-bracket-open "." "." #t))
+   (math-bracket-open "rangle" "langle" #t))
+  ("left|" "Insert large left <mid>" (math-bracket-open "|" "|" #t))
+  ("left||" "Insert large left <parallel>" (math-bracket-open "||" "||" #t))
+  ("left/" "Insert large left /" (math-bracket-open "/" "\\" #t))
+  ("leftbackslash" "Insert large left \\" (math-bracket-open "\\" "/" #t))
+  ("left." "Insert large left ." (math-bracket-open "." "." #t))
 
-  ("right(" "Insert large right (" (make-bracket-close "(" ")" #t))
-  ("right)" "Insert large )" (make-bracket-close ")" "(" #t))
-  ("right[" "Insert large right [" (make-bracket-close "[" "]" #t))
-  ("right]" "Insert large ]" (make-bracket-close "]" "[" #t))
-  ("right{" "Insert large right {" (make-bracket-close "{" "}" #t))
-  ("right}" "Insert large }" (make-bracket-close "}" "{" #t))
+  ("right(" "Insert large right (" (math-bracket-close "(" ")" #t))
+  ("right)" "Insert large )" (math-bracket-close ")" "(" #t))
+  ("right[" "Insert large right [" (math-bracket-close "[" "]" #t))
+  ("right]" "Insert large ]" (math-bracket-close "]" "[" #t))
+  ("right{" "Insert large right {" (math-bracket-close "{" "}" #t))
+  ("right}" "Insert large }" (math-bracket-close "}" "{" #t))
   ("rightlfloor" "Insert large right <lfloor>"
-   (make-bracket-close "lfloor" "rfloor" #t))
+   (math-bracket-close "lfloor" "rfloor" #t))
   ("rightrfloor" "Insert large <rfloor>"
-   (make-bracket-close "rfloor" "lfloor" #t))
+   (math-bracket-close "rfloor" "lfloor" #t))
   ("rightlceil" "Insert large right <lceil>"
-   (make-bracket-close "lceil" "rceil" #t))
+   (math-bracket-close "lceil" "rceil" #t))
   ("rightrceil" "Insert large <rceil>"
-   (make-bracket-close "rceil" "lceil" #t))
+   (math-bracket-close "rceil" "lceil" #t))
   ("rightlangle" "Insert large right <langle>"
-   (make-bracket-close "langle" "rangle" #t))
+   (math-bracket-close "langle" "rangle" #t))
   ("rightrangle" "Insert large <rangle>"
-   (make-bracket-close "rangle" "langle" #t))
-  ("right|" "Insert large right <mid>" (make-bracket-close "|" "|" #t))
-  ("right||" "Insert large right <parallel>" (make-bracket-close "||" "||" #t))
-  ("right/" "Insert large right /" (make-bracket-close "/" "\\" #t))
-  ("rightbackslash" "Insert large right \\" (make-bracket-close "\\" "/" #t))
-  ("right." "Insert large right ." (make-bracket-close "." "." #t))
+   (math-bracket-close "rangle" "langle" #t))
+  ("right|" "Insert large right <mid>" (math-bracket-close "|" "|" #t))
+  ("right||" "Insert large right <parallel>" (math-bracket-close "||" "||" #t))
+  ("right/" "Insert large right /" (math-bracket-close "/" "\\" #t))
+  ("rightbackslash" "Insert large right \\" (math-bracket-close "\\" "/" #t))
+  ("right." "Insert large right ." (math-bracket-close "." "." #t))
 
   ("rmfamily" "Use roman font family" (make-with "font-family" "rm"))
   ("ttfamily" "Use typewriter font family" (make-with "font-family" "tt"))
@@ -378,7 +374,7 @@
   ("medskip" "Insert medium vertical space" (make-vspace-after "1fn"))
   ("bigskip" "Insert big vertical space" (make-vspace-after "2fn"))
   ("item" "Insert new item or number" (make-item))
-  ("label" "Make label" (make 'label))
+  ("label" "Make label" (make-label))
   ("ref" "Make reference" (make 'reference))
   ("pageref" "Make page reference" (make 'pageref))
   ("footnote" "Insert a footnote" (make 'footnote))
@@ -389,7 +385,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (kbd-commands
-  ("big." "Insert big ." (make-big-operator "."))
+  ("big." "Insert big ." (math-big-operator "."))
   ("underbrace" "Insert underbrace" (make-wide-under "<wide-underbrace>"))
   ("overbrace" "Insert overbrace" (make-wide "<wide-overbrace>")))
 
