@@ -5,10 +5,9 @@
 ;; DESCRIPTION : the edit menu
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -17,7 +16,7 @@
 	(utils edit selections)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; Dynamic menus for formats
+;; Dynamic menus
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define (extern-clipboard-item fm name action)
@@ -30,13 +29,26 @@
 		    converter-to-menu converter-from-menu)
     `(menu-dynamic ,@(routine "texmacs-snippet" "-snippet" #t item))))
 
+(define (redo-item i)
+  (list `(concat "Branch " ,(number->string (+ i 1)))
+	(lambda () (redo i))))
+
+(tm-define (redo-menu)
+  (menu-dynamic
+    ,@(map redo-item (.. 0 (redo-possibilities)))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; The Edit menu
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (menu-bind edit-menu
-  ("Undo" (undo))
-  ("Redo" (redo))
+  (when (> (undo-possibilities) 0)
+    ("Undo" (undo 0)))
+  (when (> (redo-possibilities) 0)
+    (if (<= (redo-possibilities) 1)
+	("Redo" (redo 0)))
+    (if (> (redo-possibilities) 1)
+	(-> "Redo" (link redo-menu))))
   ---
   (when (or (selection-active-any?)
 	    (and (in-graphics?)
