@@ -42,6 +42,8 @@
   (if (in-session?) (=> "Session" (link session-menu)))
   (if (in-graphics?) (=> "Graphics" (link graphics-menu)))
   (if (in-table?) (link vertical-table-cell-menu))
+  (if (with-linking-tool?)
+      (=> "Link" (link link-menu)))
   (link texmacs-extra-menu)
   (if (not (in-graphics?)) (=> "Format" (link format-menu)))
   (=> "Document" (link document-menu))
@@ -49,15 +51,20 @@
 	   (== (get-init-tree "sectional-short-style") (tree 'macro "false")))
       (=> "Part" (link document-part-menu)))
   (if (project-attached?) (=> "Project" (link project-menu)))
-  (if (with-remote-connections?)
-      (=> "Remote" (link remote-menu)))
-  (if (with-linking-tool?)
-      (=> "Link" (link link-menu)))
+  (if (with-versioning-tool?)
+      (=> "Version" (link version-menu)))
   (=> "View" (link view-menu))
   (=> "Go" (link go-menu))
   (if (detailed-menus?) (=> "Tools" (link tools-menu)))
+  (if (with-remote-connections?)
+      (=> "Remote" (link remote-menu)))
+  (if (with-debugging-tool?)
+      (=> "Debug" (link debug-menu)))
+  (if (nnull? (test-menu))
+      (=> "Test" (link test-menu)))
   (=> "Help" (link help-menu)))
 
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; The TeXmacs popup menu
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -72,18 +79,19 @@
   (if (in-graphics?) (-> "Graphics" (link graphics-menu)))
   (if (in-session?) (-> "Session" (link session-menu)))
   (if (in-table?) (link horizontal-table-cell-menu))
+  (if (with-linking-tool?) (-> "Link" (link link-menu)))
   (if (not (in-graphics?)) (-> "Format" (link format-menu)))
   (-> "Document" (link document-menu))
   (if (== (get-init-tree "sectional-short-style") (tree 'macro "false"))
       (-> "Part" (link document-part-menu)))
   (if (project-attached?) (=> "Project" (link project-menu)))
-  (if (with-remote-connections?)
-      (-> "Remote" (link remote-menu)))
-  (if (with-linking-tool?)
-      (-> "Link" (link link-menu)))
+  (if (with-versioning-tool?) (-> "Version" (link version-menu)))
   (-> "View" (link view-menu))
   (-> "Go" (link go-menu))
   (if (detailed-menus?) (-> "Tools" (link tools-menu)))
+  (if (with-remote-connections?) (-> "Remote" (link remote-menu)))
+  (if (with-debugging-tool?) (=> "Debug" (link debug-menu)))
+  (if (nnull? (test-menu)) (=> "Test" (link test-menu)))
   ---
   (-> "Help" (link help-menu)))
 
@@ -104,23 +112,23 @@
 	  (link global-language-menu)))
   (=> (balloon (icon "tm_cancel.xpm") "Close") (link close-menu))
   |
-  ((balloon (icon "tm_cut.xpm") "Cut text#(C-w)")
+  ((balloon (icon "tm_cut.xpm") "Cut text")
    (clipboard-cut "primary"))
-  ((balloon (icon "tm_copy.xpm") "Copy text#(M-w)")
+  ((balloon (icon "tm_copy.xpm") "Copy text")
    (clipboard-copy "primary"))
-  ((balloon (icon "tm_paste.xpm") "Paste text#(C-y)")
+  ((balloon (icon "tm_paste.xpm") "Paste text")
    (clipboard-paste "primary"))
   (if (not (in-search-mode?))
-      ((balloon (icon "tm_find.xpm") "Find text#(C-s)") (search-start #t)))
+      ((balloon (icon "tm_find.xpm") "Find text") (search-start #t)))
   (if (in-search-mode?)
-      ((balloon (icon "tm_find_next.xpm") "Find next match#(C-s)")
+      ((balloon (icon "tm_find_next.xpm") "Find next match")
        (search-button-next)))
-  ((balloon (icon "tm_replace.xpm") "Query replace#(C-=)")
+  ((balloon (icon "tm_replace.xpm") "Query replace")
    (interactive replace-start-forward))
-  ((balloon (icon "tm_spell.xpm") "Check text for spelling errors#(M-$)")
+  ((balloon (icon "tm_spell.xpm") "Check text for spelling errors")
    (spell-start))
-  ((balloon (icon "tm_undo.xpm") "Undo last changes#(M-[)") (undo 0))
-  ((balloon (icon "tm_redo.xpm") "Redo undone changes#(M-])") (redo 0))
+  ((balloon (icon "tm_undo.xpm") "Undo last changes") (undo 0))
+  ((balloon (icon "tm_redo.xpm") "Redo undone changes") (redo 0))
   (if (not (in-graphics?))
       |
       (=> (balloon (icon "tm_table.xpm") "Insert a table")
@@ -142,11 +150,11 @@
 		       "Start an interactive session")
 	      (link insert-session-menu))))
   |
-  ((balloon (icon "tm_back.xpm") "Browse back (C-<)")
+  ((balloon (icon "tm_back.xpm") "Browse back")
    (cursor-history-backward))
-  ((balloon (icon "tm_reload.xpm") "Reload (C-F2)")
+  ((balloon (icon "tm_reload.xpm") "Reload")
    (revert-buffer))
-  ((balloon (icon "tm_forward.xpm") "Browse forward (C->)")
+  ((balloon (icon "tm_forward.xpm") "Browse forward")
    (cursor-history-forward)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
