@@ -5,10 +5,9 @@
 ;; DESCRIPTION : the preferences menus
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -47,7 +46,12 @@
 
 (tm-define preferences-tree
   `((enum ("Look and feel" "look and feel")
+	  ("Default" "default")
+	  ---
 	  ("Emacs" "emacs")
+	  ("Gnome" "gnome")
+	  ("KDE" "kde")
+	  ("Mac OS" "macos")
 	  ("Windows" "windows"))
 ;   (enum ("Profile" "profile")
 ;	  ("Beginner" "beginner")
@@ -65,6 +69,7 @@
 	(toggle ("Context dependent icons" "context dependent icons"))
 	(toggle ("User provided icons" "user provided icons"))
 	(toggle ("Status bar" "status bar"))
+	---
 	(enum ("Shrinking factor" "shrinking factor")
 	      "1" "2" "3" "4" "5" "7" "10" *))
     ---
@@ -93,49 +98,6 @@
 	  ("Taiwanese" "taiwanese")
 	  ("Ukrainian" "ukrainian"))
     (-> "Keyboard"
-	(enum ("A modifier" "A")
-	      ("Default" "default")
-	      ("Equivalent for#Mod1" "Mod1")
-	      ("Equivalent for#Mod2" "Mod2")
-	      ("Equivalent for#Mod3" "Mod3")
-	      ("Equivalent for#Mod4" "Mod4")
-	      ("Equivalent for#Mod5" "Mod5"))
-	(enum ("M modifier" "M")
-	      ("Default" "default")
-	      ("Equivalent for#Mod1" "Mod1")
-	      ("Equivalent for#Mod2" "Mod2")
-	      ("Equivalent for#Mod3" "Mod3")
-	      ("Equivalent for#Mod4" "Mod4")
-	      ("Equivalent for#Mod5" "Mod5"))
-	(enum ("H modifier" "H")
-	      ("Default" "default")
-	      ("Equivalent for#Mod1" "Mod1")
-	      ("Equivalent for#Mod2" "Mod2")
-	      ("Equivalent for#Mod3" "Mod3")
-	      ("Equivalent for#Mod4" "Mod4")
-	      ("Equivalent for#Mod5" "Mod5"))
-	---
-	(enum ("Alt key" "alt")
-	      ("Do not remap" "default")
-	      ("Map to#A modifier" "A")
-	      ("Map to#M modifier" "M")
-	      ("Map to#H modifier" "H"))
-	(enum ("Meta key" "meta")
-	      ("Do not remap" "default")
-	      ("Map to#A modifier" "A")
-	      ("Map to#M modifier" "M")
-	      ("Map to#H modifier" "H"))
-	(enum ("Windows key" "windows")
-	      ("Do not remap" "default")
-	      ("Map to#A modifier" "A")
-	      ("Map to#M modifier" "M")
-	      ("Map to#H modifier" "H"))
-	(enum ("Caps-lock key" "caps-lock")
-	      ("Do not remap" "default")
-	      ("Map to#A modifier" "A")
-	      ("Map to#M modifier" "M")
-	      ("Map to#H modifier" "H"))
-	---
 	(enum ("Cyrillic input method" "cyrillic input method")
 	      ("Translit" "translit")
 	      ("Jcuken" "jcuken")
@@ -144,6 +106,7 @@
 	      ("Cp1251" "cp1251"))
 	(enum ("Automatic quotes" "automatic quotes")
 	      ("Default" "default")
+	      ---
 	      ("None" "none")
 	      ("Dutch" "dutch")
 	      ("English" "english")
@@ -188,19 +151,28 @@
 	    (enum ("Encoding" "verbatim->texmacs:encoding")
 		  ("Iso-8859-1" "iso-8859-1")
 		  ("Utf-8" "utf-8"))))
-    (-> "Utilities"
-	(-> "Scripts"
-	    ("None" (set-preference "scripting language" "none"))
-	    ---
-	    (link scripts-preferences-menu))
-	(toggle ("Remote connections" "remote connections"))
-	(toggle ("Linking tool" "linking tool")))
+    (-> "Scripts"
+	("None" (set-preference "scripting language" "none"))
+	---
+	(link scripts-preferences-menu))
+    (-> "Tools"
+	(toggle ("Debugging tool" "debugging tool"))
+	(toggle ("Linking tool" "linking tool"))
+	(toggle ("Versioning tool" "versioning tool"))
+	(toggle ("Remote connections" "remote connections")))
+    (-> "Experimental"
+	(toggle ("Fast environments" "fast environments"))
+	(toggle ("Correct presentation markup" "with correct"))
+	(toggle ("Correct invisible markup" "invisible correct"))
+	(toggle ("Force matching brackets" "matching brackets"))
+	(toggle ("Semantic editing" "semantic editing")))
     ---
     (enum ("Autosave" "autosave")
 	  ("5 s" "5")
 	  ("30 s" "30")
 	  ("120 s" "120")
 	  ("300 s" "300")
+	  ---
 	  ("Disable" "0"))
     (enum ("Bibtex command" "bibtex command")
 	  "bibtex" "rubibtex" *)))
@@ -223,6 +195,8 @@
   (cond ((null? l) l)
 	((== (car l) '*)
 	 (list '--- (list "Other" (compute-preferences-entry s))))
+	((== (car l) '---)
+	 (cons '--- (compute-preferences-enum s (cdr l))))
 	(else (cons (list (id-or-car (car l))
 			  `(set-preference ,s ,(id-or-cadr (car l))))
 		    (compute-preferences-enum s (cdr l))))))
