@@ -5,10 +5,9 @@
 ;; DESCRIPTION : the tools menu
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -31,20 +30,6 @@
 ;; The Tools menu
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(menu-extend test-menu
-  (-> "Test"
-      ("Tree" (show-tree))
-      ("Path" (show-path))
-      ("Cursors" (show-cursor))
-      ("Selection" (show-selection))
-      ("Environment" (show-env))
-      ---
-      ("Error" (oops))
-      ("Test" (edit-test))
-      ("Timings" (bench-print-all))
-      ("Backtrace errors" (debug-enable 'backtrace 'debug))
-      ("Memory information" (show-meminfo))))
-
 (menu-bind tools-menu
   (-> "Execute"
       ("Execute system command" (interactive system))
@@ -62,6 +47,9 @@
       ("Create web site" (tmweb-interactive-build)))
   (-> "Project"
       (link project-manage-menu))
-  (if (nnull? (test-menu))
-      ---
-      (link test-menu)))
+  (-> "Miscellaneous"
+      ("Clear undo history" (clear-undo-history)))
+  ---
+  ("Debugging tool" (toggle-preference "debugging tool"))
+  ("Linking tool" (toggle-preference "linking tool"))
+  ("Versioning tool" (toggle-preference "versioning tool")))
