@@ -5,10 +5,9 @@
 ;; DESCRIPTION : server wide properties and resource management
 ;; COPYRIGHT   : (C) 2001  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -19,11 +18,8 @@
 ;; Preferences
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(define (get-default-look-and-feel)
-  (if (os-win32?) "windows" "emacs"))
-
 (define (get-default-interactive-questions)
-  (if (== (get-preference "look and feel") "windows") "popups" "footer"))
+  (if (or (like-gnome?) (like-macos?) (like-windows?)) "popups" "footer"))
 
 (define (notify-look-and-feel var val)
   (set-message "Restart in order to let the new look and feel take effect"
@@ -36,6 +32,12 @@
   (cond ((or (== val "bulgarian") (== val "russian") (== val "ukrainian"))
 	 (notify-preference "cyrillic input method"))))
 
+(define (notify-scripting-language var val)
+  (if (has-view?)
+      (if (== val "none")
+	  (init-default "prog-scripts")
+	  (init-env "prog-scripts" val))))
+
 (define (notify-security var val)
   (cond ((== val "accept no scripts") (set-script-status 0))
 	((== val "prompt on scripts") (set-script-status 1))
@@ -44,13 +46,32 @@
 (define (notify-bibtex-command var val)
   (set-bibtex-command val))
 
+(define (notify-tool var val)
+  ;; FIXME: the menus sometimes don't get updated,
+  ;; but the fix below does not work
+  (if (has-view?) (notify-change 1)))
+
+(define (notify-fast-environments var val)
+  (set-fast-environments (== val "on")))
+
 (define-preferences
   ("profile" "beginner" (lambda args (noop)))
-  ("look and feel" (get-default-look-and-feel) notify-look-and-feel)
+  ("look and feel" "default" notify-look-and-feel)
+  ("detailed menus" "detailed" noop)
   ("interactive questions" (get-default-interactive-questions) noop)
   ("language" (get-locale-language) notify-language)
+  ("fast environments" "off" notify-fast-environments)
+  ("with correct" "off" (lambda args (noop)))
+  ("invisible correct" "off" (lambda args (noop)))
+  ("matching brackets" "off" (lambda args (noop)))
+  ("semantic editing" "off" (lambda args (noop)))
   ("security" "prompt on scripts" notify-security)
-  ("bibtex command" "bibtex" notify-bibtex-command))
+  ("bibtex command" "bibtex" notify-bibtex-command)
+  ("scripting language" "none" notify-scripting-language)
+  ("debugging tool" "off" notify-tool)
+  ("linking tool" "off" notify-tool)
+  ("versioning tool" "off" notify-tool)
+  ("remote connections" "off" notify-tool))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Properties of some built-in routines
