@@ -5,22 +5,22 @@
 ;; DESCRIPTION : enter semantic textual markup using the keyboard
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (texmacs-module (text std-text-kbd)
-  (:use (text format-text-edit)
+  (:use (text text-kbd)
+	(text format-text-edit)
 	(text std-text-edit)))
 
 (kbd-map
   (:mode in-std-text?)
   ("$" (if (inside? 'hybrid) (insert "$") (make 'math)))
-  ("text $" (make 'equation*) (temp-proof-fix))
-  ("text &" (make 'eqnarray*) (temp-proof-fix))
+  ("text $" (make-equation*))
+  ("text &" (make-eqnarray*))
 
   ("text a" (make 'abbr))
   ("text d" (make-tmlist 'description))
