@@ -7,10 +7,9 @@
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -20,12 +19,15 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (setq nullary-keywords
-  '(cond call/cc values define-preferences menu-dynamic
+  '(begin cond else call/cc
+    values define-preferences menu-dynamic
     case-lambda kbd-map kbd-wildcards kbd-commands kbd-symbols
-    define-grammar drd-rule drd-rules assume texmacs-modes
+    define-grammar define-regexp-grammar
+    drd-rule drd-rules assume texmacs-modes
     delayed dialogue on-entry on-exit widget-delayed
     association-tile bar concat dense-bar dense-tile document
-    header-bar sequence short-bar short-tile tile))
+    header-bar sequence short-bar short-tile tile
+    wrap-selection-any wrap-selection-small))
 
 (setq nullary-misc
   '(:use :inherit))
@@ -34,22 +36,23 @@
   (append nullary-keywords nullary-misc))
 
 (setq unary-keywords
-  '(with-result
-    and-let* setup-append-if
+  '(let let* lambda
+    with-result and-let* setup-append-if
     while for repeat when
     drd-group drd-table drd-dispatcher
-    with-cc with-aux with-mutator
+    with-cc with-aux
     with-action with-module with-cursor with-server
     dialogue-user widget-with
     aspect block-input button form
     input internal short-input))
 
 (setq unary-definitions
-  '(texmacs-module provide-public
-    define-group define-macro define-public-macro
+  '(define define-public define-macro define-public-macro
+    texmacs-module provide-public define-group
     tm-define tm-define-macro tm-property request-handler
     tm-build tm-build-macro tm-build-widget
-    menu-bind menu-extend define-table define-format))
+    menu-bind menu-extend define-table
+    define-format define-language))
 
 (setq unary-no-highlight
   '(format interactive))
@@ -72,9 +75,11 @@
   ternary-keywords)
 
 (setq other-keywords
-  '(define-secure-symbols map-in-order link promise plugin-configure
+  '(for if inherit
+    define-secure-symbols map-in-order link promise plugin-configure
     plugin-input-converters use-modules export import-from inherit-modules
-    lazy-menu lazy-keyboard lazy-define lazy-format lazy-input-converter
+    lazy-menu lazy-keyboard lazy-define lazy-format
+    lazy-language lazy-input-converter
     form-cancel form-done form-next form-previous radio suggestions toggle))
 
 (setq highlight-definitions
@@ -84,12 +89,8 @@
   (append nullary-keywords unary-keywords unary-definitions
 	  binary-keywords ternary-keywords other-keywords))
 
-(setq highlight-native
-  '(let let* begin for if else while define define-macro
-    define-public define-public-macro))
-
 (setq highlight-any
-  (append highlight-definitions highlight-keywords highlight-native))
+  (append highlight-definitions highlight-keywords))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Define TeXmacs style
