@@ -5,10 +5,9 @@
 ;; DESCRIPTION : routines for cursor movement
 ;; COPYRIGHT   : (C) 2002  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -56,14 +55,17 @@
 	(else (label-in-range? lab (cDr p) until))))
 
 (define (check-pattern p l)
-  (with t (path->tree (list-drop-right p (length l)))
-    (cond ((null? l) #t)
-	  ((and (symbol? (car l)) (== (tm-car t) (car l)))
-	   (check-pattern p (cdr l)))
-	  ((and (number? (car l))
-		(== (car l) (list-ref p (- (length p) (length l) 1))))
-	   (check-pattern p (cdr l)))
-	  (else #f))))
+  (or (null? l)
+      (with t (path->tree (list-drop-right p (length l)))
+	(cond ((and (symbol? (car l)) (== (tm-car t) (car l)))
+	       (check-pattern p (cdr l)))
+	      ((and (procedure? (car l)) ((car l) t))
+	       (check-pattern p (cdr l)))
+	      ((and (number? (car l))
+		    (== (car l) (list-ref p (- (length p) (length l) 1)))
+		    (> (length p) 1))
+	       (check-pattern p (cdr l)))
+	      (else #f)))))
 
 (define (innermost-pattern p l)
   (cond ((<= (length p) (length l)) #f)
@@ -74,12 +76,19 @@
   (with p (cursor-path)
     (fun)
     (let* ((q (cursor-path))
-	   (pp (innermost-pattern (cDr p) l))
-	   (qq (innermost-pattern (cDr q) l)))
-      (if (== pp qq) #f
-	  (begin
-	    (go-to p)
-	    #t)))))
+	   (pp (innermost-pattern p l))
+	   (qq (innermost-pattern q l)))
+      (if (!= pp qq) (go-to p)))))
+
+(define (go-to-next-inside-sub fun l)
+  (do ((p (cursor-path) (cursor-path))
+       (q (begin (fun) (cursor-path)) (begin (fun) (cursor-path))))
+      ((or (== p q) (innermost-pattern q l)) (noop))))
+
+(tm-define (go-to-next-inside fun . l)
+  (with p (cursor-path)
+    (go-to-next-inside-sub fun l)
+    (if (not (innermost-pattern (cursor-path) l)) (go-to p))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Routines for cursor movement
@@ -98,9 +107,12 @@
 
 (tm-define (go-to-next-tag lab)
   (go-to-same-buffer (lambda (t p) (path-next-tag t p lab))))
-
 (tm-define (go-to-previous-tag lab)
   (go-to-same-buffer (lambda (t p) (path-previous-tag t p lab))))
+(tm-define (go-to-next-tag-same-argument lab)
+  (go-to-same-buffer (lambda (t p) (path-next-tag-same-argument t p lab))))
+(tm-define (go-to-previous-tag-same-argument lab)
+  (go-to-same-buffer (lambda (t p) (path-previous-tag-same-argument t p lab))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Cursor history
@@ -186,7 +198,7 @@
 	 (l2 (assoc (string-append name " *") m)))
     (cond (l1 ((cadr l1)))
 	  (l2 ((cadr l2)))
-	  (else (set-message (string-append "No buffer#" name)
+	  (else (set-message `(concat "Error: no buffer " ,name)
 			     "switch to buffer")))))
 
 (tm-define (with-active-buffer-sub name cmd)
