@@ -4,10 +4,9 @@
 * DESCRIPTION: conversion of tex strings into texmacs trees
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Tex/convert_tex.hpp"
@@ -21,6 +20,27 @@ static bool textm_appendices= false;
 static bool textm_unicode   = false;
 static bool textm_natbib    = false;
 
+/*
+bool
+check_tree (tree t) {
+  if (is_atomic (t)) {
+    for (int i=0; i<N(t->label); i++)
+      if (((int) t->label[i]) == 0) {
+	cout << "t= " << t << "\n";
+	return true;
+      }
+  }
+  else {
+    for (int i=0; i<N(t); i++)
+      if (check_tree (t[i])) {
+	if (is_atomic (t[i])) cout << "t= " << t << "\n";
+	return true;
+      }
+  }
+  return false;
+}
+*/
+
 /******************************************************************************
 * Preprocess preamble
 ******************************************************************************/
@@ -49,9 +69,16 @@ filter_preamble (tree t) {
 	       is_tuple (u, "\\documentstyle") ||
 	       is_tuple (u, "\\documentstyle*"))
 	r << u;
-      else if (is_tuple (u, "\\def") || is_tuple (u, "\\def*"))
+      else if (is_tuple (u, "\\def") ||
+	       is_tuple (u, "\\def*"))
 	preamble << u << "\n" << "\n";
-      else if (is_tuple (u, "\\title") || is_tuple (u, "\\author") ||
+      else if (is_tuple (u, "\\newtheorem"))
+	preamble << u << "\n" << "\n";
+      else if (is_tuple (u, "\\newenvironment") ||
+	       is_tuple (u, "\\newenvironment*"))
+	preamble << u << "\n" << "\n";
+      else if (is_tuple (u, "\\title") ||
+	       is_tuple (u, "\\author") ||
 	       is_tuple (u, "\\address"))
 	title_info << u;
     }
@@ -109,6 +136,7 @@ latex_symbol_to_tree (string s) {
       if (s == "\\noindent")  return tree (FORMAT, "no first indentation");
       if (s == "\\linebreak")  return tree (FORMAT, "line break");
       if (s == "\\newline")  return tree (FORMAT, "new line");
+      if (s == "\\nobreak")  return tree (FORMAT, "no line break");
       if (s == "\\nolinebreak")  return tree (FORMAT, "no line break");
       if (s == "\\pagebreak")  return tree (FORMAT, "page break");
       if (s == "\\nopagebreak")  return tree (FORMAT, "no page break after");
@@ -137,8 +165,12 @@ latex_symbol_to_tree (string s) {
       if (s == "\\notin") return "<nin>";
       if (s == "\\addots") return "<udots>";
       if (s == "\\dots") return "<ldots>";
+      if (s == "\\infin") return "<infty>";
+      if (s == "\\rang") return "<rangle>";
       if (s == "\\tableofcontents")
 	return compound ("table-of-contents", "toc", tree (DOCUMENT, ""));
+      if (s == "\\bgroup") return "";
+      if (s == "\\egroup") return "";
     }
 
     if (latex_type (s) == "texmacs") {
@@ -210,16 +242,16 @@ latex_symbol_to_tree (string s) {
       if (s == "pink") return tree (SET, COLOR, "pink");
 
       cerr << "The symbol was " << s << "\n";
-      fatal_error ("unexpected situation", "latex_symbol_to_tree");
+      FAILED ("unexpected situation");
     }
     if (latex_type (s) == "operator")
       return s(1,N(s));
     if (latex_type (s) == "control") return s(1,N(s));
     if ((s == "\\ldots") && (command_type ("!mode") != "math")) return "...";
+    if (s == "\\bignone") return tree (BIG, ".");
     if (latex_type (s) == "symbol")  return "<" * s(1,N(s)) * ">";
     if (latex_type (s) == "big-symbol") {
-      if (s == "\\bignone") return tree (BIG, ".");
-      else if (s(0,4)=="\\big") return tree (BIG, s(4,N(s)));
+      if (s(0,4)=="\\big") return tree (BIG, s(4,N(s)));
       else return tree (BIG, s(1,N(s)));
     }
 
@@ -273,7 +305,12 @@ string_arg (tree t) {
     return "_" * string_arg (t[0]);
   else if (is_func (t, RSUP, 1))
     return "^" * string_arg (t[0]);
-  else return "";
+  else if (is_func (t, APPLY, 1) && t[0] == "nbsp")
+    return " ";
+  else {
+    //cout << "t= " << t << "\n";
+    return "";
+  }
 }
 
 tree
@@ -322,12 +359,23 @@ latex_concat_to_tree (tree t, bool& new_flag) {
 	    continue;
 	}
 	else {
-	  if ((t[i] != tree (TUPLE, "\\ ")) && (i>0) && (is_tuple (t[i-1]))) {
-	    string s= t[i-1][0]->label;
-	    if ((s[0] == '\\') && (latex_type (s) == "command") &&
-		(s!="\\end-math") && (s!="\\end-displaymath"))
-	      if ((arity(t[i-1])==1) || (s=="\\label"))
+	  if ((t[i] != tree (TUPLE, "\\ "))) {
+	    if (i>0 && is_tuple (t[i-1])) {
+	      string s= t[i-1][0]->label;
+	      if ((s[0] == '\\') && (latex_type (s) == "command") &&
+		  (s!="\\end-math") && (s!="\\end-displaymath"))
+		if ((arity(t[i-1])==1) || (s=="\\label"))
+		  continue;
+	      if (starts (s, "\\begin-") &&
+		  (command_type["!verbatim"] != "true"))
 		continue;
+	    }
+	    if (i+1<N(t) && is_tuple (t[i+1])) {
+	      string s= t[i+1][0]->label;
+	      if (starts (s, "\\end-") &&
+		  (command_type["!verbatim"] != "true"))
+		continue;
+	    }
 	  }
 	}
       }
@@ -402,7 +450,8 @@ is_right_type (tree t) {
 
 static bool
 is_large_delimiter (tree t, int& type) {
-  if ((!is_tuple (t)) || (N(t) != 2) || is_compound (t[0])) return false;
+  if ((!is_tuple (t)) || (N(t) != 2) ||
+      is_compound (t[0]) || is_compound (t[1])) return false;
   string s= t[0]->label;
   if (starts (s, "\\Big")) s= "\\big" * s(4,N(s));
   if (starts (s, "\\bigg")) s= "\\big" * s(5,N(s));
@@ -460,6 +509,31 @@ latex_accent (tree t, string acc) {
 	       tree (WIDE, tree (WITH, MODE, "text", l2e (t)), acc));
 }
 
+tree
+latex_eps_get (tree t, string var) {
+  if (!is_atomic (t)) return "";
+  string s= t->label;
+  int start=0, i, n=N(s);
+  for (i=0; i <= n; i++)
+    if (i == n || s[i] == ',') {
+      string ss= s (start, i);
+      while (starts (ss, " ")) ss= ss (1, N(ss));
+      while (ends (ss, " ")) ss= ss (0, N(ss) - 1);
+      int j, k= N(ss);
+      for (j=0; j<k; j++)
+	if (ss[j] == '=') break;
+      string v= ss (0, j);
+      while (ends (v, " ")) v= v (0, N(v) - 1);
+      if (j < k && v == var) {
+	string val= ss (j+1, N(ss));
+	while (starts (val, " ")) val= val (1, N(val));
+	return val;
+      }
+      start= i+1;
+    }
+  return "";
+}
+
 tree
 latex_command_to_tree (tree t) {
   if (is_tuple (t, "\\def", 2)) {
@@ -477,6 +551,12 @@ latex_command_to_tree (tree t) {
     return tree (ASSIGN, var, f);
   }
 
+  if (is_tuple (t, "\\newtheorem", 2)) {
+    string var= l2e(t[1])->label;
+    string val= l2e(t[2])->label;
+    return compound ("new-theorem", var, val);
+  }
+
   if (is_tuple (t, "\\newenvironment", 3)) {
     string var= l2e(t[1])->label;
     return tree (ASSIGN, var, tree (ENV, l2e (t[2]), l2e (t[3])));
@@ -491,11 +571,6 @@ latex_command_to_tree (tree t) {
     return tree (ASSIGN, var, e);
   }
 
-  if (is_tuple (t, "\\setcounter", 2)) {
-    tree u= l2e (t[1]);
-    if (is_compound (u)) return "";
-    else return tree (ASSIGN, u->label * "nr", l2e (t[2]));
-  }
   if (is_tuple (t, "\\arabic", 1)) {
     tree u= l2e (t[1]);
     if (is_compound (u)) return "";
@@ -551,31 +626,33 @@ latex_command_to_tree (tree t) {
   if (is_tuple (t, "\\mathit", 1)) return var_m2e (t, MATH_FONT_FAMILY, "it");
   if (is_tuple (t, "\\mathsl", 1)) return var_m2e (t, MATH_FONT_FAMILY, "sl");
   if (is_tuple (t, "\\mathup", 1)) return var_m2e (t, MATH_FONT_FAMILY, "up");
-  if (is_tuple (t, "\\mathcal", 1))  return m2e (t, MATH_FONT, "cal");
+  if (is_tuple (t, "\\mathcal", 1)) return m2e (t, MATH_FONT, "cal");
   if (is_tuple (t, "\\mathfrak", 1)) return m2e (t, MATH_FONT, "Euler");
-  if (is_tuple (t, "\\mathbb", 1))   return m2e (t, MATH_FONT, "Bbb");
-  if (is_tuple (t, "\\mathbbm", 1))   return m2e (t, MATH_FONT, "Bbb*");
+  if (is_tuple (t, "\\mathbb", 1)) return m2e (t, MATH_FONT, "Bbb");
+  if (is_tuple (t, "\\mathbbm", 1)) return m2e (t, MATH_FONT, "Bbb*");
 
-  if (is_tuple (t, "\\prime", 1))  return tree (RPRIME, string_arg (t[1]));
-  if (is_tuple (t, "\\frac", 2))  return tree (FRAC, l2e (t[1]), l2e (t[2]));
+  if (is_tuple (t, "\\prime", 1)) return tree (RPRIME, string_arg (t[1]));
+  if (is_tuple (t, "\\frac", 2)) return tree (FRAC, l2e (t[1]), l2e (t[2]));
+  if (is_tuple (t, "\\atop", 2))
+    return compound ("atop", l2e (t[1]), l2e (t[2]));
   if (is_tuple (t, "\\sqrt", 1))  return tree (SQRT, l2e (t[1]));
   if (is_tuple (t, "\\sqrt*", 2)) return tree (SQRT, l2e (t[2]), l2e (t[1]));
   if (is_tuple (t, "\\<sub>", 1)) return tree (RSUB, l2e (t[1]));
-  if (is_tuple (t, "\\not", 1))   return tree (NEG, l2e (t[1]));
-  if (is_tuple (t, "\\bar", 1))  return tree (WIDE, l2e (t[1]), "<bar>");
-  if (is_tuple (t, "\\hat", 1))  return tree (WIDE, l2e (t[1]), "^");
-  if (is_tuple (t, "\\tilde", 1))  return tree (WIDE, l2e (t[1]), "~");
-  if (is_tuple (t, "\\widehat", 1))  return tree (WIDE, l2e (t[1]), "^");
-  if (is_tuple (t, "\\widetilde", 1))  return tree (WIDE, l2e (t[1]), "~");
-  if (is_tuple (t, "\\dot", 1))  return tree (WIDE, l2e (t[1]), "<dot>");
-  if (is_tuple (t, "\\ddot", 1))  return tree (WIDE, l2e (t[1]), "<ddot>");
-  if (is_tuple (t, "\\dddot", 1))  return tree (WIDE, l2e (t[1]), "<dddot>");
-  if (is_tuple (t, "\\ddddot", 1))  return tree (WIDE, l2e (t[1]), "<ddddot>");
-  if (is_tuple (t, "\\check", 1))  return tree (WIDE, l2e (t[1]), "<check>");
-  if (is_tuple (t, "\\grave", 1))  return tree (WIDE, l2e (t[1]), "<grave>");
-  if (is_tuple (t, "\\acute", 1))  return tree (WIDE, l2e (t[1]), "<acute>");
-  if (is_tuple (t, "\\vec", 1))  return tree (WIDE, l2e (t[1]), "<vect>");
-  if (is_tuple (t, "\\breve", 1))  return tree (WIDE, l2e (t[1]), "<breve>");
+  if (is_tuple (t, "\\not", 1)) return tree (NEG, l2e (t[1]));
+  if (is_tuple (t, "\\bar", 1)) return tree (WIDE, l2e (t[1]), "<bar>");
+  if (is_tuple (t, "\\hat", 1)) return tree (WIDE, l2e (t[1]), "^");
+  if (is_tuple (t, "\\tilde", 1)) return tree (WIDE, l2e (t[1]), "~");
+  if (is_tuple (t, "\\widehat", 1)) return tree (WIDE, l2e (t[1]), "^");
+  if (is_tuple (t, "\\widetilde", 1)) return tree (WIDE, l2e (t[1]), "~");
+  if (is_tuple (t, "\\dot", 1)) return tree (WIDE, l2e (t[1]), "<dot>");
+  if (is_tuple (t, "\\ddot", 1)) return tree (WIDE, l2e (t[1]), "<ddot>");
+  if (is_tuple (t, "\\dddot", 1)) return tree (WIDE, l2e (t[1]), "<dddot>");
+  if (is_tuple (t, "\\ddddot", 1)) return tree (WIDE, l2e (t[1]), "<ddddot>");
+  if (is_tuple (t, "\\check", 1)) return tree (WIDE, l2e (t[1]), "<check>");
+  if (is_tuple (t, "\\grave", 1)) return tree (WIDE, l2e (t[1]), "<grave>");
+  if (is_tuple (t, "\\acute", 1)) return tree (WIDE, l2e (t[1]), "<acute>");
+  if (is_tuple (t, "\\vec", 1)) return tree (WIDE, l2e (t[1]), "<vect>");
+  if (is_tuple (t, "\\breve", 1)) return tree (WIDE, l2e (t[1]), "<breve>");
   if (is_tuple (t, "\\abovering", 1))
     return tree (WIDE, l2e (t[1]), "<abovering>");
   if (is_tuple (t, "\\hspace", 1) || is_tuple (t, "\\hspace*", 1)) {
@@ -586,7 +663,22 @@ latex_command_to_tree (tree t) {
   if (is_tuple (t, "\\vspace", 1) || is_tuple (t, "\\vspace*", 1))
     return tree (VSPACE, t2e (t[1]));
   if (is_tuple (t, "\\label", 1)) return tree (LABEL, t2e (t[1]));
-  if (is_tuple (t, "\\ref", 1))   return tree (REFERENCE, t2e (t[1]));
+  if (is_tuple (t, "\\ref", 1)) return tree (REFERENCE, t2e (t[1]));
+  if (is_tuple (t, "\\newcounter", 1))
+    return compound ("new-counter", v2e (t[1]));
+  if (is_tuple (t, "\\value", 1))
+    return compound ("value-counter", v2e (t[1]));
+  if (is_tuple (t, "\\stepcounter", 1))
+    return compound ("inc-counter", v2e (t[1]));
+  if (is_tuple (t, "\\refstepcounter", 1))
+    return compound ("next-counter", v2e (t[1]));
+  if (is_tuple (t, "\\setcounter", 2)) // FIXME: only reset works
+    return compound ("reset-counter", v2e (t[1]));
+  if (is_tuple (t, "\\addtocounter", 2)) // FIXME: only inc works
+    return compound ("inc-counter", v2e (t[1]));
+  if (is_tuple (t, "\\setlength")) return "";
+  if (is_tuple (t, "\\addtolength")) return "";
+  if (is_tuple (t, "\\enlargethispage")) return "";
   if (is_tuple (t, "\\mathop", 1)) return l2e (t[1]);
   if (is_tuple (t, "\\mathrel", 1)) return l2e (t[1]);
   if (is_tuple (t, "\\overbrace", 1))
@@ -690,18 +782,32 @@ latex_command_to_tree (tree t) {
     tree name= v2e (t[1]);
     if (name == "") return "";
     else {
-      tree g (POSTSCRIPT, 7);
+      tree g (IMAGE, 7);
       g[0]= name;
       return g;
     }
   }
+  if (is_tuple (t, "\\epsfig", 1)) {
+    tree data  = v2e (t[1]);
+    tree name  = latex_eps_get (data, "file");
+    tree width = latex_eps_get (data, "width");
+    tree height= latex_eps_get (data, "height");
+    if (name == "") return "";
+    else {
+      tree g (IMAGE, 7);
+      g[0]= name;
+      g[1]= width;
+      g[2]= height;
+      return g;
+    }
+  }
   if (is_tuple (t, "\\noalign", 1))
     return ""; // FIXME: for larger space in maple matrices
   if (is_tuple (t, "\\etalchar", 1)) return t2e (t[1]);
   if (is_tuple (t, "\\natexlab", 1)) return t2e (t[1]);
   if (is_tuple (t, "\\penalty", 1)) return "";
   if (is_tuple (t, "\\url", 1))
-    return tree (APPLY, "slink", t2e (t[1]));
+    return tree (APPLY, "href", t2e (t[1]));
   if (is_tuple (t, "\\href", 2))
     return tree (APPLY, "hlink", l2e (t[2]), t2e (t[1]));
 
@@ -834,9 +940,9 @@ parse_matrix_params (tree t) {
 }
 
 static void
-parse_pmatrix (tree& r, tree t, int& i, bool bracket) {
+parse_pmatrix (tree& r, tree t, int& i, string lb, string rb) {
   tree tformat= parse_matrix_params (t[i]);
-  if (bracket) r << tree (LEFT, "(");
+  if (lb != "") r << tree (LEFT, lb);
 
   int rows=0, cols=0;
   tree V (CONCAT);
@@ -858,17 +964,27 @@ parse_pmatrix (tree& r, tree t, int& i, bool bracket) {
       continue;
     }
     else if (is_func (v, BEGIN) && ((v[0] == "array") ||(v[0] == "tabular"))) {
-      parse_pmatrix (E, t, i, false);
+      parse_pmatrix (E, t, i, "", "");
       if (i<N(t)) continue;
       break;
     }
     else if (v == tree (BEGIN, "matrix")) {
-      parse_pmatrix (E, t, i, false);
+      parse_pmatrix (E, t, i, "", "");
       if (i<N(t)) continue;
       break;
     }
     else if (v == tree (BEGIN, "pmatrix")) {
-      parse_pmatrix (E, t, i, true);
+      parse_pmatrix (E, t, i, "(", ")");
+      if (i<N(t)) continue;
+      break;
+    }
+    else if (v == tree (BEGIN, "bmatrix")) {
+      parse_pmatrix (E, t, i, "{", "}");
+      if (i<N(t)) continue;
+      break;
+    }
+    else if (v == tree (BEGIN, "vmatrix")) {
+      parse_pmatrix (E, t, i, "|", "|");
       if (i<N(t)) continue;
       break;
     }
@@ -876,6 +992,8 @@ parse_pmatrix (tree& r, tree t, int& i, bool bracket) {
     else if (v == tree (END, "tabular")) break;
     else if (v == tree (END, "matrix")) break;
     else if (v == tree (END, "pmatrix")) break;
+    else if (v == tree (END, "bmatrix")) break;
+    else if (v == tree (END, "vmatrix")) break;
     else if (v == tree (APPLY, "hline")) {
       int    row  = N(V)+ (N(L)==0? 0: 1);
       string row_s= row==0? as_string (row+1): as_string (row);
@@ -908,7 +1026,7 @@ parse_pmatrix (tree& r, tree t, int& i, bool bracket) {
     M= tformat;
   }
   r << M;
-  if (bracket) r << tree (RIGHT, ")");
+  if (rb != "") r << tree (RIGHT, rb);
 }
 
 static tree
@@ -921,10 +1039,12 @@ finalize_pmatrix (tree t) {
     tree r (CONCAT);
     for (i=0; i<n; i++)
       if (is_func (u[i], BEGIN)) {
-	if (u[i][0] == "array") parse_pmatrix (r, u, i, false);
-	else if (u[i][0] == "tabular") parse_pmatrix (r, u, i, false);
-	else if (u[i][0] == "matrix") parse_pmatrix (r, u, i, false);
-	else if (u[i][0] == "pmatrix") parse_pmatrix (r, u, i, true);
+	if (u[i][0] == "array") parse_pmatrix (r, u, i, "", "");
+	else if (u[i][0] == "tabular") parse_pmatrix (r, u, i, "", "");
+	else if (u[i][0] == "matrix") parse_pmatrix (r, u, i, "", "");
+	else if (u[i][0] == "pmatrix") parse_pmatrix (r, u, i, "(", ")");
+	else if (u[i][0] == "bmatrix") parse_pmatrix (r, u, i, "[", "]");
+	else if (u[i][0] == "vmatrix") parse_pmatrix (r, u, i, "|", "|");
 	else r << u[i];
       }
       else r << u[i];
@@ -1001,7 +1121,7 @@ finalize_layout (tree t) {
 
       if (is_func (v, BEGIN, 1) && (v[0] == "picture")) {
 	for (; i<n; i++)
-	  if (is_func (u[i], POSTSCRIPT)) r << u[i];
+	  if (is_func (u[i], IMAGE)) r << u[i];
 	  else if (is_func (u[i], END, 1) && (u[i][0] == "picture"))
 	    break;
 	continue;
@@ -1223,6 +1343,75 @@ handle_improper_matches (tree& r, tree t, int& pos) {
   }
 }
 
+tree
+remove_env_spaces (tree t, bool& done) {
+  if (is_atomic (t)) {
+    done= done || (t != "" && t != " ");
+    return t;
+  }
+  else if (is_func (t, CONCAT)) {
+    array<tree> r;
+    for (int i=0; i<N(t); i++)
+      if (!done && t[i] == "");
+      else if (!done && t[i] == " ");
+      else r << remove_env_spaces (t[i], done);
+    return simplify_concat (tree (CONCAT, r));
+  }
+  else if (is_func (t, WITH)) {
+    tree r= t (0, N(t));
+    r[N(t)-1]= remove_env_spaces (r[N(t)-1], done);
+    return r;
+  }
+  else return t;
+}
+
+tree
+env_hacks (tree t) {
+  int i, n= N(t);
+  bool done= false;
+  tree beg= remove_env_spaces (t[n-2], done);
+  tree end= remove_env_spaces (t[n-1], done);
+  if (beg == "") beg= tree (CONCAT);
+  else if (!is_concat (beg)) beg= tree (CONCAT, beg);
+  if (end == "") end= tree (CONCAT);
+  else if (!is_concat (end)) end= tree (CONCAT, end);
+  array<tree> ba;
+  array<tree> ea;
+  for (i=0; i<N(beg); i++)
+    if (is_func (beg[i], VSPACE))
+      ba << tree (VAR_VSPACE, A(beg[i]));
+    else if (is_func (beg[i], PAGE_BREAK))
+      ba << tree (VAR_PAGE_BREAK, A(beg[i]));
+    else if (is_func (beg[i], NO_PAGE_BREAK))
+      ba << tree (VAR_NO_PAGE_BREAK, A(beg[i]));
+    else if (is_func (beg[i], NEW_PAGE))
+      ba << tree (VAR_NEW_PAGE, A(beg[i]));
+    else ba << beg[i];
+  for (i=0; i<N(end); i++)
+    if (is_func (end[i], NO_INDENT))
+      ea << tree (VAR_NO_INDENT, A(end[i]));
+    else if (is_func (end[i], YES_INDENT))
+      ea << tree (VAR_YES_INDENT, A(end[i]));
+    else ea << end[i];
+  beg= tree (CONCAT, ba);
+  end= tree (CONCAT, ea);
+  for (i=N(beg); i>0 && is_func (beg[i-1], RESET, 1); i--);
+  bool ok= (i<<1) >= N(beg);
+  for (int k=0; k<N(beg)-i; k++) {
+    ok= ok && is_func (beg[i-k-1], SET, 2) && beg[i-k-1][0] == beg[i+k][0];
+    //cout << "Matched " << beg[i-k-1] << " and " << beg[i+k] << "\n";
+  }
+  if (ok && i<N(beg)) {
+    tree r= t (0, n);
+    r[n-2]= simplify_concat (beg (0, i));
+    r[n-1]= simplify_concat (beg (i, N(beg)) * end);
+    //cout << "<< " << t << "\n";
+    //cout << ">> " << r << "\n";
+    t= r;
+  }
+  return t;
+}
+
 tree
 handle_improper_matches (tree t) {
   if (is_atomic (t)) return t;
@@ -1240,6 +1429,8 @@ handle_improper_matches (tree t) {
       if (N(u)==1) return u[0];
       return u;
     }
+    else if (is_func (r, ENV) && N(r) >= 2)
+      return env_hacks (r);
     return r;
   }
 }
@@ -1309,6 +1500,17 @@ finalize_textm (tree t) {
   return simplify_correct (u);
 }
 
+/******************************************************************************
+* Final corrections
+******************************************************************************/
+
+tree
+tex_correct (tree t) {
+  t= superfluous_invisible_correct (t);
+  t= missing_invisible_correct (t, 1);
+  return t;
+}
+
 /******************************************************************************
 * Interface
 ******************************************************************************/
@@ -1336,7 +1538,7 @@ latex_to_tree (tree t1) {
   tree t5= is_document? finalize_preamble (t4, style): t4;
   // cout << "\n\nt5= " << t5 << "\n\n";
   tree t6= handle_improper_matches (t5);
-  // cout << "\n\nt6= " << t6 << "\n\n";
+  //cout << "\n\nt6= " << t6 << "\n\n";
   if ((!is_document) && is_func (t6, DOCUMENT, 1)) t6= t6[0];
   tree t7= upgrade_tex (t6);
   // cout << "\n\nt7= " << t7 << "\n\n";
@@ -1347,7 +1549,9 @@ latex_to_tree (tree t1) {
   tree t10= drd_correct (std_drd, t9);
   // cout << "\n\nt10= " << t10 << "\n\n";
   tree t11= simplify_correct (t10);
-  // cout << "\n\nt11= " << t11 << "\n\n";
+  //cout << "\n\nt11= " << t11 << "\n\n";
+  tree t12= tex_correct (t11);
+  //cout << "\n\nt12= " << t12 << "\n\n";
 
   if (!exists (url ("$TEXMACS_STYLE_PATH", style * ".ts")))
     style= "generic";
@@ -1366,7 +1570,7 @@ latex_to_tree (tree t1) {
     mods << tree (LANGUAGE) << tree (lan);
   }
   if (is_document) {
-    tree the_body   = compound ("body", t11);
+    tree the_body   = compound ("body", t12);
     tree the_style  = compound ("style", style);
     tree the_initial= compound ("initial", initial);
     if (textm_natbib)
@@ -1379,3 +1583,16 @@ latex_to_tree (tree t1) {
     return t10;
   }
 }
+
+tree
+latex_document_to_tree (string s) {
+  command_type ->extend ();
+  command_arity->extend ();
+  command_def  ->extend ();
+  tree t= parse_latex_document (s, true);
+  tree r= latex_to_tree (t);
+  command_type ->shorten ();
+  command_arity->shorten ();
+  command_def  ->shorten ();
+  return r;
+}
