@@ -4,10 +4,9 @@
 * DESCRIPTION: upgrade old TeXmacs formats
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "convert.hpp"
@@ -17,6 +16,10 @@
 #include "drd_std.hpp"
 #include <stdio.h>
 #include "Scheme/object.hpp"
+#include "tree_brackets.hpp"
+#include "tree_correct.hpp"
+
+static bool upgrade_tex_flag= false;
 
 /******************************************************************************
 * Retrieve older operator hashmap
@@ -38,6 +41,11 @@ get_codes (string version) {
   hashmap<string,int> H (UNKNOWN);
   H->join (STD_CODE);
 
+  if (version_inf ("1.0.7.6", version)) return H;
+
+  rename_feature (H, "group", "rigid");
+  rename_feature (H, "postscript", "image");
+
   if (version_inf ("1.0.6.9", version)) return H;
 
   rename_feature (H, "frozen", "freeze");
@@ -817,6 +825,8 @@ static tree
 upgrade_set_begin_surround (tree t, tree search, bool& found) {
   if (t == search) {
     found= true;
+    if (upgrade_tex_flag)
+      return tree (DOCUMENT, copy (t));
     return copy (t);
   }
   if (is_func (t, WITH) || is_func (t, EXPAND)) {
@@ -865,7 +875,7 @@ upgrade_env_args (tree t, tree env) {
 
 static tree
 upgrade_set_begin_env (tree t) {
-  // cout << "in  : " << t << "\n";
+  //cout << "in  : " << t << "\n";
   int i, n= N(t);
   tree u (MACRO, n);
   for (i=0; i<n-2; i++)
@@ -880,15 +890,15 @@ upgrade_set_begin_env (tree t) {
   else if (!is_concat (begin)) begin= tree (CONCAT, begin);
   if (end == "") end= tree (CONCAT);
   else if (!is_concat (end)) end= tree (CONCAT, end);
-  body << A (begin) << tree (ARG, copy (s)) << A (end);
-  // cout << "mid1: " << body << "\n";
+  body << A(begin) << tree (ARG, copy (s)) << A(end);
+  //cout << "mid1: " << body << "\n";
   body= upgrade_set_begin_concat (body);
   body= upgrade_env_args (body, t);
-  // cout << "mid2: " << body << "\n";
+  //cout << "mid2: " << body << "\n";
   bool found= false;
   u[n-1]= upgrade_set_begin_surround (body, tree (ARG, s), found);
-  // cout << "out : " << u << "\n";
-  // cout << "-------------------------------------------------------------\n";
+  //cout << "out : " << u << "\n";
+  //cout << "-------------------------------------------------------------\n";
   return u;
 }
 
@@ -2738,12 +2748,223 @@ upgrade_scheme_doc (tree t) {
   }
 }
 
+/******************************************************************************
+* Upgrade Mathemagix tag
+******************************************************************************/
+
+tree
+upgrade_mmx (tree t) {
+  int i;
+  if (is_atomic (t)) return t;
+  else if (is_compound (t, "mmx", 0) || t == tree (VALUE, "mmx"))
+    return compound ("mathemagix");
+  else if (is_compound (t, "mml", 0) || t == tree (VALUE, "mml"))
+    return compound ("mmxlib");
+  else if (is_compound (t, "scheme", 0) || t == tree (VALUE, "scheme"))
+    return compound ("scheme");
+  else if (is_compound (t, "cpp", 0) || t == tree (VALUE, "cpp"))
+    return compound ("c++");
+  else if (is_compound (t, "scheme-code", 1))
+    return compound ("scm", upgrade_mmx (t[0]));
+  else if (is_compound (t, "scheme-fragment", 1))
+    return compound ("scm-fragment", upgrade_mmx (t[0]));
+  else if (is_compound (t, "cpp-code", 1))
+    return compound ("cpp", upgrade_mmx (t[0]));
+  else {
+    int n= N(t);
+    tree r (t, n);
+    for (i=0; i<n; i++)
+      r[i]= upgrade_mmx (t[i]);
+    return r;
+  }
+}
+
+/******************************************************************************
+* Upgrade sessions
+******************************************************************************/
+
+static tree
+upgrade_session (tree t, tree lan, tree ses) {
+  if (is_atomic (t)) return t;
+  else if (is_compound (t, "session", 1))
+    return compound ("session", copy (lan), copy (ses),
+		     upgrade_session (t[0], lan, ses));
+  else if (is_func (t, WITH, 5) &&
+	   t[0] == PROG_LANGUAGE &&
+	   t[2] == PROG_SESSION)
+    return upgrade_session (t[4], t[1], t[3]);
+  else {
+    int i, n= N(t);
+    tree r (L(t));
+    for (i=0; i<n; i++) {
+      if (is_document (t) && is_compound (t[i], "input", 2)) {
+	bool m = is_compound (t[i][1], "math", 1);
+	tree in= (m? t[i][1][0]: t[i][1]);
+	if ((i+1)<n && is_compound (t[i+1], "output", 1)) {
+	  const char* op= (m? "unfolded-io-math": "unfolded-io");
+	  r << compound (op, t[i][0], in, t[i+1][0]);
+	  i++;
+	}
+	else {
+	  const char* op= (m? "input-math": "input");
+	  r << compound (op, t[i][0], in);
+	}
+      }
+      else r << upgrade_session (t[i], lan, ses);
+    }
+    return r;
+  }
+}
+
+/******************************************************************************
+* Upgrade presentation style
+******************************************************************************/
+
+tree
+upgrade_presentation (tree t) {
+  int i;
+  if (is_atomic (t)) return t;
+  else if (is_compound (t, "style") || is_compound (t, "tuple")) {
+    int n= N(t);
+    tree r (t, n);
+    for (i=0; i<n; i++)
+      if (t[i] == "presentation") r[i]= "presentation-ridged-paper";
+      else r[i]= upgrade_presentation (t[i]);
+    return r;
+  }
+  else {
+    int n= N(t);
+    tree r (t, n);
+    for (i=0; i<n; i++)
+      r[i]= upgrade_presentation (t[i]);
+    return r;
+  }
+}
+
+/******************************************************************************
+* Upgrade mathematical formulas
+******************************************************************************/
+
+bool
+is_non_style_document (tree doc) {
+  tree style= extract (doc, "style");
+  if (!is_tuple (style) || N(style) == 0 || !is_atomic (style[0]))
+    return false;
+  for (int i=0; i<N(style); i++)
+    if (style[i] == "source") return false;
+  string ms= style[0]->label;
+  return
+    (starts (ms, "tm")) ||
+    (starts (ms, "lycee")) ||
+    (ms == "article") ||
+    (ms == "beamer") ||
+    (ms == "book") ||
+    (ms == "exam") ||
+    (ms == "generic") ||
+    (ms == "letter") ||
+    (ms == "seminar") ||
+    (ms == "bibliography") ||
+    (ms == "browser") ||
+    (ms == "help") ||
+    (ms == "manual") ||
+    (ms == "mmxdoc") ||
+    (ms == "elsart") ||
+    (ms == "ifac") ||
+    (ms == "jsc") ||
+    (ms == "acmconf") ||
+    (ms == "svjour") ||
+    (ms == "svmono");
+}
+
+tree
+upgrade_math (tree t) {
+  int i;
+  if (is_atomic (t)) return t;
+  else if (is_func (t, WITH, 3) && t[0] == MODE && t[1] == "math")
+    return compound ("math", t[2]);
+  else if (is_func (t, WITH, 3) && t[0] == MODE && t[1] == "text")
+    return compound ("text", t[2]);
+  else {
+    int n= N(t);
+    tree r (t, n);
+    for (i=0; i<n; i++)
+      r[i]= upgrade_math (t[i]);
+    return r;
+  }
+}
+
+/******************************************************************************
+* Upgrade resize and clipped
+******************************************************************************/
+
+tree
+upgrade_resize_arg (tree t) {
+  if (is_func (t, MERGE, 2)) {
+    if (is_atomic (t[0]) && is_atomic (t[1]))
+      return upgrade_resize_arg (t[0]->label * t[1]->label);
+    tree u= upgrade_resize_arg (t[0]);
+    if (is_func (u, PLUS, 2) || is_func (u, MINUS, 2) ||
+	is_func (u, MINIMUM, 2) || is_func (u, MAXIMUM, 2))
+      if (u[1] == "") {
+	u[1]= upgrade_resize_arg (t[1]);
+	return u;
+      }
+    cout << "TeXmacs] warning, resize argument " << t << " not upgraded\n";
+    return t;
+  }
+  if (is_func (t, ARG, 1) ||
+      is_func (t, PLUS, 2) || is_func (t, MINUS, 2) ||
+      is_func (t, MINIMUM, 2) || is_func (t, MAXIMUM, 2))
+    return t;
+  if (!is_atomic (t)) {
+    cout << "TeXmacs] warning, resize argument " << t << " not upgraded\n";
+    return t;
+  }
+  string s= t->label;
+  if (starts (s, "c")) {
+    cout << "TeXmacs] warning, resize argument " << t << " not upgraded\n";
+    return t;
+  }
+  if (N(s) < 2) return t;
+  if (s[0] != 'l' && s[0] != 'b' && s[0] != 'r' && s[0] != 't') return t;
+  string s1= "1" * s (0, 1);
+  string s2= s (2, N(s));
+  if (s[1] == '+') return tree (PLUS, s1, s2);
+  if (s[1] == '-') return tree (MINUS, s1, s2);
+  if (s[1] == '[') return tree (MINIMUM, s1, s2);
+  if (s[1] == ']') return tree (MAXIMUM, s1, s2);
+  return t;
+}
+
+tree
+upgrade_resize_clipped (tree t) {
+  if (is_atomic (t)) return t;
+  else if (is_func (t, RESIZE, 5) || is_func (t, CLIPPED, 5)) {
+    if (is_func (t, CLIPPED))
+      t= tree (CLIPPED, t[4], t[0], t[1], t[2], t[3]);
+    int i, n= N(t);
+    tree r (t, n);
+    r[0]= upgrade_resize_clipped (t[0]);
+    for (i=1; i<n; i++)
+      r[i]= upgrade_resize_arg (t[i]);
+    return r;
+  }
+  else {
+    int i, n= N(t);
+    tree r (t, n);
+    for (i=0; i<n; i++)
+      r[i]= upgrade_resize_clipped (t[i]);
+    return r;
+  }
+}
+
 /******************************************************************************
 * Upgrade from previous versions
 ******************************************************************************/
 
 tree
 upgrade_tex (tree t) {
+  upgrade_tex_flag= true;
   t= upgrade_apply_expand_value (t);
   t= upgrade_new_environments (t);
   t= upgrade_items (t);
@@ -2766,12 +2987,21 @@ upgrade_tex (tree t) {
   t= substitute (t, tree (VALUE, "hrule"), compound ("hrule"));
   t= upgrade_doc_info (t);
   t= upgrade_bibliography (t);
+  t= upgrade_math (t);
+  t= upgrade_resize_clipped (t);
+  t= upgrade_brackets (t);
+  upgrade_tex_flag= false;
+  return t;
+}
+
+tree
+upgrade_mathml (tree t) {
+  t= upgrade_brackets (t, "math");
   return t;
 }
 
 tree
 upgrade (tree t, string version) {
-  // cout << "Upgrade from " << version << "\n";
   if (version_inf (version, "0.3.1.9")) {
     path p;
     t= upgrade_textual (t, p);
@@ -2850,5 +3080,22 @@ upgrade (tree t, string version) {
     t= upgrade_label_assignment (t);
   if (version_inf_eq (version, "1.0.6.10"))
     t= upgrade_scheme_doc (t);
+  if (version_inf_eq (version, "1.0.6.14"))
+    t= upgrade_mmx (t);
+  if (version_inf_eq (version, "1.0.7.1"))
+    t= upgrade_session (t, "scheme", "default");
+  if (version_inf_eq (version, "1.0.7.6"))
+    t= upgrade_presentation (t);
+  if (version_inf_eq (version, "1.0.7.6") && is_non_style_document (t))
+    t= upgrade_math (t);
+  if (version_inf_eq (version, "1.0.7.7"))
+    t= upgrade_resize_clipped (t);
+  if (version_inf_eq (version, "1.0.7.7") && is_non_style_document (t)) {
+    t= with_correct (t);
+    t= superfluous_with_correct (t);
+    t= upgrade_brackets (t);
+    t= superfluous_invisible_correct (t);
+    t= missing_invisible_correct (t);
+  }
   return t;
 }
