@@ -57,11 +57,40 @@ drd_info_rep::contains (string l) {
   return existing_tree_label (l) && info->contains (as_tree_label (l));
 }
 
-ostream&
-operator << (ostream& out, drd_info drd) {
+tm_ostream&
+operator << (tm_ostream& out, drd_info drd) {
   return out << "drd [" << drd->name << "]";
 }
 
+/******************************************************************************
+* Tag types
+******************************************************************************/
+
+void
+drd_info_rep::set_type (tree_label l, int tp) {
+  if (info[l]->pi.freeze_type) return;
+  if (!info->contains (l)) info(l)= copy (info[l]);
+  tag_info& ti= info(l);
+  ti->pi.type= tp;
+}
+
+int
+drd_info_rep::get_type (tree_label l) {
+  return info[l]->pi.type;
+}
+
+void
+drd_info_rep::freeze_type (tree_label l) {
+  if (!info->contains (l)) info(l)= copy (info[l]);
+  tag_info& ti= info(l);
+  ti->pi.freeze_type= true;
+}
+
+int
+drd_info_rep::get_type (tree t) {
+  return info[L(t)]->pi.type;
+}
+
 /******************************************************************************
 * Arity related methods
 ******************************************************************************/
@@ -180,33 +209,71 @@ drd_info_rep::is_dynamic (tree t) {
 ******************************************************************************/
 
 void
-drd_info_rep::set_no_border (tree_label l, bool has_no_border) {
-  if (info[l]->pi.freeze_no_border) return;
+drd_info_rep::set_border (tree_label l, int mode) {
+  if (info[l]->pi.freeze_border) return;
   if (!info->contains (l)) info(l)= copy (info[l]);
   tag_info& ti= info(l);
-  ti->pi.no_border= has_no_border;
+  ti->pi.border_mode= mode;
 }
 
-bool
-drd_info_rep::get_no_border (tree_label l) {
-  return info[l]->pi.no_border;
+int
+drd_info_rep::get_border (tree_label l) {
+  return info[l]->pi.border_mode;
 }
 
 void
-drd_info_rep::freeze_no_border (tree_label l) {
+drd_info_rep::freeze_border (tree_label l) {
   if (!info->contains (l)) info(l)= copy (info[l]);
   tag_info& ti= info(l);
-  ti->pi.freeze_no_border= true;
+  ti->pi.freeze_border= true;
 }
 
 bool
 drd_info_rep::is_child_enforcing (tree t) {
-  return info[L(t)]->pi.no_border && (N(t) != 0);
+  return ((info[L(t)]->pi.border_mode & BORDER_INNER) != 0) &&
+         (N(t) != 0);
+}
+
+bool
+drd_info_rep::is_parent_enforcing (tree t) {
+  return ((info[L(t)]->pi.border_mode & BORDER_OUTER) != 0) &&
+         (N(t) != 0);
 }
 
 bool
 drd_info_rep::var_without_border (tree_label l) {
-  return info[l]->pi.no_border && (!std_contains (as_string (l)));
+  return ((info[l]->pi.border_mode & BORDER_INNER) != 0) &&
+         (!std_contains (as_string (l)));
+}
+
+/******************************************************************************
+* With-like structures correspond to macros which just modify
+* the current environment, such as the 'strong' tag
+******************************************************************************/
+
+void
+drd_info_rep::set_with_like (tree_label l, bool is_with_like) {
+  if (info[l]->pi.freeze_with) return;
+  if (!info->contains (l)) info(l)= copy (info[l]);
+  tag_info& ti= info(l);
+  ti->pi.with_like= is_with_like;
+}
+
+bool
+drd_info_rep::get_with_like (tree_label l) {
+  return info[l]->pi.with_like;
+}
+
+void
+drd_info_rep::freeze_with_like (tree_label l) {
+  if (!info->contains (l)) info(l)= copy (info[l]);
+  tag_info& ti= info(l);
+  ti->pi.freeze_with= true;
+}
+
+bool
+drd_info_rep::is_with_like (tree t) {
+  return info[L(t)]->pi.with_like && N(t) > 0;
 }
 
 /******************************************************************************
@@ -238,6 +305,63 @@ drd_info_rep::get_name (tree_label l) {
   return as_string (get_attribute (l, "name"));
 }
 
+string
+drd_info_rep::get_class (tree t) {
+  if (is_atomic (t)) {
+    string s= "symbol:" * t->label;
+    if (!existing_tree_label (s)) return "";
+    return as_string (get_attribute (make_tree_label (s), "class"));
+  }
+  else if (is_func (t, VALUE, 1) && is_atomic (t[0])) {
+    string s= "value:" * t[0]->label;
+    if (!existing_tree_label (s)) return "";
+    return as_string (get_attribute (make_tree_label (s), "class"));
+  }
+  return as_string (get_attribute (L(t), "class"));
+}
+
+/******************************************************************************
+* Children's mode
+******************************************************************************/
+
+void
+drd_info_rep::set_type (tree_label l, int nr, int tp) {
+  if (!info->contains (l)) info(l)= copy (info[l]);
+  tag_info  & ti= info(l);
+  if (nr >= N(ti->ci)) return;
+  child_info& ci= ti->ci[nr];
+  if (ci.freeze_type) return;
+  ci.type= tp;
+}
+
+int
+drd_info_rep::get_type (tree_label l, int nr) {
+  return info[l]->ci[nr].type;
+}
+
+void
+drd_info_rep::freeze_type (tree_label l, int nr) {
+  if (!info->contains (l)) info(l)= copy (info[l]);
+  tag_info  & ti= info(l);
+  child_info& ci= ti->ci[nr];
+  ci.freeze_type= true;
+}
+
+int
+drd_info_rep::get_type_child (tree t, int i) {
+  tag_info ti= info[L(t)];
+  int index= ti->get_index (i, N(t));
+  if (is_func (t, EXTERN) && N(t)>0 && is_atomic (t[0])) {
+    ti= info[make_tree_label ("extern:" * t[0]->label)];
+    index= ti->get_index (i-1, N(t));
+  }
+  if ((index<0) || (index>=N(ti->ci))) return TYPE_INVALID;
+  int r= ti->ci[index].type;
+  if (r != TYPE_BINDING) return r;
+  if ((i & 1) == 0) return TYPE_VARIABLE;
+  return TYPE_REGULAR;
+}
+
 /******************************************************************************
 * Children's accessability related methods
 ******************************************************************************/
@@ -276,9 +400,18 @@ drd_info_rep::all_accessible (tree_label l) {
 
 bool
 drd_info_rep::is_accessible_child (tree t, int i) {
+  //cout << "l= " << as_string (L(t)) << "\n";
   tag_info ti= info[L(t)];
   int index= ti->get_index (i, N(t));
-  if ((index<0) || (index>=N(ti->ci))) return false;
+  if (is_func (t, EXTERN) && N(t)>0 && is_atomic (t[0])) {
+    ti= info[make_tree_label ("extern:" * t[0]->label)];
+    index= ti->get_index (i-1, N(t));
+  }
+  if ((index<0) || (index>=N(ti->ci))) {
+    if (get_access_mode () == DRD_ACCESS_SOURCE)
+      return !is_atomic (t) && i >= 0 && i < N(t);
+    else return false;
+  }
   switch (get_access_mode ()) {
   case DRD_ACCESS_NORMAL:
     return ti->ci[index].accessible == ACCESSIBLE_ALWAYS;
@@ -322,105 +455,237 @@ int
 drd_info_rep::get_writability_child (tree t, int i) {
   tag_info ti= info[L(t)];
   int index= ti->get_index (i, N(t));
+  if (is_func (t, EXTERN) && N(t)>0 && is_atomic (t[0])) {
+    ti= info[make_tree_label ("extern:" * t[0]->label)];
+    index= ti->get_index (i-1, N(t));
+  }
   if ((index<0) || (index>=N(ti->ci))) return WRITABILITY_DISABLE;
   return ti->ci[index].writability;
 }
 
 /******************************************************************************
-* Mode determination
+* Environment determination
 ******************************************************************************/
 
+tree
+drd_env_write (tree env, string var, tree val) {
+  for (int i=0; i<=N(env); i+=2)
+    if (i == N(env))
+      return env * tree (ATTR, var, val);
+    else if (var <= env[i]->label) {
+      if (var == env[i]->label)
+	return env (0, i) * tree (ATTR, var, val) * env (i+2, N(env));
+      return env (0, i) * tree (ATTR, var, val) * env (i, N(env));
+    }
+  return env;
+}
+
+tree
+drd_env_merge (tree env, tree t) {
+  int i, n= N(t);
+  for (i=0; i<n; i+=2)
+    if (is_atomic (t[i]))
+      env= drd_env_write (env, t[i]->label, t[i+1]);
+  return env;
+}
+
+tree
+drd_env_read (tree env, string var, tree val) {
+  int i, n= N(env);
+  for (i=0; i<n; i+=2)
+    if (env[i] == var)
+      return env[i+1];
+  return val;
+}
+
 void
-drd_info_rep::set_mode (tree_label l, int nr, int mode) {
+drd_info_rep::set_env (tree_label l, int nr, tree env) {
+  //if (as_string (l) == "section")
+  //cout << as_string (l) << ", " << nr << " -> " << env << "\n";
+  //if (as_string (l) == "session")
+  //cout << as_string (l) << ", " << nr << " -> " << env << "\n";
   if (!info->contains (l)) info(l)= copy (info[l]);
   tag_info  & ti= info(l);
   if (nr >= N(ti->ci)) return;
   child_info& ci= ti->ci[nr];
-  if (ci.freeze_mode) return;
-  ci.mode= mode;
+  if (ci.freeze_env) return;
+  ci.env= drd_encode (env);
 }
 
-int
-drd_info_rep::get_mode (tree_label l, int nr) {
-  return info[l]->ci[nr].mode;
+tree
+drd_info_rep::get_env (tree_label l, int nr) {
+  return drd_decode (info[l]->ci[nr].env);
 }
 
 void
-drd_info_rep::freeze_mode (tree_label l, int nr) {
+drd_info_rep::freeze_env (tree_label l, int nr) {
   if (!info->contains (l)) info(l)= copy (info[l]);
   tag_info  & ti= info(l);
   child_info& ci= ti->ci[nr];
-  ci.freeze_mode= true;
+  ci.freeze_env= true;
 }
 
-int
-drd_info_rep::get_mode_child (tree t, int i, int mode) {
-  tag_info ti= info[L(t)];
-  int index= ti->get_index (i, N(t));
-  if ((index<0) || (index>=N(ti->ci))) return -1;
-  int cmode= ti->ci[index].mode;
-  if (cmode == MODE_PARENT) return mode;
-  return cmode;
+tree
+drd_info_rep::get_env_child (tree t, int i, tree env) {
+  if (L(t) == ATTR && i == N(t)-1)
+    return drd_env_merge (env, t (0, N(t)-1));
+  else {
+    /* makes cursor movement (is_accessible_cursor) slow for large preambles
+    if (L(t) == DOCUMENT && N(t) > 0 &&
+	(is_compound (t[0], "hide-preamble", 1) ||
+	 is_compound (t[0], "show-preamble", 1)))
+      {
+	tree u= t[0][0];
+	if (!is_func (u, DOCUMENT)) u= tree (DOCUMENT, u);
+	tree cenv (ATTR);
+	for (int i=0; i<N(u); i++)
+	  if (is_func (u[i], ASSIGN, 2))
+	    cenv << copy (u[i][0]) << copy (u[i][1]);
+	env= drd_env_merge (env, cenv);
+      }
+    */
+
+    tag_info ti= info[L(t)];
+    int index= ti->get_index (i, N(t));
+    if ((index<0) || (index>=N(ti->ci))) return "";
+    tree cenv= drd_decode (ti->ci[index].env);
+    for (int i=1; i<N(cenv); i+=2)
+      if (is_func (cenv[i], ARG, 1) && is_int (cenv[i][0])) {
+	cenv= copy (cenv);
+	int j= as_int (cenv[i][0]);
+	if (j>=0 && j<N(t)) cenv[i]= copy (t[j]);
+      }
+    return drd_env_merge (env, cenv);
+  }
+}
+
+tree
+drd_info_rep::get_env_child (tree t, int i, string var, tree val) {
+  tree env= get_env_child (t, i, tree (ATTR));
+  return drd_env_read (env, var, val);
+}
+
+tree
+drd_info_rep::get_env_descendant (tree t, path p, tree env) {
+  if (is_nil (p) || env == "") return env;
+  int  i= p->item;
+  path q= p->next;
+  if (is_compound (t) && i >= 0 && i < N(t))
+    return get_env_descendant (t[i], q, get_env_child (t, i, env));
+  return "";
 }
 
 /******************************************************************************
 * Heuristic initialization of DRD
 ******************************************************************************/
 
-static int
-arg_access_mode (drd_info_rep* drd, tree t, tree arg, int mode) {
-  // returns -1 if unaccessible and the mode if accessible
-  if (is_atomic (t)) return -1;
-  else if (t == arg) return mode;
+tree
+drd_info_rep::arg_access (tree t, tree arg, tree env, int& type) {
+  // returns "" if unaccessible and the env if accessible
+  //cout << "  arg_access " << t << ", " << arg << ", " << env << "\n";
+  if (is_atomic (t)) return "";
+  else if (t == arg) return env;
+  else if (is_func (t, QUOTE_ARG, 1) && N(arg) == 1 && t[0] == arg[0])
+    return env;
   else if (is_func (t, MAP_ARGS) && (t[2] == arg[0])) {
     if ((N(t) >= 4) && (N(arg) >= 2) && (as_int (t[3]) > as_int (arg[1])))
-      return -1;
+      return "";
     if ((N(t) == 5) && (N(arg) >= 2) && (as_int (t[3]) <= as_int (arg[1])))
-      return -1;
+      return "";
     tree_label inner= make_tree_label (as_string (t[0]));
     tree_label outer= make_tree_label (as_string (t[1]));
-    if ((drd->get_nr_indices (inner) > 0) &&
-	(drd->get_accessible (inner, 0) == ACCESSIBLE_ALWAYS) &&
-	drd->all_accessible (outer))
-      return mode;
-    return -1;
+    if ((get_nr_indices (inner) > 0) &&
+	(get_accessible (inner, 0) == ACCESSIBLE_ALWAYS) &&
+	all_accessible (outer))
+      return env;
+    return "";
   }
-  else if (is_func (t, MACRO)) return -1;
+  else if (is_func (t, MACRO)) return "";
   else if (is_func (t, WITH)) {
-    int i, n= N(t)-1;
-    for (i=0; i<n; i+=2)
-      if (t[i] == MODE) {
-	if (t[i+1] == "text") mode= MODE_TEXT;
-	if (t[i+1] == "math") mode= MODE_MATH;
-	if (t[i+1] == "prog") mode= MODE_PROG;
-	if (t[i+1] == "src" ) mode= MODE_SRC ;
-      }
-    return arg_access_mode (drd, t[n], arg, mode);
+    int n= N(t)-1;
+    //cout << "env= " << drd_env_merge (env, t (0, n)) << "\n";
+    return arg_access (t[n], arg, drd_env_merge (env, t (0, n)), type);
   }
+  else if (is_func (t, TFORMAT)) {
+    int n= N(t)-1;
+    tree oldf= drd_env_read (env, CELL_FORMAT, tree (TFORMAT));
+    tree newf= oldf * tree (TFORMAT, A (t (0, n)));
+    tree w   = tree (ATTR, CELL_FORMAT, newf);
+    tree cenv= get_env_child (t, n, drd_env_merge (env, w));
+    return arg_access (t[n], arg, cenv, type);
+  }
+  else if (is_func (t, COMPOUND) && N(t) >= 1 && is_atomic (t[0]))
+    return arg_access (compound (t[0]->label, A (t (1, N(t)))),
+		       arg, env, type);
+  else if ((is_func (t, IF) || is_func (t, VAR_IF)) && N(t) >= 2)
+    return arg_access (t[1], arg, env, type);
   else {
     int i, n= N(t);
-    for (i=0; i<n; i++)
-      if (drd->is_accessible_child (t, i)) {
-	int cmode= drd->get_mode_child (t, i, mode);
-	int amode= arg_access_mode (drd, t[i], arg, cmode);
-	if (amode >= 0) return amode;
+    for (i=0; i<n; i++) {
+      int  ctype= get_type_child (t, i);
+      tree cenv = get_env_child (t, i, env);
+      tree aenv = arg_access (t[i], arg, cenv, ctype);
+      if (aenv != "") {
+	if (ctype != TYPE_INVALID) type= ctype;
+	if (is_accessible_child (t, i)) return aenv;
       }
-    return -1;
+    }
+    return "";
   }
 }
 
+static void
+rewrite_symbolic_arguments (tree macro, tree& env) {
+  if (!is_func (env, ATTR)) return;
+  for (int i=1; i<N(env); i+=2)
+    if (is_func (env[i], ARG, 1)) {
+      for (int j=0; j+1<N(macro); j++)
+	if (macro[j] == env[i][0])
+	  env[i]= tree (ARG, as_tree (j));
+    }
+}
+
+bool
+drd_info_rep::heuristic_with_like (tree t, tree arg) {
+  if (arg == "") {
+    if (!is_func (t, MACRO) || N(t) < 2) return false;
+    return heuristic_with_like (t[N(t)-1], t[N(t)-2]);
+  }
+  else if (t == tree (ARG, arg))
+    return true;
+  else if (is_with_like (t))
+    return heuristic_with_like (t[N(t)-1], arg);
+  else return false;
+}
+
 bool
 drd_info_rep::heuristic_init_macro (string var, tree macro) {
+  //cout << "init_macro " << var << " -> " << macro << "\n";
   tree_label l = make_tree_label (var);
   tag_info old_ti= copy (info[l]);
   int i, n= N(macro)-1;
   set_arity (l, n, 0, ARITY_NORMAL, CHILD_DETAILED);
+  set_type (l, get_type (macro[n]));
+  set_with_like (l, heuristic_with_like (macro, ""));
+  //if (heuristic_with_like (macro, ""))
+  //cout << "With-like: " << var << LF;
   for (i=0; i<n; i++) {
+    int  type= TYPE_UNKNOWN;
     tree arg (ARG, macro[i]);
-    int mode= arg_access_mode (this, macro[n], arg, MODE_PARENT);
-    if (mode >= 0) {
+    tree env= arg_access (macro[n], arg, tree (ATTR), type);
+    //if (var == "section" || var == "section-title")
+    //cout << var << " -> " << env << ", " << macro << "\n";
+    //if (var == "math")
+    //cout << var << ", " << i << " -> " << env << ", " << macro << "\n";
+    set_type (l, i, type);
+    if (env != "") {
+      //if (var == "eqnarray*")
+      //cout << var << " -> " << env << "\n";
+      //if (var == "session")
+      //cout << var << " = " << macro << ", " << i << " -> " << env << "\n";
+      rewrite_symbolic_arguments (macro, env);
       set_accessible (l, i, ACCESSIBLE_ALWAYS);
-      set_mode (l, i, mode);
+      set_env (l, i, env);
     }
   }
   // if (old_ti != info[l])
@@ -449,12 +714,15 @@ drd_info_rep::heuristic_init_xmacro (string var, tree xmacro) {
   tag_info old_ti= copy (info[l]);
   int i, m= minimal_arity (xmacro[1], xmacro[0]);
   set_arity (l, m, 1, ARITY_REPEAT, CHILD_DETAILED);
+  set_type (l, get_type (xmacro[1]));
   for (i=0; i<=m; i++) {
+    int type= TYPE_UNKNOWN;
     tree arg (ARG, xmacro[0], as_string (i));
-    int mode= arg_access_mode (this, xmacro[1], arg, MODE_PARENT);
-    if (mode >= 0) {
+    tree env= arg_access (xmacro[1], arg, tree (ATTR), type);
+    set_type (l, i, type);
+    if (env != "") {
       set_accessible (l, i, ACCESSIBLE_ALWAYS);
-      set_mode (l, i, mode);
+      set_env (l, i, env);
     }
   }
   // if (old_ti != info[l])
