@@ -4,10 +4,9 @@
 * DESCRIPTION: the environment variables
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "vars.hpp"
@@ -22,8 +21,13 @@ string PREAMBLE ("preamble");
 string SAVE_AUX ("save-aux");
 string MODE ("mode");
 string INFO_FLAG ("info-flag");
+string WINDOW_BARS ("window-bars");
+string SCROLL_BARS ("scroll-bars");
 string IDENTITY ("identity");
 string TABULAR ("tabular");
+string THE_LABEL ("the-label");
+string THE_TAGS ("the-tags");
+string THE_MODULES ("the-modules");
 
 /******************************************************************************
 * Text properties for tex, math and prog modes
@@ -38,6 +42,8 @@ string FONT_BASE_SIZE ("font-base-size");
 string MAGNIFICATION ("magnification");
 string COLOR ("color");
 string BG_COLOR ("bg-color");
+string LOCUS_COLOR ("locus-color");
+string VISITED_COLOR ("visited-color");
 string LANGUAGE ("language");
 string ATOM_DECORATIONS ("atom-decorations");
 string LINE_DECORATIONS ("line-decorations");
@@ -54,6 +60,8 @@ string MATH_LEVEL ("math-level");
 string MATH_DISPLAY ("math-display");
 string MATH_CONDENSED ("math-condensed");
 string MATH_VPOS ("math-vpos");
+string MATH_NESTING_MODE ("math-nesting-mode");
+string MATH_NESTING_LEVEL ("math-nesting-level");
 
 string PROG_LANGUAGE ("prog-language");
 string PROG_SCRIPTS ("prog-scripts");
@@ -88,6 +96,7 @@ string PAR_COLUMNS_SEP ("par-columns-sep");
 ******************************************************************************/
 
 string PAGE_MEDIUM ("page-medium");
+string PAGE_PRINTED ("page-printed");
 string PAGE_TYPE ("page-type");
 string PAGE_ORIENTATION ("page-orientation");
 string PAGE_WIDTH_MARGIN ("page-width-margin");
@@ -182,6 +191,7 @@ string CELL_BBORDER ("cell-bborder");
 string CELL_TBORDER ("cell-tborder");
 string CELL_VCORRECT ("cell-vcorrect");
 string CELL_HYPHEN ("cell-hyphen");
+string CELL_BLOCK ("cell-block");
 string CELL_ROW_SPAN ("cell-row-span");
 string CELL_COL_SPAN ("cell-col-span");
 string CELL_ROW_NR ("cell-row-nr");
@@ -228,3 +238,22 @@ string SRC_STYLE ("src-style");
 string SRC_SPECIAL ("src-special");
 string SRC_COMPACT ("src-compact");
 string SRC_CLOSE ("src-close");
+
+/******************************************************************************
+* Environment variables for the graphical user interface
+******************************************************************************/
+
+string CANVAS_TYPE ("canvas-type");
+string CANVAS_COLOR ("canvas-color");
+string CANVAS_HPADDING ("canvas-hpadding");
+string CANVAS_VPADDING ("canvas-vpadding");
+string CANVAS_BAR_WIDTH ("canvas-bar-width");
+string CANVAS_BAR_PADDING ("canvas-bar-padding");
+string CANVAS_BAR_COLOR ("canvas-bar-color");
+string ORNAMENT_SHAPE ("ornament-shape");
+string ORNAMENT_BORDER ("ornament-border");
+string ORNAMENT_HPADDING ("ornament-hpadding");
+string ORNAMENT_VPADDING ("ornament-vpadding");
+string ORNAMENT_COLOR ("ornament-color");
+string ORNAMENT_SUNNY_COLOR ("ornament-sunny-color");
+string ORNAMENT_SHADOW_COLOR ("ornament-shadow-color");
