@@ -4,10 +4,9 @@
 * DESCRIPTION: make a tree syntactically match a drd
 * COPYRIGHT  : (C) 2005  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef TREE_CORRECT_H
@@ -15,5 +14,9 @@
 #include "drd_std.hpp"
 
 tree drd_correct (drd_info drd, tree t);
+tree with_correct (tree t);
+tree superfluous_with_correct (tree t);
+tree superfluous_invisible_correct (tree t);
+tree missing_invisible_correct (tree t, int force= -1);
 
 #endif // defined TREE_CORRECT_H
