@@ -4,10 +4,9 @@
 * DESCRIPTION: the typeset structure for the mathematical editor
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef EDIT_TYPESET_H
@@ -51,6 +50,9 @@ public:
   double   divide_lengths (string l1, string l2);
 
   void     drd_update ();
+#ifdef EXPERIMENTAL
+  void     environment_update ();
+#endif
   bool     defined_at_cursor (string var_name);
   bool     defined_at_init (string var_name);
   bool     defined_in_init (string var_name);
@@ -67,6 +69,7 @@ public:
 
   tree     exec (tree t, hashmap<string,tree> env, bool expand_refs= true);
   tree     exec_texmacs (tree t, path p);
+  tree     exec_texmacs (tree t);
   tree     exec_html (tree t, path p);
   tree     exec_html (tree t);
   tree     exec_latex (tree t, path p);
@@ -85,6 +88,7 @@ public:
   void     typeset_prepare ();
   void     typeset_invalidate_env ();
   void     typeset_exec_until (path p);
+  void     typeset_invalidate (path p);
   void     typeset_invalidate_all ();
   void     typeset (SI& x1, SI& y1, SI& x2, SI& y2);
 
