@@ -32,13 +32,15 @@ protected:
   time_t        next_animate;  // time for next animation
   bool          full_screen;   // full screen mode ?
   bool          got_focus;     // do we have keyboard focus ?
-  string        sh_s;          // current string for shorthands
+  string        sh_s;          // current string for shortcuts
   double        sh_mark;       // 0 or mark for undoing shortcut
+  string        pre_edit_s;    // pre-edit string
+  double        pre_edit_mark; // 0 or mark for undoing pre-edit
   widget        popup_win;     // the current popup window
-  string        message_l;     // a left message to display
-  string        message_r;     // a right message to display
-  string        last_l;        // last displayed left message
-  string        last_r;        // last displayed right message
+  tree          message_l;     // a left message to display
+  tree          message_r;     // a right message to display
+  tree          last_l;        // last displayed left message
+  tree          last_r;        // last displayed right message
   int           sfactor;       // the current shrinking factor
   SI            pixel;         // sfactor*PIXEL
   rectangles    copy_always;   // for wiping out cursor
@@ -55,6 +57,8 @@ protected:
   bool          table_selection;
   rectangles    selection_rects;
   rectangles    env_rects;
+  rectangles    sem_rects;
+  bool          sem_correct;
   cursor        oc;
   bool          temp_invalid_cursor;
   array<string> completions;
@@ -128,13 +132,16 @@ public:
   bool kbd_get_command (string which, string& help, command& cmd);
   void interrupt_shortcut ();
   bool try_shortcut (string comb);
+  tree kbd (string s);
+  tree kbd_shortcut (string s);
   void key_press (string key);
   void emulate_keyboard (string keys, string action= "");
   bool complete_try ();
   void complete_message ();
   void complete_start (string prefix, array<string> compls);
   bool complete_keypress (string key);
-  bool session_complete_try (tree t);
+  string session_complete_command (tree t);
+  void custom_complete (tree t);
 
   /* mouse handling */
   void mouse_any (string s, SI x, SI y, int mods, time_t t);
@@ -151,19 +158,19 @@ public:
   void update_active_loci ();
 
   /* the footer */
-  string compute_text_footer (tree st);
-  string compute_operation_footer (tree st);
-  string compute_compound_footer (tree t, path p);
-  bool   set_latex_footer (tree st);
-  bool   set_hybrid_footer (tree st);
-  void   set_left_footer (string l);
-  void   append_left_footer (string& s, string env_var);
-  void   set_left_footer ();
-  void   set_right_footer (string r);
-  void   set_right_footer ();
-  void   set_footer ();
-  void   set_message (string l, string r= "", bool temp= false);
-  void   recall_message ();
+  tree compute_text_footer (tree st);
+  tree compute_operation_footer (tree st);
+  tree compute_compound_footer (tree t, path p);
+  bool set_latex_footer (tree st);
+  bool set_hybrid_footer (tree st);
+  void set_left_footer (tree l);
+  void append_left_footer (tree& l, string env_var);
+  void set_left_footer ();
+  void set_right_footer (tree r);
+  void set_right_footer ();
+  void set_footer ();
+  void set_message (tree l, tree r= "", bool temp= false);
+  void recall_message ();
 
   /* event handlers */
   void handle_get_size_hint (SI& w, SI& h);
