@@ -336,11 +336,15 @@ edit_interface_rep::update_active_loci () {
 
 void
 edit_interface_rep::handle_mouse (string kind, SI x, SI y, int m, time_t t) {
+  if (is_nil (eb)) apply_changes ();
   start_editing ();
   x *= sfactor;
   y *= sfactor;
   //cout << kind << " (" << x << ", " << y << "; " << m << ")"
   //<< " at " << t << "\n";
-  mouse_any (kind, x, y, m, t);
+  array<object> args;
+  args << object (kind) << object (x) << object (y)
+       << object (m) << object ((double) t);
+  call ("mouse-event", args);
   end_editing ();
 }
