@@ -41,6 +41,13 @@ edit_interface_rep::draw_env (renderer ren) {
       ren->fill (rs->item->x1, rs->item->y1, rs->item->x2, rs->item->y2);
       rs= rs->next;
     }
+    rs= sem_rects;
+    while (!is_nil (rs)) {
+      if (sem_correct) ren->set_color (rgb_color (112, 208, 112));
+      else ren->set_color (rgb_color (208, 112, 112));
+      ren->fill (rs->item->x1, rs->item->y1, rs->item->x2, rs->item->y2);
+      rs= rs->next;
+    }
   }
 }
 
@@ -270,7 +277,7 @@ edit_interface_rep::draw_with_stored (rectangle r) {
     draw_with_shadow (r);
     if (!win->interrupted ()) {
       if (inside_active_graphics ()) {
-	win->new_shadow (stored);
+	shadow->new_shadow (stored);
 	shadow->get_shadow (stored, sr->x1, sr->y1, sr->x2, sr->y2);
 	//stored_rects= /*stored_rects |*/ rectangles (r);
 	stored_rects= simplify (rectangles (r, stored_rects));
@@ -303,6 +310,7 @@ edit_interface_rep::handle_clear (SI x1, SI y1, SI x2, SI y2) {
 
 void
 edit_interface_rep::handle_repaint (SI x1, SI y1, SI x2, SI y2) {
+  if (is_nil (eb)) apply_changes ();
   if (env_change != 0) {
     system_warning ("Invalid situation (" * as_string (env_change) * ")",
 		    "(edit_interface_rep::handle_repaint)");
