@@ -4,13 +4,13 @@
 * DESCRIPTION: editing dynamic content
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "edit_dynamic.hpp"
+#include "tree_analyze.hpp"
 
 /******************************************************************************
 * Constructors and destructors
@@ -54,7 +54,9 @@ edit_dynamic_rep::is_multi_paragraph_macro (tree t) {
   int n= arity (t);
   if (is_document (t) || is_func (t, PARA) || is_func (t, SURROUND))
     return true;
-  if (is_func (t, MACRO) || is_func (t, WITH))
+  if (is_func (t, MACRO) || is_func (t, WITH) ||
+      is_func (t, LOCUS) ||
+      is_func (t, CANVAS) || is_func (t, ORNAMENT))
     return is_multi_paragraph_macro (t [n-1]);
   if (is_extension (t) && (!is_compound (t, "footnote"))) {
     int i;
@@ -82,7 +84,8 @@ contains_table_format (tree t, tree var) {
 
 void
 edit_dynamic_rep::make_compound (tree_label l, int n= -1) {
-  // cout << "Make compound " << as_string (l) << "\n";
+  //cout << "Make compound " << as_string (l) << "\n";
+  eval ("(use-modules (generic generic-edit))");
   if (n == -1) {
     for (n=0; true; n++) {
       if (drd->correct_arity (l, n) &&
@@ -94,6 +97,7 @@ edit_dynamic_rep::make_compound (tree_label l, int n= -1) {
   tree t (l, n);
   path p (0, 0);
   if (n == 0) insert_tree (t, 1);
+  else if (is_with_like (t) && as_bool (call ("with-like-check-insert", t)));
   else {
     tree f= get_env_value (as_string (l));
     bool block_macro= (N(f) == 2) && is_multi_paragraph_macro (f);
@@ -116,15 +120,15 @@ edit_dynamic_rep::make_compound (tree_label l, int n= -1) {
     insert_tree (t, p);
     if (table_macro) make_table (1, 1);
     if (sel != "") insert_tree (sel, end (sel));
-
-    string mess;
+    
+    tree mess= concat ();
     if (drd->get_arity_mode (l) != ARITY_NORMAL)
-      mess= "A-right: insert argument";
+      mess= concat (kbd ("A-right"), ": insert argument");
     if (!drd->all_accessible (l)) {
       if (mess != "") mess << ", ";
-      mess << "return: activate";
+      mess << kbd ("return") << ": activate";
     }
-    if (mess == "") mess= "Move to the right when finished";
+    if (mess == concat ()) mess= "Move to the right when finished";
     set_message (mess, drd->get_name (l));
   }
 }
@@ -132,7 +136,7 @@ edit_dynamic_rep::make_compound (tree_label l, int n= -1) {
 void
 edit_dynamic_rep::activate () {
   path p= search_upwards (INACTIVE);
-  if (nil (p)) return;
+  if (is_nil (p)) return;
   tree st= subtree (et, p * 0);
 
   if (is_func (st, COMPOUND) && is_atomic (st[0])) {
@@ -189,9 +193,9 @@ edit_dynamic_rep::insert_argument (path p, bool forward) {
 void
 edit_dynamic_rep::insert_argument (bool forward) {
   path p= find_dynamic (tp);
-  if (nil (p)) return;
+  if (is_nil (p)) return;
   if (p == tp) p= find_dynamic (path_up (tp));
-  if (nil (p)) return;
+  if (is_nil (p)) return;
   insert_argument (p, forward);
 }
 
@@ -261,9 +265,9 @@ edit_dynamic_rep::remove_argument (path p, bool forward) {
 void
 edit_dynamic_rep::remove_argument (bool forward) {
   path p= find_dynamic (tp);
-  if (nil (p)) return;
+  if (is_nil (p)) return;
   if (p == tp) p= find_dynamic (path_up (tp));
-  if (nil (p)) return;
+  if (is_nil (p)) return;
 
   tree t= subtree (et, path_up (p));
   int i= last_item (p), n= N(t), d= 1;
@@ -404,7 +408,7 @@ edit_dynamic_rep::remove_with (path p, string var) {
 void
 edit_dynamic_rep::back_in_with (tree t, path p, bool forward) {
   if (is_func (subtree (et, path_up (p, 2)), INACTIVE) ||
-      (is_func (t, WITH) && in_source ()))
+      ((is_func (t, WITH) || is_func (t, LOCUS)) && in_source ()))
     back_in_general (t, p, forward);
   else if (t[N(t)-1] == "") {
     assign (path_up (p), "");
@@ -478,14 +482,15 @@ edit_dynamic_rep::make_hybrid () {
   path p= end (t, path (0));
   if (in_source ()) insert_tree (t, p);
   else insert_tree (tree (INACTIVE, t), path (0, p));
-  set_message ("return: activate symbol or macro", "hybrid");
+  set_message (concat (kbd ("return"), ": activate symbol or macro"),
+	       "hybrid");
 }
 
 bool
 edit_dynamic_rep::activate_latex () {
   path p= search_upwards (LATEX);
-  if (nil (p)) p= search_upwards (HYBRID);
-  if (nil (p)) return false;
+  if (is_nil (p)) p= search_upwards (HYBRID);
+  if (is_nil (p)) return false;
   tree st= subtree (et, p);
   if (is_atomic (st[0])) {
     if (is_func (subtree (et, path_up (p)), INACTIVE))
@@ -498,7 +503,8 @@ edit_dynamic_rep::activate_latex () {
       if (N(st) == 2) insert_tree (copy (st[1]));
       return true;
     }
-    set_message ("Error: not a command name", "activate latex command");
+    set_message ("Error: not a command name",
+		 "activate latex command");
   }
   return false;
 }
@@ -509,7 +515,7 @@ edit_dynamic_rep::activate_hybrid (bool with_args_hint) {
   if (activate_latex ()) return;
   set_message ("", "");
   path p= search_upwards (HYBRID);
-  if (nil (p)) return;
+  if (is_nil (p)) return;
   tree st= subtree (et, p);
   if (is_compound (st[0])) return;
   if (is_func (subtree (et, path_up (p)), INACTIVE))
@@ -518,7 +524,7 @@ edit_dynamic_rep::activate_hybrid (bool with_args_hint) {
   // activate macro argument
   string name= st[0]->label;
   path mp= search_upwards (MACRO);
-  if (!nil (mp)) {
+  if (!is_nil (mp)) {
     tree mt= subtree (et, mp);
     int i, n= N(mt)-1;
     for (i=0; i<n; i++)
@@ -551,7 +557,8 @@ edit_dynamic_rep::activate_hybrid (bool with_args_hint) {
     make_compound (make_tree_label (name), with_args_hint? 1: 0);
     if (N(st) == 2) insert_tree (st[1]);
   }
-  else set_message ("Error: unknown command", "activate hybrid command");
+  else set_message ("Error: unknown command",
+		    "activate hybrid command");
   env_locked= old_locked;
 }
 
@@ -562,7 +569,7 @@ edit_dynamic_rep::activate_hybrid (bool with_args_hint) {
 void
 edit_dynamic_rep::activate_symbol () {
   path p= search_upwards (SYMBOL);
-  if (nil (p)) return;
+  if (is_nil (p)) return;
   tree st= subtree (et, p);
   if (is_func (subtree (et, path_up (p)), INACTIVE))
     p= path_up (p);
@@ -580,18 +587,6 @@ edit_dynamic_rep::activate_symbol () {
   correct (path_up (p));
 }
 
-void
-edit_dynamic_rep::activate_compound () {
-  path p= search_upwards (COMPOUND);
-  if (!nil (p)) {
-    tree st= subtree (et, p);
-    tree u (make_tree_label (st[0]->label));
-    u << A (st (1, N(st)));
-    assign (p, u);
-    go_to (end (et, p));
-  }
-}
-
 /******************************************************************************
 * Temporary fixes for block structures
 ******************************************************************************/
@@ -624,7 +619,7 @@ void
 edit_dynamic_rep::temp_proof_fix () {
   /* this routine should be removed as soon as possible */
   path p = search_upwards ("proof");
-  if (nil (p) || (N(tp) < N(p)+2)) return;
+  if (is_nil (p) || (N(tp) < N(p)+2)) return;
   path q = head (tp, N(p)+2);
   tree st= subtree (et, path_up (q));
   if ((!is_document (st)) || (last_item (q) != (N(st)-1))) return;
