@@ -994,6 +994,7 @@ edit_table_rep::table_ver_decorate (path fp, int row, int rbef, int raft) {
 
 void
 edit_table_rep::make_table (int nr_rows, int nr_cols) {
+  //cout << "make_table " << nr_rows << ", " << nr_cols << "\n";
   tree T= empty_table (nr_rows, nr_cols);
   path p (0, 0, 0, 0);
   tree format_T (TFORMAT, T);
@@ -1031,7 +1032,11 @@ edit_table_rep::make_table (int nr_rows, int nr_cols) {
   }
 
   table_correct_block_content ();
-  set_message ("E-down: new row, E-right: new column", "table");
+  set_message (concat (kbd_shortcut ("(structured-insert-down)"),
+		       ": new row",
+		       kbd_shortcut ("(structured-insert #t)"),
+		       ": new column"),
+	       "table");
 }
 
 void
@@ -1047,7 +1052,11 @@ edit_table_rep::make_subtable (int nr_rows, int nr_cols) {
   assign (cp * 0, T);
   go_to (cp * path (0, p));
   table_correct_block_content ();
-  set_message ("E-down: new row, E-right: new column", "table");
+  set_message (concat (kbd_shortcut ("(structured-insert-down)"),
+		       ": new row",
+		       kbd_shortcut ("(structured-insert #t)"),
+		       ": new column"),
+	       "table");
 }
 
 void
