@@ -4,10 +4,9 @@
 * DESCRIPTION: modification of text
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "edit_text.hpp"
@@ -30,7 +29,7 @@ edit_text_rep::correct_concat (path p, int done) {
   tree t (subtree (et, p));
   if (L(t) != CONCAT) {
     cerr << "\nThe tree was <" << t << ">\n";
-    fatal_error ("concat expected", "edit_text_rep::correct_concat");
+    FAILED ("concat expected");
   }
 
   int i, n= N(t);
@@ -57,7 +56,7 @@ edit_text_rep::correct_concat (path p, int done) {
       if (subtree (et, p * 1) == tree (CONCAT)) remove (p * 1, 1);
       else join (p * 0);
       remove_node (p * 0);
-      correct_concat (p, i);
+      correct_concat (p, max (i-1, 0));
       return;
     }
     else if (is_multi_paragraph (t[i]) &&
@@ -114,8 +113,8 @@ edit_text_rep::accepts_return (path p) {
     (is_func (st, XMACRO, 2) && (last_item (p) == 1)) ||
     ((is_func (st, WITH) || is_mod_active (st) ||
       is_func (st, STYLE_WITH) || is_func (st, VAR_STYLE_WITH) ||
-      is_func (st, LOCUS) || is_func (st, CANVAS) ||
-      is_func (st, ORNAMENT)) &&
+      is_func (st, LOCUS) ||
+      is_func (st, CANVAS) || is_func (st, ORNAMENT)) &&
      (last_item (p) == (N(st)-1)) && pure_line (p)) ||
     (is_extension (st) && (last_item (p) >= 0) && pure_line (p));
 }
@@ -145,7 +144,7 @@ edit_text_rep::insert_return () {
 void
 edit_text_rep::remove_return (path p) {
   if (!is_document (subtree (et, path_up (p))))
-    fatal_error ("Parent not a document", "edit_text_rep::glue_concat");
+    FAILED ("parent is not a document");
 
   if (!is_concat (subtree (et, p)))
     insert_node (p * 0, CONCAT);
@@ -344,21 +343,7 @@ edit_text_rep::make_htab (string spc) {
 }
 
 void
-edit_text_rep::make_move (string x, string y) {
-  insert_tree (tree (MOVE, "", x, y), path (0, 0));
-}
-
-void
-edit_text_rep::make_resize (string x1, string y1, string x2, string y2) {
-  tree t (RESIZE, 5);
-  t[0]= "";
-  t[1]= x1; t[2]= y1;
-  t[3]= x2; t[4]= y2;
-  insert_tree (t, path (0, 0));
-}
-
-void
-edit_text_rep::make_postscript (
+edit_text_rep::make_image (
   string file_name, bool link, string w, string h,
   string x1, string y1, string x2, string y2)
 {
@@ -367,22 +352,22 @@ edit_text_rep::make_postscript (
   if (is_rooted (image))
     image= delta (get_name (), image);
 
-  tree t (POSTSCRIPT);
+  tree t (IMAGE);
   if (link) {
     if (is_rooted (image, "default")) image= reroot (image, "file");
     t << as_string (image, URL_STANDARD);
   }
   else {
     string s;
+    tree vim= verbatim (as_string (image));
     load_string (relative (get_name (), image), s, false);
     if (s == "") {
-      set_message ("File#'" * as_string (image) * "' not found", "make image");
+      set_message (concat ("File '", vim, "' not found"), "make image");
       return;
     }
     type= suffix (image);
     if (type == "") {
-      set_message ("File#'" * as_string (image) * "' is not an image",
-		   "make image");
+      set_message (concat ("File '", vim, "' is not an image"), "make image");
       return;
     }
     t << tuple (tree (RAW_DATA, s), type);
