@@ -4,10 +4,9 @@
 * DESCRIPTION: search and query replace
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Replace/edit_replace.hpp"
@@ -39,7 +38,7 @@ edit_replace_rep::search_upwards (string what) {
 
 bool
 edit_replace_rep::inside (tree_label l) {
-  return !nil (search_upwards (l));
+  return !is_nil (search_upwards (l));
 }
 
 path
@@ -75,7 +74,7 @@ edit_replace_rep::search_parent_upwards (tree_label l) {
 
 bool
 edit_replace_rep::inside_with (string var, string val) {
-  return !nil (search_upwards_with (var, val));
+  return !is_nil (search_upwards_with (var, val));
 }
 
 path
@@ -92,7 +91,7 @@ edit_replace_rep::search_upwards_with (string var, string val) {
 string
 edit_replace_rep::inside_which (tree t) {
   path p= search_upwards_in_set (t);
-  if ((p == rp) || nil (p)) return "";
+  if ((p == rp) || is_nil (p)) return "";
   tree st= subtree (et, p);
   if (is_func (st, COMPOUND)) return as_string (st[0]);
   else return as_string (L(st));
@@ -124,7 +123,7 @@ edit_replace_rep::search_upwards_in_set (tree t) {
 
 static bool
 is_accessible_path (drd_info drd, tree t, path p) {
-  if (nil (p)) return true;
+  if (is_nil (p)) return true;
   return
     drd->is_accessible_child (t, p->item) &&
     (p->item < N(t)) &&
@@ -263,14 +262,14 @@ edit_replace_rep::step_ascend (bool forward) {
 
   if (forward) {
     if (l == N(st)) {
-      if (atom (search_at - rp)) search_at= rp;
+      if (is_atom (search_at / rp)) search_at= rp;
       else step_ascend (forward);
     }
     else step_descend (forward);
   }
   else {
     if (l == -1) {
-      if (atom (search_at - rp)) search_at= rp;
+      if (is_atom (search_at / rp)) search_at= rp;
       else step_ascend (forward);
     }
     else step_descend (forward);
@@ -365,12 +364,12 @@ edit_replace_rep::next_match (bool forward) {
       notify_change (THE_SELECTION);
       return;
     }
-    int old= get_access_mode ();
+    int new_mode= DRD_ACCESS_HIDDEN;
     if (get_init_string (MODE) == "src" || inside ("show-preamble"))
-      set_access_mode (DRD_ACCESS_SOURCE);
-    else set_access_mode (DRD_ACCESS_HIDDEN);
+      new_mode= DRD_ACCESS_SOURCE;
+    int old_mode= set_access_mode (new_mode);
     step_horizontal (forward);
-    set_access_mode (old);
+    set_access_mode (old_mode);
   }
 }
 
@@ -403,10 +402,10 @@ edit_replace_rep::search_next (bool forward) {
 
   next_match (forward);
   if (search_at == rp) {
-    set_message ("No more matches for#" * w, r);
+    set_message (concat ("No more matches for ", verbatim (w)), r);
     beep ();
   }
-  else set_message ("Searching#" * w, r);
+  else set_message (concat ("Searching ", verbatim (w)), r);
 }
 
 void
@@ -434,7 +433,9 @@ edit_replace_rep::search_button_next () {
 
 bool
 edit_replace_rep::search_keypress (string s) {
-  if (N(s)==1) {
+  set_message ("", "");
+  if (s == "space") s= " ";
+  if (N(s) == 1) {
     if (is_atomic (search_what))
       search_next (as_string (search_what) * s, forward, false);
   }
@@ -449,23 +450,21 @@ edit_replace_rep::search_keypress (string s) {
       }
     else if ((s == "C-c") || (s == "C-g"))
       search_stop ();
-    else if ((s == "C-r") || (s == "C-s") ||
-	     (s == "C-f") || (s == "F3") ||
-	     (s == "find") || (s == "again")) {
+    else if ((s == "next") || (s == "previous")) {
       if (search_what == "") {
 	tree t= selection_raw_get ("search");
 	if (is_tuple (t, "texmacs", 3) &&
 	    (t[1] != "") &&
 	    (t[2] == search_mode) &&
 	    (t[3] == search_lan))
-	  search_next (t[1], s != "C-r", true);
+	  search_next (t[1], s != "previous", true);
       }
-      else search_next (search_what, s != "C-r", true);
+      else search_next (search_what, s != "previous", true);
     }
     else if ((s == "delete") || (s == "backspace")) {
-      if (nil (where_stack))
+      if (is_nil (where_stack))
 	search_stop ();
-      else if (atom (where_stack)) {
+      else if (is_atom (where_stack)) {
 	go_to (where_stack->item);
 	search_stop ();
       }
@@ -540,7 +539,7 @@ edit_replace_rep::replace_next () {
 
   next_match (forward);
   if (search_at == rp) {
-    string l= "Replaced#" * as_string (nr_replaced) * "#occurrences";
+    tree l= concat ("Replaced ", as_string (nr_replaced), " occurrences");
     if (nr_replaced == 0) l= "No matches found";
     if (nr_replaced == 1) l= "Replaced one occurrence";
     set_message (l, r);
@@ -552,6 +551,8 @@ edit_replace_rep::replace_next () {
 
 bool
 edit_replace_rep::replace_keypress (string s) {
+  set_message ("", "");
+  if (s == "space") s= " ";
   if ((s == "C-c") || (s == "C-g") || (s == "escape"))
     set_input_normal ();
   else if (s == "y") {
