@@ -4,15 +4,15 @@
 * DESCRIPTION: Selection handling
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Replace/edit_select.hpp"
 #include "Interface/edit_interface.hpp"
 #include "convert.hpp"
+#include "packrat.hpp"
 
 /******************************************************************************
 * Internationalization
@@ -58,29 +58,73 @@ edit_select_rep::edit_select_rep ():
   selecting (false), shift_selecting (false), mid_p (),
   selection_import ("texmacs"), selection_export ("texmacs") {}
 edit_select_rep::~edit_select_rep () {}
-void edit_select_rep::get_selection (path& start, path& end) {
-  start= copy (start_p); end= copy (end_p); }
-void edit_select_rep::set_selection (path start, path end) {
-  start_p= copy (start); end_p= copy (end); }
+
+/******************************************************************************
+* Semantic selections
+******************************************************************************/
+
+path
+edit_select_rep::semantic_root (path p) {
+  while (!is_nil (p) && is_script (subtree (et, p)))
+    p= path_up (p);
+  while (!is_nil (p) && is_format (subtree (et, path_up (p))))
+    p= path_up (p);
+  return p;
+}
+
+bool
+edit_select_rep::semantic_active (path p) {
+  p= semantic_root (p);
+  if (as_string (eval ("(get-preference \"semantic editing\")")) == "on") {
+    //cout << subtree (et, p) << ", " << p << " -> " << end (et, p) << "\n";
+    tree mode= get_env_value (MODE, end (et, p));
+    tree plan= get_env_value (PROG_LANGUAGE, end (et, p));
+    return mode == "math" || (mode == "prog" && plan == "minimal");
+  }
+  else return false;
+}
+
+bool
+edit_select_rep::semantic_select (path p, path& q1, path& q2, int mode) {
+  if (!semantic_active (p)) return false;
+  p= semantic_root (p);
+  tree mt= get_env_value (MODE, end (et, p));
+  tree lt= get_env_value (MODE_LANGUAGE (mt->label), end (et, p));
+  string lan= (is_atomic (lt)? lt->label: string ("std-math"));
+  path p1= q1 / p, p2= q2 / p;
+  path cp= (p <= tp? tp / p: path ());
+  tree st= subtree (et, p);
+  bool ret= packrat_select (lan, "Main", st, cp, p1, p2, mode);
+  if (ret) {
+    q1= p * p1;
+    q2= p * p2;
+  }
+  return ret;
+}
 
 /******************************************************************************
 * Selecting particular things
 ******************************************************************************/
 
 void
-edit_select_rep::select (path p) {
-  select (start (et, p), end (et, p));
+edit_select_rep::select (path p1, path p2) {
+  if (start_p == p1 && end_p == p2) return;
+  if (p1 != p2)
+    (void) semantic_select (common (p1, p2), p1, p2, 0);
+  if (path_less (p1, p2)) {
+    start_p= copy (p1);
+    end_p  = copy (p2);
+  }
+  else {
+    start_p= copy (p2);
+    end_p  = copy (p1);
+  }
+  notify_change (THE_SELECTION);
 }
 
 void
-edit_select_rep::select (path p1, path p2) {
-  start_p= p1;
-  end_p  = p2;
-  if (path_less_eq (end_p, start_p)) {
-    start_p= p2;
-    end_p  = p1;
-  }
-  notify_change (THE_SELECTION);
+edit_select_rep::select (path p) {
+  select (start (et, p), end (et, p));
 }
 
 void
@@ -93,114 +137,158 @@ edit_select_rep::select_line () {
   select (search_parent_upwards (DOCUMENT));
 }
 
+void edit_select_rep::get_selection (path& start, path& end) {
+  start= copy (start_p); end= copy (end_p); }
+void edit_select_rep::set_selection (path start, path end) {
+  select (start, end); }
+
 /******************************************************************************
 * For interface with cursor movement
 ******************************************************************************/
 
 void
 edit_select_rep::select_from_cursor () {
-  if (!(selecting || shift_selecting)) return;
-  if (path_less (mid_p, tp)) {
-    start_p= copy (mid_p);
-    end_p  = copy (tp);
+  if (selecting) {
+    select (mid_p, tp);
+    if (shift_selecting) selecting = false;
   }
-  else {
-    start_p= copy (tp);
-    end_p  = copy (mid_p);
-  }
-  notify_change (THE_SELECTION);
 }
 
 void
 edit_select_rep::select_from_cursor_if_active () {
-  if (selecting) select_from_cursor ();
+  if (selecting) select (mid_p, tp);
+  else selection_cancel ();
 }
 
 void
 edit_select_rep::select_from_keyboard (bool flag) {
   selecting= flag;
   shift_selecting= false;
-  if (flag) mid_p= copy (tp);
+  if (flag) {
+    start_p= copy (tp);
+    mid_p  = copy (tp);
+    end_p  = copy (tp);
+  }
   else mid_p= rp;
 }
 
 void
 edit_select_rep::select_from_shift_keyboard () {
-  if ((!shift_selecting) || (end_p == start_p) ||
-      ((tp != start_p) && (tp != end_p)))
-    {
-      selecting= false;
-      shift_selecting= true;
-      mid_p= copy (tp);
-    }
+  if (!shift_selecting || end_p == start_p || (tp != start_p && tp != end_p))
+    mid_p= copy (tp);
+  selecting= true;
+  shift_selecting= true;
 }
 
 /******************************************************************************
 * Enlarging an existing selection
 ******************************************************************************/
 
+static int
+breaking_force (char c) {
+  if (c == ' ') return 3;
+  if (is_punctuation (c)) return 2;
+  if (is_iso_alpha (c) || is_digit (c)) return 0;
+  return 1;
+}
+
+void
+edit_select_rep::select_enlarge_text () {
+  path p= common (start_p, end_p);
+  if (start_p == end_p) p= path_up (p);
+  tree st= subtree (et, p);
+  ASSERT (is_atomic (st), "non textual tree");
+  string s= st->label;
+  string mode= get_env_string (MODE);
+  int i1= last_item (start_p), j1= i1;
+  int i2= last_item (end_p), j2= i2;
+  path q= path_up (p);
+
+  if (mode == "text" || mode == "src") {
+    int i, f= 4;
+    if (i1 > 0) {
+      i= i1; tm_char_backwards (s, i);
+      f= min (f, breaking_force (s[i]));
+    }
+    if (i2 < N(s))
+      f= min (f, breaking_force (s[i2]));
+
+    while (i1 > 0) {
+      i= i1; tm_char_backwards (s, i);
+      if (breaking_force (s[i]) > f) break;
+      i1= i;
+    }
+    while (i2 < N(s)) {
+      if (breaking_force (s[i2]) > f) break;
+      tm_char_forwards (s, i2);
+    }
+
+    if (i1 < i2 && (i1 != j1 || i2 != j2)) {
+      if (is_concat (subtree (et, q)) && i1 == 0 && i2 == N(s))
+	select (q * 0, q * 1);
+      else select (p * i1, p * i2);
+      return;
+    }
+  }
+
+  if (is_concat (subtree (et, q)) || (i1 == 0 && i2 == N(s)))
+    select (q * 0, q * 1);
+  else select (p * 0, p * N(s));
+}
+
+bool
+incomplete_script_selection (tree t, path lp, path rp) {
+  if (!is_func (t, CONCAT)) return false;
+  if (N(lp) < 2 || N(rp) < 2) return false;
+  int l= lp->item, r= rp->item;
+  if (is_func (t[l], RSUB) || is_func (t[l], RSUP)) return true;
+  if (is_func (t[r], LSUB) || is_func (t[r], LSUP)) return true;
+  if (l  >0    && (is_func (t[l-1], LSUB) || is_func (t[l-1], LSUP))) return true;
+  if (r+1<N(t) && (is_func (t[r+1], RSUB) || is_func (t[r+1], RSUP))) return true;
+  return false;
+}
+
 void
 edit_select_rep::select_enlarge () {
+  path sp, sq;
   if (start_p == end_p) {
-    path p = path_up (start_p);
-    tree st= subtree (et, p);
-    if (is_atomic (st)) {
-      string s= st->label;
-      string mode= get_env_string (MODE);
-      if (mode == "text" || mode == "src") {
-	int i1= last_item (start_p), i2= i1;
-	while (i1>0) {
-	  if (s[i1-1] == ' ' || is_punctuation (s[i1-1])) break;
-	  tm_char_backwards (s, i1);
-	}
-	while (i2<N(s)) {
-	  if (s[i2] == ' ' || is_punctuation (s[i2])) break;
-	  tm_char_forwards (s, i2);
-	}
-	if (i1<i2) select (p * i1, p * i2);
-	else {
-	  if (s == "") { p= path_up (p); select (p * 0, p * 1); }
-	  else select (p * 0, p * N(s));
-	}
-      }
-      else {
-	path q= path_up (p);
-	if (is_concat (subtree (et, q)) || (s == ""))
-	  select (q * 0, q * 1);
-	else select (p * 0, p * N(s));
-      }
-    }
-    else select (p * 0, p * 1);
+    sp= path_up (start_p);
+    sq= sp;
   }
   else {
-    path p= common (start_p, end_p);
-    if (!(rp < p)) {
+    sp= common (start_p, end_p);
+    if (!(rp < sp)) {
       selection_cancel ();
       set_message ("", "");
       return;
     }
-    tree st= subtree (et, p);
-    path q = path_up (p);
-    int  i1= last_item (start_p);
-    int  i2= last_item (end_p);
-    if (is_atomic (st) && (!is_concat (subtree (et, q))) &&
-	((i1 != 0) || (i2 != N(st->label))))
-      select (p * 0, p * N(st->label));
-    else select (q * 0, q * 1);
+    sq= path_up (sp);
+  }
+  path pp= sp, p1= start_p, p2= end_p;
+  if (start_p == pp * 0 && end_p == pp * right_index (subtree (et, pp)))
+    if (!is_nil (pp)) pp= path_up (pp);
+  if (semantic_select (pp, p1, p2, 1))
+    select (p1, p2);
+  else {
+    if (is_atomic (subtree (et, sp))) select_enlarge_text ();
+    else select (sq * 0, sq * 1);
   }
 
   path p = common (start_p, end_p);
   tree st= subtree (et, p);
-  if (is_func (st, TFORMAT) || is_func (st, DOCUMENT, 1) ||
-      drd->var_without_border (L(st)))
+  if (drd->var_without_border (L(st)) ||
+      is_func (st, TFORMAT) ||
+      is_func (st, DOCUMENT, 1) ||
+      is_script (st) ||
+      incomplete_script_selection (st, start_p / p, end_p / p))
     select_enlarge ();
   else {
-    string s;
+    tree s;
     if (is_atomic (st)) s= "text";
     else if (is_func (st, COMPOUND)) s= as_string (st[0]);
-    else if (is_func (st, WITH)) s= "with#" * as_string (st[0]);
+    else if (is_func (st, WITH)) s= concat ("with ", as_string (st[0]));
     else s= as_string (L(st));
-    set_message ("selected#" * s, "enlarge selection");
+    set_message (concat ("selected ", s), "enlarge selection");
   }
   selecting= shift_selecting= false;
 }
@@ -376,7 +464,8 @@ static void
 selection_bcorrect (drd_info drd, tree t, path i1, path i2, path& o1, path& o2)
 {
   o1= i1; o2= i2;
-  if (is_compound (t) && !is_atom (i1) && !is_atom (i2) && i1->item == i2->item) {
+  if (is_compound (t) && !is_atom (i1) && !is_atom (i2) &&
+      i1->item == i2->item) {
     path O1, O2;
     selection_bcorrect (drd, t[i1->item], i1->next, i2->next, O1, O2);
     if (drd->var_without_border (L(t[i1->item])) && (O1->item != O2->item)) {
@@ -532,19 +621,17 @@ edit_select_rep::selection_raw_get (string key) {
 
 void
 edit_select_rep::selection_set_start (path p) {
-  bool flag= selection_active_any ();
-  if (rp < p) start_p= p;
-  else start_p= tp;
-  if (path_less_eq (end_p, start_p) || (!flag)) end_p= start_p;
-  notify_change (THE_SELECTION);
+  if (!selection_active_any ()) select (start_p, start_p);
+  if (is_nil (p)) selection_set_start (tp);
+  else if (path_less_eq (end_p, p)) select (p, p);
+  else if (rp < p) select (p, end_p);
 }
 
 void
 edit_select_rep::selection_set_end (path p) {
-  if (rp < p) end_p= p;
-  else end_p= tp;
-  if (path_less_eq (end_p, start_p)) start_p= end_p;
-  notify_change (THE_SELECTION);
+  if (is_nil (p)) selection_set_end (tp);
+  else if (path_less_eq (p, start_p)) select (p, p);
+  else if (rp < p) select (start_p, p);
 }
 
 void
@@ -553,12 +640,11 @@ edit_select_rep::selection_set (string key, tree t, bool persistant) {
   string mode= get_env_string (MODE);
   string lan = get_env_string (MODE_LANGUAGE (mode));
   tree sel= tuple ("texmacs", t, mode, lan);
-/*TODO: add mode="graphics" somewhere in the context of the <graphics>
-    tag. To be done when implementing the different embeddings for
-    nicely copying graphics into text, text into graphics, etc.
- */
+  /* TODO: add mode="graphics" somewhere in the context of the <graphics>
+     tag. To be done when implementing the different embeddings for
+     nicely copying graphics into text, text into graphics, etc. */
   string s;
-  if (key == "primary") {
+  if (key == "primary" || key == "mouse") {
     if (selection_export == "verbatim") t= exec_texmacs (t, tp);
     if (selection_export == "html") t= exec_html (t, tp);
     if (selection_export == "latex") t= exec_latex (t, tp);
@@ -646,8 +732,7 @@ void
 edit_select_rep::selection_cancel () {
   selecting= shift_selecting= false;
   if (end_p == start_p) return;
-  end_p= start_p;
-  notify_change (THE_SELECTION);
+  select (start_p, start_p);
 }
 
 void
@@ -746,7 +831,7 @@ edit_select_rep::raw_cut (path p1, path p2) {
     cerr << "p = " << p << "\n";
     cerr << "p1= " << p1 << "\n";
     cerr << "p2= " << p2 << "\n";
-    fatal_error ("invalid cut", "edit_select_rep::raw_cut");
+    FAILED ("invalid cut");
   }
 
   if (is_atomic (t)) {
@@ -760,7 +845,7 @@ edit_select_rep::raw_cut (path p1, path p2) {
       cerr << "p = " << p << "\n";
       cerr << "p1= " << p1 << "\n";
       cerr << "p2= " << p2 << "\n";
-      fatal_error ("invalid object cut", "edit_select_rep::raw_cut");
+      FAILED ("invalid object cut");
     }
     assign (p, "");
   }
@@ -769,27 +854,29 @@ edit_select_rep::raw_cut (path p1, path p2) {
 void
 edit_select_rep::selection_cut (string key) {
   if (inside_active_graphics ()) {
-    tree t= as_tree (eval ("(graphics-cut)"));
-    selection_set (key, t);
-    return;
+    if (key != "none") {
+      tree t= as_tree (eval ("(graphics-cut)"));
+      selection_set (key, t);
+    }
   }
-  if (!selection_active_any ()) return;
-  if (selection_active_table ()) {
-    path p1= start_p, p2= end_p;
-    tree sel= selection_get ();
-    selection_set (key, sel);
-    cut (p1, p2);
-  }
-  else {
+  else if (selection_active_any ()) {
     path p1, p2;
-    selection_get (p1, p2);
-    go_to (p2);
-    if (p2 == p1) return;
-
-    tree sel= compute_selection (et, p1, p2);
-    // cout << "Selection " << sel << "\n";
-    selection_set (key, simplify_correct (sel));
-    // cout << "Selected  " << sel << "\n";
+    if (selection_active_table ()) {
+      p1= start_p; p2= end_p;
+      if(key != "none") {
+        tree sel= selection_get ();
+        selection_set (key, sel);
+      }
+    }
+    else {
+      selection_get (p1, p2);
+      go_to (p2);
+      if (p2 == p1) return;
+      if (key != "none") {
+        tree sel= compute_selection (et, p1, p2);
+        selection_set (key, simplify_correct (sel));
+      }
+    }
     cut (p1, p2);
   }
 }
@@ -797,7 +884,7 @@ edit_select_rep::selection_cut (string key) {
 tree
 edit_select_rep::selection_get_cut () {
   tree t= selection_get ();
-  selection_cut ();
+  selection_cut ("none");
   return t;
 }
 
