@@ -43,6 +43,7 @@ class tm_buffer_rep;
 typedef tm_buffer_rep* tm_buffer;
 class server_rep;
 class modification;
+extern bool enable_fastenv;
 
 class editor_rep: public simple_widget_rep {
 public:
@@ -92,9 +93,12 @@ protected:
   virtual void   typeset (SI& x1, SI& y1, SI& x2, SI& y2) = 0;
 
   /* protected subroutines for deletion of content */
+  virtual void back_around (tree t, path p, bool forward) = 0;
   virtual void back_prime (tree t, path p, bool forward) = 0;
+  virtual void back_in_around (tree t, path p, bool forward) = 0;
   virtual void back_in_wide (tree t, path p, bool forward) = 0;
   virtual void back_in_tree (tree t, path p, bool forward) = 0;
+  virtual void pre_remove_around (path p) = 0;
   virtual void back_table (path p, bool forward) = 0;
   virtual void back_in_table (tree t, path p, bool forward) = 0;
   virtual void back_monolithic (path p) = 0;
@@ -103,10 +107,11 @@ protected:
   virtual void back_in_general (tree t, path p, bool forward) = 0;
 
   /* other protected subroutines */
+  virtual tree kbd (string s) = 0;
+  virtual tree kbd_shortcut (string s) = 0;
   virtual path tree_path (path sp, SI x, SI y, SI delta) = 0;
   virtual void apply_changes () = 0;
   virtual void animate () = 0;
-  virtual void correct_concat (path p, int done=0) = 0;
   virtual path search_format (int& row, int& col) = 0;
   virtual void table_bound (path fp, int& i1, int& j1, int& i2, int& j2) = 0;
   virtual tree table_get_subtable (path p, int i1, int j1, int i2, int j2) = 0;
@@ -146,7 +151,8 @@ public:
   virtual bool complete_try () = 0;
   virtual void complete_start (string prefix, array<string> compls) = 0;
   virtual bool complete_keypress (string key) = 0;
-  virtual bool session_complete_try (tree t) = 0;
+  virtual string session_complete_command (tree t) = 0;
+  virtual void custom_complete (tree t) = 0;
   virtual void mouse_any (string s, SI x, SI y, int mods, time_t t) = 0;
   virtual void mouse_click (SI x, SI y) = 0;
   virtual bool mouse_extra_click (SI x, SI y) = 0;
@@ -158,7 +164,7 @@ public:
   virtual cursor get_cursor () = 0;
   virtual void set_pointer (string name) = 0;
   virtual void set_pointer (string curs_name, string mask_name) = 0;
-  virtual void set_message (string l, string r= "", bool temp= false) = 0;
+  virtual void set_message (tree l, tree r= "", bool temp= false) = 0;
   virtual void recall_message () = 0;
 
   /* public routines from edit_cursor */
@@ -292,6 +298,7 @@ public:
 
   /* public routines from edit_text */
   virtual void correct (path p) = 0;
+  virtual void correct_concat (path p, int done=0) = 0;
   virtual bool insert_return () = 0;
   virtual void remove_return (path p) = 0;
   virtual void insert_tree (tree t, path p_in_t) = 0;
@@ -311,15 +318,13 @@ public:
   virtual void make_vspace_after (string s) = 0;
   virtual void make_vspace_after (string smin, string sdef, string smax) = 0;
   virtual void make_htab (string spc) = 0;
-  virtual void make_move (string x, string y) = 0;
-  virtual void make_resize (string x1, string y1, string x2, string y2) = 0;
-  virtual void make_postscript (string file_name, bool link,
+  virtual void make_image (string file_name, bool link,
 				string w, string h,
 				string x1, string y1,
 				string x2, string y2) = 0;
 
   /* public routines from edit_math */
-  virtual void make_group () = 0;
+  virtual void make_rigid () = 0;
   virtual void make_lprime (string s) = 0;
   virtual void make_rprime (string s) = 0;
   virtual void make_below () = 0;
@@ -381,7 +386,6 @@ public:
   virtual bool activate_latex () = 0;
   virtual void activate_hybrid (bool with_args_hint) = 0;
   virtual void activate_symbol () = 0;
-  virtual void activate_compound () = 0;
   virtual bool make_return_before () = 0;
   virtual bool make_return_after () = 0;
   virtual void temp_proof_fix () = 0;
@@ -395,6 +399,10 @@ public:
   virtual bool get_save_aux () = 0;
 
   /* public routines from edit_select */
+  virtual path semantic_root (path p) = 0;
+  virtual bool semantic_active (path p) = 0;
+  virtual bool semantic_select (path p, path& q1, path& q2, int mode) = 0;
+
   virtual void select (path p) = 0;
   virtual void select (path start, path end) = 0;
   virtual void select_all () = 0;
@@ -486,6 +494,7 @@ public:
   virtual tree the_buffer () = 0;
   virtual tree the_subtree (path p) = 0;
   virtual path the_path () = 0;
+  virtual path the_shifted_path () = 0;
   virtual path the_buffer_path () = 0;
   virtual void show_tree () = 0;
   virtual void show_env () = 0;
