@@ -48,6 +48,7 @@ enum slot_id {
   SLOT_SCROLLBARS_VISIBILITY,
   SLOT_SCROLL_POSITION,
   SLOT_CANVAS,
+  SLOT_CURSOR,
 
   SLOT_HEADER_VISIBILITY,
   SLOT_MAIN_MENU,
@@ -83,10 +84,12 @@ public:
   inline bool operator != (slot_id sid2) { return sid != sid2; }
   inline bool operator == (slot s) { return sid == s.sid; }
   inline bool operator != (slot s) { return sid != s.sid; }
-  inline friend ostream& operator << (ostream& out, slot s) {
+  inline friend tm_ostream& operator << (tm_ostream& out, slot s) {
     return out << s.sid; }
 };
 
+const char * slot_name (const slot s);
+
 //extern bool* slot_state_table;
 //inline bool is_state_slot (slot s) { return slots_state_table[s]; }
 
@@ -447,6 +450,12 @@ set_canvas (widget w, widget cv) {
   write (w, SLOT_CANVAS, cv);
 }
 
+inline void
+send_cursor (widget w, SI x1, SI y1) {
+  // send current cursor coordinates
+  send<SI,SI> (w, SLOT_CURSOR, x1, y1);
+}
+
 /******************************************************************************
 * Top-level window related messages (also behaves as a canvas)
 ******************************************************************************/
