@@ -5,10 +5,9 @@
 ;; DESCRIPTION : Building basic glue for the editor
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public licence and comes WITHOUT
-;; ANY WARRENTY WHATSOEVER. See the file $TEXMACS_PATH/LICENCE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -24,13 +23,12 @@
   (buffer-tree the_buffer (tree))
   (paragraph-tree the_line (tree))
   (cursor-path the_path (path))
+  (cursor-path* the_shifted_path (path))
   (selection-tree selection_get (tree))
-  (mutator-path get_mutator_path (path))
-  (mutator-time get_mutator_time (int))
 
   ;; low-level modification routines
   (path->tree the_subtree (tree path))
-  (path-correct correct (void path))
+  (path-correct-old correct (void path))
   (path-insert-with insert_with (void path string content))
   (path-remove-with remove_with (void path string))
 
@@ -44,7 +42,7 @@
   (insert insert_tree (void content))
   (insert-go-to var_insert_tree (void content path))
   (insert-raw-go-to insert_tree (void content path))
-  (insert-return insert_return (void))
+  (insert-raw-return insert_return (void))
   (remove-text remove_text (void bool))
   (remove-structure remove_structure (void bool))
   (remove-structure-upwards remove_structure_upwards (void))
@@ -61,7 +59,6 @@
   (activate-latex activate_latex (void))
   (activate-hybrid activate_hybrid (void bool))
   (activate-symbol activate_symbol (void))
-  (activate-compound activate_compound (void))
   (make-return-before make_return_before (void))
   (make-return-after make_return_after (bool))
   (temp-proof-fix temp_proof_fix (void))
@@ -94,9 +91,7 @@
     (void string string string))
   (make-vspace-after make_vspace_after (void string))
   (make-var-vspace-after make_vspace_after (void string string string))
-  (make-move make_move (void string string))
-  (make-resize make_resize (void string string string string))
-  (make-postscript make_postscript
+  (make-image make_image
     (void string bool string string string string string string))
 
   (length-decode as_length (int string))
@@ -106,7 +101,7 @@
   (length-divide divide_lengths (double string string))
 
   ;; modify mathematics
-  (make-group make_group (void))
+  (make-rigid make_rigid (void))
   (make-lprime make_lprime (void string))
   (make-rprime make_rprime (void string))
   (make-below make_below (void))
@@ -148,11 +143,18 @@
   (cell-del-format cell_del_format (void string))
   (table-test table_test (void))
 
-  ;; keyboard handling
+  ;; keyboard and mouse handling
   (key-press key_press (void string))
-  (emulate-keyboard emulate_keyboard (void string))
-  (emulate-keyboard-message emulate_keyboard (void string string))
+  (raw-emulate-keyboard emulate_keyboard (void string))
   (complete-try? complete_try (bool))
+  (get-input-mode get_input_mode (int))
+  (key-press-search search_keypress (bool string))
+  (key-press-replace replace_keypress (bool string))
+  (key-press-spell spell_keypress (bool string))
+  (key-press-complete complete_keypress (bool string))
+  (mouse-any mouse_any (void string int int int double))
+  (set-mouse-pointer set_pointer (void string string))
+  (set-predef-mouse-pointer set_pointer (void string))
   
   ;; moving the cursor
   (go-to-path go_to (void path))
@@ -208,12 +210,17 @@
   (clipboard-get-export selection_get_export (string))
 
   ;; undo and redo
+  (clear-undo-history clear_undo_history (void))
+  (commit-changes end_editing (void))
+  (start-slave start_slave (void double))
   (remove-undo-mark remove_undo_mark (void))
   (add-undo-mark add_undo_mark (void))
   (unredoable-undo unredoable_undo (void))
-  (forget-undo forget_undo (void))
-  (undo undo (void))
-  (redo redo (void))
+  (undo-possibilities undo_possibilities (int))
+  (undo undo (void int))
+  (redo-possibilities redo_possibilities (int))
+  (redo redo (void int))
+  (show-history show_history (void))
 
   ;; graphics
   (in-graphics? inside_graphics (bool))
@@ -237,28 +244,8 @@
   (spell-replace spell_replace (void string))
 
   ;; sessions
-  (make-session make_session (void string string))
-  (start-input start_input (void string string path))
-  (process-input process_input (void))
-  (session-use-math-input session_use_math_input (void bool))
-  (session-math-input? session_is_using_math_input (bool))
-  (session-go-up session_go_up (void))
-  (session-go-down session_go_down (void))
-  (session-go-page-up session_go_page_up (void))
-  (session-go-page-down session_go_page_down (void))
-  (session-remove session_remove (void bool))
-  (session-insert-text-field session_insert_text_field (void))
-  (session-insert-input-above session_insert_input_above (void))
-  (session-insert-input-below session_insert_input_below (void))
-  (session-fold-input session_fold_input (void))
-  (session-remove-input session_remove_input (void bool))
-  (session-remove-all-outputs session_remove_all_outputs (void))
-  (session-remove-previous-output session_remove_previous_output (void))
-  (session-split session_split (void))
-  (session-complete-try? session_complete_try (bool))
-  (connection-busy? busy_connection (bool))
-  (connection-interrupt interrupt_connection (void))
-  (connection-stop stop_connection (void))
+  (session-complete-command session_complete_command (string tree))
+  (custom-complete custom_complete (void tree))
 
   ;; miscellaneous routines
   (view-set-property set_property (void scheme_tree scheme_tree))
@@ -271,6 +258,7 @@
   (generate-all-aux generate_aux (void))
   (generate-aux generate_aux (void string))
   (notify-page-change notify_page_change (void))
+  (notify-change notify_change (void int))
   (print-to-file print_to_file (void url))
   (print-pages-to-file print_to_file (void url string string))
   (print print_buffer (void))
@@ -292,7 +280,4 @@
   (show-selection show_selection (void))
   (show-meminfo show_meminfo (void))
   (edit-special edit_special (void))
-  (edit-test edit_test (void))
-
-  (set-mouse-pointer set_pointer (void string string))
-  (set-predef-mouse-pointer set_pointer (void string)))
+  (edit-test edit_test (void)))
