@@ -16,11 +16,15 @@
 #include "connect.hpp"
 #include "convert.hpp"
 #include "file.hpp"
+#include "image_files.hpp"
 #include "sys_utils.hpp"
 #include "tmfs.hpp"
 #include "client_server.hpp"
 #include "analyze.hpp"
 #include "tree_traverse.hpp"
+#include "tree_analyze.hpp"
+#include "tree_correct.hpp"
+#include "tree_modify.hpp"
 #include "tm_frame.hpp"
 #include "Concat/concater.hpp"
 #include "converter.hpp"
@@ -29,10 +33,12 @@
 #include "Freetype/free_type.hpp"
 #include "Freetype/tt_file.hpp"
 #include "Bibtex/bibtex.hpp"
+#include "Bibtex/bibtex_functions.hpp"
 #include "link.hpp"
 #include "dictionary.hpp"
 #include "patch.hpp"
 #include "grammar.hpp"
+#include "packrat.hpp"
 #include <string.h>
 #include <libguile.h>
 
@@ -49,6 +55,10 @@ extern void initialize_glue_basic ();
 extern void initialize_glue_editor ();
 extern void initialize_glue_server ();
 
+/******************************************************************************
+* Miscellaneous routines for use by glue only
+******************************************************************************/
+
 string
 scheme_dialect () {
 #ifdef GUILE_A
@@ -76,40 +86,9 @@ texmacs_version (string which) {
   return TEXMACS_VERSION;
 }
 
-bool
-gui_is_x () {
-#ifdef QTTEXMACS
-  return false;
-#else
-  return true;
-#endif
-}
-
-bool
-gui_is_qt () {
-#ifdef QTTEXMACS
-  return true;
-#else
-  return false;
-#endif
-}
-
-bool
-os_win32 () {
-#ifdef OS_WIN32
-  return true;
-#else
-  return false;
-#endif
-}
-
-bool
-os_mingw () {
-#ifdef __MINGW32__
-  return true;
-#else
-  return false;
-#endif
+void
+set_fast_environments (bool b) {
+  enable_fastenv= b;
 }
 
 void
@@ -118,6 +97,18 @@ win32_display (string s) {
   cout.flush ();
 }
 
+void
+tm_output (string s) {
+  cout << s;
+  cout.flush ();
+}
+
+void
+tm_errput (string s) {
+  cerr << s;
+  cerr.flush ();
+}
+
 #ifdef GUILE_C
 #define SET_SMOB(smob,data,type)   \
   SCM_NEWSMOB (smob, SCM_UNPACK (type), data);
@@ -128,6 +119,20 @@ win32_display (string s) {
   SCM_SETCDR (smob, (SCM) (data));
 #endif
 
+/******************************************************************************
+* Redirections
+******************************************************************************/
+
+void
+cout_buffer () {
+  cout.buffer ();
+}
+
+string
+cout_unbuffer () {
+  return cout.unbuffer ();
+}
+
 /******************************************************************************
 * Direct access to scheme objects
 ******************************************************************************/
@@ -189,13 +194,13 @@ scm_to_int (SCM i) {
 #define SCM_ASSERT_DOUBLE(i,arg,rout) \
   SCM_ASSERT (SCM_REALP (i), i, arg, rout);
 
-static SCM
+SCM
 double_to_scm (double i) {
   return scm_double2scm (i);
 }
 
 #ifndef GUILE_C
-static double
+double
 scm_to_double (SCM i) {
   return scm_scm2double (i);
 }
@@ -375,8 +380,8 @@ tree_active (tree t) {
 
 tree
 tree_child_insert (tree t, int pos, tree x) {
-  cout << "t= " << t << "\n";
-  cout << "x= " << x << "\n";
+  //cout << "t= " << t << "\n";
+  //cout << "x= " << x << "\n";
   int i, n= N(t);
   tree r (t, n+1);
   for (i=0; i<pos; i++) r[i]= t[i];
