@@ -44,6 +44,10 @@ typedef long long int DI;
 #endif
 typedef void* pointer;
 
+/******************************************************************************
+* debugging
+******************************************************************************/
+
 #if (defined OS_WIN32 || defined __SUNPRO_CC)
 #define STACK_NEW_ARRAY(name,T,size) T* name= tm_new_array<T> (size)
 #define STACK_DELETE_ARRAY(name) tm_delete_array (name)
@@ -54,10 +58,14 @@ typedef void* pointer;
 
 enum { DEBUG_FLAG_AUTO, DEBUG_FLAG_VERBOSE, DEBUG_FLAG_EVENTS,
        DEBUG_FLAG_STD, DEBUG_FLAG_IO, DEBUG_FLAG_BENCH,
-       DEBUG_FLAG_HISTORY, DEBUG_FLAG_QT };
+       DEBUG_FLAG_HISTORY, DEBUG_FLAG_QT, DEBUG_FLAG_KEYBOARD,
+       DEBUG_FLAG_PACKRAT };
 bool debug (int which, bool write_flag= false);
 int  debug_off ();
 void debug_on (int status);
+class string;
+void debug_set (string s, bool flag);
+bool debug_get (string s);
 #define DEBUG_AUTO (debug (DEBUG_FLAG_AUTO))
 #define DEBUG_VERBOSE (debug (DEBUG_FLAG_VERBOSE))
 #define DEBUG_EVENTS (debug (DEBUG_FLAG_EVENTS))
@@ -66,6 +74,8 @@ void debug_on (int status);
 #define DEBUG_BENCH (debug (DEBUG_FLAG_BENCH))
 #define DEBUG_HISTORY (debug (DEBUG_FLAG_HISTORY))
 #define DEBUG_QT (debug (DEBUG_FLAG_QT))
+#define DEBUG_KEYBOARD (debug (DEBUG_FLAG_KEYBOARD))
+#define DEBUG_PACKRAT (debug (DEBUG_FLAG_PACKRAT))
 
 #ifdef DEBUG_ASSERT
 #include <assert.h>
@@ -75,6 +85,10 @@ void debug_on (int status);
 #endif
 #define FAILED(msg) ASSERT(false,msg)
 
+/******************************************************************************
+* miscellaneous routines
+******************************************************************************/
+
 inline SI min (SI i, SI j) { if (i<j) return i; else return j; }
 inline SI max (SI i, SI j) { if (i>j) return i; else return j; }
 inline double min (double i, double j) { if (i<j) return i; else return j; }
@@ -86,7 +100,29 @@ inline int copy (int x) { return x; }
 inline SI as_int (double x) { return (SI) floor (x + 0.5); }
 
 enum display_control { INDENT, UNINDENT, HRULE, LF };
-ostream& operator << (ostream& out, display_control ctrl);
+tm_ostream& operator << (tm_ostream& out, display_control ctrl);
+
+bool gui_is_x ();
+bool gui_is_qt ();
+bool os_win32 ();
+bool os_mingw ();
+bool os_macos ();
+bool use_macos_fonts ();
+const char* default_look_and_feel ();
+
+template<typename T>
+struct type_helper {
+  static int id;
+  static T   init;
+};
+
+int new_type_identifier ();
+template<typename T> int type_helper<T>::id  = new_type_identifier ();
+template<typename T> T   type_helper<T>::init= T ();
+
+/******************************************************************************
+* concrete and abstract base structures
+******************************************************************************/
 
 extern int concrete_count;
 struct concrete_struct {
@@ -102,16 +138,6 @@ struct abstract_struct {
   virtual inline ~abstract_struct () { TM_DEBUG(abstract_count--); }
 };
 
-template<typename T>
-struct type_helper {
-  static int id;
-  static T   init;
-};
-
-int new_type_identifier ();
-template<typename T> int type_helper<T>::id  = new_type_identifier ();
-template<typename T> T   type_helper<T>::init= T ();
-
 /******************************************************************************
 * indirect structures
 ******************************************************************************/
