@@ -17,6 +17,7 @@
 
 observer nil_observer;
 extern tree the_et;
+extern bool packrat_invalid_colors;
 
 /******************************************************************************
 * Debugging facilities
@@ -62,8 +63,8 @@ stretched_print (tree t, bool ips, int indent) {
   }
 }
 
-ostream&
-operator << (ostream& out, observer o) {
+tm_ostream&
+operator << (tm_ostream& out, observer o) {
   out << "<observer";
   if (is_nil (o)) out << " null";
   else o->print (out);
@@ -339,6 +340,7 @@ raw_apply (tree& t, modification mod) {
     raw_remove_node (subtree (t, root (mod)), index (mod));
     break;
   }
+  packrat_invalid_colors= true;
 }
 
 /******************************************************************************
@@ -368,7 +370,8 @@ void
 apply (tree& ref, modification mod) {
   ASSERT (is_applicable (ref, mod), "invalid modification");
   path ip= obtain_ip (ref);
-  path p = reverse (ip) * root (mod);
+  path rp= reverse (ip);
+  path p = rp * root (mod);
   if (versioning_busy) raw_apply (ref, mod);
   else if (is_busy) {
     if (ip_attached (ip) && !busy_path (p)) {
@@ -391,6 +394,8 @@ apply (tree& ref, modification mod) {
       }
       busy_paths= list<path> ();
       is_busy= false;
+      if (has_subtree (the_et, rp))
+	ref= subtree (the_et, rp);
     }
   }
 }
@@ -435,6 +440,13 @@ remove_node (tree& ref, int pos) {
   apply (ref, mod_remove_node (path (), pos));
 }
 
+void
+touch (tree& ref) {
+  //cout << "Touch " << ref << "\n";
+  if (!is_nil (ref->obs))
+    ref->obs->touched (ref, path ());
+}
+
 /******************************************************************************
 * Wrappers for trees given by a path
 ******************************************************************************/
@@ -482,6 +494,11 @@ remove_node (path p) {
   remove_node (subtree (the_et, path_up (p)), last_item (p));
 }
 
+void
+touch (path p) {
+  touch (subtree (the_et, p));
+}
+
 /******************************************************************************
 * Default virtual routines
 ******************************************************************************/
@@ -522,6 +539,11 @@ observer_rep::done (tree& ref, modification mod) {
   (void) ref; (void) mod;
 }
 
+void
+observer_rep::touched (tree& ref, path p) {
+  (void) ref; (void) p;
+}
+
 void
 observer_rep::announce_assign (tree& ref, path p, tree t) {
   (void) ref; (void) p; (void) t;
@@ -657,3 +679,14 @@ observer_rep::get_tree (tree& t) {
   (void) t;
   return false;
 }
+
+bool
+observer_rep::set_highlight (int lan, int col, int start, int end) {
+  (void) col; (void) start; (void) end;
+  return false;
+}
+
+bool
+observer_rep::get_highlight (int lan, array<int>& cols) {
+  (void) lan; (void) cols; return false;
+}
