@@ -54,7 +54,7 @@ string::string (char c) {
 }
 
 string::string (const char* a) {
-  register int i, n=strlen(a);
+  int i, n=strlen(a);
   rep= tm_new<string_rep> (n);
   for (i=0; i<n; i++)
     rep->a[i]=a[i];
@@ -172,8 +172,8 @@ operator <= (string s1, string s2) {
   return true;
 }
 
-ostream&
-operator << (ostream& out, string a) {
+tm_ostream&
+operator << (tm_ostream& out, string a) {
   int i, n=N(a);
   if (n==0) return out;
   for (i=0; i<n; i++) out << a[i];
