@@ -78,6 +78,34 @@ tree::tree (tree_label l,
   (static_cast<compound_rep*> (rep))->a[5]=t6;
 }
 
+tree::tree (tree_label l,
+	    tree t1, tree t2, tree t3, tree t4, tree t5, tree t6, tree t7):
+  rep (tm_new<compound_rep> (l, array<tree> (7)))
+{
+  (static_cast<compound_rep*> (rep))->a[0]=t1;
+  (static_cast<compound_rep*> (rep))->a[1]=t2;
+  (static_cast<compound_rep*> (rep))->a[2]=t3;
+  (static_cast<compound_rep*> (rep))->a[3]=t4;
+  (static_cast<compound_rep*> (rep))->a[4]=t5;
+  (static_cast<compound_rep*> (rep))->a[5]=t6;
+  (static_cast<compound_rep*> (rep))->a[6]=t7;
+}
+
+tree::tree (tree_label l,
+	    tree t1, tree t2, tree t3, tree t4,
+	    tree t5, tree t6, tree t7, tree t8):
+  rep (tm_new<compound_rep> (l, array<tree> (8)))
+{
+  (static_cast<compound_rep*> (rep))->a[0]=t1;
+  (static_cast<compound_rep*> (rep))->a[1]=t2;
+  (static_cast<compound_rep*> (rep))->a[2]=t3;
+  (static_cast<compound_rep*> (rep))->a[3]=t4;
+  (static_cast<compound_rep*> (rep))->a[4]=t5;
+  (static_cast<compound_rep*> (rep))->a[5]=t6;
+  (static_cast<compound_rep*> (rep))->a[6]=t7;
+  (static_cast<compound_rep*> (rep))->a[7]=t8;
+}
+
 tree
 tree::operator () (int begin, int end) {
   int i;
@@ -148,8 +176,8 @@ operator << (tree& t, array<tree> a) {
   return t;
 }
 
-ostream&
-operator << (ostream& out, tree t) {
+tm_ostream&
+operator << (tm_ostream& out, tree t) {
   if (is_atomic (t)) return out << t->label;
   else if (is_compound (t)) {
     int i, n= N(t);
@@ -162,6 +190,7 @@ operator << (ostream& out, tree t) {
     return out;
   }
   else out << as_blackbox (t);
+  return out;
 }
 
 void
@@ -192,16 +221,19 @@ hash (tree t) {
 }
 
 string
-var_as_string (tree t) {
+tree_as_string (tree t) {
   if (is_atomic (t)) return t->label;
   else if (is_concat (t) || is_document (t)) {
     int i, n= N(t);
     string cumul;
     for (i=0; i<n; i++)
-      cumul << var_as_string (t[i]);
+      cumul << tree_as_string (t[i]);
     return cumul;
   }
-  else if (is_compound (t, "nbsp", 0)) return " ";
+  else if (is_func (t, WITH))
+    return tree_as_string (t[N(t)-1]);
+  else if (is_compound (t, "nbsp", 0))
+    return " ";
   return "";
 }
 
@@ -287,6 +319,11 @@ is_multi_paragraph (tree t) {
   }
 }
 
+bool
+is_around (tree t) {
+  return is_func (t, AROUND, 3) || is_func (t, VAR_AROUND, 3);
+}
+
 bool
 is_script (tree t) {
   return
