@@ -5,10 +5,9 @@
 *              generate them if they can't be found.
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "load_tex.hpp"
@@ -24,10 +23,10 @@
 #endif
 
 static int
-mag (int dpi, int size, int dsize) {
+mag (double dpi, double size, double dsize) {
   if ((size>=100) && (dsize<100)) dsize *= 100;
   if ((dsize>=100) && (size<100))  size *= 100;
-  return (size*((unsigned long int) dpi))/dsize;
+  return (int) (((size * dpi) / dsize) + 0.5);
 }
 
 /******************************************************************************
@@ -237,8 +236,8 @@ try_pk (string family, int size, int dpi, int dsize,
       return false;
     }
   }
-  pk = font_glyphs (new pk_font_glyphs_rep (name_pk,
-					    new pk_loader(u, tfm, dpi)));
+  pk = font_glyphs (tm_new<pk_font_glyphs_rep> (name_pk,
+					    tm_new<pk_loader> (u, tfm, dpi)));
   return true;
 }
 
@@ -327,7 +326,6 @@ load_tex (string family, int size, int dpi, int dsize,
 #endif
   string name= family * as_string (size) * "@" * as_string (dpi);
   cerr << "\n\nI could not open " << name << "\n";
-  fatal_error ("Tex seems not to be installed properly",
-	       "load_tex", "load_tex.cpp");
+  FAILED ("Tex seems not to be installed properly");
   bench_cumul ("load tex font");
 }
