@@ -15,6 +15,8 @@
 #include "qt_gui.hpp"
 #include "Scheme/object.hpp"
 #include <QObject>
+#include <QAction>
+#include <QTranslator>
 
 class QTMGuiHelper : public QObject {
   Q_OBJECT
@@ -28,21 +30,40 @@ protected:
   
 public slots:
   void doUpdate ();
-  void doSocketNotification (int socket);  
-  void doCommands ();
+  void doRefresh ();
+  void doReadSocketNotification (int socket);  
+  void doWriteSocketNotification (int socket);  
+  
+signals:
+  void refresh ();  
 };
 
 
-class QTMCommandHelper : public QObject {
+// this custom action frees its menu if it does not already have an owner.
+class QTMAction : public QAction {
+  
   Q_OBJECT
-  object cmd;
-  QTimer timer;
   
 public:
-  QTMCommandHelper (object _cmd, int _delay);
+  string str;
   
-public slots:
-  void doCommand ();
+  QTMAction(QObject *parent = NULL);
+  ~QTMAction();
+  
+  public slots:
+  void doRefresh();
+  
+};
+
+
+class QTMTranslator : public QTranslator {
+  
+  Q_OBJECT
+  
+public:
+  QTMTranslator(QObject * parent = NULL ) : QTranslator(parent) {};
+  virtual QString translate ( const char * context, const char * sourceText, 
+                             const char * disambiguation = 0 ) const ;  
 };
 
 #endif // QTMGUIHELPER_HPP
