@@ -18,7 +18,7 @@
 #include <QAction>
 #include <QMenu>
 
-#include "gui.hpp"
+#include "qt_gui.hpp"
 
 class QTMCommand: public QObject {
   Q_OBJECT
@@ -29,9 +29,20 @@ public:
     cmd (_cmd) {  }
 
 public slots:
-  inline void apply() {
-    if (!is_nil(cmd)) { cmd->apply();  needs_update(); }
-  }
+  void apply();
+};
+
+
+class QTMKeyCommand: public QObject {
+  Q_OBJECT
+  string ks;
+  
+public:
+  inline QTMKeyCommand (string _ks):
+  ks (_ks) {  }
+  
+public slots:
+  void apply();
 };
 
 class QTMLazyMenu: public QMenu {
