@@ -20,14 +20,13 @@
 #include <QtGui>
 #include <QFileDialog>
 #include <QInputDialog>
+#include "QTMFileDialog.hpp"
 
-extern char  *slot_name(slot s); // in qt_widget.cpp
 
 #define TYPE_CHECK(b) ASSERT (b, "type mismatch")
 #define NOT_IMPLEMENTED \
   { if (DEBUG_QT) cout << "STILL NOT IMPLEMENTED\n";  }
 
-#pragma mark qt_chooser_widget_rep
 
 class qt_chooser_widget_rep: public qt_widget_rep {
 protected:      
@@ -217,8 +216,18 @@ qt_chooser_widget_rep::perform_dialog () {
   // int result;
   // FIXME: the chooser dialog is widely incomplete
 
-  QFileDialog dialog (NULL, to_qstring (win_title), to_qstring(directory * "/" * file));
+  QTMFileDialog *dialog;
+  QTMImageDialog *imgdialog= 0; // to avoid a dynamic_cast
+  
+  if (type  == "image")
+    dialog= imgdialog= new QTMImageDialog (NULL, to_qstring_utf8 (win_title), to_qstring_utf8(directory * "/" * file));
+  else
+    dialog= new QTMFileDialog (NULL, to_qstring_utf8 (win_title), to_qstring_utf8(directory * "/" * file));
 
+#if (defined(Q_WS_MAC) && (QT_VERSION >= 0x040500))
+  dialog->setOptions(QFileDialog::DontUseNativeDialog);
+#endif
+  
   QPoint pos = to_qpoint(position);
   //cout << "Size :" << size.x1 << "," << size.x2 << LF;
   if (DEBUG_QT) {
@@ -226,46 +235,79 @@ qt_chooser_widget_rep::perform_dialog () {
     cout << "Dir: " << directory * "/" * file << LF;
   }
   
-  dialog.updateGeometry();
-  QSize sz = dialog.sizeHint();
+  dialog->updateGeometry();
+  QSize sz = dialog->sizeHint();
   QRect r; r.setSize(sz);
   r.moveCenter(pos);
-  dialog.setGeometry(r);
+  dialog->setGeometry(r);
     
-  //dialog.setFileMode (QFileDialog::AnyFile);
-  //dialog.setNameFilter ("TeXmacs file (*.tm)");
-  dialog.setViewMode (QFileDialog::Detail);
+  dialog->setViewMode (QFileDialog::Detail);
   if (type == "directory") {
-    dialog.setFileMode(QFileDialog::Directory);
+    dialog->setFileMode(QFileDialog::Directory);
   } else if (type == "image") {
-    dialog.setFileMode(QFileDialog::ExistingFile);
+    dialog->setFileMode(QFileDialog::ExistingFile);
   } else {
-    dialog.setFileMode(QFileDialog::AnyFile);
+    dialog->setFileMode(QFileDialog::AnyFile);
   }
 
-  dialog.setLabelText(QFileDialog::Accept, "Ok");
+#if (QT_VERSION >= 0x040400)
+  if (type == "directory") {  
+  } else if (type == "texmacs") {
+  dialog->setNameFilter ("TeXmacs file (*.tm *.ts *.tp)");
+  dialog->setDefaultSuffix ("tm");
+  } else if (type == "image") {
+  dialog->setNameFilter ("Image file (*.gif *.jpg *.jpeg *.pdf *.png *.pnm *.ps *.eps *.ppm *.svg *.tif *.fig *.xpm)");
+  } else if (type == "bibtex") {
+  dialog->setNameFilter ("BibTeX file (*.bib)");
+  dialog->setDefaultSuffix ("bib");
+  } else if (type == "html") {
+  dialog->setNameFilter ("Html file (*.htm *.html *.xhtml)");
+  dialog->setDefaultSuffix ("html");
+  } else if (type == "latex") {
+  dialog->setNameFilter ("LaTeX file (*.tex *.ltx *.sty *.cls)");
+  dialog->setDefaultSuffix ("tex");
+  } else if (type == "stm") {
+  dialog->setNameFilter ("Scheme file (*.stm *.scm)");
+  dialog->setDefaultSuffix ("stm");
+  } else if (type == "verbatim") {
+  dialog->setNameFilter ("Verbatim file (*.txt)");
+  dialog->setDefaultSuffix ("txt");
+  } else if (type == "tmml") {
+  dialog->setNameFilter ("XML file (*.tmml)");
+  dialog->setDefaultSuffix ("tmml");  
+  } else if (type == "pdf") {
+  dialog->setNameFilter ("Pdf file (*.pdf)");
+  dialog->setDefaultSuffix ("pdf");
+  } else if (type == "postscript") {
+  dialog->setNameFilter ("PostScript file (*.ps *.eps)");
+  dialog->setDefaultSuffix ("ps");  
+  }
+#endif
+  
+  dialog->setLabelText(QFileDialog::Accept, "Ok");
 
   QStringList fileNames;
-  if (dialog.exec ()) {
-    fileNames = dialog.selectedFiles();
+  if (dialog->exec ()) {
+    fileNames = dialog->selectedFiles();
     if (fileNames.count() > 0) {
       file = from_qstring (fileNames[0]);
       url u = url_system (scm_unquote (file));
       if (type == "image")
         file = "(list (url-system " *
           scm_quote (as_string (u)) *
-          ") \"100\" \"100\" \"0\" \"0\" \"10\" \"10\")";
-      //FIXME: fake image dimensions
+          ") " * imgdialog->getParamsAsString () * ")";
       else
         file = "(url-system " * scm_quote (as_string (u)) * ")";
     }
   } else {
     file = "#f";
   }
-  cmd ();       
+
+  delete dialog;
+
+  cmd ();
 }
 
-#pragma mark qt_input_widget_rep
 
 class qt_field_widget;
 
@@ -476,19 +518,24 @@ qt_input_widget_rep::perform_dialog() {
   for(int i=0; i<N(fields); i++) {
     QHBoxLayout *hl = new QHBoxLayout();
 
-    QLabel *lab = new QLabel (to_qstring (fields[i]->prompt),&d);
+    QLabel *lab = new QLabel (to_qstring_utf8 (tm_var_encode( (fields[i]->prompt))),&d);
     cbs[i] = new QComboBox(&d);
     cbs[i] -> setSizeAdjustPolicy (QComboBox::AdjustToMinimumContentsLength);
-    cbs[i] -> setEditText (to_qstring (fields[i]->input));
+    cbs[i] -> setEditText (to_qstring_utf8 (fields[i]->input));
     int minlen = 0;
     for(int j=0; j < N(fields[i]->proposals); j++) {
-      QString str = to_qstring (fields[i]->proposals[j]);
+      QString str = to_qstring_utf8 (fields[i]->proposals[j]);
       cbs[i] -> addItem (str);
       int c = str.count();
       if (c > minlen) minlen = c;
     }
     cbs[i] -> setMinimumContentsLength (minlen>50 ? 50 : (minlen < 2 ? 10 : minlen));
     cbs[i] -> setEditable (true);
+    // apparently the following flag prevents Qt from substituting an history item
+    // for an input when they differ only from the point of view of case (upper/lower)
+    // eg. if the history contains aAAAAa and you type AAAAAA then the combo box
+    // will retain the string aAAAAa    
+    cbs[i]->setDuplicatesEnabled(true); 
     lab -> setBuddy (cbs[i]);
     hl -> addWidget (lab);
     hl -> addWidget (cbs[i]);
@@ -512,7 +559,7 @@ qt_input_widget_rep::perform_dialog() {
     vl -> addWidget (buttonBox);
   }
 //  d.setLayout (vl);
-  d.setWindowTitle(to_qstring(win_title));
+  d.setWindowTitle(to_qstring_utf8(win_title));
   QPoint pos = to_qpoint(position);
   //cout << "Size :" << size.x1 << "," << size.x2 << LF;
   //cout << "Position :" << pos.x() << "," << pos.y() << LF;
@@ -559,7 +606,7 @@ qt_tm_widget_rep::do_interactive_prompt () {
   QString label= to_qstring_utf8 (((qt_text_widget_rep*) int_prompt.rep)->str);
   qt_input_text_widget_rep* it = (qt_input_text_widget_rep*) (int_input.rep);
   for (int j=0; j < N(it->def); j++)
-    items << to_qstring(it->def[j]);
+    items << to_qstring_utf8(it->def[j]);
   bool ok;
   QString item =
     QInputDialog::getItem (NULL, "Interactive Prompt", label,
@@ -574,13 +621,13 @@ qt_tm_widget_rep::do_interactive_prompt () {
 void
 qt_tm_widget_rep::do_interactive_prompt () {
   QStringList items;
-  QString label= to_qstring_utf8 (((qt_text_widget_rep*) int_prompt.rep)->str);
+  QString label= to_qstring_utf8 (tm_var_encode (((qt_text_widget_rep*) int_prompt.rep)->str));
   qt_input_text_widget_rep* it = (qt_input_text_widget_rep*) (int_input.rep);
   if ( N(it->def) == 0) {
    items << "";
   } else {
     for (int j=0; j < N(it->def); j++) {
-      items << to_qstring(it->def[j]);
+      items << to_qstring_utf8(it->def[j]);
     }
   }
   QDialog d (0, Qt::Sheet);
@@ -600,11 +647,16 @@ qt_tm_widget_rep::do_interactive_prompt () {
   }
   cb -> setMinimumContentsLength (minlen>50 ? 50 : (minlen < 2 ? 10 : minlen));
   cb -> setEditable (true);
+  // apparently the following flag prevents Qt from substituting an history item
+  // for an input when they differ only from the point of view of case (upper/lower)
+  // eg. if the history contains aAAAAa and you type AAAAAA then the combo box
+  // will retain the string aAAAAa
+  cb->setDuplicatesEnabled(true); 
   lab -> setBuddy (cb);
   hl -> addWidget (lab);
   hl -> addWidget (cb);
   vl -> addLayout (hl);
-    
+  
   if (ends (it->type, "file") || it->type == "directory") {
     // autocompletion
     QCompleter *completer = new QCompleter(&d);
@@ -612,7 +664,6 @@ qt_tm_widget_rep::do_interactive_prompt () {
     completer->setModel(dirModel);
     cb->setCompleter(completer);
   }
-
   
   {
     QDialogButtonBox* buttonBox =
@@ -623,8 +674,17 @@ qt_tm_widget_rep::do_interactive_prompt () {
     vl -> addWidget (buttonBox);
   }
   //  d.setLayout (vl);
+  
+  QRect wframe = view->window()->frameGeometry();
+  QPoint pos = QPoint(wframe.x()+wframe.width()/2,wframe.y()+wframe.height()/2);
+  
   d.setWindowTitle("Interactive Prompt");
   d.updateGeometry();
+  QSize sz = d.sizeHint();
+  QRect r; r.setSize(sz);
+  r.moveCenter(pos);
+  d.setGeometry(r);
+  
   
   int result = d.exec ();
   if (result == QDialog::Accepted) {
