@@ -31,8 +31,9 @@
 #include <QStyleOptionMenuItem>
 #include <QKeySequence>
 
-extern char  *slot_name(slot s); // from qt_widget.cpp
 
+#include "QTMGuiHelper.hpp"
+#include "qt_gui.hpp"
 
 // REMARK on memory management.
 // the hierarchy of a QMenu has parents correctly set to the proper supermenu
@@ -54,16 +55,44 @@ extern char  *slot_name(slot s); // from qt_widget.cpp
 // and be attached to some QTMAction. This guarantees correct memory management.
 
 
-// this custom action frees its menu if it does not already have an owner.
-class QTMAction : public QAction {
-public:
-  QTMAction(QObject *parent = NULL) : QAction(parent) {  }
- ~QTMAction() { 
-    if (menu() && !(menu()->parent())) delete menu(); 
- }
-};
+
+QTMAction::QTMAction(QObject *parent) : QAction(parent) { 
+  QObject::connect(the_gui->gui_helper, SIGNAL(refresh()), this, SLOT(doRefresh()));
+}
+
+QTMAction::~QTMAction() { 
+  QObject::disconnect(the_gui->gui_helper, 0, this, 0);
+  if (menu() && !(menu()->parent())) delete menu(); 
+}
 
 
+void 
+QTMAction::doRefresh() {
+  if (N(str)) {
+    string t= tm_var_encode (str);
+    if (t == "Help") t= "Help ";
+    setText(to_qstring_utf8 (t));
+  }
+}
+
+
+void 
+QTMCommand::apply()  {
+  if (!is_nil(cmd)) { the_gui->process_command(cmd); }
+}
+
+
+void 
+QTMKeyCommand::apply()  {
+  if (N(ks)) { 
+    QTMWidget *w = qobject_cast<QTMWidget*>(qApp->focusWidget());
+    if (w && w->tm_widget()) {
+      if (DEBUG_QT)
+        cout << "shortcut: " << ks << LF;
+      the_gui -> process_keypress (w->tm_widget(), ks, texmacs_time());
+    }
+  }
+}
 
 class qt_menu_rep: public qt_widget_rep {
 public:
@@ -102,7 +131,7 @@ qt_menu_rep::make_popup_widget () {
 
 widget
 qt_menu_rep::popup_window_widget (string s) {
-  item->menu()->setWindowTitle (to_qstring (s));
+  item->menu()->setWindowTitle (to_qstring_utf8 (s));
   return this;
 }
 
@@ -285,11 +314,10 @@ menu_separator (bool vertical) {
 }
 
 widget
-menu_group (string name, string lan) {
+menu_group (string name) {
   // a menu group; the name should be greyed and centered
-  (void) lan;
   QAction* a= new QTMAction (NULL);
-  a->setText(to_qstring (name));
+  a->setText(to_qstring_utf8(tm_var_encode ((name))));
   a->setEnabled (false);
   return tm_new<qt_menu_rep> (a);
 }
@@ -316,8 +344,11 @@ pullright_button (widget w, promise<widget> pw) {
 
 QAction*
 qt_text_widget_rep::as_qaction () {
-  QAction* a= new QTMAction (NULL);
-  a->setText(to_qstring_utf8 (str));
+  QTMAction* a= new QTMAction (NULL);
+  string t= tm_var_encode (str);
+  if (t == "Help") t= "Help ";
+  a->setText(to_qstring_utf8 (t));
+  a->str = str;
   return a;
 }
 
@@ -333,18 +364,46 @@ qt_image_widget_rep::as_qaction () {
 QAction*
 qt_balloon_widget_rep::as_qaction() {
   QAction* a= concrete(text)->as_qaction();
-  a->setToolTip (to_qstring (((qt_text_widget_rep*) hint.rep) -> str));
+  a->setToolTip (to_qstring_utf8 (((qt_text_widget_rep*) hint.rep) -> str));
   return a;
 }
 
 string
-conv (const string ks) {
+conv_sub (string ks) {
   string r(ks);
-  r = replace (r, "C-", "Ctrl+");
-  r = replace (r, "M-", "Meta+");
-  r = replace (r, "A-", "Alt+");
+#ifdef Q_WS_MAC
   r = replace (r, "S-", "Shift+");
+  r = replace (r, "C-", "Meta+");
+  r = replace (r, "A-", "Alt+");
+  r = replace (r, "M-", "Ctrl+");
+  //r = replace (r, "K-", "");
   r = replace (r, " ", ",");
+#else
+  r = replace (r, "S-", "Shift+");
+  r = replace (r, "C-", "Ctrl+");
+  r = replace (r, "A-", "Alt+");
+  r = replace (r, "M-", "Meta+");
+  //r = replace (r, "K-", "");
+  r = replace (r, " ", ",");
+#endif
+  if (N(r) == 1 || (N(r) > 2 && r[N(r)-2] == '+')) {
+    if (is_locase (r[N(r)-1]))
+      r= r (0, N(r)-1) * upcase_all (r (N(r)-1, N(r)));
+    else if (is_upcase (r[N(r)-1]))
+      r= r (0, N(r)-1) * "Shift+" * upcase_all (r (N(r)-1, N(r)));
+  }
+  return r;
+}
+
+string
+conv (string s) {
+  int i=0, k;
+  string r;
+  for (k=0; k<=N(s); k++)
+    if (k == N(s) || s[k] == ' ') {
+      r << conv_sub (s (i, k));
+      i= k;
+    }
   return r;
 }
 
@@ -354,16 +413,24 @@ menu_button (widget w, command cmd, string pre, string ks, bool ok) {
   // keyboard shortcut; if ok does not hold, then the button is greyed
   QAction* a= NULL;
   a= concrete(w)->as_qaction();
-  QTMCommand* c= new QTMCommand (cmd.rep);
-  c->setParent (a);
-  QObject::connect (a, SIGNAL (triggered ()), c, SLOT (apply ()),
-                    Qt::QueuedConnection);
+#ifdef Q_WS_MAC
+  if (search_forwards (" ", ks) != -1) ks= "";
+#endif
   if (N(ks) > 0) {
     string qtks = conv (ks);
     QKeySequence qks (to_qstring (qtks));
     if (DEBUG_QT)
       cout << "ks: " << ks << " " << qks.toString().toAscii().data() << "\n";
     a->setShortcut (qks);
+    QTMKeyCommand* c= new QTMKeyCommand (ks);
+    c->setParent (a);
+    QObject::connect (a, SIGNAL (triggered ()), c, SLOT (apply ()),
+                      Qt::QueuedConnection);    
+  } else {
+    QTMCommand* c= new QTMCommand (cmd.rep);
+    c->setParent (a);
+    QObject::connect (a, SIGNAL (triggered ()), c, SLOT (apply ()),
+                      Qt::QueuedConnection);    
   }
   // FIXME: implement complete prefix handling
   a->setEnabled (ok? true: false);
@@ -384,11 +451,9 @@ balloon_widget (widget w, widget help)  {
 }
 
 widget
-text_widget (string s, color col, bool tsp, string lan) {
-  // a text widget with a given color, transparency and language
-  string t= qt_translate (s);
-  if (t == "Help") t= "Help ";
-  return tm_new<qt_text_widget_rep> (t, col, tsp, lan);
+text_widget (string s, color col, bool tsp) {
+  // a text widget with a given color and transparency
+  return tm_new<qt_text_widget_rep> (s, col, tsp);
 }
 
 widget
@@ -413,19 +478,21 @@ impress (simple_widget_rep* wid) {
     wid->handle_get_size_hint (width, height);
     QSize s = QSize (width/PIXEL, height/PIXEL);
     QPixmap pxm(s);
-    QRect rect = QRect (0, 0, s.width(), s.height());
     //cout << "impress (" << s.width() << "," << s.height() << ")\n";
     pxm.fill (Qt::transparent);
-    the_qt_renderer()->begin (static_cast<QPaintDevice*>(&pxm));
-    wid->set_current_renderer(the_qt_renderer());
-
-    the_qt_renderer()->set_clipping
-      (rect.x() * PIXEL, -(rect.y() + rect.height()) * PIXEL,
-       (rect.x() + rect.width()) * PIXEL, -rect.y() * PIXEL);
-    wid->handle_repaint
-      (rect.x() * PIXEL, -(rect.y() + rect.height()) * PIXEL,
-       (rect.x() + rect.width()) * PIXEL, -rect.y() * PIXEL);
-    the_qt_renderer()->end();
+    {
+      qt_renderer_rep *ren = the_qt_renderer();
+      ren->begin (static_cast<QPaintDevice*>(&pxm));
+      wid->set_current_renderer(the_qt_renderer());
+      rectangle r = rectangle (0, 0, s.width(), s.height());
+      ren->set_origin(0,0);
+      ren->encode (r->x1, r->y1);
+      ren->encode (r->x2, r->y2);
+      ren->set_clipping (r->x1, r->y2, r->x2, r->y1);
+      wid->handle_repaint (r->x1, r->y2, r->x2, r->y1);
+      ren->end();
+      wid->set_current_renderer(NULL);
+    }
     return pxm;
   }
   else {
@@ -460,7 +527,6 @@ rerootActions (QWidget* dest, QWidget* src) {
   }
 }
 
-
 void
 QTMLazyMenu::force () {
   widget w= pm ();
