@@ -14,11 +14,12 @@
 #include "image_files.hpp"
 #include "qt_utilities.hpp"
 #include "file.hpp"
-#include <QWidget>
+#include "image_files.hpp"
 
-#ifdef MACOSX_EXTENSIONS
-#include "MacOS/mac_images.h"
-#endif
+#include <QObject>
+#include <QWidget>
+#include <QPaintDevice>
+#include <QPixmap>
 
 /******************************************************************************
 * Qt images
@@ -70,25 +71,29 @@ CONCRETE_NULL_CODE(qt_pixmap);
 * Global support variables for all qt_renderers
 ******************************************************************************/
 
-static hashmap<basic_character,qt_image> character_image;  // bitmaps of all characters
+// bitmaps of all characters
+static hashmap<basic_character,qt_image> character_image;  
+// image cache
 static hashmap<string,qt_pixmap> images;
 
 /******************************************************************************
 * qt_renderer
 ******************************************************************************/
 
-qt_renderer_rep::qt_renderer_rep (int w2, int h2):
-  basic_renderer_rep(w2, h2) {}
+qt_renderer_rep::qt_renderer_rep (QPainter *_painter, int w2, int h2):
+  basic_renderer_rep(w2, h2), painter(_painter) {}
 
 qt_renderer_rep::~qt_renderer_rep () {}
 
 void
 qt_renderer_rep::begin (void* handle) {
-   QPaintDevice *device = (QPaintDevice*)handle;
-  painter.begin (device);
+  QPaintDevice *device = (QPaintDevice*)handle;
+  painter->begin (device);
+  w = painter->device()->width();
+  h = painter->device()->height();
 }
 
-void qt_renderer_rep::end () { painter.end (); }
+void qt_renderer_rep::end () { painter->end (); }
 
 QColor
 qt_color(color c)
@@ -98,30 +103,59 @@ qt_color(color c)
   return QColor(r, g, b);
 }
 
+void 
+qt_renderer_rep::get_extents (int& w2, int& h2) {  
+  if (painter->device()) {
+    w2 = painter->device()->width(); h2 = painter->device()->height();
+  } else {
+    w2 = w; h2 = h;
+  }
+}
+
 /******************************************************************************
-* Drawing into drawables
+ * Clipping
+ ******************************************************************************/
+
+void
+qt_renderer_rep::set_clipping (SI x1, SI y1, SI x2, SI y2, bool restore)
+{
+  (void) restore;
+  basic_renderer_rep::set_clipping (x1, y1, x2, y2);
+  outer_round (x1, y1, x2, y2);
+  decode (x1, y1);
+  decode (x2, y2);
+  if ((x1<x2) && (y2<y1)) {
+    QRect r(x1,y2,x2-x1,y1-y2);
+    painter->setClipRect(r);
+  }
+}
+
+
+
+/******************************************************************************
+* Drawing 
 ******************************************************************************/
 
 void
 qt_renderer_rep::set_color (color c) {
   basic_renderer_rep::set_color(c);
-  QPen p (painter.pen ());
-  QBrush b (painter.brush ());
+  QPen p (painter->pen ());
+  QBrush b (painter->brush ());
   p.setColor (qt_color(cur_fg));
   b.setColor (qt_color(cur_fg));
-  painter.setPen (p);
-  painter.setBrush (b);
+  painter->setPen (p);
+  painter->setBrush (b);
 }
 
 void
 qt_renderer_rep::set_line_style (SI lw, int type, bool round) {
   (void) type;
-  QPen p (painter.pen ());
+  QPen p (painter->pen ());
   if (lw <= pixel) p.setWidth (0);
   else p.setWidth ((lw+thicken) / (1.0*pixel));
   p.setCapStyle (round? Qt::RoundCap: Qt::SquareCap);
   p.setJoinStyle (Qt::RoundJoin);
-  painter.setPen (p);
+  painter->setPen (p);
 }
 
 void
@@ -129,8 +163,8 @@ qt_renderer_rep::line (SI x1, SI y1, SI x2, SI y2) {
   decode (x1, y1);
   decode (x2, y2);
   // y1--; y2--; // top-left origin to bottom-left origin conversion
-  painter.setRenderHints (QPainter::Antialiasing);
-  painter.drawLine (x1, y1, x2, y2);
+  painter->setRenderHints (QPainter::Antialiasing);
+  painter->drawLine (x1, y1, x2, y2);
 }
 
 void
@@ -144,8 +178,8 @@ qt_renderer_rep::lines (array<SI> x, array<SI> y) {
     pnt[i].rx()= xx;
     pnt[i].ry()= yy;
     if (i>0) {
-      painter.setRenderHints (QPainter::Antialiasing);
-      painter.drawLine (pnt[i-1], pnt[i]); // FIX: hack
+      painter->setRenderHints (QPainter::Antialiasing);
+      painter->drawLine (pnt[i-1], pnt[i]); // FIX: hack
     }
   }
   // XDrawLines (dpy, win, gc, pnt, n, CoordModeOrigin);
@@ -161,8 +195,8 @@ qt_renderer_rep::clear (SI x1, SI y1, SI x2, SI y2) {
   decode (x2, y2);
   if ((x1>=x2) || (y1<=y2)) return;
   QBrush brush (qt_color(cur_bg));
-  painter.setRenderHints (0);
-  painter.fillRect (x1, y2, x2-x1, y1-y2, brush);       
+  painter->setRenderHints (0);
+  painter->fillRect (x1, y2, x2-x1, y1-y2, brush);       
 }
 
 void
@@ -187,8 +221,8 @@ qt_renderer_rep::fill (SI x1, SI y1, SI x2, SI y2) {
   decode (x2, y2);
 
   QBrush brush (qt_color(cur_fg));
-  painter.setRenderHints (0);
-  painter.fillRect (x1, y2, x2-x1, y1-y2, brush);       
+  painter->setRenderHints (0);
+  painter->fillRect (x1, y2, x2-x1, y1-y2, brush);       
 }
 
 void
@@ -197,7 +231,8 @@ qt_renderer_rep::arc (SI x1, SI y1, SI x2, SI y2, int alpha, int delta) {
   if ((x1>=x2) || (y1>=y2)) return;
   decode (x1, y1);
   decode (x2, y2);
-  //FIXME: XDrawArc (dpy, win, gc, x1, y2, x2-x1, y1-y2, alpha, delta);
+  painter->setRenderHints (QPainter::Antialiasing);
+  painter->drawArc (x1, y2, x2-x1, y1-y2, alpha / 4, delta / 4);
 }
 
 void
@@ -206,7 +241,14 @@ qt_renderer_rep::fill_arc (SI x1, SI y1, SI x2, SI y2, int alpha, int delta) {
   if ((x1>=x2) || (y1>=y2)) return;
   decode (x1, y1);
   decode (x2, y2);
-  //FIXME: XFillArc (dpy, win, gc, x1, y2, x2-x1, y1-y2, alpha, delta);
+  QBrush brush(qt_color(cur_fg));
+  QPainterPath pp;
+  pp.arcMoveTo (x1, y2, x2-x1, y1-y2, alpha / 64);
+  pp.arcTo (x1, y2, x2-x1, y1-y2, alpha / 64, delta / 64);
+  pp.closeSubpath ();
+  pp.setFillRule (Qt::WindingFill);
+  painter->setRenderHints (QPainter::Antialiasing);
+  painter->fillPath (pp, brush);
 }
 
 void
@@ -224,8 +266,8 @@ qt_renderer_rep::polygon (array<SI> x, array<SI> y, bool convex) {
   pp.addPolygon (poly);
   pp.closeSubpath ();
   pp.setFillRule (convex? Qt::OddEvenFill: Qt::WindingFill);
-  painter.setRenderHints (QPainter::Antialiasing);
-  painter.fillPath (pp, brush);
+  painter->setRenderHints (QPainter::Antialiasing);
+  painter->fillPath (pp, brush);
 }
 
 
@@ -253,6 +295,10 @@ qt_renderer_rep::image (url u, SI w, SI h, SI x, SI y,
   w= w/pixel; h= h/pixel;
   decode (x, y);
 
+  // safety check
+  url ru = resolve(u);
+  u = is_none (ru) ? "$TEXMACS_PATH/misc/pixmaps/unknown.ps" : ru;
+  
   QImage *pm = NULL;
   tree lookup= tuple (u->t);
   lookup << as_string (w ) << as_string (h )
@@ -264,18 +310,16 @@ qt_renderer_rep::image (url u, SI w, SI h, SI x, SI y,
   } else {
     // rendering
     bool needs_crop= false;
-    if (qt_supports_image (u)) {
-      pm= new QImage (to_qstring (as_string (u)));
+    if (qt_supports (u)) {
+      pm= new QImage (to_qstring (concretize (u)));
       needs_crop= true;
     } else if (suffix (u) == "ps" ||
              suffix (u) == "eps" ||
              suffix (u) == "pdf") {
-
-#ifdef MACOSX_EXTENSIONS
       url temp= url_temp (".png");
-      mac_image_to_png (u, temp);
+      image_to_png (u, temp, w, h);
       needs_crop= true;
-#else
+/*
       string idstr= eval_system ("identify",u);
       int i=0;
       int a=0,b=0;
@@ -321,12 +365,12 @@ qt_renderer_rep::image (url u, SI w, SI h, SI x, SI y,
              * "+" * as_string (cx1*w/(cx2-cx1))
              * "+" * as_string ((1-cy2)*h/(cy2-cy1))
              * "! -background white -flatten", u, temp);
-#endif
+*/
       pm= new QImage (to_qstring (as_string (temp)));
       remove (temp);
     }
     if (pm == NULL || pm->isNull ()) {
-      cout << "TeXmacs] warning: cannot render " << as_string (u) << "\n";
+      cout << "TeXmacs] warning: cannot render " << concretize (u) << "\n";
       if (pm != NULL) delete pm;
       return;
     }
@@ -350,7 +394,7 @@ qt_renderer_rep::image (url u, SI w, SI h, SI x, SI y,
     (ci->nr)++;
   }
 
-  painter.drawImage (x, y-h, *pm);
+  painter->drawImage (x, y-h, *pm);
 };
 
 
@@ -363,9 +407,8 @@ qt_renderer_rep::draw_clipped (QImage *im, int w, int h, SI x, SI y) {
   decode (x2, y2);
   y--; // top-left origin to bottom-left origin conversion
        // clear(x1,y1,x2,y2);
-  painter.setRenderHints (0);
-  painter.drawImage (x, y, *im);
-  // [im drawAtPoint:NSMakePoint(x,y) fromRect:NSMakeRect(0,0,w,h) operation:NSCompositeSourceAtop fraction:1.0];
+  painter->setRenderHints (0);
+  painter->drawImage (x, y, *im);
 }
 
 void
@@ -373,9 +416,8 @@ qt_renderer_rep::draw_clipped (QPixmap *im, int w, int h, SI x, SI y) {
   decode (x , y );
   y--; // top-left origin to bottom-left origin conversion
   // clear(x1,y1,x2,y2);
-  painter.setRenderHints (0);
-  painter.drawPixmap (x, y, w, h, *im);
-  // [im drawAtPoint:NSMakePoint(x,y) fromRect:NSMakeRect(0,0,w,h) operation:NSCompositeSourceAtop fraction:1.0];
+  painter->setRenderHints (0);
+  painter->drawPixmap (x, y, w, h, *im);
 }
 
 
@@ -398,11 +440,11 @@ qt_renderer_rep::draw (int c, font_glyphs fng, SI x, SI y) {
       int nr_cols= sfactor*sfactor;
       if (nr_cols >= 64) nr_cols= 64;
 
+      im->fill (Qt::transparent);
       QPainter pp(im);
-      QPen pen(painter.pen());
+      QPen pen(painter->pen());
       QBrush brush(pen.color());
       pp.setPen(Qt::NoPen);
-      im->fill (Qt::transparent);
       for (j=0; j<h; j++)
         for (i=0; i<w; i++) {
           int col = gl->get_x (i, j);
@@ -433,7 +475,8 @@ qt_renderer_rep::draw (int c, font_glyphs fng, SI x, SI y) {
     mi = mi2;
     //[im release]; // qt_image retains im
     character_image (xc)= mi;
-    // FIXME: we must release the image at some point (this should be ok now, see qt_image)
+    // FIXME: we must release the image at some point 
+    //        (this should be ok now, see qt_image)
   }
 
   // draw the character
@@ -460,7 +503,8 @@ qt_renderer_rep::xpm_image (url file_name) {
     pxm->loadFromData (buf, N(sss));
     tm_delete_array ((char*) buf);
     //out << sss;
-    //cout << "pxm: " << file_name << "(" << pxm->size().width() << "," <<  pxm->size().height() << ")\n";
+    //cout << "pxm: " << file_name << "(" << pxm->size().width()
+    //     << "," <<  pxm->size().height() << ")\n";
     qt_pixmap mi2 (pxm, 0, 0, pxm->width(), pxm->height());
     mi= mi2;
     images (as_string (file_name))= mi2;
@@ -483,6 +527,103 @@ qt_renderer_rep::xpm (url file_name, SI x, SI y) {
   char_clip=old_clip;
 }
 
+
+void
+qt_renderer_rep::new_shadow (renderer& ren) {
+  SI mw, mh, sw, sh;
+  get_extents (mw, mh);
+  if (ren != NULL) {
+    ren->get_extents (sw, sh);
+    if (sw != mw || sh != mh) {
+      delete_shadow (ren);
+      ren= NULL;
+    }
+    // cout << "Old: " << sw << ", " << sh << "\n";
+  }
+  if (ren == NULL)  ren= (renderer) tm_new<qt_proxy_renderer_rep> (this);
+  
+  // cout << "Create " << mw << ", " << mh << "\n";
+}
+
+void 
+qt_renderer_rep::delete_shadow (renderer& ren)  {
+  if (ren != NULL) {
+    tm_delete (ren);
+    ren= NULL;
+  }
+}
+
+
+void 
+qt_renderer_rep::get_shadow (renderer ren, SI x1, SI y1, SI x2, SI y2) {
+  // FIXME: we should use the routine fetch later
+  ASSERT (ren != NULL, "invalid renderer");
+  if (ren->is_printer ()) return;
+  qt_renderer_rep* shadow= static_cast<qt_renderer_rep*>(ren);
+  outer_round (x1, y1, x2, y2);
+  x1= max (x1, cx1- ox);
+  y1= max (y1, cy1- oy);
+  x2= min (x2, cx2- ox);
+  y2= min (y2, cy2- oy);
+  shadow->ox= ox;
+  shadow->oy= oy;
+  shadow->cx1= x1+ ox;
+  shadow->cy1= y1+ oy;
+  shadow->cx2= x2+ ox;
+  shadow->cy2= y2+ oy;
+  shadow->master= this;
+#if 0
+  decode (x1, y1);
+  decode (x2, y2);
+  if (x1<x2 && y2<y1) {
+    QRect rect = QRect(x1, y2, x2-x1, y1-y2);
+    //    shadow->painter->setCompositionMode(QPainter::CompositionMode_Source);   
+    shadow->painter->drawPixmap (rect, px, rect);
+    //    cout << "qt_shadow_renderer_rep::get_shadow " 
+    //         << rectangle(x1,y2,x2,y1) << LF;
+    //  XCopyArea (dpy, win, shadow->win, gc, x1, y2, x2-x1, y1-y2, x1, y2);
+  }
+#endif
+}
+
+void 
+qt_renderer_rep::put_shadow (renderer ren, SI x1, SI y1, SI x2, SI y2) {
+  // FIXME: we should use the routine fetch later
+  ASSERT (ren != NULL, "invalid renderer");
+  if (ren->is_printer ()) return;
+  if (painter == static_cast<qt_renderer_rep*>(ren)->painter) return;
+  qt_shadow_renderer_rep* shadow= static_cast<qt_shadow_renderer_rep*>(ren);
+  outer_round (x1, y1, x2, y2);
+  x1= max (x1, cx1- ox);
+  y1= max (y1, cy1- oy);
+  x2= min (x2, cx2- ox);
+  y2= min (y2, cy2- oy);
+  decode (x1, y1);
+  decode (x2, y2);
+  if (x1<x2 && y2<y1) {
+    QRect rect = QRect(x1, y2, x2-x1, y1-y2);
+    //    cout << "qt_shadow_renderer_rep::put_shadow " 
+    //         << rectangle(x1,y2,x2,y1) << LF;
+    //    painter->setCompositionMode(QPainter::CompositionMode_Source);
+    painter->drawPixmap (rect, shadow->px, rect);
+    //  XCopyArea (dpy, shadow->win, win, gc, x1, y2, x2-x1, y1-y2, x1, y2);
+  }
+}
+
+
+void 
+qt_renderer_rep::apply_shadow (SI x1, SI y1, SI x2, SI y2)  {
+  if (master == NULL) return;
+  if (painter == static_cast<qt_renderer_rep*>(master)->painter) return;
+  outer_round (x1, y1, x2, y2);
+  decode (x1, y1);
+  decode (x2, y2);
+  static_cast<qt_renderer_rep*>(master)->encode (x1, y1);
+  static_cast<qt_renderer_rep*>(master)->encode (x2, y2);
+  master->put_shadow (this, x1, y1, x2, y2);
+}
+
+
 /******************************************************************************
  * main qt renderer
  ******************************************************************************/
@@ -490,7 +631,125 @@ qt_renderer_rep::xpm (url file_name, SI x, SI y) {
 
 qt_renderer_rep*
 the_qt_renderer () {
+  static QPainter *the_painter = NULL;
   static qt_renderer_rep* the_renderer= NULL;
-  if (!the_renderer) the_renderer= tm_new<qt_renderer_rep> ();
+  if (!the_renderer) {
+    the_painter = new QPainter();
+    the_renderer= tm_new<qt_renderer_rep> (the_painter);
+  }
   return the_renderer;
 }
+
+/******************************************************************************
+ * proxy qt renderer
+ ******************************************************************************/
+
+
+
+void 
+qt_proxy_renderer_rep::new_shadow (renderer& ren) {
+  SI mw, mh, sw, sh;
+  get_extents (mw, mh);
+  if (ren != NULL) {
+    ren->get_extents (sw, sh);
+    if (sw != mw || sh != mh) {
+      delete_shadow (ren);
+      ren= NULL;
+    }
+    else 
+      static_cast<qt_shadow_renderer_rep*>(ren)->end();
+    // cout << "Old: " << sw << ", " << sh << "\n";
+  }
+  if (ren == NULL)  
+    ren= (renderer) tm_new<qt_shadow_renderer_rep> (QPixmap (mw, mh));
+  
+  // cout << "Create " << mw << ", " << mh << "\n";
+  static_cast<qt_shadow_renderer_rep*>(ren)->begin(
+          &(static_cast<qt_shadow_renderer_rep*>(ren)->px));
+}
+
+
+void 
+qt_proxy_renderer_rep::get_shadow (renderer ren, SI x1, SI y1, SI x2, SI y2) {
+  // FIXME: we should use the routine fetch later
+  ASSERT (ren != NULL, "invalid renderer");
+  if (ren->is_printer ()) return;
+  qt_renderer_rep* shadow= static_cast<qt_renderer_rep*>(ren);
+  outer_round (x1, y1, x2, y2);
+  x1= max (x1, cx1- ox);
+  y1= max (y1, cy1- oy);
+  x2= min (x2, cx2- ox);
+  y2= min (y2, cy2- oy);
+  shadow->ox= ox;
+  shadow->oy= oy;
+  shadow->cx1= x1+ ox;
+  shadow->cy1= y1+ oy;
+  shadow->cx2= x2+ ox;
+  shadow->cy2= y2+ oy;
+  shadow->master= this;
+  decode (x1, y1);
+  decode (x2, y2);
+  if (x1<x2 && y2<y1) {
+    QRect rect = QRect(x1, y2, x2-x1, y1-y2);
+    //    shadow->painter->setCompositionMode(QPainter::CompositionMode_Source);
+    QPixmap *_pixmap = static_cast<QPixmap*>(painter->device()); 
+    if (_pixmap) {
+      shadow->painter->drawPixmap (rect, *_pixmap, rect);
+    }
+    //    cout << "qt_shadow_renderer_rep::get_shadow " 
+    //         << rectangle(x1,y2,x2,y1) << LF;
+    //  XCopyArea (dpy, win, shadow->win, gc, x1, y2, x2-x1, y1-y2, x1, y2);
+  }
+}
+
+
+/******************************************************************************
+ * shadow qt renderer
+ ******************************************************************************/
+
+qt_shadow_renderer_rep::qt_shadow_renderer_rep (QPixmap _px) 
+// : qt_renderer_rep (_px.width(),_px.height()), px(_px) 
+: qt_renderer_rep (new QPainter()), px(_px) 
+{ 
+  //cout << px.width() << "," << px.height() << " " << LF;
+ // painter->begin(&px);
+}
+
+qt_shadow_renderer_rep::~qt_shadow_renderer_rep () 
+{ 
+  painter->end(); 
+  delete painter;
+  painter = NULL;
+}
+
+void 
+qt_shadow_renderer_rep::get_shadow (renderer ren, SI x1, SI y1, SI x2, SI y2) {
+  // FIXME: we should use the routine fetch later
+  ASSERT (ren != NULL, "invalid renderer");
+  if (ren->is_printer ()) return;
+  qt_shadow_renderer_rep* shadow= static_cast<qt_shadow_renderer_rep*>(ren);
+  outer_round (x1, y1, x2, y2);
+  x1= max (x1, cx1- ox);
+  y1= max (y1, cy1- oy);
+  x2= min (x2, cx2- ox);
+  y2= min (y2, cy2- oy);
+  shadow->ox= ox;
+  shadow->oy= oy;
+  shadow->cx1= x1+ ox;
+  shadow->cy1= y1+ oy;
+  shadow->cx2= x2+ ox;
+  shadow->cy2= y2+ oy;
+  shadow->master= this;
+  decode (x1, y1);
+  decode (x2, y2);
+  if (x1<x2 && y2<y1) {
+    QRect rect = QRect(x1, y2, x2-x1, y1-y2);
+//    shadow->painter->setCompositionMode(QPainter::CompositionMode_Source);   
+    shadow->painter->drawPixmap (rect, px, rect);
+//    cout << "qt_shadow_renderer_rep::get_shadow " 
+//         << rectangle(x1,y2,x2,y1) << LF;
+//  XCopyArea (dpy, win, shadow->win, gc, x1, y2, x2-x1, y1-y2, x1, y2);
+  }
+}
+
+
