@@ -67,7 +67,7 @@ inline wk_widget concrete (widget w) {
 array<widget> abstract (array<wk_widget> a);
 array<wk_widget> concrete (array<widget> a);
 
-ostream& operator << (ostream& out, wk_widget w);
+tm_ostream& operator << (tm_ostream& out, wk_widget w);
 wk_widget operator << (wk_widget w, event ev);
 
 void wk_grab_pointer (wk_widget w);
@@ -94,9 +94,9 @@ wk_widget switch_widget (array<wk_widget> a, array<string> name, int init= 0);
 wk_widget optional_widget (wk_widget w, bool on= true);
 wk_widget glue_wk_widget (bool hx=true, bool vx=true, SI w=0, SI h=0);
 wk_widget separator_wk_widget (SI pre=0, SI post=0, bool vert=false);
-wk_widget text_wk_widget (string s, bool tsp= false, string lan="");
+wk_widget text_wk_widget (string s, bool tsp= false);
 wk_widget menu_text_wk_widget (string s, color col, bool tsp=true,
-			       string lan="", bool tt= false);
+			       bool tt= false);
 wk_widget xpm_wk_widget (url file_name, bool transp= true);
 wk_widget command_button (wk_widget w, command cmd, bool button_flag= false);
 wk_widget command_button (wk_widget lw, wk_widget rw, command cmd);
