@@ -4,10 +4,9 @@
 * DESCRIPTION: Initialization of the X11 window manager
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "X11/x_window.hpp"
@@ -17,6 +16,7 @@
 #include "dictionary.hpp"
 #include "iterator.hpp"
 #include "message.hpp"
+#include "sys_utils.hpp"
 #include <locale.h>
 
 x_gui_rep* the_gui= NULL;
@@ -38,8 +38,31 @@ static int CFACTOR= 5;
 static int GREYS  = 16;
 static int CTOTAL = (CFACTOR*CFACTOR*CFACTOR+GREYS+1);
 
+static void
+reverse (int& r, int& g, int& b) {
+  int m= min (r, min (g, b));
+  int M= max (r, max (g, b));
+  int t= (r + g + b) / 3;
+  int tt= 255 - t;
+  double mu= 1.0;
+  // tt= 6 * tt / 7;
+  if (M != m) {
+    double lambda1= max (((double) (t - m)) / t,
+			 ((double) (M - t)) / (255 - t));
+    double lambda2= max (((double) (t - m)) / tt,
+			 ((double) (M - t)) / (255 - tt));
+    mu= lambda1 / lambda2;
+  }
+  r= (int) (tt + mu * (r - t) + 0.5);
+  g= (int) (tt + mu * (g - t) + 0.5);
+  b= (int) (tt + mu * (b - t) + 0.5);
+}
+
 int
 x_alloc_color (int r, int g, int b) {
+  if (true_color)
+    return ((r >> 8) << 16) + ((g >> 8) << 8) + (b >> 8);
+
   if (reverse_colors) {
     int m= min (r, min (g, b));
     int M= max (r, max (g, b));
@@ -58,8 +81,6 @@ x_alloc_color (int r, int g, int b) {
     g= (int) (tt + mu * (g - t) + 0.5);
     b= (int) (tt + mu * (b - t) + 0.5);
   }
-  if (true_color)
-    return (r << 16) + (g << 8) + b;
 
   XColor col;
   col.red  = r;
@@ -75,7 +96,7 @@ x_init_color_map () {
   if (true_color) return;
 
   int i, r, g, b;
-  the_gui->cmap= new color [CTOTAL];
+  the_gui->cmap= tm_new_array<color> (CTOTAL);
 
   for (i=0; i<=GREYS; i++)
     the_gui->cmap[i]=
@@ -93,7 +114,10 @@ x_init_color_map () {
 
 color
 rgb_color (int r, int g, int b) {
-  if (true_color) return (r << 16) + (g << 8) + b;
+  if (true_color) {
+    if (reverse_colors) reverse (r, g, b);
+    return (r << 16) + (g << 8) + b;
+  }
   else if ((r==g) && (g==b)) return (r*GREYS+ 128)/255;
   else {
     r= (r*CSCALES+ 128)/255;
@@ -109,6 +133,7 @@ get_rgb_color (color col, int& r, int& g, int& b) {
     r= (col >> 16) & 255;
     g= (col >> 8 ) & 255;
     b=  col        & 255;
+    if (reverse_colors) reverse (r, g, b);
   }
   else if (col <= GREYS) {
     r= (col*255)/GREYS;
@@ -419,9 +444,9 @@ x_gui_rep::initialize_keyboard_pointer () {
   Map (XK_Cyrillic_E,   "\xdd");
   Map (XK_Cyrillic_YU,  "\xde");
   Map (XK_Cyrillic_YA,  "\xdf");
-  
+
   //Ukrainian letters in T2A encoding
-  Map (XK_Ukrainian_i,   "i"); // Fall back! 
+  Map (XK_Ukrainian_i,   "i"); // Fall back!
   Map (XK_Ukrainian_I,   "I"); // Fall back!
   Map (XK_Ukrainian_yi,   "\xa8");
   Map (XK_Ukrainian_YI,   "\x88");
@@ -685,6 +710,14 @@ x_gui_rep::initialize_keyboard_pointer () {
   map (XK_F10, "F10");
   map (XK_F11, "F11");
   map (XK_F12, "F12");
+  map (XK_F13, "F13");
+  map (XK_F14, "F14");
+  map (XK_F15, "F15");
+  map (XK_F16, "F16");
+  map (XK_F17, "F17");
+  map (XK_F18, "F18");
+  map (XK_F19, "F19");
+  map (XK_F20, "F20");
   // map (XK_Mode_switch, "modeswitch");
 
   // Keypad keys
@@ -771,16 +804,16 @@ x_gui_rep::get_max_size (SI& width, SI& height) {
 * Main initialization
 ******************************************************************************/
 
-x_gui_rep::x_gui_rep (int argc2, char** argv2):
+x_gui_rep::x_gui_rep (int& argc2, char** argv2):
   color_scale ((void*) NULL),
   character_bitmap (NULL), character_pixmap ((pointer) 0),
   xpm_bitmap (0), xpm_pixmap (0),
   lower_key (""), upper_key (""),
-  selection (NULL), selection_t ("none"), selection_s ("")
+  selection_t ("none"), selection_s (""), selection_w ((Window) 0)
 {
   the_gui= this;
-  if ((dpy= XOpenDisplay (NULL)) == NULL)
-    fatal_error ("I failed to connect to Xserver", "x_gui_rep::x_gui_rep");
+  ASSERT ((dpy= XOpenDisplay (NULL)) != NULL,
+	  "failure to connect to Xserver");
   // XSynchronize (dpy, true);
 
   XGCValues values;
@@ -802,6 +835,9 @@ x_gui_rep::x_gui_rep (int argc2, char** argv2):
   interrupted        = false;
   interrupt_time     = texmacs_time ();
 
+  XA_CLIPBOARD = XInternAtom (dpy, "CLIPBOARD", false);
+  XA_TARGETS = XInternAtom (dpy, "TARGETS", false);
+
   if (XMatchVisualInfo (dpy, scr, depth, TrueColor, &visual) != 0) {
     if (visual.red_mask   == (255 << 16) &&
 	visual.green_mask == (255 << 8) &&
@@ -811,6 +847,37 @@ x_gui_rep::x_gui_rep (int argc2, char** argv2):
 
   XSetGraphicsExposures (dpy, gc, true);
 
+  int start= 0;
+  string xmm= eval_system ("xmodmap");
+  for (int i=0; i<=N(xmm); i++)
+    if (i == N(xmm) || xmm[i] == '\n') {
+      string s= xmm (start, i);
+      if (starts (s, "mod") && N(s)>3 && s[3] >= '1' && s[3] <= '5') {
+	int nr= ((int) (s[3] - '0'));
+	int mask= 4 << nr;
+	if (occurs ("Alt_L", s) || occurs ("Alt_R", s)) {
+	  //cout << "alt_mask= " << mask << "\n";
+	  alt_mask= mask;
+	}
+	else if (alt_mask == 0 && occurs ("Mode_switch", s)) {
+	  //cout << "alt_mask= " << mask << "\n";
+	  alt_mask= mask;
+	}
+	else if (occurs ("Meta_L", s) || occurs ("Meta_R", s)) {
+	  //cout << "meta_mask= " << mask << "\n";
+	  meta_mask= mask;
+	}
+	else if (meta_mask == 0 &&
+		 (occurs ("Super_L", s) || occurs ("Super_R", s))) {
+	  //cout << "meta_mask= " << mask << "\n";
+	  meta_mask= mask;
+	}
+      }
+      start= i+1;
+    }
+  if (alt_mask == 0) alt_mask= 8;
+  if (meta_mask == 0) meta_mask= 16;
+
   //get_xmodmap ();
   x_initialize_colors ();
   initialize_input_method ();
@@ -824,14 +891,13 @@ x_gui_rep::~x_gui_rep () {
   clear_selection ("primary");
   XFreeGC (dpy, gc);
   XCloseDisplay (dpy);
-  if (!true_color) delete[] cmap;
+  if (!true_color) tm_delete_array (cmap);
 }
 
 void
-gui_open (int argc2, char** argv2) {
-  if (the_gui != NULL)
-    fatal_error ("gui already open", "gui_open");
-  the_gui= new x_gui_rep (argc2, argv2);
+gui_open (int& argc2, char** argv2) {
+  ASSERT (the_gui == NULL, "gui already open");
+  the_gui= tm_new<x_gui_rep> (argc2, argv2);
 }
 
 void
@@ -841,9 +907,8 @@ gui_start_loop () {
 
 void
 gui_close () {
-  if (the_gui == NULL)
-    fatal_error ("gui not yet open", "gui_close");
-  delete the_gui;
+  ASSERT (the_gui != NULL, "gui not yet open");
+  tm_delete (the_gui);
   the_gui= NULL;
 }
 
