@@ -5,10 +5,9 @@
 *              you just upgraded your TeXmacs distribution
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "boot.hpp"
@@ -72,38 +71,50 @@ init_upgrade_scheme () {
 * Generate documentation about changes
 ******************************************************************************/
 
+static string
+string_load (url u) {
+  string s;
+  (void) load_string (u, s, false);
+  return s;
+}
+
 static void
 init_upgrade_doc (string install_version) {
   url from_dir= "$TEXMACS_PATH/doc/about/changes";
   url to= "$TEXMACS_HOME_PATH/doc/about/changes/changes-recent.en.tm";
-  copy (from_dir * "changes-pre.en.ptm", to);
+  string s= string_load (from_dir * "changes-pre.en.ptm");
   if (version_inf (install_version, "0.3.3.24"))
-    append (from_dir * "changes-1.en.ptm", to);
+    s << string_load (from_dir * "changes-1.en.ptm");
   if (version_inf_eq (install_version, "0.3.4.9"))
-    append (from_dir * "changes-2.en.ptm", to);
+    s << string_load (from_dir * "changes-2.en.ptm");
   if (version_inf_eq (install_version, "1.0.0.4"))
-    append (from_dir * "changes-3.en.ptm", to);
+    s << string_load (from_dir * "changes-3.en.ptm");
   if (version_inf_eq (install_version, "1.0.0.6"))
-    append (from_dir * "changes-4.en.ptm", to);
+    s << string_load (from_dir * "changes-4.en.ptm");
   if (version_inf_eq (install_version, "1.0.0.11"))
-    append (from_dir * "changes-5.en.ptm", to);
+    s << string_load (from_dir * "changes-5.en.ptm");
   if (version_inf_eq (install_version, "1.0.2.0"))
-    append (from_dir * "changes-6.en.ptm", to);
+    s << string_load (from_dir * "changes-6.en.ptm");
   if (version_inf_eq (install_version, "1.0.2.6"))
-    append (from_dir * "changes-7.en.ptm", to);
+    s << string_load (from_dir * "changes-7.en.ptm");
   if (version_inf_eq (install_version, "1.0.2.8"))
-    append (from_dir * "changes-8.en.ptm", to);
+    s << string_load (from_dir * "changes-8.en.ptm");
   if (version_inf_eq (install_version, "1.0.3.4"))
-    append (from_dir * "changes-9.en.ptm", to);
+    s << string_load (from_dir * "changes-9.en.ptm");
   if (version_inf_eq (install_version, "1.0.4"))
-    append (from_dir * "changes-10.en.ptm", to);
+    s << string_load (from_dir * "changes-10.en.ptm");
   if (version_inf_eq (install_version, "1.0.5.9"))
-    append (from_dir * "changes-11.en.ptm", to);
+    s << string_load (from_dir * "changes-11.en.ptm");
   if (version_inf_eq (install_version, "1.0.5.9"))
-    append (from_dir * "changes-12.en.ptm", to);
-  if (version_inf_eq (install_version, "1.0.5.9")) {
-    append (from_dir * "changes-13.en.ptm", to);
-    append (from_dir * "changes-post.en.ptm", to);
+    s << string_load (from_dir * "changes-12.en.ptm");
+  if (version_inf_eq (install_version, "1.0.5.9"))
+    s << string_load (from_dir * "changes-13.en.ptm");
+  if (version_inf_eq (install_version, "1.0.6.2"))
+    s << string_load (from_dir * "changes-14.en.ptm");
+  if (version_inf_eq (install_version, "1.0.7.6")) {
+    s << string_load (from_dir * "changes-15.en.ptm");
+    s << string_load (from_dir * "changes-post.en.ptm");
+    save_string (to, s, false);
   }
   else remove (to);
 }
@@ -131,11 +142,11 @@ init_upgrade () {
   init_upgrade_scheme ();
   init_upgrade_doc (install_version);
 
-  remove ("$TEXMACS_HOME_PATH/system/setup.scm");
-  remove ("$TEXMACS_HOME_PATH/system/cache" * url_wildcard ("__*"));
-  remove ("$TEXMACS_HOME_PATH/system/cache/dir_cache.scm");
-  remove ("$TEXMACS_HOME_PATH/system/cache/doc_cache");
-  remove ("$TEXMACS_HOME_PATH/system/cache/file_cache");
-  remove ("$TEXMACS_HOME_PATH/system/cache/stat_cache.scm");
+  remove (url ("$TEXMACS_HOME_PATH/system/setup.scm"));
+  remove (url ("$TEXMACS_HOME_PATH/system/cache") * url_wildcard ("__*"));
+  remove (url ("$TEXMACS_HOME_PATH/system/cache/dir_cache.scm"));
+  remove (url ("$TEXMACS_HOME_PATH/system/cache/doc_cache"));
+  remove (url ("$TEXMACS_HOME_PATH/system/cache/file_cache"));
+  remove (url ("$TEXMACS_HOME_PATH/system/cache/stat_cache.scm"));
   cache_refresh ();
 }
