@@ -30,7 +30,8 @@ mathemagix_language_rep::mathemagix_language_rep (string name):
 }
 
 text_property
-mathemagix_language_rep::advance (string s, int& pos) {
+mathemagix_language_rep::advance (tree t, int& pos) {
+  string s= t->label;
   if (pos==N(s)) return &tp_normal_rep;
   char c= s[pos];
   if (c == ' ') {
@@ -77,6 +78,13 @@ mathemagix_color_setup_constants (hashmap<string, string> & t) {
   t ("mmout")= c;
   t ("mmin")= c;
   t ("mmerr")= c;
+  t ("blank")= c;
+  t ("stroke")= c;
+  t ("indent")= c;
+  t ("unindent")= c;
+  t ("lf")= c;
+  t ("hrule")= c;
+  t ("flush_now")= c;
   t ("nil")= c;
 }
 
@@ -99,6 +107,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("constructor")= c;
   t ("continue")= c;
   t ("convert")= c;
+  t ("debugger")= c;
   t ("destructor")= c;
   t ("direct")= c;
   t ("div")= c;
@@ -152,6 +161,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("operator")= c;
   t ("or")= c;
   t ("packed")= c;
+  t ("penalty")= c;
   t ("postfix")= "postfix";
   t ("prefix")= c;
   t ("private")= c;
@@ -162,6 +172,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("raise")= c;
   t ("require")= c;
   t ("return")= c ;
+  t ("sequel")= c;
   t ("split")= c;
   t ("step")= c;
   t ("supports?")= c;
@@ -743,5 +754,5 @@ mathemagix_language_rep::get_color (tree t, int start, int end) {
   }
   while (pos<N(s));
   }
-  return none;
+  if (type=="identifier_markup") {return COLOR_MARKUP;} else return none;
 }
