@@ -13,7 +13,7 @@
 #include "convert.hpp"
 #include "file.hpp"
 #include "web_files.hpp"
-#include "socket_server.hpp"
+#include "tm_link.hpp"
 #include "message.hpp"
 #include "dictionary.hpp"
 
@@ -53,8 +53,7 @@ string
 tm_data_rep::new_menu_name (url u) {
   string name= as_string (tail (u));
   if (starts (name, "no_name_") && ends (name, ".tm")) {
-    string lan= get_output_language ();
-    string no_name= translate ("No name", "english", lan);
+    string no_name= translate ("No name");
     for (int i=0; i<N(no_name); i++)
       if (((unsigned char) (no_name[i])) >= (unsigned char) 128)
 	{ no_name= "No name"; break; }
@@ -83,7 +82,9 @@ menu_append_buffer (string& s, tm_buffer buf) {
   if (buf->in_menu) {
     string name= copy (buf->abbr);
     if (buf->needs_to_be_saved ()) name << " *"; 
-    s << " (" << scm_quote (name);
+    string mname= scm_quote (name);
+    if (!starts (name, "Help")) mname= "(verbatim " * mname * ")";
+    s << " (" << mname;
     s << " (switch-to-buffer " * scm_quote (as_string (buf->name)) * "))";
   }
 }
@@ -243,8 +244,10 @@ tm_data_rep::set_abbr_buffer (string abbr) {
   buf->abbr= abbr;
   for (i=0; i<N(buf->vws); i++) {
     tm_view vw2= buf->vws[i];
-    if (vw2->win != NULL)
+    if (vw2->win != NULL) {
       vw2->win->set_window_name (buf->abbr);
+      vw2->win->set_window_url (is_none (buf->extra)? buf->name: buf->extra);
+    }
   }
 }
 
@@ -340,6 +343,7 @@ tm_data_rep::attach_view (tm_window win, tm_view vw) {
   ASSERT (is_attached (wid), "widget should be attached");
   vw->ed->resume ();
   win->set_window_name (vw->buf->abbr);
+  win->set_window_url (is_none (vw->buf->extra)? vw->buf->name: vw->buf->extra);
   // cout << "View attached\n";
 }
 
@@ -354,6 +358,7 @@ tm_data_rep::detach_view (tm_view vw) {
   vw->ed->suspend ();
   set_canvas (wid, glue_widget ());
   win->set_window_name ("TeXmacs");
+  win->set_window_url (url_none ());
   // cout << "View detached\n";
 }
 
@@ -365,7 +370,7 @@ class kill_window_command_rep: public command_rep {
 public:
   inline kill_window_command_rep () {}
   inline void apply () { exec_delayed (scheme_cmd ("(safely-kill-window)")); }
-  ostream& print (ostream& out) { return out << "kill window"; }
+  tm_ostream& print (tm_ostream& out) { return out << "kill window"; }
 };
 
 tm_window
@@ -401,7 +406,7 @@ tm_data_rep::delete_view_from_window (tm_window win) {
 
 void
 tm_data_rep::delete_window (tm_window win) {
-  while (delete_view_from_window (win));
+  while (delete_view_from_window (win)) {}
   win->unmap ();
   destroy_window_widget (win->win);
   tm_delete (win);
@@ -737,7 +742,7 @@ tm_data_rep::get_project_buffer_menu () {
       string name= as_string (head (buf->prj->name) * as_string (t[i][0]));
       for (j=N(name)-1; j>=0; j--)
 	if (name[j]=='/') break;
-      s << " (" << scm_quote (name (j+1, N(name))) << " ";
+      s << " ((verbatim " << scm_quote (name (j+1, N(name))) << ") ";
       s << "(switch-to-buffer " * scm_quote (name) * "))";
     }
 
