@@ -16,10 +16,8 @@
 #include "connect.hpp"
 #include "sys_utils.hpp"
 #include "file.hpp"
-#include "pipe_link.hpp"
-#include "socket_link.hpp"
-#include "socket_server.hpp"
 #include "dictionary.hpp"
+#include "tm_link.hpp"
 #include "socket_notifier.hpp"
 
 server* the_server= NULL;
@@ -69,6 +67,7 @@ get_subtree (path p) {
 void
 gui_set_output_language (string lan) {
   set_output_language (lan);
+  get_server () -> refresh ();
   gui_refresh ();
 }
 
@@ -193,7 +192,7 @@ compute_style_menu (url u, int kind) {
     string cmd ("init-style");
     if (kind == 1) cmd= "init-add-package";
     if (kind == 2) cmd= "init-remove-package";
-    return "(\"" * l * "\" (" * cmd * " \"" * l * "\"))";
+    return "((verbatim \"" * l * "\") (" * cmd * " \"" * l * "\"))";
   }
   return "";
 }
@@ -291,20 +290,28 @@ tm_server_rep::style_get_cache (
 * Miscellaneous routines
 ******************************************************************************/
 
+void
+tm_server_rep::refresh () {
+  path p= windows_list ();
+  while (!is_nil (p)) {
+    tm_view vw= window_find_view (p->item);
+    vw->win->refresh ();
+    p= p->next;
+  }
+  
+}
+
 void
 tm_server_rep::interpose_handler () {
 #ifdef QTTEXMACS
   // TeXmacs/Qt handles delayed messages and socket notification
-  // in its own runloop 
-#else
-#if 0 // choice between old and new socket listening methods
-  listen_to_servers ();
-  listen_to_pipes ();
-  listen_to_sockets ();
-  listen_to_connections ();
-#else
+  // in its own runloop
+#ifndef QTPIPES
   perform_select ();
 #endif
+  process_all_pipes ();
+#else
+  perform_select ();
   exec_pending_commands ();
 #endif
 
@@ -324,7 +331,7 @@ tm_server_rep::interpose_handler () {
 
 void
 tm_server_rep::wait_handler (string message, string arg) {
-  show_wait_indicator (get_window () -> win, message, arg);
+  show_wait_indicator (get_window () -> win, translate (message), arg);
 }
 
 void
