@@ -9,7 +9,10 @@
 * in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
-#include <fstream>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <unistd.h>
 
 #include "boot.hpp"
 #include "file.hpp"
@@ -25,7 +28,7 @@ void mac_fix_paths ();
 #include <QApplication>
 #endif
 
-#if defined(X11TEXMACS) && defined(MACOSX_EXTENSIONS)
+#ifdef MACOSX_EXTENSIONS
 #include "MacOS/mac_app.h"
 #endif
 
@@ -42,7 +45,8 @@ extern int geometry_x, geometry_y;
 extern tree the_et;
 extern bool texmacs_started;
 
-std::ofstream log_ofstream;
+tm_ostream& cout= tm_ostream::cout;
+tm_ostream& cerr= tm_ostream::cerr;
 
 /******************************************************************************
 * For testing
@@ -63,6 +67,7 @@ test_routines () {
 
 void
 TeXmacs_init_paths (int& argc, char** argv) {
+  (void) argc; (void) argv;
 #ifdef QTTEXMACS
   url exedir = url_system (qt_application_directory ());
 #else
@@ -72,6 +77,24 @@ TeXmacs_init_paths (int& argc, char** argv) {
   }
 #endif
 
+#if (defined(QTTEXMACS) && defined(Q_WS_MAC)) 
+  // inibith external plugin loading
+  QCoreApplication::setLibraryPaths(QStringList());
+  {
+    // ensure that private versions of the Qt frameworks have priority on
+    // other instances.
+    // in the event that we load qt plugins which could possibly link to
+    // other instances of the Qt libraries
+    string buf;
+    buf = as_string(exedir * "../Frameworks");
+    if (get_env("DYLD_FRAMEWORK_PATH") != "") buf = buf * ":" * get_env("DYLD_FRAMEWORK_PATH");    
+    set_env ("DYLD_FRAMEWORK_PATH", buf);    
+    buf = as_string(exedir * "../Resources/lib");
+    if (get_env("DYLD_LIBRARY_PATH") != "") buf = buf * ":" * get_env("DYLD_LIBRARY_PATH");    
+    set_env ("DYLD_LIBRARY_PATH", buf);    
+  }
+#endif
+
 #if defined(AQUATEXMACS) ||(defined(QTTEXMACS) && defined(Q_WS_MAC)) || (defined(X11TEXMACS) && defined (MACOSX_EXTENSIONS))
   // Mac bundle environment initialization
   // We set some environment variables when the executable
@@ -80,9 +103,15 @@ TeXmacs_init_paths (int& argc, char** argv) {
     set_env ("TEXMACS_PATH", as_string(exedir * "../Resources/share/TeXmacs"));
   //cout << get_env("PATH") * ":" * as_string(url("$PWD") * argv[0]
   // * "../../Resources/share/TeXmacs/bin") << LF;
-  set_env ("PATH", get_env("PATH") * ":" *
-	           as_string (exedir * "../Resources/share/TeXmacs/bin"));
-  //system("set");
+  if (exists("/bin/bash")) {
+    string shell_env =  eval_system("PATH='' /bin/bash -l -c 'echo $PATH'");
+    set_env ("PATH", get_env("PATH") * ":" * shell_env * ":" *
+           as_string (exedir * "../Resources/share/TeXmacs/bin"));
+  } else {
+    set_env ("PATH", get_env("PATH") * ":" *
+               as_string (exedir * "../Resources/share/TeXmacs/bin"));
+  }
+  // system("set");
 #endif
 
 #ifdef __MINGW32__
@@ -132,6 +161,8 @@ TeXmacs_main (int argc, char** argv) {
       else if (s == "-debug-bench") debug (DEBUG_FLAG_BENCH, true);
       else if (s == "-debug-history") debug (DEBUG_FLAG_HISTORY, true);
       else if (s == "-debug-qt") debug (DEBUG_FLAG_QT, true);
+      else if (s == "-debug-keyboard") debug (DEBUG_FLAG_KEYBOARD, true);
+      else if (s == "-debug-packrat") debug (DEBUG_FLAG_PACKRAT, true);
       else if (s == "-debug-all") {
 	debug (DEBUG_FLAG_EVENTS, true);
 	debug (DEBUG_FLAG_STD, true);
@@ -355,26 +386,32 @@ immediate_options (int argc, char** argv) {
       remove (url ("$TEXMACS_HOME_PATH/system/cache/dir_cache.scm"));
       remove (url ("$TEXMACS_HOME_PATH/system/cache/stat_cache.scm"));
     }
-#if defined(__MINGW__) || defined(__MINGW32__) || defined(OS_WIN32)
-    else if (s == "-log-file" && i+1 < argc) {
+    else if (s == "-log-file" && i + 1 < argc) {
       i++;
       char* log_file = argv[i];
-      log_ofstream.open (log_file, std::ios_base::out | std::ios_base::trunc);
-      if (log_ofstream.rdstate() & std::ofstream::failbit)
-	cerr << "TeXmacs] Error: could not open " << log_file << "\n";
-      else {
-	cout.rdbuf (log_ofstream.rdbuf ());
-	cerr.rdbuf (log_ofstream.rdbuf ());
-      }
+      FILE* f= fopen (log_file, "w");
+      if (! f || ! cout.open (f) || ! cerr.open (f))
+        cerr << "TeXmacs] Error: could not open " << log_file << "\n";
     }
-#endif
   }
 }
 
+#include <cstdio>
+
 int
 main (int argc, char** argv) {
   immediate_options (argc, argv);
   set_env ("LC_NUMERIC", "POSIX");
+#ifdef MACOSX_EXTENSIONS
+  // Reset TeXmacs if Alt is pressed during startup
+  if (mac_alternate_startup()) {
+    cout << "TeXmacs] Performing setup (Alt on startup)" << LF; 
+    remove (url ("$TEXMACS_HOME_PATH/system/settings.scm"));
+    remove (url ("$TEXMACS_HOME_PATH/system/setup.scm"));
+    remove (url ("$TEXMACS_HOME_PATH/system/cache") * url_wildcard ("*"));
+    remove (url ("$TEXMACS_HOME_PATH/fonts/error") * url_wildcard ("*"));    
+  }
+#endif
 #ifdef QTTEXMACS
   // initialize the Qt application infrastructure
   new QApplication (argc, argv);
@@ -394,5 +431,7 @@ main (int argc, char** argv) {
 //  test_environments ();
 //#endif
   start_guile (argc, argv, TeXmacs_main);
+  cout.close ();
+  cerr.close ();
   return 0;
 }
