@@ -34,8 +34,10 @@ public:
   tm_window_rep (widget wid2, tree geom);
   ~tm_window_rep ();
   void set_window_name (string s);
+  void set_window_url (url u);
   void map ();
   void unmap ();
+  void refresh ();
   inline void set_property (scheme_tree what, scheme_tree val) {
     props (what)= val; }
   inline scheme_tree get_property (scheme_tree what) {
