@@ -4,10 +4,9 @@
 * DESCRIPTION: grid boxes for the graphics
 * COPYRIGHT  : (C) 2003  Henri Lesourd
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "env.hpp"
@@ -26,12 +25,12 @@ struct grid_box_rep: public box_rep {
   grid g;
   frame f;
   bool first_time;
-  int dev_pixel;
+  int ren_pixel;
   array<box> bs;
   SI un;
   grid_box_rep (
     path ip, grid g, frame f, SI un, point lim1, point lim2);
-  void display (ps_device dev);
+  void display (renderer ren);
   operator tree () { return (tree)g; }
   path find_lip () { return path (-1); }
   path find_rip () { return path (-1); }
@@ -53,9 +52,9 @@ grid_box_rep::grid_box_rep (
 }
 
 void
-grid_box_rep::display (ps_device dev) {
+grid_box_rep::display (renderer ren) {
   int i;
-  if (first_time || dev->pixel!=dev_pixel) {
+  if (first_time || ren->pixel!=ren_pixel) {
     point p1= f [point (x1, y1)];
     point p2= f [point (x2, y2)];
     point l1= point (min (p1[0], p2[0]), min (p1[1], p2[1]));
@@ -74,9 +73,9 @@ grid_box_rep::display (ps_device dev) {
     L2t= norm (e3t - e2t);
     L3t= norm (e4t - e3t);
     L4t= norm (e1t - e4t);
-    if (fnull (L1t, 1e-6) || fnull (L2t, 1e-6) 
-     || fnull (L3t, 1e-6) || fnull (L4t, 1e-6))
-      fatal_error ("One side of the grid has length zero");
+    ASSERT (!fnull (L1t, 1e-6) && !fnull (L2t, 1e-6) &&
+	    !fnull (L3t, 1e-6) && !fnull (L4t, 1e-6),
+	    "one side of the grid has length zero");
     double u, u1, u2, u3, u4;
     u1= u= L1 / L1t;
     u2= min (u, L2 / L2t);
@@ -87,30 +86,33 @@ grid_box_rep::display (ps_device dev) {
     for (i=0; i<N(grads); i++) {
       curve c= f (grads[i]->c);
       bs << curve_box (
-	      decorate (ip), c, dev->pixel, dev->get_color (grads[i]->col),
-	      array<bool> (0), 0, FILL_MODE_NONE, dev->white, array<box> (0));
+	      decorate (ip), c, ren->pixel, named_color (grads[i]->col),
+	      array<bool> (0), 0, FILL_MODE_NONE, white, array<box> (0));
     }
     first_time= false;
-    dev_pixel= dev->pixel;
+    ren_pixel= ren->pixel;
   }
   for (i=0; i<N(bs); i++)
-    bs[i]->display (dev);
+    bs[i]->display (ren);
 }
 
 gr_selections
 grid_box_rep::graphical_select (SI x, SI y, SI dist) {
+  (void) x; (void) y; (void) dist;
   gr_selections res;
   return res;
 }
 
 gr_selections
 grid_box_rep::graphical_select (SI x1, SI y1, SI x2, SI y2) {
+  (void) x1; (void) y1; (void) x2; (void) y2;
   gr_selections res;
   return res;
 }
 
 int
 grid_box_rep::reindex (int i, int item, int n) {
+  (void) item; (void) n;
   return i;
 }
 
@@ -120,5 +122,5 @@ grid_box_rep::reindex (int i, int item, int n) {
 
 box
 grid_box (path ip, grid g, frame f, SI un, point lim1, point lim2) {
-  return new grid_box_rep (ip, g, f, un, lim1, lim2);
+  return tm_new<grid_box_rep> (ip, g, f, un, lim1, lim2);
 }
