@@ -4,10 +4,9 @@
 * DESCRIPTION: the exported box construction routines
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef CONSTRUCT_H
@@ -22,6 +21,7 @@
 ******************************************************************************/
 
 box empty_box (path ip, int x1=0, int y1=0, int x2=0, int y2=0);
+box marker_box (path ip, int x1, int y1, int x2, int y2);
 box test_box (path ip);
 box line_box (path ip, SI x1, SI y1, SI x2, SI y2, SI w, color c);
 box arc_box (path ip, SI x1, SI y1, SI x2, SI y2,
@@ -83,6 +83,7 @@ box symbol_box (path ip, box b, int n);
 box shorter_box (path ip, box b, int n);
 box frozen_box (path ip, box b);
 box move_box (path ip, box b, SI x, SI y, bool chf= false, bool bigf= false);
+box shift_box (path ip, box b, SI x, SI y, bool chf= false, bool bigf= false);
 box resize_box (path ip, box b, SI x1, SI y1, SI x2, SI y2,
 		bool chf= false, bool adjust= false);
 box clip_box (path ip, box b, SI x1, SI y1, SI x2, SI y2);
