@@ -4,10 +4,9 @@
 * DESCRIPTION: Typesetting markup around macro expansion mechanisms
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "concater.hpp"
@@ -111,7 +110,8 @@ concater_rep::typeset_compound (tree t, path ip) {
 	  i<m? t[i+d]: attach_dip (tree (UNINIT), decorate_right(ip));
 	env->macro_src->item (var)= i<m? descend (ip,i+d): decorate_right(ip);
       }
-    if (is_decoration (ip)) typeset (attach_here (f[n], ip));
+    if (is_decoration (ip))
+      typeset (attach_here (f[n], ip));
     else {
       /*IF_NON_CHILD_ENFORCING(t)*/ marker (descend (ip, 0));
       typeset (attach_right (f[n], ip));
@@ -323,7 +323,9 @@ concater_rep::typeset_dynamic (tree t, path ip) {
     a[i]->b->relocate (decorate_left (ip));
   if (i<end) {
     if (a[i]->b->decoration ())
-      if ((a[i]->type==STD_ITEM) || (a[i]->type==STRING_ITEM))
+      if ((a[i]->type==STD_ITEM) ||
+          (a[i]->type == MARKER_ITEM) ||
+	  (a[i]->type==STRING_ITEM))
 	a[i]->b= macro_box (decorate_right (ip), a[i]->b);
     a[i]->b->relocate (decorate_middle (ip));
     i++;
@@ -344,3 +346,45 @@ concater_rep::typeset_dynamic (tree t, path ip) {
     cout << i << ": " << a[i]->b << ", " << a[i]->b->ip << "\n";
   */
 }
+
+void
+concater_rep::typeset_range (tree t, path ip) {
+  if (N(t) != 3)
+    typeset_dynamic (tree (ERROR, "bad range"), ip);
+  else {
+    tree t1= env->exec (t[0]);
+    tree t2= env->exec (t[1]);
+    tree t3= env->exec (t[2]);
+    if (!(is_int (t2) && is_int (t3)))
+      typeset_dynamic (tree (ERROR, "bad range"), ip);
+    else if (is_compound (t1)) {
+      if (is_tuple (t1)) {
+	int i1= max (0, as_int (t2));
+	int i2= min (N (t1), as_int (t3));
+	i2 = max (i1, i2);
+	typeset_dynamic (t1 (i1, i2), ip);
+      }
+      else typeset_dynamic (tree (ERROR, "bad range"), ip);
+    }
+    else {
+      int i1= max (0, as_int (t2));
+      int i2= min (N(t1->label), as_int (t3));
+      i2 = max (i1, i2);
+      path ip1= obtain_ip (t1);
+      if (is_decoration (ip1))
+	typeset_dynamic (t1->label (i1, i2), ip);
+      else {
+	marker (descend (ip, 0));
+	if (env->mode == 1)
+	  typeset_text_string (t1->label, ip1, i1, i2);
+	else if (env->mode == 2)
+	  typeset_math_string (t1->label, ip1, i1, i2);
+	else if (env->mode == 3)
+	  typeset_prog_string (t1       , ip1, i1, i2);
+	else
+	  typeset_text_string (t1->label, ip1, i1, i2);
+	marker (descend (ip, 1));
+      }
+    }
+  }
+}
