@@ -4,25 +4,14 @@
 * DESCRIPTION: Typesetting mathematical markup
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "concater.hpp"
 #include "analyze.hpp"
 
-/******************************************************************************
-* Grouping markup
-******************************************************************************/
-
-void
-concater_rep::typeset_group (tree t, path ip) {
-  box b= typeset_as_concat (env, t[0], descend (ip, 0));
-  print (STD_ITEM, move_box (ip, b, 0, 0, true));
-}
-
 /******************************************************************************
 * Typesetting special mathematical symbols
 ******************************************************************************/
@@ -33,7 +22,7 @@ concater_rep::typeset_large (tree t, path ip, int type, string prefix) {
     string s= prefix * t[0]->label * ">";
     box b= text_box (ip, 0, s, env->fn, env->col);
     print (type, b);
-    // temporarary: use parameters from group-open class in texmath.syx
+    // temporarary: use parameters from group-open class in std-math.syx
     // bug: allow hyphenation after ) and before *
   }
   else if ((N(t) == 2) && is_atomic (t[0]) && is_int (t[1])) {
@@ -74,19 +63,28 @@ concater_rep::typeset_bigop (tree t, path ip) {
     penalty_min (HYPH_PANIC);
     if ((l != "int") && (l != "oint")) with_limits (LIMITS_DISPLAY);
     if (flag) print (spc);
-    // temporarary: use parameters from operator-big class in texmath.syx
+    // temporarary: use parameters from operator-big class in std-math.syx
   }
 }
 
 void
 concater_rep::typeset_lprime (tree t, path ip) {
   if ((N(t) == 1) && is_atomic (t[0])) {
-    tree old_il= env->local_begin_script ();
+    string s= t[0]->label;
+    bool flag= (env->fn->type == FONT_TYPE_UNICODE);
+    if (flag)
+      for (int i=0; i<N(s); i++)
+	flag= flag && (s[i] == '\'' || s[i] == '`');
+    tree old_il;
+    if (!flag) old_il= env->local_begin_script ();
     path sip= descend (ip, 0);
-    box b1, b2= typeset_as_concat (env, t[0], sip);
+    box b1, b2;
+    b2= typeset_as_concat (env, t[0], sip);
     b2= symbol_box (sip, b2, N(t[0]->label));
-    b2= move_box (sip, b2, env->as_length (string ("-0.05fn")), 0);
-    env->local_end_script (old_il);
+    b2= move_box (sip, b2,
+		  flag? 0: env->as_length (string ("-0.05fn")),
+		  flag? env->as_length ("-0.75ex"): 0);
+    if (!flag) env->local_end_script (old_il);
     print (LSUP_ITEM, script_box (ip, b1, b2, env->fn));
     penalty_max (HYPH_INVALID);
   }
@@ -95,12 +93,21 @@ concater_rep::typeset_lprime (tree t, path ip) {
 void
 concater_rep::typeset_rprime (tree t, path ip) {
   if ((N(t) == 1) && is_atomic (t[0])) {
-    tree old_il= env->local_begin_script ();
+    string s= t[0]->label;
+    bool flag= (env->fn->type == FONT_TYPE_UNICODE);
+    if (flag)
+      for (int i=0; i<N(s); i++)
+	flag= flag && (s[i] == '\'' || s[i] == '`');
+    tree old_il;
+    if (!flag) old_il= env->local_begin_script ();
     path sip= descend (ip, 0);
-    box b1, b2= typeset_as_concat (env, t[0], sip);
+    box b1, b2;
+    b2= typeset_as_concat (env, t[0], sip);
     b2= symbol_box (sip, b2, N(t[0]->label));
-    b2= move_box (sip, b2, env->as_length (string ("0.05fn")), 0);
-    env->local_end_script (old_il);
+    b2= move_box (sip, b2,
+		  flag? 0: env->as_length (string ("0.05fn")),
+		  flag? env->as_length ("-0.75ex"): 0);
+    if (!flag) env->local_end_script (old_il);
     penalty_max (HYPH_INVALID);
     if (N(a)>0) a[N(a)-1]->limits= false;
     print (RSUP_ITEM, script_box (ip, b1, b2, env->fn));
@@ -211,7 +218,8 @@ concater_rep::typeset_wide (tree t, path ip, bool above) {
   bool wide;
   box b= typeset_as_concat (env, t[0], descend (ip, 0));
   string s= as_string (t[1]);
-  if (env->get_string (MATH_FONT) == "adobe") {
+  if (env->get_string (MATH_FONT) == "adobe" ||
+      env->fn->type == FONT_TYPE_UNICODE) {
     if (s == "^") s= "<hat>";
     if (s == "~") s= "<tilde>";
   }
@@ -255,6 +263,9 @@ concater_rep::typeset_wide (tree t, path ip, bool above) {
   else {
     SI sep= above? -env->fn->yx: env->fn->sep;
     box wideb= text_box (decorate_middle (ip), 0, s, env->fn, env->col);
+    if (env->fn->type == FONT_TYPE_UNICODE && b->right_slope () != 0)
+      wideb= shift_box (decorate_middle (ip), wideb,
+			(SI) (-0.5 * b->right_slope () * env->fn->yx), 0);
     print (STD_ITEM, wide_box (ip, b, wideb, env->fn, sep, above));
   }
 }
@@ -266,9 +277,65 @@ concater_rep::typeset_neg (tree t, path ip) {
 }
 
 /******************************************************************************
-* Trees and tables
+* Other markup
 ******************************************************************************/
 
+static string
+bracket_color (int nl) {
+  switch (nl % 3) {
+  case 0 : return "#662266";
+  case 1 : return "#226666";
+  default: return "#663322";
+  }
+}
+
+static tree
+make_large (tree_label l, tree t) {
+  if (!is_atomic (t)) return tree (l, ".");
+  string s= t->label;
+  if (N(s) <= 1) return tree (l, s);
+  if (s[0] != '<' || s[N(s)-1] != '>' || s == "<nobracket>")
+    return tree (l, ".");
+  return tree (l, s (1, N(s)-1));
+}
+
+void
+concater_rep::typeset_around (tree t, path ip, bool colored) {
+  if (colored) {
+    int nl= env->get_int (MATH_NESTING_LEVEL);
+    tree old_col= env->local_begin (COLOR, bracket_color (nl));
+    tree old_nl = env->local_begin (MATH_NESTING_LEVEL, as_string (nl+1));
+    typeset_around (t, ip, false);
+    env->local_end (MATH_NESTING_LEVEL, old_nl);
+    env->local_end (COLOR, old_col);
+  }
+  else {
+    marker (descend (ip, 0));
+    switch (L(t)) {
+    case AROUND:
+      typeset (t[0], descend (ip, 0));
+      typeset (t[1], descend (ip, 1));
+      typeset (t[2], descend (ip, 2));
+      break;
+    case VAR_AROUND:
+      typeset (make_large (LEFT, t[0]),
+	       decorate_middle (descend (ip, 0)));
+      typeset (t[1], descend (ip, 1));
+      typeset (make_large (RIGHT, t[2]),
+	       decorate_middle (descend (ip, 2)));
+      break;
+    case BIG_AROUND:
+      typeset (make_large (BIG, t[0]),
+	       decorate_middle (descend (ip, 0)));
+      typeset (t[1], descend (ip, 1));
+      break;
+    default:
+      break;
+    }
+    marker (descend (ip, 1));
+  }
+}
+
 void
 concater_rep::typeset_tree (tree t, path ip) {
   int i, n= N(t);
