@@ -5,10 +5,9 @@
 *              an array of line_items is created of the right types.
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "concater.hpp"
@@ -37,14 +36,14 @@ concater_rep::marker (path ip) {
   if (is_decoration (ip)) ip= path (0, ip);
   string fn_name= "cmr";
   int sz= script (env->fn_size, env->index_level);
-  font gfn (tex_font (env->dis, fn_name, sz, (int) (env->magn*env->dpi)));
-  box b= text_box (ip->next, ip->item, "", gfn, env->dis->blue);
-  a << line_item (STD_ITEM, b, HYPH_INVALID);
+  font gfn (tex_font (fn_name, sz, (int) (env->magn*env->dpi)));
+  box b= text_box (ip->next, ip->item, "", gfn, blue);
+  a << line_item (MARKER_ITEM, b, HYPH_INVALID);
 }
 
 void
 concater_rep::ghost (string s, path ip) {
-  ghost (s, ip, env->dis->blue);
+  ghost (s, ip, blue);
 }
 
 void
@@ -66,7 +65,7 @@ concater_rep::ghost (string s, path ip, color col) {
     else if (s[0] == '}') { fn_name= "cmsy"; s= "g"; }
   }
   int sz= script (env->fn_size, env->index_level);
-  font gfn (tex_font (env->dis, fn_name, sz, (int) (env->magn*env->dpi)));
+  font gfn (tex_font (fn_name, sz, (int) (env->magn*env->dpi)));
   box b= text_box (decorate (ip), 0, s, gfn, col);
   array<box> bs (1);
   bs[0]= b;
@@ -78,11 +77,11 @@ concater_rep::flag_ok (string s, path ip, color col) {
   path dip = decorate_right (ip);
   SI h= 4*env->fn->wfn/5;
   int r, g, b;
-  env->dis->get_rgb (col, r, g, b);
+  get_rgb_color (col, r, g, b);
   r= 255- (255 - r)/6;
   g= 255- (255 - g)/6;
   b= 255- (255 - b)/6;
-  color light= env->dis->rgb (r, g, b);
+  color light= rgb_color (r, g, b);
   string info_flag= env->get_string (INFO_FLAG);
   if (info_flag == "short") {
     box infob= info_box (dip, h, env->fn->wline, col, light);
@@ -91,7 +90,7 @@ concater_rep::flag_ok (string s, path ip, color col) {
   }
   if (info_flag == "detailed" || info_flag == "paper") {
     int sz= script (env->fn_size, env->index_level+2);
-    font gfn (tex_font (env->dis, "ecrm", sz, (int) (env->magn*env->dpi)));
+    font gfn (tex_font ("ecrm", sz, (int) (env->magn*env->dpi)));
     box textb= text_box (decorate (ip), 0, s, gfn, col);
     box flagb= flag_box (dip, textb, h, env->fn->wline, col, light);
     if (info_flag == "detailed") {
@@ -145,6 +144,7 @@ concater_rep::with_limits (int status) {
 
 void
 concater_rep::typeset (tree t, path ip) {
+  // cout << "Typeset " << t << "\n";
   // cout << "Typeset " << t << ", " << ip << ", " << obtain_ip (t) << "\n";
 
   /*
@@ -159,8 +159,14 @@ concater_rep::typeset (tree t, path ip) {
       ip= ip2;
   }
 
+  if (env->hl_lan != 0)
+    env->lan->highlight (t);
+
   if (is_atomic (t)) {
-    typeset_string (t->label, ip);
+    if      (env->mode == 1) typeset_text_string (t, ip, 0, N(t->label));
+    else if (env->mode == 2) typeset_math_string (t, ip, 0, N(t->label));
+    else if (env->mode == 3) typeset_prog_string (t, ip, 0, N(t->label));
+    else                     typeset_text_string (t, ip, 0, N(t->label));
     return;
   }
 
@@ -184,26 +190,31 @@ concater_rep::typeset (tree t, path ip) {
   case CONCAT:
     typeset_concat (t, ip);
     break;
-  case GROUP:
-    typeset_group (t, ip);
+  case RIGID:
+    typeset_rigid (t, ip);
     break;
   case HIDDEN:
-    (void) env->exec (t);
+    //(void) env->exec (t);
+    (void) typeset_as_concat (env, t[0], descend (ip, 0));
     break;
-  case FROZEN:
+  case FREEZE:
+    //typeset (freeze (t[0]), decorate_middle (ip));
     typeset (attach_middle (t[0], ip));
     break;
+  case UNFREEZE:
+    typeset (t[0], descend (ip, 0));
+    break;
   case HSPACE:
     t= env->exec (t);
     typeset_hspace (t, ip);
     break;
   case VAR_VSPACE:
-    flag (env->drd->get_name (L(t)), ip, env->dis->brown);
+    flag (env->drd->get_name (L(t)), ip, brown);
     t= tree (VAR_VSPACE, env->exec (tree (TMLEN, A(t))));
     control (t, ip);
     break;
   case VSPACE:
-    flag (env->drd->get_name (L(t)), ip, env->dis->brown);
+    flag (env->drd->get_name (L(t)), ip, brown);
     t= tree (VSPACE, env->exec (tree (TMLEN, A(t))));
     control (t, ip);
     break;
@@ -212,15 +223,22 @@ concater_rep::typeset (tree t, path ip) {
     typeset_space (attach_here (t, ip));
     break;
   case HTAB:
+    if (N(a)==0) print (STD_ITEM, empty_box (ip, 0, 0, 0, env->fn->yx));
     print (space (env->as_length (t[0])));
     control (t, ip);
     break;
   case MOVE:
     typeset_move (t, ip);
     break;
+  case SHIFT:
+    typeset_shift (t, ip);
+    break;
   case RESIZE:
     typeset_resize (t, ip);
     break;
+  case CLIPPED:
+    typeset_clipped (t, ip);
+    break;
   case REPEAT:
     typeset_repeat (t, ip);
     break;
@@ -242,19 +260,19 @@ concater_rep::typeset (tree t, path ip) {
 
   case WITH_LIMITS:
     with_limits (LIMITS_DISPLAY);
-    flag ("with-limits", ip, env->dis->brown);
+    flag ("with-limits", ip, brown);
     control (t, ip);
     break;
   case LINE_BREAK:
     if (N(a)>0) a[N(a)-1]->penalty = 0;	
-    flag ("line-break", ip, env->dis->brown);
+    flag ("line-break", ip, brown);
     control (t, ip);
     break;
   case NEW_LINE:
   case NEXT_LINE:
     {
       string name= env->drd->get_name (L(t));
-      flag (name, ip, env->dis->brown);
+      flag (name, ip, brown);
       control (t, ip);
       break;
     }
@@ -264,23 +282,23 @@ concater_rep::typeset (tree t, path ip) {
 	(a[N(a)-1]->type == STRING_ITEM) &&
 	(a[N(a)-1]->b->get_leaf_string () == ""))
       a[N(a)-2]->penalty = HYPH_INVALID;	
-    flag ("no line break", ip, env->dis->brown);
+    flag ("no line break", ip, brown);
     control (t, ip);
     break;
   case YES_INDENT:
-    flag ("yes-first-indent", ip, env->dis->brown);
+    flag ("yes-first-indent", ip, brown);
     control (tuple ("env_par", PAR_FIRST, env->read (PAR_FIRST)), ip);
     break;
   case NO_INDENT:
-    flag ("no-first-indent", ip, env->dis->brown);
+    flag ("no-first-indent", ip, brown);
     control (tuple ("env_par", PAR_FIRST, "0cm"), ip);
     break;
   case VAR_YES_INDENT:
-    flag ("yes-first-indent-after", ip, env->dis->brown);
+    flag ("yes-first-indent-after", ip, brown);
     control (tuple ("env_par", PAR_NO_FIRST, "false"), ip);
     break;
   case VAR_NO_INDENT:
-    flag ("no-first-indent-after", ip, env->dis->brown);
+    flag ("no-first-indent-after", ip, brown);
     control (tuple ("env_par", PAR_NO_FIRST, "true"), ip);
     break;
   case VAR_PAGE_BREAK:
@@ -293,11 +311,16 @@ concater_rep::typeset (tree t, path ip) {
   case NEW_DPAGE:
     {
       string name= env->drd->get_name (L(t));
-      flag (name, ip, env->dis->brown);
+      flag (name, ip, brown);
       control (t, ip);
       break;
     }
 
+  case AROUND:
+  case VAR_AROUND:
+  case BIG_AROUND:
+    typeset_around (t, ip, env->get_string (MATH_NESTING_MODE) != "off");
+    break;
   case LEFT:
     typeset_large (t, ip, LEFT_BRACKET_ITEM, "<left-");
     break;
@@ -414,6 +437,9 @@ concater_rep::typeset (tree t, path ip) {
   case MARK:
     typeset_mark (t, ip);
     break;
+  case EXPAND_AS:
+    typeset_expand_as (t, ip);
+    break;
   case EVAL:
     typeset_eval (t, ip);
     break;
@@ -449,6 +475,7 @@ concater_rep::typeset (tree t, path ip) {
     typeset_include (t, ip);
     break;
   case USE_PACKAGE:
+  case USE_MODULE:
     typeset_executable (t, ip);
     break;
 
@@ -462,9 +489,22 @@ concater_rep::typeset (tree t, path ip) {
   case OVER:
   case DIV:
   case MOD:
+  case MINIMUM:
+  case MAXIMUM:
+  case MATH_SQRT:
+  case EXP:
+  case LOG:
+  case POW:
+  case COS:
+  case SIN:
+  case TAN:
   case MERGE:
   case LENGTH:
+    typeset_executable (t, ip);
+    break;
   case RANGE:
+    typeset_range (t, ip);
+    break;
   case NUMBER:
   case _DATE:
   case TRANSLATE:
@@ -533,6 +573,42 @@ concater_rep::typeset (tree t, path ip) {
   case SYMBOL:
   case LATEX:
   case HYBRID:
+    typeset_inactive (t, ip);
+    break;
+
+  case LOCUS:
+    typeset_locus (t, ip);
+    break;
+  case ID:
+    typeset_inactive (t, ip);
+    break;
+  case HARD_ID:
+    typeset_executable (t, ip);
+    break;
+  case LINK:
+  case URL:
+  case SCRIPT:
+    typeset_inactive (t, ip);
+    break;
+  case HLINK:
+  case ACTION:
+    typeset_compound (t, ip);
+    break;
+  case SET_BINDING:
+    typeset_set_binding (t, ip);
+    break;
+  case GET_BINDING:
+    typeset_executable (t, ip);
+    break;
+  case LABEL:
+  case REFERENCE:
+  case PAGEREF:
+    typeset_compound (t, ip);
+    break;
+  case WRITE:
+    typeset_write (t, ip);
+    break;
+
   case TUPLE:
   case ATTR:
   case TMLEN:
@@ -541,33 +617,15 @@ concater_rep::typeset (tree t, path ip) {
   case BACKUP:
     typeset_inactive (t, ip);
     break;
-  case LABEL:
-    typeset_label (t, ip);
-    break;
-  case REFERENCE:
-    typeset_reference (t, ip, 0);
-    break;
-  case PAGEREF:
-    typeset_reference (t, ip, 1);
-    break;
-  case WRITE:
-    typeset_write (t, ip);
+  case PATTERN:
+  case GRADIENT:
+    marker (descend (ip, 0));
+    typeset_inactive (env->exec (t), decorate (ip));
+    marker (descend (ip, 1));
     break;
   case SPECIFIC:
     typeset_specific (t, ip);
     break;
-  case HLINK:
-    typeset_hyperlink (t, ip);
-    break;
-  case ACTION:
-    typeset_action (t, ip);
-    break;
-  case TAG:
-    typeset_tag (t, ip);
-    break;
-  case MEANING:
-    typeset_meaning (t, ip);
-    break;
   case FLAG:
     typeset_flag (t, ip);
     break;
@@ -636,9 +694,17 @@ concater_rep::typeset (tree t, path ip) {
   case FILL:
     typeset_fill (t, ip);
     break;
-  case POSTSCRIPT:
-    typeset_postscript (t, ip);
+  case IMAGE:
+    typeset_image (t, ip);
     break;
+
+  case CANVAS:
+    typeset_canvas (t, ip);
+    break;
+  case ORNAMENT:
+    typeset_ornament (t, ip);
+    break;
+
   default:
     if (L(t) < START_EXTENSIONS) print (STD_ITEM, test_box (ip));
     else typeset_compound (t, ip);
@@ -654,26 +720,26 @@ concater_rep::concater_rep (edit_env env2): env (env2) {}
 
 array<line_item>
 typeset_concat (edit_env env, tree t, path ip) {
-  concater ccc= new concater_rep (env);
+  concater ccc= tm_new<concater_rep> (env);
   ccc->typeset (t, ip);
   ccc->finish ();
   array<line_item> a= ccc->a;
-  delete ccc;
+  tm_delete (ccc);
   return a;
 }
 
 array<line_item>
 typeset_marker (edit_env env, path ip) {
-  concater ccc= new concater_rep (env);
+  concater ccc= tm_new<concater_rep> (env);
   ccc->marker (ip);
   array<line_item> a= ccc->a;
-  delete ccc;
+  tm_delete (ccc);
   return a;
 }
 
 box
 typeset_as_concat (edit_env env, tree t, path ip) {
-  concater ccc= new concater_rep (env);
+  concater ccc= tm_new<concater_rep> (env);
   ccc->typeset (t, ip);
   ccc->finish ();
   array<line_item> a= ccc->a;
@@ -692,7 +758,7 @@ typeset_as_concat (edit_env env, tree t, path ip) {
   }
   box b= concat_box (ip, items, spc);
 
-  delete ccc;
+  tm_delete (ccc);
   return b;
 }
 
@@ -715,32 +781,64 @@ typeset_as_box (edit_env env, tree t, path ip) {
   return composite_box (ip, bs, xs, ys);
 }
 
+box
+typeset_as_atomic (edit_env env, tree t, path ip) {
+  if (is_func (t, WITH)) {
+    int i, n= N(t), k= (n-1)>>1; // is k=0 allowed ?
+    if ((n&1) != 1) return empty_box (ip);
+
+    STACK_NEW_ARRAY(vars,string,k);
+    STACK_NEW_ARRAY(oldv,tree,k);
+    STACK_NEW_ARRAY(newv,tree,k);
+    for (i=0; i<k; i++) {
+      tree var_t= env->exec (t[i<<1]);
+      if (is_atomic (var_t)) {
+	string var= var_t->label;
+	vars[i]= var;
+	oldv[i]= env->read (var);
+	newv[i]= env->exec (t[(i<<1)+1]);
+      }
+      else {
+	STACK_DELETE_ARRAY(vars);
+	STACK_DELETE_ARRAY(oldv);
+	STACK_DELETE_ARRAY(newv);
+	return empty_box (ip);
+      }
+    }
+
+    // for (i=0; i<k; i++) env->monitored_write_update (vars[i], newv[i]);
+    for (i=0; i<k; i++) env->write_update (vars[i], newv[i]);
+    box b= typeset_as_atomic (env, t[n-1], descend (ip, n-1));
+    for (i=k-1; i>=0; i--) env->write_update (vars[i], oldv[i]);
+    STACK_DELETE_ARRAY(vars);
+    STACK_DELETE_ARRAY(oldv);
+    STACK_DELETE_ARRAY(newv);
+    return b;
+  }
+  else {
+    array<line_item> a= typeset_concat (env, t, ip);
+    if (N(a) == 1) return a[0]->b;
+
+    int i, n=N(a);
+    if (n == 0) return empty_box (ip); // FIXME: n=0 should never happen
+    array<box> items (n);
+    array<SI>  spc (n);
+    if (n>0) {
+      spc[0]=0;
+      for (i=0; i<n-1; i++) {
+	items[i]  = a[i]->b;
+	spc  [i+1]= a[i]->spc->def;
+      }
+      items[i]= a[i]->b;
+    }
+    return concat_box (ip, items, spc);
+  }
+}
+
 tree
 box_info (edit_env env, tree t, string what) {
-  box b= typeset_as_concat (env, attach_here (t, decorate ()));
-  /* FIXME: very dirty hack ; necessary because
-     typeset_as_concat () doesn't always returns
-     a box with correct values of x1, y1, x2, y2,
-     etc. In particular, this happens when we try
-     to compute box_info (<with|...>).
-   */
-  int i, n=0;
-  for (i=0; i<N(b); i++)
-    if (b[i]!="") n++;
-  if (n) {
-    array<box> bx(n);
-    n=0;
-    for (i=0; i<N(b); i++) if (b[i]!="") {
-      array<box> bx2(1);
-      array<SI> spc2(1);
-      bx2[0]= b[i];
-      spc2[0]=0;
-      bx[n]= concat_box (path (0), bx2, spc2);
-      n++;
-    }
-    b= composite_box (path (0), bx);
-  }
-  // end very dirty hack
+  box b= typeset_as_atomic (env, attach_here (t, decorate ()));
+
   tree r= tuple();
   for (int i=0; i<N(what); i++) {
     switch (what[i]) {
