@@ -42,16 +42,18 @@ class concater_rep {
   // textual markup
   void typeset_substring (string s, path ip, int pos);
   void typeset_colored_substring (string s, path ip, int pos, string col);
-  void typeset_text_string (string s, path ip);
-  void typeset_math_string (string s, path ip);
-  void typeset_prog_string (tree t, path ip);
+  void typeset_text_string (tree t, path ip, int start, int end);
+  void typeset_math_string (tree t, path ip, int start, int end);
+  void typeset_prog_string (tree t, path ip, int start, int end);
   void typeset_document (tree t, path ip);
   void typeset_paragraph (tree t, path ip);
   void typeset_surround (tree t, path ip);
   void typeset_concat (tree t, path ip);
+  void typeset_rigid (tree t, path ip);
   void typeset_hspace (tree t, path ip);
   void typeset_space (tree t, path ip);
   void typeset_move (tree t, path ip);
+  void typeset_shift (tree t, path ip);
   void typeset_resize (tree t, path ip);
   void typeset_clipped (tree t, path ip);
   void typeset_float (tree t, path ip);
@@ -60,7 +62,7 @@ class concater_rep {
   void typeset_decorated_box (tree t, path ip);
 
   // mathematical markup
-  void typeset_group (tree t, path ip);
+  void typeset_around (tree t, path ip, bool colored);
   void typeset_large (tree t, path ip, int type, string prefix);
   //void typeset_left (tree t, path ip);
   //void typeset_middle (tree t, path ip);
@@ -109,6 +111,7 @@ class concater_rep {
   void typeset_if (tree t, path ip);
   void typeset_var_if (tree t, path ip);
   void typeset_case (tree t, path ip);
+  void typeset_range (tree t, path ip);
   void typeset_locus (tree t, path ip);
   void typeset_set_binding (tree t, path ip);
   void typeset_write (tree t, path ip);
@@ -137,7 +140,7 @@ class concater_rep {
   void typeset_var_spline (tree t, path ip);
   void typeset_cspline (tree t, path ip);
   void typeset_fill (tree t, path ip);
-  void typeset_postscript (tree t, path ip);
+  void typeset_image (tree t, path ip);
 
   // markup for graphical user interface
   void typeset_canvas (tree t, path ip);
