@@ -4,10 +4,9 @@
 * DESCRIPTION: default values of the environment variables
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "env.hpp"
@@ -39,8 +38,13 @@ initialize_default_env () {
   env (SAVE_AUX)         = "true";      // save auxiliary data on disk ?
   env (MODE)             = "text";      // typesetting mode
   env (INFO_FLAG)        = "short";     // information about labels, etc.
+  env (WINDOW_BARS)      = "auto";      // override menu/icon bar settings
+  env (SCROLL_BARS)      = "true";      // allow scroll bars around canvas?
   env (IDENTITY)         = identity_m;  // identity macro
   env (TABULAR)          = tabular_m;   // tabular macro
+  env (THE_LABEL)        = "?";         // value of the next label
+  env (THE_TAGS)         = tree(TUPLE); // current tags
+  env (THE_MODULES)      = tree(TUPLE); // necessary modules and plug-ins
 
   env (FONT)             = "roman";     // the font name in text mode
   env (FONT_FAMILY)      = "rm";        // the font family in text mode
@@ -51,6 +55,8 @@ initialize_default_env () {
   env (MAGNIFICATION)    = "1";         // magnification (slides for instance)
   env (COLOR)            = "black";     // the color
   env (BG_COLOR)         = "white";     // the background color
+  env (LOCUS_COLOR)      = "global";    // the color of loci
+  env (VISITED_COLOR)    = "global";    // the color of visited loci
   env (LANGUAGE)         = "english";   // the language
   env (ATOM_DECORATIONS) = DATOMS;      // dots, underline, hyperlinks?, etc.
   env (LINE_DECORATIONS) = DLINES;      // boxed pars, nested envs, etc.
@@ -58,7 +64,7 @@ initialize_default_env () {
   env (XOFF_DECORATIONS) = "0tmpt";     // hor. placement of decorations
   env (YOFF_DECORATIONS) = "0tmpt";     // vert. placement of decorations
 
-  env (MATH_LANGUAGE)    = "texmath";   // the default mathematical language
+  env (MATH_LANGUAGE)    = "std-math";  // the default mathematical language
   env (MATH_FONT)        = "roman";     // the font name in math mode
   env (MATH_FONT_FAMILY) = "mr";        // the font family in math mode
   env (MATH_FONT_SERIES) = "medium";    // the font series in math mode
@@ -67,6 +73,8 @@ initialize_default_env () {
   env (MATH_DISPLAY)     = "false";     // true if we are in display style
   env (MATH_CONDENSED)   = "false";     // ignore spaces between operators ?
   env (MATH_VPOS)        = "0";         // used in fractions (-1, 0 or 1)
+  env (MATH_NESTING_MODE)= "off";       // color nested brackets?
+  env (MATH_NESTING_LEVEL)= "0";        // nesting level inside brackets
 
   env (PROG_LANGUAGE)    = "scheme";    // the default programming language
   env (PROG_SCRIPTS)     = "scheme";    // the scripting language
@@ -93,6 +101,7 @@ initialize_default_env () {
   env (PAR_COLUMNS_SEP)  = "2fn";       // separation between columns
 
   env (PAGE_MEDIUM)      = "papyrus";   // paper medium: paper, papyrus, auto
+  env (PAGE_PRINTED)     = "false";     // printed version?
   env (PAGE_TYPE)        = "a4";        // paper type (-> width & height)
   env (PAGE_ORIENTATION) = "portrait";  // paper orientation
   env (PAGE_WIDTH_MARGIN)  = "false";   // compute margins from par-width?
@@ -135,8 +144,8 @@ initialize_default_env () {
 
   env (TABLE_WIDTH)      = "";          // width of table
   env (TABLE_HEIGHT)     = "";          // height of table
-  env (TABLE_HMODE)      = "";          // width determination mode
-  env (TABLE_VMODE)      = "";          // height determination mode
+  env (TABLE_HMODE)      = "auto";      // width determination mode
+  env (TABLE_VMODE)      = "auto";      // height determination mode
   env (TABLE_HALIGN)     = "l";         // horizontal alignment
   env (TABLE_VALIGN)     = "f";         // vertical alignment (fraction height)
   env (TABLE_ROW_ORIGIN) = "0";         // row origin
@@ -163,8 +172,8 @@ initialize_default_env () {
   env (CELL_HEIGHT)      = "";          // height of cell
   env (CELL_HPART)       = "";          // take part of unused horizontal space
   env (CELL_VPART)       = "";          // take part of unused vertical space
-  env (CELL_HMODE)       = "exact";     // width determination mode
-  env (CELL_VMODE)       = "exact";     // height determination mode
+  env (CELL_HMODE)       = "auto";      // width determination mode
+  env (CELL_VMODE)       = "auto";      // height determination mode
   env (CELL_HALIGN)      = "l";         // horizontal alignment
   env (CELL_VALIGN)      = "B";         // vertical alignment
   env (CELL_LSEP)        = "0fn";       // left cell padding
@@ -177,6 +186,7 @@ initialize_default_env () {
   env (CELL_TBORDER)     = "0ln";       // top cell border width
   env (CELL_VCORRECT)    = "a";         // vertical limits correction
   env (CELL_HYPHEN)      = "n";         // horizontal hyphenation
+  env (CELL_BLOCK)       = "auto";      // cell contains block content?
   env (CELL_ROW_SPAN)    = "1";         // row span of cell
   env (CELL_COL_SPAN)    = "1";         // column span of cell
   env (CELL_ROW_NR)      = "1";         // row coordinate of cell
@@ -216,11 +226,54 @@ initialize_default_env () {
   env (SRC_COMPACT)      = "normal";    // compact inline/multi-paragraph tags?
   env (SRC_CLOSE)        = "compact";   // how to close long tags
 
+  env (CANVAS_TYPE)           = "plain";        // which kind of scrollbars
+  env (CANVAS_COLOR)          = "white";        // canvas colour
+  env (CANVAS_HPADDING)       = "0px";          // horizontal canvas padding
+  env (CANVAS_VPADDING)       = "0px";          // vertical canvas padding
+  env (CANVAS_BAR_WIDTH)      = "1em";          // width of scroll bars
+  env (CANVAS_BAR_PADDING)    = "0.25em";       // distance of scrollbars
+  env (CANVAS_BAR_COLOR)      = "grey";         // color of bar
+  env (ORNAMENT_SHAPE)        = "rectangular";  // shape of the ornament
+  env (ORNAMENT_BORDER)       = "1ln";          // border width
+  env (ORNAMENT_HPADDING)     = "0px";          // horizontal padding of body
+  env (ORNAMENT_VPADDING)     = "0px";          // vertical padding of body
+  env (ORNAMENT_COLOR)        = "light grey";   // background color
+  env (ORNAMENT_SUNNY_COLOR)  = "white";        // sunny color
+  env (ORNAMENT_SHADOW_COLOR) = "dark grey";    // shadow color
+
   /* hiding and showing content */
   env ("shown")= identity_m;
   env ("ignore")=
     tree (MACRO, "x", tree (HIDDEN, tree (ARG, "x")));
 
+  /* linking macros */
+  tree src_id (ID, tree (HARD_ID, tree (ARG, "x")));
+  tree var_src_id (ID, tree (ARG, "x"));
+  tree dest_url (URL, tree (ARG, "y"));
+  tree dest_script (SCRIPT, tree (ARG, "y"), tree (ARG, "z"));
+  tree dest_ref (URL, tree (MERGE, "#", tree (ARG, "x")));
+  tree ln1 (LINK, "hyperlink", copy (src_id), copy (dest_url));
+  tree ln2 (LINK, "action", copy (src_id), copy (dest_script));
+  tree ln3 (LINK, "hyperlink", copy (src_id), copy (dest_ref));
+  tree labflag (FLAG, tree (ARG, "x"), "blue", "x");
+  tree labtxt (SET_BINDING, tree (ARG, "x"), tree (VALUE, THE_LABEL));
+  tree merged (MERGE, tree (VALUE, THE_TAGS), tuple (tree (ARG, "x")));
+  tree tagflag (FLAG, tree (ARG, "x"), "blue", "x");
+  tree reftxt (GET_BINDING, tree (ARG, "x"));
+  tree preftxt (GET_BINDING, tree (ARG, "x"), "1");
+  env ("hlink")= tree (MACRO, "x", "y",
+		       tree (LOCUS, copy (src_id), ln1, tree (ARG, "x")));
+  env ("action")= tree (MACRO, "x", "y", "z",
+			tree (LOCUS, copy (src_id), ln2, tree (ARG, "x")));
+  env ("label")= tree (MACRO, "x", tree (CONCAT, labflag, labtxt));
+  env ("tag")= tree (MACRO, "x", "y",
+		     tree (WITH, "the-tags", merged,
+			   tree (SURROUND, tagflag, "", tree (ARG, "y"))));
+  env ("reference")= tree (MACRO, "x",
+			   tree (LOCUS, copy (src_id), ln3, reftxt));
+  env ("pageref")= tree (MACRO, "x",
+			 tree (LOCUS, copy (src_id), copy (ln3), preftxt));
+
   /* further standard macros */
   env ("error")=
     tree (MACRO, "x", tree (REWRITE_INACTIVE, tree (ARG, "x"), "error"));
@@ -236,35 +289,55 @@ initialize_default_env () {
     tree (MACRO, "x", tree (REWRITE_INACTIVE, tree (ARG, "x"), "once"));
   env ("inactive*")=
     tree (MACRO, "x", tree (REWRITE_INACTIVE, tree (ARG, "x"), "recurse"));
-  env ("indent")=
+  env ("right-flush")=
+    tree (MACRO, tree (HTAB, "0fn", "first"));
+  env ("indent*")=
     tree (MACRO, "x",
 	  tree (WITH, PAR_LEFT, tree (PLUS, tree (VALUE, PAR_LEFT), "1.5fn"),
 		tree (ARG, "x")));
-  env ("rightflush")=
-    tree (MACRO, tree (HTAB, "0fn", "first"));
+  env ("indent")=
+    tree (MACRO, "x",
+	  tree (SURROUND, "", compound ("right-flush"),
+		compound ("indent*", tree (ARG, "x"))));
+  env ("math")=
+    tree (MACRO, "x", tree (WITH, MODE, "math", tree (ARG, "x")));
+  env ("text")=
+    tree (MACRO, "x", tree (WITH, MODE, "text", tree (ARG, "x")));
+  env ("pre-edit")=
+    tree (MACRO, "x", tree (WITH, COLOR, "#4040c0", tree (ARG, "x")));
   env ("mutator")=
     tree (MACRO, "x", "y", tree (ARG, "x"));
 
   /* syntactic highlighting */
+  env ("src-regular")=
+    tree (MACRO, "x", tree (WITH, COLOR, "black", tree (ARG, "x")));
   env ("src-macro")=
-    tree (MACRO, "x", tree (WITH, COLOR, "blue",
+    tree (MACRO, "x", tree (WITH, MODE, "src", COLOR, "blue",
 			    FONT_FAMILY, "ss", tree (ARG, "x")));
   env ("src-var")=
-    tree (MACRO, "x", tree (WITH, COLOR, "dark green",
+    tree (MACRO, "x", tree (WITH, MODE, "src", COLOR, "dark green",
 			    FONT_SHAPE, "italic", tree (ARG, "x")));
   env ("src-arg")=
-    tree (MACRO, "x", tree (WITH, COLOR, "brown",
+    tree (MACRO, "x", tree (WITH, MODE, "src", COLOR, "brown",
 			    FONT_SHAPE, "italic", tree (ARG, "x")));
   env ("src-tt")=
-    tree (MACRO, "x", tree (WITH, COLOR, "#224",
+    tree (MACRO, "x", tree (WITH, MODE, "src", COLOR, "#228",
 			    FONT_FAMILY, "tt", tree (ARG, "x")));
-  env ("src-integer")=
-    tree (MACRO, "x", tree (WITH, COLOR, "dark grey", tree (ARG, "x")));
+  env ("src-numeric")=
+    tree (MACRO, "x", tree (WITH, MODE, "src", COLOR, "#848",
+			    tree (ARG, "x")));
+  env ("src-textual")=
+    tree (MACRO, "x", tree (WITH, MODE, "src", COLOR, "black",
+			    tree (ARG, "x")));
   env ("src-length")=
-    tree (MACRO, "x", tree (WITH, COLOR, "dark grey", tree (ARG, "x")));
+    tree (MACRO, "x", tree (WITH, MODE, "src", COLOR, "#288",
+			    tree (ARG, "x")));
+  env ("src-unknown")=
+    tree (MACRO, "x", tree (WITH, COLOR, "#C68", tree (ARG, "x")));
   env ("src-error")=
     tree (MACRO, "x", tree (WITH, COLOR, "red", tree (ARG, "x")));
 
+
   /* for correct importation of style files and packages */
   env ("src-title")= identity_m;
   env ("src-style-file")=
