@@ -4,10 +4,9 @@
 * DESCRIPTION: evaluation of trees w.r.t. the environment
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "env.hpp"
@@ -47,15 +46,16 @@ edit_env_rep::rewrite (tree t) {
   case EXTERN:
     {
       int i, n= N(t);
+      if (n == 0) return tree (ERROR, "invalid extern");
       tree r (TUPLE, n);
       for (i=0; i<n; i++)
 	r[i]= exec (t[i]);
       object expr= null_object ();
       for (i=n-1; i>0; i--)
 	expr= cons (object (r[i]), expr);
+      if (N(t) < 1) return tree (ERROR, "invalid extern");
       string fun= exec_string (t[0]);
       expr= cons (string_to_object (fun), expr);
-      (void) eval ("(lazy-markup-modules-force)");
       if (!secure && script_status < 2) {
 	if (!as_bool (call ("secure?", expr)))
 	  return tree (ERROR, "insecure script");
@@ -68,7 +68,8 @@ edit_env_rep::rewrite (tree t) {
     }
   case MAP_ARGS:
     {
-      if (!(is_atomic (t[0]) && is_atomic (t[1]) && is_atomic (t[2])))
+      if (N(t) < 3 ||
+	  !(is_atomic (t[0]) && is_atomic (t[1]) && is_atomic (t[2])))
 	return tree (ERROR, "invalid map arguments");
       if (is_nil (macro_arg) || (!macro_arg->item->contains (t[2]->label)))
 	return tree (ERROR, "map arguments " * t[2]->label);
@@ -96,11 +97,14 @@ edit_env_rep::rewrite (tree t) {
     }
   case INCLUDE:
     {
+      if (N(t) == 0) return tree (ERROR, "invalid include");
       url file_name= url_system (exec_string (t[0]));
       return load_inclusion (relative (base_file_name, file_name));
     }
   case REWRITE_INACTIVE:
     {
+      if (N(t) == 0 || N(t[0]) == 0)
+	return tree (ERROR, "invalid rewrite-inactive");
       if ((!is_func (t[0], ARG)) ||
 	  is_compound (t[0][0]) ||
 	  is_nil (macro_arg) ||
@@ -113,6 +117,8 @@ edit_env_rep::rewrite (tree t) {
 	if ((j>=0) && (j<N(val))) val= val[j];
 	else return tree (ERROR, "invalid rewrite-inactive");
       }
+      if (N(t) < 2)
+	return tree (ERROR, "invalid rewrite-inactive");
       if (t[1] == "recurse") inactive_mode= INACTIVE_INLINE_RECURSE;
       else if (t[1] == "recurse*") inactive_mode= INACTIVE_BLOCK_RECURSE;
       else if (t[1] == "once") inactive_mode= INACTIVE_INLINE_ONCE;
@@ -206,21 +212,40 @@ edit_env_rep::exec (tree t) {
   case EVAL_ARGS:
     return exec_eval_args (t);
   case MARK:
+    if (N(t) < 2)
+      return tree (ERROR, "invalid mark");
     return tree (MARK, copy (t[0]), exec (t[1]));
   case EXPAND_AS:
+    if (N(t) < 2)
+      return tree (ERROR, "invalid expand-as");
     return exec (t[1]);
   case EVAL:
+    if (N(t) < 1)
+      return tree (ERROR, "invalid eval");
     return exec (exec (t[0]));
   case QUOTE:
+    if (N(t) < 1)
+      return tree (ERROR, "invalid quote");
     return t[0];
   case QUASI:
+    if (N(t) < 1)
+      return tree (ERROR, "invalid quasi");
     return exec (exec_quasiquoted (t[0]));
   case QUASIQUOTE:
+    if (N(t) < 1)
+      return tree (ERROR, "invalid quasiquote");
     return exec_quasiquoted (t[0]);
   case UNQUOTE:
+    if (N(t) < 1)
+      return tree (ERROR, "invalid unquote");
+    return exec (t[0]);
   case VAR_UNQUOTE:
+    if (N(t) < 1)
+      return tree (ERROR, "invalid var-unquote");
     return exec (t[0]);
   case COPY:
+    if (N(t) < 1)
+      return tree (ERROR, "invalid copy");
     return copy (exec (t[0]));
   case IF:
   case VAR_IF:
@@ -258,6 +283,9 @@ edit_env_rep::exec (tree t) {
     return exec_divide (t);
   case MOD:
     return exec_modulo (t);
+  case MINIMUM:
+  case MAXIMUM:
+    return exec_min_max (t);
   case MATH_SQRT:
     return exec_math_sqrt (t);
   case EXP:
@@ -367,11 +395,13 @@ edit_env_rep::exec (tree t) {
     return exec_sec_length ();
   case MIN_LENGTH:
     return exec_min_length ();
-  case H_LENGTH:
-    return exec_h_length ();
+  case HR_LENGTH:
+    return exec_hr_length ();
 
   case STYLE_WITH:
   case VAR_STYLE_WITH:
+    if (N(t) < 1)
+      return tree (ERROR, "invalid style-with");
     return exec (t[N(t)-1]);
   case STYLE_ONLY:
   case VAR_STYLE_ONLY:
@@ -422,14 +452,18 @@ edit_env_rep::exec (tree t) {
 
 tree
 edit_env_rep::exec_formatting (tree t, string v) {
-  int n= N(t);
+  int i, n= N(t);
+  if (n < 1)
+    return tree (ERROR, "bad formatting");
+  tree r (t, n);
+  for (i=0; i<n-1; i++) r[i]= exec (t[i]);
   tree oldv= read (v);
-  tree newv= oldv * t (0, n-1);
+  tree newv= oldv * r (0, n-1);
   // monitored_write_update (v, newv);
   write_update (v, newv);
-  tree r= exec (t[n-1]);
+  r[n-1]= exec (t[n-1]);
   write_update (v, oldv);
-  return t (0, n-1) * tree (TFORMAT, r);
+  return r;
 }
 
 tree
@@ -447,9 +481,9 @@ edit_env_rep::exec_table (tree t) {
 
 tree
 edit_env_rep::exec_assign (tree t) {
-  if (N(t)!=2) return tree (ERROR, "bad assignment");
+  if (N(t)!=2) return tree (ERROR, "bad assign");
   tree r= exec (t[0]);
-  if (is_compound (r)) return tree (ERROR, "bad assignment");
+  if (is_compound (r)) return tree (ERROR, "bad assign");
   assign (r->label, copy (t[1]));
   return tree (ASSIGN, r, tree (QUOTE, read (r->label)));
 }
@@ -498,6 +532,7 @@ tree
 edit_env_rep::exec_compound (tree t) {
   int d; tree f;
   if (L(t) == COMPOUND) {
+    if (N(t)<1) return tree (ERROR, "bad compound");
     d= 1;
     f= t[0];
     if (is_compound (f)) f= exec (f);
@@ -538,6 +573,29 @@ edit_env_rep::exec_compound (tree t) {
   else return exec (f);
 }
 
+static int
+decode_type (string s) {
+  if (s == "regular") return TYPE_REGULAR;
+  else if (s == "adhoc") return TYPE_ADHOC;
+  else if (s == "variable") return TYPE_VARIABLE;
+  else if (s == "argument") return TYPE_ARGUMENT;
+  else if (s == "boolean") return TYPE_BOOLEAN;
+  else if (s == "integer") return TYPE_INTEGER;
+  else if (s == "string") return TYPE_STRING;
+  else if (s == "length") return TYPE_LENGTH;
+  else if (s == "numeric") return TYPE_NUMERIC;
+  else if (s == "code") return TYPE_CODE;
+  else if (s == "identifier") return TYPE_IDENTIFIER;
+  else if (s == "url") return TYPE_URL;
+  else if (s == "graphical") return TYPE_GRAPHICAL;
+  else if (s == "point") return TYPE_POINT;
+  else if (s == "animation") return TYPE_ANIMATION;
+  else if (s == "duration") return TYPE_DURATION;
+  else if (s == "unknown") return TYPE_UNKNOWN;
+  else if (s == "error") return TYPE_ERROR;
+  else return -1;
+}
+
 tree
 edit_env_rep::exec_drd_props (tree t) {
   int i, n= N(t);
@@ -557,21 +615,46 @@ edit_env_rep::exec_drd_props (tree t) {
 			  ARITY_NORMAL, CHILD_DETAILED);
 	drd->freeze_arity (l);
       }
-      if (prop == "border") {
-	if (val == "yes") drd->set_no_border (l, false);
-	if (val == "no") drd->set_no_border (l, true);
-	drd->freeze_no_border (l);
+      else if (prop == "name") {
+	if (is_atomic (val))
+	  drd->set_attribute (l, prop, val->label);
       }
-      if (prop == "unaccessible" ||
-	  prop == "hidden" ||
-	  prop == "accessible")
+      else if (prop == "class") {
+	if (is_atomic (val))
+	  drd->set_attribute (l, prop, val->label);
+      }
+      else if (prop == "border") {
+	if (val == "yes") drd->set_border (l, BORDER_YES);
+	if (val == "inner") drd->set_border (l, BORDER_INNER);
+	if (val == "outer") drd->set_border (l, BORDER_OUTER);
+	if (val == "no") drd->set_border (l, BORDER_INNER);
+	drd->freeze_border (l);
+      }
+      else if (prop == "with-like") {
+	if (val == "yes") drd->set_with_like (l, true);
+	if (val == "no") drd->set_with_like (l, false);
+	drd->freeze_with_like (l);
+      }
+      else if (prop == "locals") {
+	int i, n= drd->get_nr_indices (l);
+	for (i=0; i<n; i++) {
+	  drd->set_env (l, i, val);
+	  drd->freeze_env (l, i);
+	}
+      }
+      else if (prop == "unaccessible" ||
+	       prop == "hidden" ||
+	       prop == "accessible")
 	{
 	  int prop_code= ACCESSIBLE_NEVER;
 	  if (prop == "hidden") prop_code= ACCESSIBLE_HIDDEN;
 	  if (prop == "accessible") prop_code= ACCESSIBLE_ALWAYS;
 	  if (val == "none") prop_code= ACCESSIBLE_NEVER;
-	  if (is_int (val))
-	    drd->set_accessible (l, as_int (val), prop_code);
+	  if (is_int (val)) {
+	    int i= as_int (val);
+	    drd->set_accessible (l, i, prop_code);
+	    drd->freeze_accessible (l, i);
+	  }
 	  else if (val == "none" || val == "all") {
 	    int i, n= drd->get_nr_indices (l);
 	    for (i=0; i<n; i++) {
@@ -580,15 +663,18 @@ edit_env_rep::exec_drd_props (tree t) {
 	    }
 	  }
 	}
-      if (prop == "normal-writability" ||
+      else if (prop == "normal-writability" ||
 	  prop == "disable-writability" ||
 	  prop == "enable-writability")
 	{
 	  int prop_code= WRITABILITY_NORMAL;
 	  if (prop == "disable-writability") prop_code= WRITABILITY_DISABLE;
 	  if (prop == "enable-writability") prop_code= WRITABILITY_ENABLE;
-	  if (is_int (val))
-	    drd->set_writability (l, as_int (val), prop_code);
+	  if (is_int (val)) {
+	    int i= as_int (val);
+	    drd->set_writability (l, i, prop_code);
+	    drd->freeze_writability (l, i);
+	  }
 	  else if (val == "all") {
 	    int i, n= drd->get_nr_indices (l);
 	    for (i=0; i<n; i++) {
@@ -597,12 +683,32 @@ edit_env_rep::exec_drd_props (tree t) {
 	    }
 	  }
 	}
+      else if (prop == "returns" && decode_type (as_string (val)) >= 0) {
+	drd->set_type (l, decode_type (as_string (val)));
+	drd->freeze_type (l);
+      }
+      else if (decode_type (prop) >= 0) {
+	int tp= decode_type (prop);
+	if (is_int (val)) {
+	  int i= as_int (val);
+	  drd->set_type (l, i, tp);
+	  drd->freeze_type (l, i);
+	}
+	else if (val == "all") {
+	  int i, n= drd->get_nr_indices (l);
+	  for (i=0; i<n; i++) {
+	    drd->set_type (l, i, tp);
+	    drd->freeze_type (l, i);
+	  }
+	}
+      }
     }
   return t;
 }
 
 tree
 edit_env_rep::exec_provides (tree t) {
+  if (N(t)<1) return tree (ERROR, "bad provides");
   tree r= exec (t[0]);
   if (is_compound (r)) return tree (ERROR, "bad provides");
   if (provides (r->label)) return "true"; else return "false";
@@ -610,6 +716,7 @@ edit_env_rep::exec_provides (tree t) {
 
 tree
 edit_env_rep::exec_value (tree t) {
+  if (N(t)<1) return tree (ERROR, "bad value");
   tree r= exec (t[0]);
   if (is_compound (r)) return tree (ERROR, "bad value");
   return exec (read (r->label));
@@ -617,16 +724,18 @@ edit_env_rep::exec_value (tree t) {
 
 tree
 edit_env_rep::exec_quote_value (tree t) {
+  if (N(t)<1) return tree (ERROR, "bad quote-value");
   tree r= exec (t[0]);
-  if (is_compound (r)) return tree (ERROR, "bad quoted value");
+  if (is_compound (r)) return tree (ERROR, "bad quote-value");
   return read (r->label);
 }
 
 tree
 edit_env_rep::exec_arg (tree t) {
+  if (N(t)<1) return tree (ERROR, "bad arg");
   tree r= t[0];
   if (is_compound (r))
-    return tree (ERROR, "bad argument application");
+    return tree (ERROR, "bad arg");
   if (is_nil (macro_arg) || (!macro_arg->item->contains (r->label)))
     return tree (ERROR, "argument " * r->label);
   r= macro_arg->item [r->label];
@@ -654,9 +763,10 @@ static bool quote_substitute= false;
 
 tree
 edit_env_rep::exec_quote_arg (tree t) {
+  if (N(t)<1) return tree (ERROR, "bad quote-arg");
   tree r= t[0];
   if (is_compound (r))
-    return tree (ERROR, "bad quoted argument application");
+    return tree (ERROR, "bad quote-arg");
   if (is_nil (macro_arg) || (!macro_arg->item->contains (r->label)))
     return tree (ERROR, "quoted argument " * r->label);
   r= macro_arg->item [r->label];
@@ -682,18 +792,21 @@ edit_env_rep::exec_quote_arg (tree t) {
 
 tree
 edit_env_rep::exec_get_label (tree t) {
+  if (N(t)<1) return tree (ERROR, "bad get-label");
   tree r= exec (t[0]);
   return copy (as_string (L(r)));
 }
 
 tree
 edit_env_rep::exec_get_arity (tree t) {
+  if (N(t)<1) return tree (ERROR, "bad get-arity");
   tree r= exec (t[0]);
   return as_string (arity (r));
 }
 
 tree
 edit_env_rep::exec_eval_args (tree t) {
+  if (N(t)<1) return tree (ERROR, "bad eval-args");
   tree v= macro_arg->item [as_string (t[0])];
   if (is_atomic (v) || is_nil (macro_arg))
     return tree (ERROR, "eval arguments " * t[0]->label);
@@ -780,10 +893,10 @@ edit_env_rep::exec_while (tree t) {
 
 tree
 edit_env_rep::exec_for_each (tree t) {
-  if (N(t)!=2) return tree (ERROR, "bad for each");
+  if (N(t)!=2) return tree (ERROR, "bad for-each");
   tree fun = exec (t[0]);
   tree args= exec (t[1]);
-  if (!is_tuple (args)) return tree (ERROR, "bad for each");
+  if (!is_tuple (args)) return tree (ERROR, "bad for-each");
   int i, n= N(args);
   for (i=0; i<n; i++)
     exec (tree (COMPOUND, fun, args[i]));
@@ -930,17 +1043,41 @@ edit_env_rep::exec_plus_minus (tree t) {
   else return tree (ERROR, "bad plus/minus");
 }
 
-bool
-is_percentage (tree t, string s= "%") {
-  return
-    is_atomic (t) &&
-    ends (t->label, s) &&
-    is_double (t->label (0, N (t->label) - 1));
-}
-
-double
-as_percentage (tree t) {
-  return as_double (t->label (0, N (t->label) - 1)) / 100.0;
+tree
+edit_env_rep::exec_min_max (tree t) {
+  int i, n= N(t);
+  if (n==0) return tree (ERROR, "bad min/max");
+  tree first= exec (t[0]);
+  if (is_double (first)) {
+    double ret= as_double (first);
+    for (i=1; i<n; i++) {
+      tree next= exec (t[i]);
+      if (!is_double (next))
+	return tree (ERROR, "bad min/max");
+      if (is_func (t, MINIMUM))
+	ret= min (ret, as_double (next));
+      else
+	ret= max (ret, as_double (next));
+    }
+    return as_string (ret);
+  }
+  else if (is_anylen (first)) {
+    tree ret= as_tmlen (first);
+    if ((n==1) && is_func (t, MINUS))
+      ret= tmlen_times (-1, ret);
+    for (i=1; i<n; i++) {
+      tree next= exec (t[i]);
+      if (!is_anylen (next))
+	return tree (ERROR, "bad min/max");
+      next= as_tmlen (next);
+      if (is_func (t, MINIMUM))
+	ret= tmlen_min (ret, next);
+      else
+	ret= tmlen_max (ret, next);
+    }
+    return ret;
+  }
+  else return tree (ERROR, "bad min/max");
 }
 
 tree
@@ -993,6 +1130,7 @@ edit_env_rep::exec_times_over (tree t) {
 
 tree
 edit_env_rep::exec_divide (tree t) {
+  /* this doesn't match the documentation */
   if (N(t)!=2) return tree (ERROR, "bad divide");
   tree t1= exec (t[0]);
   tree t2= exec (t[1]);
@@ -1090,11 +1228,12 @@ edit_env_rep::exec_merge (tree t) {
   int i, n= N(t);
   if (n == 0) return "";
   tree acc= exec (t[0]);
-  if (is_concat (acc)) acc= var_as_string (acc);
+  if (is_concat (acc)) acc= tree_as_string (acc);
   for (i=1; i<n; i++) {
     tree add= exec (t[i]);
-    if (is_atomic (acc) && (is_atomic (add) || is_concat (add)))
-      acc= acc->label * var_as_string (add);
+    if (is_atomic (acc) &&
+	(is_atomic (add) || is_concat (add) || is_document (add)))
+      acc= acc->label * tree_as_string (add);
     else if (is_tuple (acc) && is_tuple (add))
       acc= acc * add;
     else if (is_func (acc, MACRO) && is_func (add, MACRO) &&
@@ -1112,7 +1251,11 @@ edit_env_rep::exec_merge (tree t) {
 	r[N(r)-1]= u;
 	acc= r;
       }
-    else return tree (ERROR, "bad merge");
+    else {
+      //cout << "acc= " << acc << "\n";
+      //cout << "add= " << add << "\n";
+      return tree (ERROR, "bad merge");
+    }
   }
   return acc;
 }
@@ -1165,7 +1308,7 @@ edit_env_rep::exec_number (tree t) {
   if (s2 == "alpha") return alpha_nr (nr);
   if (s2 == "Alpha") return Alpha_nr (nr);
   if (s2 == "fnsymbol")
-    return tree (WITH, MODE, "math", tree (GROUP, fnsymbol_nr (nr)));
+    return tree (WITH, MODE, "math", tree (RIGID, fnsymbol_nr (nr)));
   return tree (ERROR, "bad number");
 }
 
@@ -1393,23 +1536,36 @@ edit_env_rep::exec_set_binding (tree t) {
   tree keys, value;
   if (N(t) == 1) {
     keys= read ("the-tags");
-    if (!is_tuple (keys))
+    if (!is_tuple (keys)) {
+      //cout << "t= " << t << "\n";
+      //cout << "keys= " << keys << "\n";
       return tree (ERROR, "bad set binding");
+    }
     for (int i=0; i<N(keys); i++)
-      if (!is_atomic (keys[i]))
+      if (!is_atomic (keys[i])) {
+	//cout << "t= " << t << "\n";
+	//cout << "keys= " << keys << "\n";
 	return tree (ERROR, "bad set binding");
+      }
     value= exec (t[0]);
     assign (string ("the-tags"), tree (TUPLE));
     assign (string ("the-label"), copy (value));
   }
   else if (N(t) >= 2) {
     tree key= exec (t[0]);
-    if (!is_atomic (key)) 
+    if (!is_atomic (key)) {
+      //cout << "t= " << t << "\n";
+      //cout << "key= " << key << "\n";
       return tree (ERROR, "bad set binding");
+    }
     keys= tuple (key);
     value= exec (t[1]);
   }
-  else return tree (ERROR, "bad set binding");
+  else {
+    //cout << "t= " << t << "\n";
+    return tree (ERROR, "bad set binding");
+  }
+  //cout << t << ": " << keys << " -> " << value << "\n";
 
   for (int i=0; i<N(keys); i++) {
     string key= keys[i]->label;
@@ -1427,15 +1583,15 @@ edit_env_rep::exec_set_binding (tree t) {
       local_ref (key) << extra;
     }
     if (complete && is_tuple (old_value) && N(old_value) >= 1) {
-      string old_s= var_as_string (old_value[0]);
-      string new_s= var_as_string (value);
+      string old_s= tree_as_string (old_value[0]);
+      string new_s= tree_as_string (value);
       if (new_s != old_s && !starts (key, "auto-")) {
 	if (new_s == "") system_warning ("Redefined", key);
 	else system_warning ("Redefined " * key * " as", new_s);
       }
     }
   }
-  return keys;
+  return tree (HIDDEN, "", keys);
 }
 
 tree
@@ -1449,14 +1605,13 @@ edit_env_rep::exec_get_binding (tree t) {
   else if (type == 1) value= tree (UNINIT);
   if (complete && value == tree (UNINIT))
     system_warning ("Undefined reference", key);
+  //cout << t << ": " << key << " -> " << value << "\n";
   return value;
 }
 
-bool is_magnification (string s);
-double get_magnification (string s);
-
 tree
 edit_env_rep::exec_pattern (tree t) {
+  if (N(t)<1) return tree (ERROR, "bad pattern");
   url im= exec_string (t[0]);
   url image= resolve (relative (base_file_name, im));
   if (is_none (image))
@@ -1468,6 +1623,7 @@ edit_env_rep::exec_pattern (tree t) {
   SI imw= (SI) (((double) imw_pt) * pt);
   SI imh= (SI) (((double) imh_pt) * pt);
   if (imw <= 0 || imh <= 0) return "white";
+  if (N(t)<3) return tree (ERROR, "bad pattern");
   string w= exec_string (t[1]);
   string h= exec_string (t[2]);
   if (is_length (w))
@@ -1514,6 +1670,7 @@ edit_env_rep::exec_point (tree t) {
 
 tree
 edit_env_rep::exec_box_info (tree t) {
+  if (N(t)<2) return tree (ERROR, "bad box-info");
   tree t1= t[0];
   tree t2= t[1];
   if (!is_string (t2))
@@ -1523,12 +1680,14 @@ edit_env_rep::exec_box_info (tree t) {
 
 tree
 edit_env_rep::exec_frame_direct (tree t) {
+  if (N(t)<1) return tree (ERROR, "bad frame-direct");
   tree t1= exec (t[0]);
   return as_tree (!is_nil (fr) ? fr (::as_point (t1)) : point ());
 }
 
 tree
 edit_env_rep::exec_frame_inverse (tree t) {
+  if (N(t)<1) return tree (ERROR, "bad frame-inverse");
   tree t1= exec (t[0]);
   return as_tree (!is_nil (fr) ? fr [::as_point (t1)] : point ());
 }
@@ -2079,6 +2238,8 @@ tree
 edit_env_rep::expand (tree t, bool search_accessible) {
   if (is_atomic (t) || is_nil (macro_arg)) return t;
   else if (is_func (t, ARG) || is_func (t, QUOTE_ARG)) {
+    if (N(t) < 1)
+      return tree (ERROR, "bad argument application");
     if (is_compound (t[0]))
       return tree (ERROR, "bad argument application");
     if (!macro_arg->item->contains (t[0]->label))
@@ -2104,9 +2265,11 @@ edit_env_rep::expand (tree t, bool search_accessible) {
     macro_src= old_src;
     return r;
   }
-  else if (is_func (t, EXPAND_AS, 2))
+  else if (is_func (t, EXPAND_AS, 2)) {
+    if (N(t) < 1)
+      return tree (ERROR, "bad argument application");
     return expand (t[0], search_accessible);
-  else if (search_accessible && is_accessible (obtain_ip (t)))
+  } else if (search_accessible && is_accessible (obtain_ip (t)))
     return t;
   else {
     int i, n= N(t);
