@@ -4,10 +4,9 @@
 * DESCRIPTION: Lazy typesetting of various primitives
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Line/lazy_typeset.hpp"
@@ -16,6 +15,7 @@
 #include "Stack/stacker.hpp"
 #include "Boxes/construct.hpp"
 #include "analyze.hpp"
+#include "packrat.hpp"
 
 array<line_item> typeset_marker (edit_env env, path ip);
 array<line_item> typeset_concat (edit_env, tree t, path ip);
@@ -481,6 +481,9 @@ make_lazy (edit_env env, tree t, path ip) {
       ip= ip2;
   }
 
+  if (env->hl_lan != 0)
+    env->lan->highlight (t);
+
   switch (L(t)) {
   case DOCUMENT:
     return lazy_document (env, t, ip);
